var Zbe=Object.defineProperty;var MB=e=>{throw TypeError(e)};var Hbe=(e,t,n)=>t in e?Zbe(e,t,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n;var $_=(e,t,n)=>Hbe(e,typeof t!="symbol"?t+"":t,n),V5=(e,t,n)=>t.has(e)||MB("Cannot "+n);var bt=(e,t,n)=>(V5(e,t,"read from private field"),n?n.call(e):t.get(e)),Ui=(e,t,n)=>t.has(e)?MB("Cannot add the same private member more than once"):t instanceof WeakSet?t.add(e):t.set(e,n),Rn=(e,t,n,r)=>(V5(e,t,"write to private field"),r?r.call(e,n):t.set(e,n),n),jn=(e,t,n)=>(V5(e,t,"access private method"),n);import{W as Xbe,R as Ybe,O as KO,P as WO,S as Gbe,a as U5,b as Kbe,c as Wbe,B as Jbe,C as eOe,L as tOe,d as rJ,N as nOe,A as rOe,e as FB,f as mC,g as iOe,U as aOe,V as li,h as Jl,i as uOe,T as lOe,D as oOe,j as sOe,k as cOe,l as fOe,m as NB,Q as IB,M as mO,n as gO,o as dOe,p as hOe,I as pOe,F as H7,q as X7,r as qO,s as mOe,t as RF,u as iJ,v as gOe,w as LB,x as BB,y as vOe,z as V3,E as yOe,G as bOe,H as aJ,J as OOe,K as xOe,X as SOe,Y as _Oe}from"./vendor-three-CmB8bl_y.js";function EOe(e,t){for(var n=0;n<t.length;n++){const r=t[n];if(typeof r!="string"&&!Array.isArray(r)){for(const i in r)if(i!=="default"&&!(i in e)){const a=Object.getOwnPropertyDescriptor(r,i);a&&Object.defineProperty(e,i,a.get?a:{enumerable:!0,get:()=>r[i]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var Hd=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function sa(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}function DOe(e){if(Object.prototype.hasOwnProperty.call(e,"__esModule"))return e;var t=e.default;if(typeof t=="function"){var n=function r(){return this instanceof r?Reflect.construct(t,arguments,this.constructor):t.apply(this,arguments)};n.prototype=t.prototype}else n={};return Object.defineProperty(n,"__esModule",{value:!0}),Object.keys(e).forEach(function(r){var i=Object.getOwnPropertyDescriptor(e,r);Object.defineProperty(n,r,i.get?i:{enumerable:!0,get:function(){return e[r]}})}),n}var j5={exports:{}},j4={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var QB;function $Oe(){if(QB)return j4;QB=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.fragment");function n(r,i,a){var u=null;if(a!==void 0&&(u=""+a),i.key!==void 0&&(u=""+i.key),"key"in i){a={};for(var l in i)l!=="key"&&(a[l]=i[l])}else a=i;return i=a.ref,{$$typeof:e,type:r,key:u,ref:i!==void 0?i:null,props:a}}return j4.Fragment=t,j4.jsx=n,j4.jsxs=n,j4}var zB;function COe(){return zB||(zB=1,j5.exports=$Oe()),j5.exports}var Mr=COe(),Z5={exports:{}},ir={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var qB;function wOe(){if(qB)return ir;qB=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),i=Symbol.for("react.profiler"),a=Symbol.for("react.consumer"),u=Symbol.for("react.context"),l=Symbol.for("react.forward_ref"),o=Symbol.for("react.suspense"),s=Symbol.for("react.memo"),c=Symbol.for("react.lazy"),d=Symbol.for("react.activity"),h=Symbol.iterator;function m(K){return K===null||typeof K!="object"?null:(K=h&&K[h]||K["@@iterator"],typeof K=="function"?K:null)}var y={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},v=Object.assign,_={};function S(K,X,B){this.props=K,this.context=X,this.refs=_,this.updater=B||y}S.prototype.isReactComponent={},S.prototype.setState=function(K,X){if(typeof K!="object"&&typeof K!="function"&&K!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,K,X,"setState")},S.prototype.forceUpdate=function(K){this.updater.enqueueForceUpdate(this,K,"forceUpdate")};function E(){}E.prototype=S.prototype;function C(K,X,B){this.props=K,this.context=X,this.refs=_,this.updater=B||y}var T=C.prototype=new E;T.constructor=C,v(T,S.prototype),T.isPureReactComponent=!0;var R=Array.isArray;function $(){}var k={H:null,A:null,T:null,S:null},F=Object.prototype.hasOwnProperty;function L(K,X,B){var ne=B.ref;return{$$typeof:e,type:K,key:X,ref:ne!==void 0?ne:null,props:B}}function j(K,X){return L(K.type,X,K.props)}function V(K){return typeof K=="object"&&K!==null&&K.$$typeof===e}function q(K){var X={"=":"=0",":":"=2"};return"$"+K.replace(/[=:]/g,function(B){return X[B]})}var N=/\/+/g;function U(K,X){return typeof K=="object"&&K!==null&&K.key!=null?q(""+K.key):X.toString(36)}function W(K){switch(K.status){case"fulfilled":return K.value;case"rejected":throw K.reason;default:switch(typeof K.status=="string"?K.then($,$):(K.status="pending",K.then(function(X){K.status==="pending"&&(K.status="fulfilled",K.value=X)},function(X){K.status==="pending"&&(K.status="rejected",K.reason=X)})),K.status){case"fulfilled":return K.value;case"rejected":throw K.reason}}throw K}function G(K,X,B,ne,oe){var ie=typeof K;(ie==="undefined"||ie==="boolean")&&(K=null);var de=!1;if(K===null)de=!0;else switch(ie){case"bigint":case"string":case"number":de=!0;break;case"object":switch(K.$$typeof){case e:case t:de=!0;break;case c:return de=K._init,G(de(K._payload),X,B,ne,oe)}}if(de)return oe=oe(K),de=ne===""?"."+U(K,0):ne,R(oe)?(B="",de!=null&&(B=de.replace(N,"$&/")+"/"),G(oe,X,B,"",function(pe){return pe})):oe!=null&&(V(oe)&&(oe=j(oe,B+(oe.key==null||K&&K.key===oe.key?"":(""+oe.key).replace(N,"$&/")+"/")+de)),X.push(oe)),1;de=0;var be=ne===""?".":ne+":";if(R(K))for(var ve=0;ve<K.length;ve++)ne=K[ve],ie=be+U(ne,ve),de+=G(ne,X,B,ie,oe);else if(ve=m(K),typeof ve=="function")for(K=ve.call(K),ve=0;!(ne=K.next()).done;)ne=ne.value,ie=be+U(ne,ve++),de+=G(ne,X,B,ie,oe);else if(ie==="object"){if(typeof K.then=="function")return G(W(K),X,B,ne,oe);throw X=String(K),Error("Objects are not valid as a React child (found: "+(X==="[object Object]"?"object with keys {"+Object.keys(K).join(", ")+"}":X)+"). If you meant to render a collection of children, use an array instead.")}return de}function J(K,X,B){if(K==null)return K;var ne=[],oe=0;return G(K,ne,"","",function(ie){return X.call(B,ie,oe++)}),ne}function te(K){if(K._status===-1){var X=K._result;X=X(),X.then(function(B){(K._status===0||K._status===-1)&&(K._status=1,K._result=B)},function(B){(K._status===0||K._status===-1)&&(K._status=2,K._result=B)}),K._status===-1&&(K._status=0,K._result=X)}if(K._status===1)return K._result.default;throw K._result}var H=typeof reportError=="function"?reportError:function(K){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var X=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof K=="object"&&K!==null&&typeof K.message=="string"?String(K.message):String(K),error:K});if(!window.dispatchEvent(X))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",K);return}console.error(K)},M={map:J,forEach:function(K,X,B){J(K,function(){X.apply(this,arguments)},B)},count:function(K){var X=0;return J(K,function(){X++}),X},toArray:function(K){return J(K,function(X){return X})||[]},only:function(K){if(!V(K))throw Error("React.Children.only expected to receive a single React element child.");return K}};return ir.Activity=d,ir.Children=M,ir.Component=S,ir.Fragment=n,ir.Profiler=i,ir.PureComponent=C,ir.StrictMode=r,ir.Suspense=o,ir.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=k,ir.__COMPILER_RUNTIME={__proto__:null,c:function(K){return k.H.useMemoCache(K)}},ir.cache=function(K){return function(){return K.apply(null,arguments)}},ir.cacheSignal=function(){return null},ir.cloneElement=function(K,X,B){if(K==null)throw Error("The argument must be a React element, but you passed "+K+".");var ne=v({},K.props),oe=K.key;if(X!=null)for(ie in X.key!==void 0&&(oe=""+X.key),X)!F.call(X,ie)||ie==="key"||ie==="__self"||ie==="__source"||ie==="ref"&&X.ref===void 0||(ne[ie]=X[ie]);var ie=arguments.length-2;if(ie===1)ne.children=B;else if(1<ie){for(var de=Array(ie),be=0;be<ie;be++)de[be]=arguments[be+2];ne.children=de}return L(K.type,oe,ne)},ir.createContext=function(K){return K={$$typeof:u,_currentValue:K,_currentValue2:K,_threadCount:0,Provider:null,Consumer:null},K.Provider=K,K.Consumer={$$typeof:a,_context:K},K},ir.createElement=function(K,X,B){var ne,oe={},ie=null;if(X!=null)for(ne in X.key!==void 0&&(ie=""+X.key),X)F.call(X,ne)&&ne!=="key"&&ne!=="__self"&&ne!=="__source"&&(oe[ne]=X[ne]);var de=arguments.length-2;if(de===1)oe.children=B;else if(1<de){for(var be=Array(de),ve=0;ve<de;ve++)be[ve]=arguments[ve+2];oe.children=be}if(K&&K.defaultProps)for(ne in de=K.defaultProps,de)oe[ne]===void 0&&(oe[ne]=de[ne]);return L(K,ie,oe)},ir.createRef=function(){return{current:null}},ir.forwardRef=function(K){return{$$typeof:l,render:K}},ir.isValidElement=V,ir.lazy=function(K){return{$$typeof:c,_payload:{_status:-1,_result:K},_init:te}},ir.memo=function(K,X){return{$$typeof:s,type:K,compare:X===void 0?null:X}},ir.startTransition=function(K){var X=k.T,B={};k.T=B;try{var ne=K(),oe=k.S;oe!==null&&oe(B,ne),typeof ne=="object"&&ne!==null&&typeof ne.then=="function"&&ne.then($,H)}catch(ie){H(ie)}finally{X!==null&&B.types!==null&&(X.types=B.types),k.T=X}},ir.unstable_useCacheRefresh=function(){return k.H.useCacheRefresh()},ir.use=function(K){return k.H.use(K)},ir.useActionState=function(K,X,B){return k.H.useActionState(K,X,B)},ir.useCallback=function(K,X){return k.H.useCallback(K,X)},ir.useContext=function(K){return k.H.useContext(K)},ir.useDebugValue=function(){},ir.useDeferredValue=function(K,X){return k.H.useDeferredValue(K,X)},ir.useEffect=function(K,X){return k.H.useEffect(K,X)},ir.useEffectEvent=function(K){return k.H.useEffectEvent(K)},ir.useId=function(){return k.H.useId()},ir.useImperativeHandle=function(K,X,B){return k.H.useImperativeHandle(K,X,B)},ir.useInsertionEffect=function(K,X){return k.H.useInsertionEffect(K,X)},ir.useLayoutEffect=function(K,X){return k.H.useLayoutEffect(K,X)},ir.useMemo=function(K,X){return k.H.useMemo(K,X)},ir.useOptimistic=function(K,X){return k.H.useOptimistic(K,X)},ir.useReducer=function(K,X,B){return k.H.useReducer(K,X,B)},ir.useRef=function(K){return k.H.useRef(K)},ir.useState=function(K){return k.H.useState(K)},ir.useSyncExternalStore=function(K,X,B){return k.H.useSyncExternalStore(K,X,B)},ir.useTransition=function(){return k.H.useTransition()},ir.version="19.2.0",ir}var VB;function nr(){return VB||(VB=1,Z5.exports=wOe()),Z5.exports}var P=nr();const ye=sa(P),Y7=EOe({__proto__:null,default:ye},[P]);function ROe(e){if(e.sheet)return e.sheet;for(var t=0;t<document.styleSheets.length;t++)if(document.styleSheets[t].ownerNode===e)return document.styleSheets[t]}function AOe(e){var t=document.createElement("style");return t.setAttribute("data-emotion",e.key),e.nonce!==void 0&&t.setAttribute("nonce",e.nonce),t.appendChild(document.createTextNode("")),t.setAttribute("data-s",""),t}var TOe=(function(){function e(n){var r=this;this._insertTag=function(i){var a;r.tags.length===0?r.insertionPoint?a=r.insertionPoint.nextSibling:r.prepend?a=r.container.firstChild:a=r.before:a=r.tags[r.tags.length-1].nextSibling,r.container.insertBefore(i,a),r.tags.push(i)},this.isSpeedy=n.speedy===void 0?!0:n.speedy,this.tags=[],this.ctr=0,this.nonce=n.nonce,this.key=n.key,this.container=n.container,this.prepend=n.prepend,this.insertionPoint=n.insertionPoint,this.before=null}var t=e.prototype;return t.hydrate=function(r){r.forEach(this._insertTag)},t.insert=function(r){this.ctr%(this.isSpeedy?65e3:1)===0&&this._insertTag(AOe(this));var i=this.tags[this.tags.length-1];if(this.isSpeedy){var a=ROe(i);try{a.insertRule(r,a.cssRules.length)}catch{}}else i.appendChild(document.createTextNode(r));this.ctr++},t.flush=function(){this.tags.forEach(function(r){var i;return(i=r.parentNode)==null?void 0:i.removeChild(r)}),this.tags=[],this.ctr=0},e})(),ds="-ms-",xD="-moz-",Ri="-webkit-",uJ="comm",AF="rule",TF="decl",kOe="@import",lJ="@keyframes",POe="@layer",MOe=Math.abs,gC=String.fromCharCode,FOe=Object.assign;function NOe(e,t){return ko(e,0)^45?(((t<<2^ko(e,0))<<2^ko(e,1))<<2^ko(e,2))<<2^ko(e,3):0}function oJ(e){return e.trim()}function IOe(e,t){return(e=t.exec(e))?e[0]:e}function Ai(e,t,n){return e.replace(t,n)}function G7(e,t){return e.indexOf(t)}function ko(e,t){return e.charCodeAt(t)|0}function ix(e,t,n){return e.slice(t,n)}function p0(e){return e.length}function kF(e){return e.length}function C_(e,t){return t.push(e),e}function LOe(e,t){return e.map(t).join("")}var vC=1,S3=1,sJ=0,lf=0,gl=0,U3="";function yC(e,t,n,r,i,a,u){return{value:e,root:t,parent:n,type:r,props:i,children:a,line:vC,column:S3,length:u,return:""}}function Z4(e,t){return FOe(yC("",null,null,"",null,null,0),e,{length:-e.length},t)}function BOe(){return gl}function QOe(){return gl=lf>0?ko(U3,--lf):0,S3--,gl===10&&(S3=1,vC--),gl}function Uf(){return gl=lf<sJ?ko(U3,lf++):0,S3++,gl===10&&(S3=1,vC++),gl}function D0(){return ko(U3,lf)}function LE(){return lf}function tS(e,t){return ix(U3,e,t)}function ax(e){switch(e){case 0:case 9:case 10:case 13:case 32:return 5;case 33:case 43:case 44:case 47:case 62:case 64:case 126:case 59:case 123:case 125:return 4;case 58:return 3;case 34:case 39:case 40:case 91:return 2;case 41:case 93:return 1}return 0}function cJ(e){return vC=S3=1,sJ=p0(U3=e),lf=0,[]}function fJ(e){return U3="",e}function BE(e){return oJ(tS(lf-1,K7(e===91?e+2:e===40?e+1:e)))}function zOe(e){for(;(gl=D0())&&gl<33;)Uf();return ax(e)>2||ax(gl)>3?"":" "}function qOe(e,t){for(;--t&&Uf()&&!(gl<48||gl>102||gl>57&&gl<65||gl>70&&gl<97););return tS(e,LE()+(t<6&&D0()==32&&Uf()==32))}function K7(e){for(;Uf();)switch(gl){case e:return lf;case 34:case 39:e!==34&&e!==39&&K7(gl);break;case 40:e===41&&K7(e);break;case 92:Uf();break}return lf}function VOe(e,t){for(;Uf()&&e+gl!==57;)if(e+gl===84&&D0()===47)break;return"/*"+tS(t,lf-1)+"*"+gC(e===47?e:Uf())}function UOe(e){for(;!ax(D0());)Uf();return tS(e,lf)}function jOe(e){return fJ(QE("",null,null,null,[""],e=cJ(e),0,[0],e))}function QE(e,t,n,r,i,a,u,l,o){for(var s=0,c=0,d=u,h=0,m=0,y=0,v=1,_=1,S=1,E=0,C="",T=i,R=a,$=r,k=C;_;)switch(y=E,E=Uf()){case 40:if(y!=108&&ko(k,d-1)==58){G7(k+=Ai(BE(E),"&","&\f"),"&\f")!=-1&&(S=-1);break}case 34:case 39:case 91:k+=BE(E);break;case 9:case 10:case 13:case 32:k+=zOe(y);break;case 92:k+=qOe(LE()-1,7);continue;case 47:switch(D0()){case 42:case 47:C_(ZOe(VOe(Uf(),LE()),t,n),o);break;default:k+="/"}break;case 123*v:l[s++]=p0(k)*S;case 125*v:case 59:case 0:switch(E){case 0:case 125:_=0;case 59+c:S==-1&&(k=Ai(k,/\f/g,"")),m>0&&p0(k)-d&&C_(m>32?jB(k+";",r,n,d-1):jB(Ai(k," ","")+";",r,n,d-2),o);break;case 59:k+=";";default:if(C_($=UB(k,t,n,s,c,i,l,C,T=[],R=[],d),a),E===123)if(c===0)QE(k,t,$,$,T,a,d,l,R);else switch(h===99&&ko(k,3)===110?100:h){case 100:case 108:case 109:case 115:QE(e,$,$,r&&C_(UB(e,$,$,0,0,i,l,C,i,T=[],d),R),i,R,d,l,r?T:R);break;default:QE(k,$,$,$,[""],R,0,l,R)}}s=c=m=0,v=S=1,C=k="",d=u;break;case 58:d=1+p0(k),m=y;default:if(v<1){if(E==123)--v;else if(E==125&&v++==0&&QOe()==125)continue}switch(k+=gC(E),E*v){case 38:S=c>0?1:(k+="\f",-1);break;case 44:l[s++]=(p0(k)-1)*S,S=1;break;case 64:D0()===45&&(k+=BE(Uf())),h=D0(),c=d=p0(C=k+=UOe(LE())),E++;break;case 45:y===45&&p0(k)==2&&(v=0)}}return a}function UB(e,t,n,r,i,a,u,l,o,s,c){for(var d=i-1,h=i===0?a:[""],m=kF(h),y=0,v=0,_=0;y<r;++y)for(var S=0,E=ix(e,d+1,d=MOe(v=u[y])),C=e;S<m;++S)(C=oJ(v>0?h[S]+" "+E:Ai(E,/&\f/g,h[S])))&&(o[_++]=C);return yC(e,t,n,i===0?AF:l,o,s,c)}function ZOe(e,t,n){return yC(e,t,n,uJ,gC(BOe()),ix(e,2,-2),0)}function jB(e,t,n,r){return yC(e,t,n,TF,ix(e,0,r),ix(e,r+1,-1),r)}function JO(e,t){for(var n="",r=kF(e),i=0;i<r;i++)n+=t(e[i],i,e,t)||"";return n}function HOe(e,t,n,r){switch(e.type){case POe:if(e.children.length)break;case kOe:case TF:return e.return=e.return||e.value;case uJ:return"";case lJ:return e.return=e.value+"{"+JO(e.children,r)+"}";case AF:e.value=e.props.join(",")}return p0(n=JO(e.children,r))?e.return=e.value+"{"+n+"}":""}function XOe(e){var t=kF(e);return function(n,r,i,a){for(var u="",l=0;l<t;l++)u+=e[l](n,r,i,a)||"";return u}}function YOe(e){return function(t){t.root||(t=t.return)&&e(t)}}function GOe(e){var t=Object.create(null);return function(n){return t[n]===void 0&&(t[n]=e(n)),t[n]}}var KOe=function(t,n,r){for(var i=0,a=0;i=a,a=D0(),i===38&&a===12&&(n[r]=1),!ax(a);)Uf();return tS(t,lf)},WOe=function(t,n){var r=-1,i=44;do switch(ax(i)){case 0:i===38&&D0()===12&&(n[r]=1),t[r]+=KOe(lf-1,n,r);break;case 2:t[r]+=BE(i);break;case 4:if(i===44){t[++r]=D0()===58?"&\f":"",n[r]=t[r].length;break}default:t[r]+=gC(i)}while(i=Uf());return t},JOe=function(t,n){return fJ(WOe(cJ(t),n))},ZB=new WeakMap,e3e=function(t){if(!(t.type!=="rule"||!t.parent||t.length<1)){for(var n=t.value,r=t.parent,i=t.column===r.column&&t.line===r.line;r.type!=="rule";)if(r=r.parent,!r)return;if(!(t.props.length===1&&n.charCodeAt(0)!==58&&!ZB.get(r))&&!i){ZB.set(t,!0);for(var a=[],u=JOe(n,a),l=r.props,o=0,s=0;o<u.length;o++)for(var c=0;c<l.length;c++,s++)t.props[s]=a[o]?u[o].replace(/&\f/g,l[c]):l[c]+" "+u[o]}}},t3e=function(t){if(t.type==="decl"){var n=t.value;n.charCodeAt(0)===108&&n.charCodeAt(2)===98&&(t.return="",t.value="")}};function dJ(e,t){switch(NOe(e,t)){case 5103:return Ri+"print-"+e+e;case 5737:case 4201:case 3177:case 3433:case 1641:case 4457:case 2921:case 5572:case 6356:case 5844:case 3191:case 6645:case 3005:case 6391:case 5879:case 5623:case 6135:case 4599:case 4855:case 4215:case 6389:case 5109:case 5365:case 5621:case 3829:return Ri+e+e;case 5349:case 4246:case 4810:case 6968:case 2756:return Ri+e+xD+e+ds+e+e;case 6828:case 4268:return Ri+e+ds+e+e;case 6165:return Ri+e+ds+"flex-"+e+e;case 5187:return Ri+e+Ai(e,/(\w+).+(:[^]+)/,Ri+"box-$1$2"+ds+"flex-$1$2")+e;case 5443:return Ri+e+ds+"flex-item-"+Ai(e,/flex-|-self/,"")+e;case 4675:return Ri+e+ds+"flex-line-pack"+Ai(e,/align-content|flex-|-self/,"")+e;case 5548:return Ri+e+ds+Ai(e,"shrink","negative")+e;case 5292:return Ri+e+ds+Ai(e,"basis","preferred-size")+e;case 6060:return Ri+"box-"+Ai(e,"-grow","")+Ri+e+ds+Ai(e,"grow","positive")+e;case 4554:return Ri+Ai(e,/([^-])(transform)/g,"$1"+Ri+"$2")+e;case 6187:return Ai(Ai(Ai(e,/(zoom-|grab)/,Ri+"$1"),/(image-set)/,Ri+"$1"),e,"")+e;case 5495:case 3959:return Ai(e,/(image-set\([^]*)/,Ri+"$1$`$1");case 4968:return Ai(Ai(e,/(.+:)(flex-)?(.*)/,Ri+"box-pack:$3"+ds+"flex-pack:$3"),/s.+-b[^;]+/,"justify")+Ri+e+e;case 4095:case 3583:case 4068:case 2532:return Ai(e,/(.+)-inline(.+)/,Ri+"$1$2")+e;case 8116:case 7059:case 5753:case 5535:case 5445:case 5701:case 4933:case 4677:case 5533:case 5789:case 5021:case 4765:if(p0(e)-1-t>6)switch(ko(e,t+1)){case 109:if(ko(e,t+4)!==45)break;case 102:return Ai(e,/(.+:)(.+)-([^]+)/,"$1"+Ri+"$2-$3$1"+xD+(ko(e,t+3)==108?"$3":"$2-$3"))+e;case 115:return~G7(e,"stretch")?dJ(Ai(e,"stretch","fill-available"),t)+e:e}break;case 4949:if(ko(e,t+1)!==115)break;case 6444:switch(ko(e,p0(e)-3-(~G7(e,"!important")&&10))){case 107:return Ai(e,":",":"+Ri)+e;case 101:return Ai(e,/(.+:)([^;!]+)(;|!.+)?/,"$1"+Ri+(ko(e,14)===45?"inline-":"")+"box$3$1"+Ri+"$2$3$1"+ds+"$2box$3")+e}break;case 5936:switch(ko(e,t+11)){case 114:return Ri+e+ds+Ai(e,/[svh]\w+-[tblr]{2}/,"tb")+e;case 108:return Ri+e+ds+Ai(e,/[svh]\w+-[tblr]{2}/,"tb-rl")+e;case 45:return Ri+e+ds+Ai(e,/[svh]\w+-[tblr]{2}/,"lr")+e}return Ri+e+ds+e+e}return e}var n3e=function(t,n,r,i){if(t.length>-1&&!t.return)switch(t.type){case TF:t.return=dJ(t.value,t.length);break;case lJ:return JO([Z4(t,{value:Ai(t.value,"@","@"+Ri)})],i);case AF:if(t.length)return LOe(t.props,function(a){switch(IOe(a,/(::plac\w+|:read-\w+)/)){case":read-only":case":read-write":return JO([Z4(t,{props:[Ai(a,/:(read-\w+)/,":"+xD+"$1")]})],i);case"::placeholder":return JO([Z4(t,{props:[Ai(a,/:(plac\w+)/,":"+Ri+"input-$1")]}),Z4(t,{props:[Ai(a,/:(plac\w+)/,":"+xD+"$1")]}),Z4(t,{props:[Ai(a,/:(plac\w+)/,ds+"input-$1")]})],i)}return""})}},r3e=[n3e],i3e=function(t){var n=t.key;if(n==="css"){var r=document.querySelectorAll("style[data-emotion]:not([data-s])");Array.prototype.forEach.call(r,function(v){var _=v.getAttribute("data-emotion");_.indexOf(" ")!==-1&&(document.head.appendChild(v),v.setAttribute("data-s",""))})}var i=t.stylisPlugins||r3e,a={},u,l=[];u=t.container||document.head,Array.prototype.forEach.call(document.querySelectorAll('style[data-emotion^="'+n+' "]'),function(v){for(var _=v.getAttribute("data-emotion").split(" "),S=1;S<_.length;S++)a[_[S]]=!0;l.push(v)});var o,s=[e3e,t3e];{var c,d=[HOe,YOe(function(v){c.insert(v)})],h=XOe(s.concat(i,d)),m=function(_){return JO(jOe(_),h)};o=function(_,S,E,C){c=E,m(_?_+"{"+S.styles+"}":S.styles),C&&(y.inserted[S.name]=!0)}}var y={key:n,sheet:new TOe({key:n,container:u,nonce:t.nonce,speedy:t.speedy,prepend:t.prepend,insertionPoint:t.insertionPoint}),nonce:t.nonce,inserted:a,registered:{},insert:o};return y.sheet.hydrate(l),y};function of(){return of=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},of.apply(null,arguments)}var H5={exports:{}},Bi={};/** @license React v16.13.1
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var HB;function a3e(){if(HB)return Bi;HB=1;var e=typeof Symbol=="function"&&Symbol.for,t=e?Symbol.for("react.element"):60103,n=e?Symbol.for("react.portal"):60106,r=e?Symbol.for("react.fragment"):60107,i=e?Symbol.for("react.strict_mode"):60108,a=e?Symbol.for("react.profiler"):60114,u=e?Symbol.for("react.provider"):60109,l=e?Symbol.for("react.context"):60110,o=e?Symbol.for("react.async_mode"):60111,s=e?Symbol.for("react.concurrent_mode"):60111,c=e?Symbol.for("react.forward_ref"):60112,d=e?Symbol.for("react.suspense"):60113,h=e?Symbol.for("react.suspense_list"):60120,m=e?Symbol.for("react.memo"):60115,y=e?Symbol.for("react.lazy"):60116,v=e?Symbol.for("react.block"):60121,_=e?Symbol.for("react.fundamental"):60117,S=e?Symbol.for("react.responder"):60118,E=e?Symbol.for("react.scope"):60119;function C(R){if(typeof R=="object"&&R!==null){var $=R.$$typeof;switch($){case t:switch(R=R.type,R){case o:case s:case r:case a:case i:case d:return R;default:switch(R=R&&R.$$typeof,R){case l:case c:case y:case m:case u:return R;default:return $}}case n:return $}}}function T(R){return C(R)===s}return Bi.AsyncMode=o,Bi.ConcurrentMode=s,Bi.ContextConsumer=l,Bi.ContextProvider=u,Bi.Element=t,Bi.ForwardRef=c,Bi.Fragment=r,Bi.Lazy=y,Bi.Memo=m,Bi.Portal=n,Bi.Profiler=a,Bi.StrictMode=i,Bi.Suspense=d,Bi.isAsyncMode=function(R){return T(R)||C(R)===o},Bi.isConcurrentMode=T,Bi.isContextConsumer=function(R){return C(R)===l},Bi.isContextProvider=function(R){return C(R)===u},Bi.isElement=function(R){return typeof R=="object"&&R!==null&&R.$$typeof===t},Bi.isForwardRef=function(R){return C(R)===c},Bi.isFragment=function(R){return C(R)===r},Bi.isLazy=function(R){return C(R)===y},Bi.isMemo=function(R){return C(R)===m},Bi.isPortal=function(R){return C(R)===n},Bi.isProfiler=function(R){return C(R)===a},Bi.isStrictMode=function(R){return C(R)===i},Bi.isSuspense=function(R){return C(R)===d},Bi.isValidElementType=function(R){return typeof R=="string"||typeof R=="function"||R===r||R===s||R===a||R===i||R===d||R===h||typeof R=="object"&&R!==null&&(R.$$typeof===y||R.$$typeof===m||R.$$typeof===u||R.$$typeof===l||R.$$typeof===c||R.$$typeof===_||R.$$typeof===S||R.$$typeof===E||R.$$typeof===v)},Bi.typeOf=C,Bi}var XB;function u3e(){return XB||(XB=1,H5.exports=a3e()),H5.exports}var X5,YB;function l3e(){if(YB)return X5;YB=1;var e=u3e(),t={childContextTypes:!0,contextType:!0,contextTypes:!0,defaultProps:!0,displayName:!0,getDefaultProps:!0,getDerivedStateFromError:!0,getDerivedStateFromProps:!0,mixins:!0,propTypes:!0,type:!0},n={name:!0,length:!0,prototype:!0,caller:!0,callee:!0,arguments:!0,arity:!0},r={$$typeof:!0,render:!0,defaultProps:!0,displayName:!0,propTypes:!0},i={$$typeof:!0,compare:!0,defaultProps:!0,displayName:!0,propTypes:!0,type:!0},a={};a[e.ForwardRef]=r,a[e.Memo]=i;function u(y){return e.isMemo(y)?i:a[y.$$typeof]||t}var l=Object.defineProperty,o=Object.getOwnPropertyNames,s=Object.getOwnPropertySymbols,c=Object.getOwnPropertyDescriptor,d=Object.getPrototypeOf,h=Object.prototype;function m(y,v,_){if(typeof v!="string"){if(h){var S=d(v);S&&S!==h&&m(y,S,_)}var E=o(v);s&&(E=E.concat(s(v)));for(var C=u(y),T=u(v),R=0;R<E.length;++R){var $=E[R];if(!n[$]&&!(_&&_[$])&&!(T&&T[$])&&!(C&&C[$])){var k=c(v,$);try{l(y,$,k)}catch{}}}}return y}return X5=m,X5}l3e();var o3e=!0;function s3e(e,t,n){var r="";return n.split(" ").forEach(function(i){e[i]!==void 0?t.push(e[i]+";"):i&&(r+=i+" ")}),r}var hJ=function(t,n,r){var i=t.key+"-"+n.name;(r===!1||o3e===!1)&&t.registered[i]===void 0&&(t.registered[i]=n.styles)},pJ=function(t,n,r){hJ(t,n,r);var i=t.key+"-"+n.name;if(t.inserted[n.name]===void 0){var a=n;do t.insert(n===a?"."+i:"",a,t.sheet,!0),a=a.next;while(a!==void 0)}};function c3e(e){for(var t=0,n,r=0,i=e.length;i>=4;++r,i-=4)n=e.charCodeAt(r)&255|(e.charCodeAt(++r)&255)<<8|(e.charCodeAt(++r)&255)<<16|(e.charCodeAt(++r)&255)<<24,n=(n&65535)*1540483477+((n>>>16)*59797<<16),n^=n>>>24,t=(n&65535)*1540483477+((n>>>16)*59797<<16)^(t&65535)*1540483477+((t>>>16)*59797<<16);switch(i){case 3:t^=(e.charCodeAt(r+2)&255)<<16;case 2:t^=(e.charCodeAt(r+1)&255)<<8;case 1:t^=e.charCodeAt(r)&255,t=(t&65535)*1540483477+((t>>>16)*59797<<16)}return t^=t>>>13,t=(t&65535)*1540483477+((t>>>16)*59797<<16),((t^t>>>15)>>>0).toString(36)}var f3e={animationIterationCount:1,aspectRatio:1,borderImageOutset:1,borderImageSlice:1,borderImageWidth:1,boxFlex:1,boxFlexGroup:1,boxOrdinalGroup:1,columnCount:1,columns:1,flex:1,flexGrow:1,flexPositive:1,flexShrink:1,flexNegative:1,flexOrder:1,gridRow:1,gridRowEnd:1,gridRowSpan:1,gridRowStart:1,gridColumn:1,gridColumnEnd:1,gridColumnSpan:1,gridColumnStart:1,msGridRow:1,msGridRowSpan:1,msGridColumn:1,msGridColumnSpan:1,fontWeight:1,lineHeight:1,opacity:1,order:1,orphans:1,scale:1,tabSize:1,widows:1,zIndex:1,zoom:1,WebkitLineClamp:1,fillOpacity:1,floodOpacity:1,stopOpacity:1,strokeDasharray:1,strokeDashoffset:1,strokeMiterlimit:1,strokeOpacity:1,strokeWidth:1},d3e=/[A-Z]|^ms/g,h3e=/_EMO_([^_]+?)_([^]*?)_EMO_/g,mJ=function(t){return t.charCodeAt(1)===45},GB=function(t){return t!=null&&typeof t!="boolean"},Y5=GOe(function(e){return mJ(e)?e:e.replace(d3e,"-$&").toLowerCase()}),KB=function(t,n){switch(t){case"animation":case"animationName":if(typeof n=="string")return n.replace(h3e,function(r,i,a){return m0={name:i,styles:a,next:m0},i})}return f3e[t]!==1&&!mJ(t)&&typeof n=="number"&&n!==0?n+"px":n};function ux(e,t,n){if(n==null)return"";var r=n;if(r.__emotion_styles!==void 0)return r;switch(typeof n){case"boolean":return"";case"object":{var i=n;if(i.anim===1)return m0={name:i.name,styles:i.styles,next:m0},i.name;var a=n;if(a.styles!==void 0){var u=a.next;if(u!==void 0)for(;u!==void 0;)m0={name:u.name,styles:u.styles,next:m0},u=u.next;var l=a.styles+";";return l}return p3e(e,t,n)}case"function":{if(e!==void 0){var o=m0,s=n(e);return m0=o,ux(e,t,s)}break}}var c=n;return c}function p3e(e,t,n){var r="";if(Array.isArray(n))for(var i=0;i<n.length;i++)r+=ux(e,t,n[i])+";";else for(var a in n){var u=n[a];if(typeof u!="object"){var l=u;GB(l)&&(r+=Y5(a)+":"+KB(a,l)+";")}else if(Array.isArray(u)&&typeof u[0]=="string"&&t==null)for(var o=0;o<u.length;o++)GB(u[o])&&(r+=Y5(a)+":"+KB(a,u[o])+";");else{var s=ux(e,t,u);switch(a){case"animation":case"animationName":{r+=Y5(a)+":"+s+";";break}default:r+=a+"{"+s+"}"}}}return r}var WB=/label:\s*([^\s;{]+)\s*(;|$)/g,m0;function PF(e,t,n){if(e.length===1&&typeof e[0]=="object"&&e[0]!==null&&e[0].styles!==void 0)return e[0];var r=!0,i="";m0=void 0;var a=e[0];if(a==null||a.raw===void 0)r=!1,i+=ux(n,t,a);else{var u=a;i+=u[0]}for(var l=1;l<e.length;l++)if(i+=ux(n,t,e[l]),r){var o=a;i+=o[l]}WB.lastIndex=0;for(var s="",c;(c=WB.exec(i))!==null;)s+="-"+c[1];var d=c3e(i)+s;return{name:d,styles:i,next:m0}}var m3e=function(t){return t()},gJ=Y7.useInsertionEffect?Y7.useInsertionEffect:!1,g3e=gJ||m3e,JB=gJ||P.useLayoutEffect,vJ=P.createContext(typeof HTMLElement<"u"?i3e({key:"css"}):null);vJ.Provider;var yJ=function(t){return P.forwardRef(function(n,r){var i=P.useContext(vJ);return t(n,i,r)})},bJ=P.createContext({}),nS={}.hasOwnProperty,W7="__EMOTION_TYPE_PLEASE_DO_NOT_USE__",MF=function(t,n){var r={};for(var i in n)nS.call(n,i)&&(r[i]=n[i]);return r[W7]=t,r},v3e=function(t){var n=t.cache,r=t.serialized,i=t.isStringTag;return hJ(n,r,i),g3e(function(){return pJ(n,r,i)}),null},y3e=yJ(function(e,t,n){var r=e.css;typeof r=="string"&&t.registered[r]!==void 0&&(r=t.registered[r]);var i=e[W7],a=[r],u="";typeof e.className=="string"?u=s3e(t.registered,a,e.className):e.className!=null&&(u=e.className+" ");var l=PF(a,void 0,P.useContext(bJ));u+=t.key+"-"+l.name;var o={};for(var s in e)nS.call(e,s)&&s!=="css"&&s!==W7&&(o[s]=e[s]);return o.className=u,n&&(o.ref=n),P.createElement(P.Fragment,null,P.createElement(v3e,{cache:t,serialized:l,isStringTag:typeof i=="string"}),P.createElement(i,o))}),FF=y3e,Rnt=Mr.Fragment,Ant=function(t,n,r){return nS.call(n,"css")?Mr.jsx(FF,MF(t,n),r):Mr.jsx(t,n,r)},Tnt=function(t,n,r){return nS.call(n,"css")?Mr.jsxs(FF,MF(t,n),r):Mr.jsxs(t,n,r)},G5={exports:{}},H4={},K5={exports:{}},W5={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var eQ;function b3e(){return eQ||(eQ=1,(function(e){function t(G,J){var te=G.length;G.push(J);e:for(;0<te;){var H=te-1>>>1,M=G[H];if(0<i(M,J))G[H]=J,G[te]=M,te=H;else break e}}function n(G){return G.length===0?null:G[0]}function r(G){if(G.length===0)return null;var J=G[0],te=G.pop();if(te!==J){G[0]=te;e:for(var H=0,M=G.length,K=M>>>1;H<K;){var X=2*(H+1)-1,B=G[X],ne=X+1,oe=G[ne];if(0>i(B,te))ne<M&&0>i(oe,B)?(G[H]=oe,G[ne]=te,H=ne):(G[H]=B,G[X]=te,H=X);else if(ne<M&&0>i(oe,te))G[H]=oe,G[ne]=te,H=ne;else break e}}return J}function i(G,J){var te=G.sortIndex-J.sortIndex;return te!==0?te:G.id-J.id}if(e.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var a=performance;e.unstable_now=function(){return a.now()}}else{var u=Date,l=u.now();e.unstable_now=function(){return u.now()-l}}var o=[],s=[],c=1,d=null,h=3,m=!1,y=!1,v=!1,_=!1,S=typeof setTimeout=="function"?setTimeout:null,E=typeof clearTimeout=="function"?clearTimeout:null,C=typeof setImmediate<"u"?setImmediate:null;function T(G){for(var J=n(s);J!==null;){if(J.callback===null)r(s);else if(J.startTime<=G)r(s),J.sortIndex=J.expirationTime,t(o,J);else break;J=n(s)}}function R(G){if(v=!1,T(G),!y)if(n(o)!==null)y=!0,$||($=!0,q());else{var J=n(s);J!==null&&W(R,J.startTime-G)}}var $=!1,k=-1,F=5,L=-1;function j(){return _?!0:!(e.unstable_now()-L<F)}function V(){if(_=!1,$){var G=e.unstable_now();L=G;var J=!0;try{e:{y=!1,v&&(v=!1,E(k),k=-1),m=!0;var te=h;try{t:{for(T(G),d=n(o);d!==null&&!(d.expirationTime>G&&j());){var H=d.callback;if(typeof H=="function"){d.callback=null,h=d.priorityLevel;var M=H(d.expirationTime<=G);if(G=e.unstable_now(),typeof M=="function"){d.callback=M,T(G),J=!0;break t}d===n(o)&&r(o),T(G)}else r(o);d=n(o)}if(d!==null)J=!0;else{var K=n(s);K!==null&&W(R,K.startTime-G),J=!1}}break e}finally{d=null,h=te,m=!1}J=void 0}}finally{J?q():$=!1}}}var q;if(typeof C=="function")q=function(){C(V)};else if(typeof MessageChannel<"u"){var N=new MessageChannel,U=N.port2;N.port1.onmessage=V,q=function(){U.postMessage(null)}}else q=function(){S(V,0)};function W(G,J){k=S(function(){G(e.unstable_now())},J)}e.unstable_IdlePriority=5,e.unstable_ImmediatePriority=1,e.unstable_LowPriority=4,e.unstable_NormalPriority=3,e.unstable_Profiling=null,e.unstable_UserBlockingPriority=2,e.unstable_cancelCallback=function(G){G.callback=null},e.unstable_forceFrameRate=function(G){0>G||125<G?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):F=0<G?Math.floor(1e3/G):5},e.unstable_getCurrentPriorityLevel=function(){return h},e.unstable_next=function(G){switch(h){case 1:case 2:case 3:var J=3;break;default:J=h}var te=h;h=J;try{return G()}finally{h=te}},e.unstable_requestPaint=function(){_=!0},e.unstable_runWithPriority=function(G,J){switch(G){case 1:case 2:case 3:case 4:case 5:break;default:G=3}var te=h;h=G;try{return J()}finally{h=te}},e.unstable_scheduleCallback=function(G,J,te){var H=e.unstable_now();switch(typeof te=="object"&&te!==null?(te=te.delay,te=typeof te=="number"&&0<te?H+te:H):te=H,G){case 1:var M=-1;break;case 2:M=250;break;case 5:M=1073741823;break;case 4:M=1e4;break;default:M=5e3}return M=te+M,G={id:c++,callback:J,priorityLevel:G,startTime:te,expirationTime:M,sortIndex:-1},te>H?(G.sortIndex=te,t(s,G),n(o)===null&&G===n(s)&&(v?(E(k),k=-1):v=!0,W(R,te-H))):(G.sortIndex=M,t(o,G),y||m||(y=!0,$||($=!0,q()))),G},e.unstable_shouldYield=j,e.unstable_wrapCallback=function(G){var J=h;return function(){var te=h;h=J;try{return G.apply(this,arguments)}finally{h=te}}}})(W5)),W5}var tQ;function O3e(){return tQ||(tQ=1,K5.exports=b3e()),K5.exports}var J5={exports:{}},cs={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var nQ;function x3e(){if(nQ)return cs;nQ=1;var e=nr();function t(o){var s="https://react.dev/errors/"+o;if(1<arguments.length){s+="?args[]="+encodeURIComponent(arguments[1]);for(var c=2;c<arguments.length;c++)s+="&args[]="+encodeURIComponent(arguments[c])}return"Minified React error #"+o+"; visit "+s+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function n(){}var r={d:{f:n,r:function(){throw Error(t(522))},D:n,C:n,L:n,m:n,X:n,S:n,M:n},p:0,findDOMNode:null},i=Symbol.for("react.portal");function a(o,s,c){var d=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:i,key:d==null?null:""+d,children:o,containerInfo:s,implementation:c}}var u=e.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function l(o,s){if(o==="font")return"";if(typeof s=="string")return s==="use-credentials"?s:""}return cs.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=r,cs.createPortal=function(o,s){var c=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!s||s.nodeType!==1&&s.nodeType!==9&&s.nodeType!==11)throw Error(t(299));return a(o,s,null,c)},cs.flushSync=function(o){var s=u.T,c=r.p;try{if(u.T=null,r.p=2,o)return o()}finally{u.T=s,r.p=c,r.d.f()}},cs.preconnect=function(o,s){typeof o=="string"&&(s?(s=s.crossOrigin,s=typeof s=="string"?s==="use-credentials"?s:"":void 0):s=null,r.d.C(o,s))},cs.prefetchDNS=function(o){typeof o=="string"&&r.d.D(o)},cs.preinit=function(o,s){if(typeof o=="string"&&s&&typeof s.as=="string"){var c=s.as,d=l(c,s.crossOrigin),h=typeof s.integrity=="string"?s.integrity:void 0,m=typeof s.fetchPriority=="string"?s.fetchPriority:void 0;c==="style"?r.d.S(o,typeof s.precedence=="string"?s.precedence:void 0,{crossOrigin:d,integrity:h,fetchPriority:m}):c==="script"&&r.d.X(o,{crossOrigin:d,integrity:h,fetchPriority:m,nonce:typeof s.nonce=="string"?s.nonce:void 0})}},cs.preinitModule=function(o,s){if(typeof o=="string")if(typeof s=="object"&&s!==null){if(s.as==null||s.as==="script"){var c=l(s.as,s.crossOrigin);r.d.M(o,{crossOrigin:c,integrity:typeof s.integrity=="string"?s.integrity:void 0,nonce:typeof s.nonce=="string"?s.nonce:void 0})}}else s==null&&r.d.M(o)},cs.preload=function(o,s){if(typeof o=="string"&&typeof s=="object"&&s!==null&&typeof s.as=="string"){var c=s.as,d=l(c,s.crossOrigin);r.d.L(o,c,{crossOrigin:d,integrity:typeof s.integrity=="string"?s.integrity:void 0,nonce:typeof s.nonce=="string"?s.nonce:void 0,type:typeof s.type=="string"?s.type:void 0,fetchPriority:typeof s.fetchPriority=="string"?s.fetchPriority:void 0,referrerPolicy:typeof s.referrerPolicy=="string"?s.referrerPolicy:void 0,imageSrcSet:typeof s.imageSrcSet=="string"?s.imageSrcSet:void 0,imageSizes:typeof s.imageSizes=="string"?s.imageSizes:void 0,media:typeof s.media=="string"?s.media:void 0})}},cs.preloadModule=function(o,s){if(typeof o=="string")if(s){var c=l(s.as,s.crossOrigin);r.d.m(o,{as:typeof s.as=="string"&&s.as!=="script"?s.as:void 0,crossOrigin:c,integrity:typeof s.integrity=="string"?s.integrity:void 0})}else r.d.m(o)},cs.requestFormReset=function(o){r.d.r(o)},cs.unstable_batchedUpdates=function(o,s){return o(s)},cs.useFormState=function(o,s,c){return u.H.useFormState(o,s,c)},cs.useFormStatus=function(){return u.H.useHostTransitionStatus()},cs.version="19.2.0",cs}var rQ;function OJ(){if(rQ)return J5.exports;rQ=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),J5.exports=x3e(),J5.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var iQ;function S3e(){if(iQ)return H4;iQ=1;var e=O3e(),t=nr(),n=OJ();function r(f){var p="https://react.dev/errors/"+f;if(1<arguments.length){p+="?args[]="+encodeURIComponent(arguments[1]);for(var O=2;O<arguments.length;O++)p+="&args[]="+encodeURIComponent(arguments[O])}return"Minified React error #"+f+"; visit "+p+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function i(f){return!(!f||f.nodeType!==1&&f.nodeType!==9&&f.nodeType!==11)}function a(f){var p=f,O=f;if(f.alternate)for(;p.return;)p=p.return;else{f=p;do p=f,(p.flags&4098)!==0&&(O=p.return),f=p.return;while(f)}return p.tag===3?O:null}function u(f){if(f.tag===13){var p=f.memoizedState;if(p===null&&(f=f.alternate,f!==null&&(p=f.memoizedState)),p!==null)return p.dehydrated}return null}function l(f){if(f.tag===31){var p=f.memoizedState;if(p===null&&(f=f.alternate,f!==null&&(p=f.memoizedState)),p!==null)return p.dehydrated}return null}function o(f){if(a(f)!==f)throw Error(r(188))}function s(f){var p=f.alternate;if(!p){if(p=a(f),p===null)throw Error(r(188));return p!==f?null:f}for(var O=f,D=p;;){var Q=O.return;if(Q===null)break;var Y=Q.alternate;if(Y===null){if(D=Q.return,D!==null){O=D;continue}break}if(Q.child===Y.child){for(Y=Q.child;Y;){if(Y===O)return o(Q),f;if(Y===D)return o(Q),p;Y=Y.sibling}throw Error(r(188))}if(O.return!==D.return)O=Q,D=Y;else{for(var ce=!1,Ee=Q.child;Ee;){if(Ee===O){ce=!0,O=Q,D=Y;break}if(Ee===D){ce=!0,D=Q,O=Y;break}Ee=Ee.sibling}if(!ce){for(Ee=Y.child;Ee;){if(Ee===O){ce=!0,O=Y,D=Q;break}if(Ee===D){ce=!0,D=Y,O=Q;break}Ee=Ee.sibling}if(!ce)throw Error(r(189))}}if(O.alternate!==D)throw Error(r(190))}if(O.tag!==3)throw Error(r(188));return O.stateNode.current===O?f:p}function c(f){var p=f.tag;if(p===5||p===26||p===27||p===6)return f;for(f=f.child;f!==null;){if(p=c(f),p!==null)return p;f=f.sibling}return null}var d=Object.assign,h=Symbol.for("react.element"),m=Symbol.for("react.transitional.element"),y=Symbol.for("react.portal"),v=Symbol.for("react.fragment"),_=Symbol.for("react.strict_mode"),S=Symbol.for("react.profiler"),E=Symbol.for("react.consumer"),C=Symbol.for("react.context"),T=Symbol.for("react.forward_ref"),R=Symbol.for("react.suspense"),$=Symbol.for("react.suspense_list"),k=Symbol.for("react.memo"),F=Symbol.for("react.lazy"),L=Symbol.for("react.activity"),j=Symbol.for("react.memo_cache_sentinel"),V=Symbol.iterator;function q(f){return f===null||typeof f!="object"?null:(f=V&&f[V]||f["@@iterator"],typeof f=="function"?f:null)}var N=Symbol.for("react.client.reference");function U(f){if(f==null)return null;if(typeof f=="function")return f.$$typeof===N?null:f.displayName||f.name||null;if(typeof f=="string")return f;switch(f){case v:return"Fragment";case S:return"Profiler";case _:return"StrictMode";case R:return"Suspense";case $:return"SuspenseList";case L:return"Activity"}if(typeof f=="object")switch(f.$$typeof){case y:return"Portal";case C:return f.displayName||"Context";case E:return(f._context.displayName||"Context")+".Consumer";case T:var p=f.render;return f=f.displayName,f||(f=p.displayName||p.name||"",f=f!==""?"ForwardRef("+f+")":"ForwardRef"),f;case k:return p=f.displayName||null,p!==null?p:U(f.type)||"Memo";case F:p=f._payload,f=f._init;try{return U(f(p))}catch{}}return null}var W=Array.isArray,G=t.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,J=n.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,te={pending:!1,data:null,method:null,action:null},H=[],M=-1;function K(f){return{current:f}}function X(f){0>M||(f.current=H[M],H[M]=null,M--)}function B(f,p){M++,H[M]=f.current,f.current=p}var ne=K(null),oe=K(null),ie=K(null),de=K(null);function be(f,p){switch(B(ie,p),B(oe,f),B(ne,null),p.nodeType){case 9:case 11:f=(f=p.documentElement)&&(f=f.namespaceURI)?o1(f):0;break;default:if(f=p.tagName,p=p.namespaceURI)p=o1(p),f=os(p,f);else switch(f){case"svg":f=1;break;case"math":f=2;break;default:f=0}}X(ne),B(ne,f)}function ve(){X(ne),X(oe),X(ie)}function pe(f){f.memoizedState!==null&&B(de,f);var p=ne.current,O=os(p,f.type);p!==O&&(B(oe,f),B(ne,O))}function _e(f){oe.current===f&&(X(ne),X(oe)),de.current===f&&(X(de),sv._currentValue=te)}var se,me;function ge(f){if(se===void 0)try{throw Error()}catch(O){var p=O.stack.trim().match(/\n( *(at )?)/);se=p&&p[1]||"",me=-1<O.stack.indexOf(`
    at`)?" (<anonymous>)":-1<O.stack.indexOf("@")?"@unknown:0:0":""}return`
`+se+f+me}var we=!1;function Ne(f,p){if(!f||we)return"";we=!0;var O=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var D={DetermineComponentFrameRoot:function(){try{if(p){var xt=function(){throw Error()};if(Object.defineProperty(xt.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(xt,[])}catch(ft){var lt=ft}Reflect.construct(f,[],xt)}else{try{xt.call()}catch(ft){lt=ft}f.call(xt.prototype)}}else{try{throw Error()}catch(ft){lt=ft}(xt=f())&&typeof xt.catch=="function"&&xt.catch(function(){})}}catch(ft){if(ft&&lt&&typeof ft.stack=="string")return[ft.stack,lt.stack]}return[null,null]}};D.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var Q=Object.getOwnPropertyDescriptor(D.DetermineComponentFrameRoot,"name");Q&&Q.configurable&&Object.defineProperty(D.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var Y=D.DetermineComponentFrameRoot(),ce=Y[0],Ee=Y[1];if(ce&&Ee){var Le=ce.split(`
`),at=Ee.split(`
`);for(Q=D=0;D<Le.length&&!Le[D].includes("DetermineComponentFrameRoot");)D++;for(;Q<at.length&&!at[Q].includes("DetermineComponentFrameRoot");)Q++;if(D===Le.length||Q===at.length)for(D=Le.length-1,Q=at.length-1;1<=D&&0<=Q&&Le[D]!==at[Q];)Q--;for(;1<=D&&0<=Q;D--,Q--)if(Le[D]!==at[Q]){if(D!==1||Q!==1)do if(D--,Q--,0>Q||Le[D]!==at[Q]){var mt=`
`+Le[D].replace(" at new "," at ");return f.displayName&&mt.includes("<anonymous>")&&(mt=mt.replace("<anonymous>",f.displayName)),mt}while(1<=D&&0<=Q);break}}}finally{we=!1,Error.prepareStackTrace=O}return(O=f?f.displayName||f.name:"")?ge(O):""}function Re(f,p){switch(f.tag){case 26:case 27:case 5:return ge(f.type);case 16:return ge("Lazy");case 13:return f.child!==p&&p!==null?ge("Suspense Fallback"):ge("Suspense");case 19:return ge("SuspenseList");case 0:case 15:return Ne(f.type,!1);case 11:return Ne(f.type.render,!1);case 1:return Ne(f.type,!0);case 31:return ge("Activity");default:return""}}function et(f){try{var p="",O=null;do p+=Re(f,O),O=f,f=f.return;while(f);return p}catch(D){return`
Error generating stack: `+D.message+`
`+D.stack}}var tt=Object.prototype.hasOwnProperty,Oe=e.unstable_scheduleCallback,$e=e.unstable_cancelCallback,Ae=e.unstable_shouldYield,Ue=e.unstable_requestPaint,Ze=e.unstable_now,Ye=e.unstable_getCurrentPriorityLevel,Me=e.unstable_ImmediatePriority,ze=e.unstable_UserBlockingPriority,st=e.unstable_NormalPriority,Ot=e.unstable_LowPriority,Nt=e.unstable_IdlePriority,gt=e.log,qt=e.unstable_setDisableYieldValue,zt=null,an=null;function rn(f){if(typeof gt=="function"&&qt(f),an&&typeof an.setStrictMode=="function")try{an.setStrictMode(zt,f)}catch{}}var Fe=Math.clz32?Math.clz32:Qt,ht=Math.log,Tt=Math.LN2;function Qt(f){return f>>>=0,f===0?32:31-(ht(f)/Tt|0)|0}var un=256,Ln=262144,ln=4194304;function Zn(f){var p=f&42;if(p!==0)return p;switch(f&-f){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return f&261888;case 262144:case 524288:case 1048576:case 2097152:return f&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return f&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return f}}function cr(f,p,O){var D=f.pendingLanes;if(D===0)return 0;var Q=0,Y=f.suspendedLanes,ce=f.pingedLanes;f=f.warmLanes;var Ee=D&134217727;return Ee!==0?(D=Ee&~Y,D!==0?Q=Zn(D):(ce&=Ee,ce!==0?Q=Zn(ce):O||(O=Ee&~f,O!==0&&(Q=Zn(O))))):(Ee=D&~Y,Ee!==0?Q=Zn(Ee):ce!==0?Q=Zn(ce):O||(O=D&~f,O!==0&&(Q=Zn(O)))),Q===0?0:p!==0&&p!==Q&&(p&Y)===0&&(Y=Q&-Q,O=p&-p,Y>=O||Y===32&&(O&4194048)!==0)?p:Q}function ur(f,p){return(f.pendingLanes&~(f.suspendedLanes&~f.pingedLanes)&p)===0}function Cr(f,p){switch(f){case 1:case 2:case 4:case 8:case 64:return p+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return p+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Vr(){var f=ln;return ln<<=1,(ln&62914560)===0&&(ln=4194304),f}function ke(f){for(var p=[],O=0;31>O;O++)p.push(f);return p}function He(f,p){f.pendingLanes|=p,p!==268435456&&(f.suspendedLanes=0,f.pingedLanes=0,f.warmLanes=0)}function nt(f,p,O,D,Q,Y){var ce=f.pendingLanes;f.pendingLanes=O,f.suspendedLanes=0,f.pingedLanes=0,f.warmLanes=0,f.expiredLanes&=O,f.entangledLanes&=O,f.errorRecoveryDisabledLanes&=O,f.shellSuspendCounter=0;var Ee=f.entanglements,Le=f.expirationTimes,at=f.hiddenUpdates;for(O=ce&~O;0<O;){var mt=31-Fe(O),xt=1<<mt;Ee[mt]=0,Le[mt]=-1;var lt=at[mt];if(lt!==null)for(at[mt]=null,mt=0;mt<lt.length;mt++){var ft=lt[mt];ft!==null&&(ft.lane&=-536870913)}O&=~xt}D!==0&&dt(f,D,0),Y!==0&&Q===0&&f.tag!==0&&(f.suspendedLanes|=Y&~(ce&~p))}function dt(f,p,O){f.pendingLanes|=p,f.suspendedLanes&=~p;var D=31-Fe(p);f.entangledLanes|=p,f.entanglements[D]=f.entanglements[D]|1073741824|O&261930}function $t(f,p){var O=f.entangledLanes|=p;for(f=f.entanglements;O;){var D=31-Fe(O),Q=1<<D;Q&p|f[D]&p&&(f[D]|=p),O&=~Q}}function Ut(f,p){var O=p&-p;return O=(O&42)!==0?1:Zt(O),(O&(f.suspendedLanes|p))!==0?0:O}function Zt(f){switch(f){case 2:f=1;break;case 8:f=4;break;case 32:f=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:f=128;break;case 268435456:f=134217728;break;default:f=0}return f}function Lt(f){return f&=-f,2<f?8<f?(f&134217727)!==0?32:268435456:8:2}function Vt(){var f=J.p;return f!==0?f:(f=window.event,f===void 0?32:O_(f.type))}function tn(f,p){var O=J.p;try{return J.p=f,p()}finally{J.p=O}}var nn=Math.random().toString(36).slice(2),Rt="__reactFiber$"+nn,sn="__reactProps$"+nn,gr="__reactContainer$"+nn,Pi="__reactEvents$"+nn,Da="__reactListeners$"+nn,mi="__reactHandles$"+nn,Ur="__reactResources$"+nn,wu="__reactMarker$"+nn;function Al(f){delete f[Rt],delete f[sn],delete f[Pi],delete f[Da],delete f[mi]}function Hr(f){var p=f[Rt];if(p)return p;for(var O=f.parentNode;O;){if(p=O[gr]||O[Rt]){if(O=p.alternate,p.child!==null||O!==null&&O.child!==null)for(f=r_(f);f!==null;){if(O=f[Rt])return O;f=r_(f)}return p}f=O,O=f.parentNode}return null}function Pt(f){if(f=f[Rt]||f[gr]){var p=f.tag;if(p===5||p===6||p===13||p===31||p===26||p===27||p===3)return f}return null}function ca(f){var p=f.tag;if(p===5||p===26||p===27||p===6)return f.stateNode;throw Error(r(33))}function Wi(f){var p=f[Ur];return p||(p=f[Ur]={hoistableStyles:new Map,hoistableScripts:new Map}),p}function ti(f){f[wu]=!0}var Ru=new Set,uo={};function Xn(f,p){gi(f,p),gi(f+"Capture",p)}function gi(f,p){for(uo[f]=p,f=0;f<p.length;f++)Ru.add(p[f])}var xs=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Ss={},ni={};function _s(f){return tt.call(ni,f)?!0:tt.call(Ss,f)?!1:xs.test(f)?ni[f]=!0:(Ss[f]=!0,!1)}function $a(f,p,O){if(_s(p))if(O===null)f.removeAttribute(p);else{switch(typeof O){case"undefined":case"function":case"symbol":f.removeAttribute(p);return;case"boolean":var D=p.toLowerCase().slice(0,5);if(D!=="data-"&&D!=="aria-"){f.removeAttribute(p);return}}f.setAttribute(p,""+O)}}function pc(f,p,O){if(O===null)f.removeAttribute(p);else{switch(typeof O){case"undefined":case"function":case"symbol":case"boolean":f.removeAttribute(p);return}f.setAttribute(p,""+O)}}function Fr(f,p,O,D){if(D===null)f.removeAttribute(O);else{switch(typeof D){case"undefined":case"function":case"symbol":case"boolean":f.removeAttribute(O);return}f.setAttributeNS(p,O,""+D)}}function Ji(f){switch(typeof f){case"bigint":case"boolean":case"number":case"string":case"undefined":return f;case"object":return f;default:return""}}function Io(f){var p=f.type;return(f=f.nodeName)&&f.toLowerCase()==="input"&&(p==="checkbox"||p==="radio")}function Op(f,p,O){var D=Object.getOwnPropertyDescriptor(f.constructor.prototype,p);if(!f.hasOwnProperty(p)&&typeof D<"u"&&typeof D.get=="function"&&typeof D.set=="function"){var Q=D.get,Y=D.set;return Object.defineProperty(f,p,{configurable:!0,get:function(){return Q.call(this)},set:function(ce){O=""+ce,Y.call(this,ce)}}),Object.defineProperty(f,p,{enumerable:D.enumerable}),{getValue:function(){return O},setValue:function(ce){O=""+ce},stopTracking:function(){f._valueTracker=null,delete f[p]}}}}function mf(f){if(!f._valueTracker){var p=Io(f)?"checked":"value";f._valueTracker=Op(f,p,""+f[p])}}function Lo(f){if(!f)return!1;var p=f._valueTracker;if(!p)return!0;var O=p.getValue(),D="";return f&&(D=Io(f)?f.checked?"true":"false":f.value),f=D,f!==O?(p.setValue(f),!0):!1}function Tl(f){if(f=f||(typeof document<"u"?document:void 0),typeof f>"u")return null;try{return f.activeElement||f.body}catch{return f.body}}var oh=/[\n"\\]/g;function Ha(f){return f.replace(oh,function(p){return"\\"+p.charCodeAt(0).toString(16)+" "})}function td(f,p,O,D,Q,Y,ce,Ee){f.name="",ce!=null&&typeof ce!="function"&&typeof ce!="symbol"&&typeof ce!="boolean"?f.type=ce:f.removeAttribute("type"),p!=null?ce==="number"?(p===0&&f.value===""||f.value!=p)&&(f.value=""+Ji(p)):f.value!==""+Ji(p)&&(f.value=""+Ji(p)):ce!=="submit"&&ce!=="reset"||f.removeAttribute("value"),p!=null?nd(f,ce,Ji(p)):O!=null?nd(f,ce,Ji(O)):D!=null&&f.removeAttribute("value"),Q==null&&Y!=null&&(f.defaultChecked=!!Y),Q!=null&&(f.checked=Q&&typeof Q!="function"&&typeof Q!="symbol"),Ee!=null&&typeof Ee!="function"&&typeof Ee!="symbol"&&typeof Ee!="boolean"?f.name=""+Ji(Ee):f.removeAttribute("name")}function Es(f,p,O,D,Q,Y,ce,Ee){if(Y!=null&&typeof Y!="function"&&typeof Y!="symbol"&&typeof Y!="boolean"&&(f.type=Y),p!=null||O!=null){if(!(Y!=="submit"&&Y!=="reset"||p!=null)){mf(f);return}O=O!=null?""+Ji(O):"",p=p!=null?""+Ji(p):O,Ee||p===f.value||(f.value=p),f.defaultValue=p}D=D??Q,D=typeof D!="function"&&typeof D!="symbol"&&!!D,f.checked=Ee?f.checked:!!D,f.defaultChecked=!!D,ce!=null&&typeof ce!="function"&&typeof ce!="symbol"&&typeof ce!="boolean"&&(f.name=ce),mf(f)}function nd(f,p,O){p==="number"&&Tl(f.ownerDocument)===f||f.defaultValue===""+O||(f.defaultValue=""+O)}function mc(f,p,O,D){if(f=f.options,p){p={};for(var Q=0;Q<O.length;Q++)p["$"+O[Q]]=!0;for(O=0;O<f.length;O++)Q=p.hasOwnProperty("$"+f[O].value),f[O].selected!==Q&&(f[O].selected=Q),Q&&D&&(f[O].defaultSelected=!0)}else{for(O=""+Ji(O),p=null,Q=0;Q<f.length;Q++){if(f[Q].value===O){f[Q].selected=!0,D&&(f[Q].defaultSelected=!0);return}p!==null||f[Q].disabled||(p=f[Q])}p!==null&&(p.selected=!0)}}function gc(f,p,O){if(p!=null&&(p=""+Ji(p),p!==f.value&&(f.value=p),O==null)){f.defaultValue!==p&&(f.defaultValue=p);return}f.defaultValue=O!=null?""+Ji(O):""}function Bo(f,p,O,D){if(p==null){if(D!=null){if(O!=null)throw Error(r(92));if(W(D)){if(1<D.length)throw Error(r(93));D=D[0]}O=D}O==null&&(O=""),p=O}O=Ji(p),f.defaultValue=O,D=f.textContent,D===O&&D!==""&&D!==null&&(f.value=D),mf(f)}function Au(f,p){if(p){var O=f.firstChild;if(O&&O===f.lastChild&&O.nodeType===3){O.nodeValue=p;return}}f.textContent=p}var Ds=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function $s(f,p,O){var D=p.indexOf("--")===0;O==null||typeof O=="boolean"||O===""?D?f.setProperty(p,""):p==="float"?f.cssFloat="":f[p]="":D?f.setProperty(p,O):typeof O!="number"||O===0||Ds.has(p)?p==="float"?f.cssFloat=O:f[p]=(""+O).trim():f[p]=O+"px"}function Z0(f,p,O){if(p!=null&&typeof p!="object")throw Error(r(62));if(f=f.style,O!=null){for(var D in O)!O.hasOwnProperty(D)||p!=null&&p.hasOwnProperty(D)||(D.indexOf("--")===0?f.setProperty(D,""):D==="float"?f.cssFloat="":f[D]="");for(var Q in p)D=p[Q],p.hasOwnProperty(Q)&&O[Q]!==D&&$s(f,Q,D)}else for(var Y in p)p.hasOwnProperty(Y)&&$s(f,Y,p[Y])}function gf(f){if(f.indexOf("-")===-1)return!1;switch(f){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var H0=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),xp=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function vf(f){return xp.test(""+f)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":f}function lo(){}var sh=null;function ch(f){return f=f.target||f.srcElement||window,f.correspondingUseElement&&(f=f.correspondingUseElement),f.nodeType===3?f.parentNode:f}var Cs=null,vc=null;function X0(f){var p=Pt(f);if(p&&(f=p.stateNode)){var O=f[sn]||null;e:switch(f=p.stateNode,p.type){case"input":if(td(f,O.value,O.defaultValue,O.defaultValue,O.checked,O.defaultChecked,O.type,O.name),p=O.name,O.type==="radio"&&p!=null){for(O=f;O.parentNode;)O=O.parentNode;for(O=O.querySelectorAll('input[name="'+Ha(""+p)+'"][type="radio"]'),p=0;p<O.length;p++){var D=O[p];if(D!==f&&D.form===f.form){var Q=D[sn]||null;if(!Q)throw Error(r(90));td(D,Q.value,Q.defaultValue,Q.defaultValue,Q.checked,Q.defaultChecked,Q.type,Q.name)}}for(p=0;p<O.length;p++)D=O[p],D.form===f.form&&Lo(D)}break e;case"textarea":gc(f,O.value,O.defaultValue);break e;case"select":p=O.value,p!=null&&mc(f,!!O.multiple,p,!1)}}}var Sp=!1;function _p(f,p,O){if(Sp)return f(p,O);Sp=!0;try{var D=f(p);return D}finally{if(Sp=!1,(Cs!==null||vc!==null)&&(De(),Cs&&(p=Cs,f=vc,vc=Cs=null,X0(p),f)))for(p=0;p<f.length;p++)X0(f[p])}}function ws(f,p){var O=f.stateNode;if(O===null)return null;var D=O[sn]||null;if(D===null)return null;O=D[p];e:switch(p){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(D=!D.disabled)||(f=f.type,D=!(f==="button"||f==="input"||f==="select"||f==="textarea")),f=!D;break e;default:f=!1}if(f)return null;if(O&&typeof O!="function")throw Error(r(231,p,typeof O));return O}var Qo=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),Ep=!1;if(Qo)try{var fh={};Object.defineProperty(fh,"passive",{get:function(){Ep=!0}}),window.addEventListener("test",fh,fh),window.removeEventListener("test",fh,fh)}catch{Ep=!1}var yc=null,dh=null,wr=null;function Bn(){if(wr)return wr;var f,p=dh,O=p.length,D,Q="value"in yc?yc.value:yc.textContent,Y=Q.length;for(f=0;f<O&&p[f]===Q[f];f++);var ce=O-f;for(D=1;D<=ce&&p[O-D]===Q[Y-D];D++);return wr=Q.slice(f,1<D?1-D:void 0)}function bc(f){var p=f.keyCode;return"charCode"in f?(f=f.charCode,f===0&&p===13&&(f=13)):f=p,f===10&&(f=13),32<=f||f===13?f:0}function zo(){return!0}function Oc(){return!1}function ea(f){function p(O,D,Q,Y,ce){this._reactName=O,this._targetInst=Q,this.type=D,this.nativeEvent=Y,this.target=ce,this.currentTarget=null;for(var Ee in f)f.hasOwnProperty(Ee)&&(O=f[Ee],this[Ee]=O?O(Y):Y[Ee]);return this.isDefaultPrevented=(Y.defaultPrevented!=null?Y.defaultPrevented:Y.returnValue===!1)?zo:Oc,this.isPropagationStopped=Oc,this}return d(p.prototype,{preventDefault:function(){this.defaultPrevented=!0;var O=this.nativeEvent;O&&(O.preventDefault?O.preventDefault():typeof O.returnValue!="unknown"&&(O.returnValue=!1),this.isDefaultPrevented=zo)},stopPropagation:function(){var O=this.nativeEvent;O&&(O.stopPropagation?O.stopPropagation():typeof O.cancelBubble!="unknown"&&(O.cancelBubble=!0),this.isPropagationStopped=zo)},persist:function(){},isPersistent:zo}),p}var Rs={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(f){return f.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},rd=ea(Rs),kl=d({},Rs,{view:0,detail:0}),id=ea(kl),ta,As,Pl,ad=d({},kl,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:Ts,button:0,buttons:0,relatedTarget:function(f){return f.relatedTarget===void 0?f.fromElement===f.srcElement?f.toElement:f.fromElement:f.relatedTarget},movementX:function(f){return"movementX"in f?f.movementX:(f!==Pl&&(Pl&&f.type==="mousemove"?(ta=f.screenX-Pl.screenX,As=f.screenY-Pl.screenY):As=ta=0,Pl=f),ta)},movementY:function(f){return"movementY"in f?f.movementY:As}}),Dp=ea(ad),ri=d({},ad,{dataTransfer:0}),Y0=ea(ri),G0=d({},kl,{relatedTarget:0}),ud=ea(G0),K0=d({},Rs,{animationName:0,elapsedTime:0,pseudoElement:0}),xc=ea(K0),ld=d({},Rs,{clipboardData:function(f){return"clipboardData"in f?f.clipboardData:window.clipboardData}}),fa=ea(ld),od=d({},Rs,{data:0}),La=ea(od),_g={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},$p={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},qo={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function hh(f){var p=this.nativeEvent;return p.getModifierState?p.getModifierState(f):(f=qo[f])?!!p[f]:!1}function Ts(){return hh}var vi=d({},kl,{key:function(f){if(f.key){var p=_g[f.key]||f.key;if(p!=="Unidentified")return p}return f.type==="keypress"?(f=bc(f),f===13?"Enter":String.fromCharCode(f)):f.type==="keydown"||f.type==="keyup"?$p[f.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:Ts,charCode:function(f){return f.type==="keypress"?bc(f):0},keyCode:function(f){return f.type==="keydown"||f.type==="keyup"?f.keyCode:0},which:function(f){return f.type==="keypress"?bc(f):f.type==="keydown"||f.type==="keyup"?f.keyCode:0}}),Vo=ea(vi),Cp=d({},ad,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),wp=ea(Cp),Rp=d({},kl,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:Ts}),ks=ea(Rp),Ap=d({},Rs,{propertyName:0,elapsedTime:0,pseudoElement:0}),Dy=ea(Ap),W0=d({},ad,{deltaX:function(f){return"deltaX"in f?f.deltaX:"wheelDeltaX"in f?-f.wheelDeltaX:0},deltaY:function(f){return"deltaY"in f?f.deltaY:"wheelDeltaY"in f?-f.wheelDeltaY:"wheelDelta"in f?-f.wheelDelta:0},deltaZ:0,deltaMode:0}),oo=ea(W0),Xu=d({},Rs,{newState:0,oldState:0}),J0=ea(Xu),ph=[9,13,27,32],Sc=Qo&&"CompositionEvent"in window,Uo=null;Qo&&"documentMode"in document&&(Uo=document.documentMode);var Ps=Qo&&"TextEvent"in window&&!Uo,Ba=Qo&&(!Sc||Uo&&8<Uo&&11>=Uo),mh=" ",gh=!1;function sd(f,p){switch(f){case"keyup":return ph.indexOf(p.keyCode)!==-1;case"keydown":return p.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function cd(f){return f=f.detail,typeof f=="object"&&"data"in f?f.data:null}var Ms=!1;function fu(f,p){switch(f){case"compositionend":return cd(p);case"keypress":return p.which!==32?null:(gh=!0,mh);case"textInput":return f=p.data,f===mh&&gh?null:f;default:return null}}function Tp(f,p){if(Ms)return f==="compositionend"||!Sc&&sd(f,p)?(f=Bn(),wr=dh=yc=null,Ms=!1,f):null;switch(f){case"paste":return null;case"keypress":if(!(p.ctrlKey||p.altKey||p.metaKey)||p.ctrlKey&&p.altKey){if(p.char&&1<p.char.length)return p.char;if(p.which)return String.fromCharCode(p.which)}return null;case"compositionend":return Ba&&p.locale!=="ko"?null:p.data;default:return null}}var Xa={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function kp(f){var p=f&&f.nodeName&&f.nodeName.toLowerCase();return p==="input"?!!Xa[f.type]:p==="textarea"}function fd(f,p,O,D){Cs?vc?vc.push(D):vc=[D]:Cs=D,p=i1(p,"onChange"),0<p.length&&(O=new rd("onChange","change",null,O,D),f.push({event:O,listeners:p}))}var yf=null,dd=null;function Yu(f){XS(f,0)}function so(f){var p=ca(f);if(Lo(p))return f}function em(f,p){if(f==="change")return p}var du=!1;if(Qo){var bf;if(Qo){var Sr="oninput"in document;if(!Sr){var vh=document.createElement("div");vh.setAttribute("oninput","return;"),Sr=typeof vh.oninput=="function"}bf=Sr}else bf=!1;du=bf&&(!document.documentMode||9<document.documentMode)}function Pp(){yf&&(yf.detachEvent("onpropertychange",co),dd=yf=null)}function co(f){if(f.propertyName==="value"&&so(dd)){var p=[];fd(p,dd,f,ch(f)),_p(Yu,p)}}function Kn(f,p,O){f==="focusin"?(Pp(),yf=p,dd=O,yf.attachEvent("onpropertychange",co)):f==="focusout"&&Pp()}function yl(f){if(f==="selectionchange"||f==="keyup"||f==="keydown")return so(dd)}function Eg(f,p){if(f==="click")return so(p)}function Mi(f,p){if(f==="input"||f==="change")return so(p)}function hu(f,p){return f===p&&(f!==0||1/f===1/p)||f!==f&&p!==p}var fr=typeof Object.is=="function"?Object.is:hu;function Of(f,p){if(fr(f,p))return!0;if(typeof f!="object"||f===null||typeof p!="object"||p===null)return!1;var O=Object.keys(f),D=Object.keys(p);if(O.length!==D.length)return!1;for(D=0;D<O.length;D++){var Q=O[D];if(!tt.call(p,Q)||!fr(f[Q],p[Q]))return!1}return!0}function tm(f){for(;f&&f.firstChild;)f=f.firstChild;return f}function nm(f,p){var O=tm(f);f=0;for(var D;O;){if(O.nodeType===3){if(D=f+O.textContent.length,f<=p&&D>=p)return{node:O,offset:p-f};f=D}e:{for(;O;){if(O.nextSibling){O=O.nextSibling;break e}O=O.parentNode}O=void 0}O=tm(O)}}function vr(f,p){return f&&p?f===p?!0:f&&f.nodeType===3?!1:p&&p.nodeType===3?vr(f,p.parentNode):"contains"in f?f.contains(p):f.compareDocumentPosition?!!(f.compareDocumentPosition(p)&16):!1:!1}function rm(f){f=f!=null&&f.ownerDocument!=null&&f.ownerDocument.defaultView!=null?f.ownerDocument.defaultView:window;for(var p=Tl(f.document);p instanceof f.HTMLIFrameElement;){try{var O=typeof p.contentWindow.location.href=="string"}catch{O=!1}if(O)f=p.contentWindow;else break;p=Tl(f.document)}return p}function xf(f){var p=f&&f.nodeName&&f.nodeName.toLowerCase();return p&&(p==="input"&&(f.type==="text"||f.type==="search"||f.type==="tel"||f.type==="url"||f.type==="password")||p==="textarea"||f.contentEditable==="true")}var _c=Qo&&"documentMode"in document&&11>=document.documentMode,Xe=null,pt=null,rt=null,Bt=!1;function Dn(f,p,O){var D=O.window===O?O.document:O.nodeType===9?O:O.ownerDocument;Bt||Xe==null||Xe!==Tl(D)||(D=Xe,"selectionStart"in D&&xf(D)?D={start:D.selectionStart,end:D.selectionEnd}:(D=(D.ownerDocument&&D.ownerDocument.defaultView||window).getSelection(),D={anchorNode:D.anchorNode,anchorOffset:D.anchorOffset,focusNode:D.focusNode,focusOffset:D.focusOffset}),rt&&Of(rt,D)||(rt=D,D=i1(pt,"onSelect"),0<D.length&&(p=new rd("onSelect","select",null,p,O),f.push({event:p,listeners:D}),p.target=Xe)))}function rr(f,p){var O={};return O[f.toLowerCase()]=p.toLowerCase(),O["Webkit"+f]="webkit"+p,O["Moz"+f]="moz"+p,O}var Fi={animationend:rr("Animation","AnimationEnd"),animationiteration:rr("Animation","AnimationIteration"),animationstart:rr("Animation","AnimationStart"),transitionrun:rr("Transition","TransitionRun"),transitionstart:rr("Transition","TransitionStart"),transitioncancel:rr("Transition","TransitionCancel"),transitionend:rr("Transition","TransitionEnd")},Nr={},Ya={};Qo&&(Ya=document.createElement("div").style,"AnimationEvent"in window||(delete Fi.animationend.animation,delete Fi.animationiteration.animation,delete Fi.animationstart.animation),"TransitionEvent"in window||delete Fi.transitionend.transition);function Ec(f){if(Nr[f])return Nr[f];if(!Fi[f])return f;var p=Fi[f],O;for(O in p)if(p.hasOwnProperty(O)&&O in Ya)return Nr[f]=p[O];return f}var _i=Ec("animationend"),hd=Ec("animationiteration"),Ml=Ec("animationstart"),fo=Ec("transitionrun"),ho=Ec("transitionstart"),Sf=Ec("transitioncancel"),_r=Ec("transitionend"),jo=new Map,yh="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");yh.push("scrollEnd");function da(f,p){jo.set(f,p),Xn(p,[f])}var Zo=typeof reportError=="function"?reportError:function(f){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var p=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof f=="object"&&f!==null&&typeof f.message=="string"?String(f.message):String(f),error:f});if(!window.dispatchEvent(p))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",f);return}console.error(f)},Ca=[],po=0,Fs=0;function Ga(){for(var f=po,p=Fs=po=0;p<f;){var O=Ca[p];Ca[p++]=null;var D=Ca[p];Ca[p++]=null;var Q=Ca[p];Ca[p++]=null;var Y=Ca[p];if(Ca[p++]=null,D!==null&&Q!==null){var ce=D.pending;ce===null?Q.next=Q:(Q.next=ce.next,ce.next=Q),D.pending=Q}Y!==0&&$c(O,Q,Y)}}function Gu(f,p,O,D){Ca[po++]=f,Ca[po++]=p,Ca[po++]=O,Ca[po++]=D,Fs|=D,f.lanes|=D,f=f.alternate,f!==null&&(f.lanes|=D)}function Dc(f,p,O,D){return Gu(f,p,O,D),Cc(f)}function Ku(f,p){return Gu(f,null,null,p),Cc(f)}function $c(f,p,O){f.lanes|=O;var D=f.alternate;D!==null&&(D.lanes|=O);for(var Q=!1,Y=f.return;Y!==null;)Y.childLanes|=O,D=Y.alternate,D!==null&&(D.childLanes|=O),Y.tag===22&&(f=Y.stateNode,f===null||f._visibility&1||(Q=!0)),f=Y,Y=Y.return;return f.tag===3?(Y=f.stateNode,Q&&p!==null&&(Q=31-Fe(O),f=Y.hiddenUpdates,D=f[Q],D===null?f[Q]=[p]:D.push(p),p.lane=O|536870912),Y):null}function Cc(f){if(50<Lh)throw Lh=0,Bh=null,Error(r(185));for(var p=f.return;p!==null;)f=p,p=f.return;return f.tag===3?f.stateNode:null}var pu={};function pd(f,p,O,D){this.tag=f,this.key=O,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=p,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=D,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function na(f,p,O,D){return new pd(f,p,O,D)}function Xi(f){return f=f.prototype,!(!f||!f.isReactComponent)}function Wu(f,p){var O=f.alternate;return O===null?(O=na(f.tag,p,f.key,f.mode),O.elementType=f.elementType,O.type=f.type,O.stateNode=f.stateNode,O.alternate=f,f.alternate=O):(O.pendingProps=p,O.type=f.type,O.flags=0,O.subtreeFlags=0,O.deletions=null),O.flags=f.flags&65011712,O.childLanes=f.childLanes,O.lanes=f.lanes,O.child=f.child,O.memoizedProps=f.memoizedProps,O.memoizedState=f.memoizedState,O.updateQueue=f.updateQueue,p=f.dependencies,O.dependencies=p===null?null:{lanes:p.lanes,firstContext:p.firstContext},O.sibling=f.sibling,O.index=f.index,O.ref=f.ref,O.refCleanup=f.refCleanup,O}function mu(f,p){f.flags&=65011714;var O=f.alternate;return O===null?(f.childLanes=0,f.lanes=p,f.child=null,f.subtreeFlags=0,f.memoizedProps=null,f.memoizedState=null,f.updateQueue=null,f.dependencies=null,f.stateNode=null):(f.childLanes=O.childLanes,f.lanes=O.lanes,f.child=O.child,f.subtreeFlags=0,f.deletions=null,f.memoizedProps=O.memoizedProps,f.memoizedState=O.memoizedState,f.updateQueue=O.updateQueue,f.type=O.type,p=O.dependencies,f.dependencies=p===null?null:{lanes:p.lanes,firstContext:p.firstContext}),f}function bh(f,p,O,D,Q,Y){var ce=0;if(D=f,typeof f=="function")Xi(f)&&(ce=1);else if(typeof f=="string")ce=M5(f,O,ne.current)?26:f==="html"||f==="head"||f==="body"?27:5;else e:switch(f){case L:return f=na(31,O,p,Q),f.elementType=L,f.lanes=Y,f;case v:return Fl(O.children,Q,Y,p);case _:ce=8,Q|=24;break;case S:return f=na(12,O,p,Q|2),f.elementType=S,f.lanes=Y,f;case R:return f=na(13,O,p,Q),f.elementType=R,f.lanes=Y,f;case $:return f=na(19,O,p,Q),f.elementType=$,f.lanes=Y,f;default:if(typeof f=="object"&&f!==null)switch(f.$$typeof){case C:ce=10;break e;case E:ce=9;break e;case T:ce=11;break e;case k:ce=14;break e;case F:ce=16,D=null;break e}ce=29,O=Error(r(130,f===null?"null":typeof f,"")),D=null}return p=na(ce,O,p,Q),p.elementType=f,p.type=D,p.lanes=Y,p}function Fl(f,p,O,D){return f=na(7,f,D,p),f.lanes=O,f}function _f(f,p,O){return f=na(6,f,null,p),f.lanes=O,f}function Oh(f){var p=na(18,null,null,0);return p.stateNode=f,p}function gu(f,p,O){return p=na(4,f.children!==null?f.children:[],f.key,p),p.lanes=O,p.stateNode={containerInfo:f.containerInfo,pendingChildren:null,implementation:f.implementation},p}var Mp=new WeakMap;function Tu(f,p){if(typeof f=="object"&&f!==null){var O=Mp.get(f);return O!==void 0?O:(p={value:f,source:p,stack:et(p)},Mp.set(f,p),p)}return{value:f,source:p,stack:et(p)}}var Nl=[],wc=0,Ni=null,Ei=0,ku=[],pn=0,Pu=null,Ho=1,ue="";function I(f,p){Nl[wc++]=Ei,Nl[wc++]=Ni,Ni=f,Ei=p}function re(f,p,O){ku[pn++]=Ho,ku[pn++]=ue,ku[pn++]=Pu,Pu=f;var D=Ho;f=ue;var Q=32-Fe(D)-1;D&=~(1<<Q),O+=1;var Y=32-Fe(p)+Q;if(30<Y){var ce=Q-Q%5;Y=(D&(1<<ce)-1).toString(32),D>>=ce,Q-=ce,Ho=1<<32-Fe(p)+Q|O<<Q|D,ue=Y+f}else Ho=1<<Y|O<<Q|D,ue=f}function fe(f){f.return!==null&&(I(f,1),re(f,1,0))}function xe(f){for(;f===Ni;)Ni=Nl[--wc],Nl[wc]=null,Ei=Nl[--wc],Nl[wc]=null;for(;f===Pu;)Pu=ku[--pn],ku[pn]=null,ue=ku[--pn],ku[pn]=null,Ho=ku[--pn],ku[pn]=null}function Te(f,p){ku[pn++]=Ho,ku[pn++]=ue,ku[pn++]=Pu,Ho=p.id,ue=p.overflow,Pu=f}var Qe=null,Be=null,je=!1,Ct=null,Kt=!1,Qn=Error(r(519));function cn(f){var p=Error(r(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw Il(Tu(p,f)),Qn}function vn(f){var p=f.stateNode,O=f.type,D=f.memoizedProps;switch(p[Rt]=f,p[sn]=D,O){case"dialog":Dr("cancel",p),Dr("close",p);break;case"iframe":case"object":case"embed":Dr("load",p);break;case"video":case"audio":for(O=0;O<r1.length;O++)Dr(r1[O],p);break;case"source":Dr("error",p);break;case"img":case"image":case"link":Dr("error",p),Dr("load",p);break;case"details":Dr("toggle",p);break;case"input":Dr("invalid",p),Es(p,D.value,D.defaultValue,D.checked,D.defaultChecked,D.type,D.name,!0);break;case"select":Dr("invalid",p);break;case"textarea":Dr("invalid",p),Bo(p,D.value,D.defaultValue,D.children)}O=D.children,typeof O!="string"&&typeof O!="number"&&typeof O!="bigint"||p.textContent===""+O||D.suppressHydrationWarning===!0||KS(p.textContent,O)?(D.popover!=null&&(Dr("beforetoggle",p),Dr("toggle",p)),D.onScroll!=null&&Dr("scroll",p),D.onScrollEnd!=null&&Dr("scrollend",p),D.onClick!=null&&(p.onclick=lo),p=!0):p=!1,p||cn(f,!0)}function Di(f){for(Qe=f.return;Qe;)switch(Qe.tag){case 5:case 31:case 13:Kt=!1;return;case 27:case 3:Kt=!0;return;default:Qe=Qe.return}}function Qa(f){if(f!==Qe)return!1;if(!je)return Di(f),je=!0,!1;var p=f.tag,O;if((O=p!==3&&p!==27)&&((O=p===5)&&(O=f.type,O=!(O!=="form"&&O!=="button")||Kp(f.type,f.memoizedProps)),O=!O),O&&Be&&cn(f),Di(f),p===13){if(f=f.memoizedState,f=f!==null?f.dehydrated:null,!f)throw Error(r(317));Be=n_(f)}else if(p===31){if(f=f.memoizedState,f=f!==null?f.dehydrated:null,!f)throw Error(r(317));Be=n_(f)}else p===27?(p=Be,qn(f.type)?(f=F4,F4=null,Be=f):Be=p):Be=Qe?Uc(f.stateNode.nextSibling):null;return!0}function Se(){Be=Qe=null,je=!1}function bl(){var f=Ct;return f!==null&&(sl===null?sl=f:sl.push.apply(sl,f),Ct=null),f}function Il(f){Ct===null?Ct=[f]:Ct.push(f)}var Mu=K(null),zn=null,Ka=null;function Ns(f,p,O){B(Mu,p._currentValue),p._currentValue=O}function Ll(f){f._currentValue=Mu.current,X(Mu)}function Fu(f,p,O){for(;f!==null;){var D=f.alternate;if((f.childLanes&p)!==p?(f.childLanes|=p,D!==null&&(D.childLanes|=p)):D!==null&&(D.childLanes&p)!==p&&(D.childLanes|=p),f===O)break;f=f.return}}function Rc(f,p,O,D){var Q=f.child;for(Q!==null&&(Q.return=f);Q!==null;){var Y=Q.dependencies;if(Y!==null){var ce=Q.child;Y=Y.firstContext;e:for(;Y!==null;){var Ee=Y;Y=Q;for(var Le=0;Le<p.length;Le++)if(Ee.context===p[Le]){Y.lanes|=O,Ee=Y.alternate,Ee!==null&&(Ee.lanes|=O),Fu(Y.return,O,f),D||(ce=null);break e}Y=Ee.next}}else if(Q.tag===18){if(ce=Q.return,ce===null)throw Error(r(341));ce.lanes|=O,Y=ce.alternate,Y!==null&&(Y.lanes|=O),Fu(ce,O,f),ce=null}else ce=Q.child;if(ce!==null)ce.return=Q;else for(ce=Q;ce!==null;){if(ce===f){ce=null;break}if(Q=ce.sibling,Q!==null){Q.return=ce.return,ce=Q;break}ce=ce.return}Q=ce}}function Bl(f,p,O,D){f=null;for(var Q=p,Y=!1;Q!==null;){if(!Y){if((Q.flags&524288)!==0)Y=!0;else if((Q.flags&262144)!==0)break}if(Q.tag===10){var ce=Q.alternate;if(ce===null)throw Error(r(387));if(ce=ce.memoizedProps,ce!==null){var Ee=Q.type;fr(Q.pendingProps.value,ce.value)||(f!==null?f.push(Ee):f=[Ee])}}else if(Q===de.current){if(ce=Q.alternate,ce===null)throw Error(r(387));ce.memoizedState.memoizedState!==Q.memoizedState.memoizedState&&(f!==null?f.push(sv):f=[sv])}Q=Q.return}f!==null&&Rc(p,f,O,D),p.flags|=262144}function md(f){for(f=f.firstContext;f!==null;){if(!fr(f.context._currentValue,f.memoizedValue))return!0;f=f.next}return!1}function xh(f){zn=f,Ka=null,f=f.dependencies,f!==null&&(f.firstContext=null)}function vu(f){return $y(zn,f)}function mo(f,p){return zn===null&&xh(f),$y(f,p)}function $y(f,p){var O=p._currentValue;if(p={context:p,memoizedValue:O,next:null},Ka===null){if(f===null)throw Error(r(308));Ka=p,f.dependencies={lanes:0,firstContext:p},f.flags|=524288}else Ka=Ka.next=p;return O}var Nb=typeof AbortController<"u"?AbortController:function(){var f=[],p=this.signal={aborted:!1,addEventListener:function(O,D){f.push(D)}};this.abort=function(){p.aborted=!0,f.forEach(function(O){return O()})}},Ib=e.unstable_scheduleCallback,Cy=e.unstable_NormalPriority,yn={$$typeof:C,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Is(){return{controller:new Nb,data:new Map,refCount:0}}function Nu(f){f.refCount--,f.refCount===0&&Ib(Cy,function(){f.controller.abort()})}var Sh=null,wy=0,Ef=0,Ls=null;function Xo(f,p){if(Sh===null){var O=Sh=[];wy=0,Ef=Gs(),Ls={status:"pending",value:void 0,then:function(D){O.push(D)}}}return wy++,p.then(Ry,Ry),p}function Ry(){if(--wy===0&&Sh!==null){Ls!==null&&(Ls.status="fulfilled");var f=Sh;Sh=null,Ef=0,Ls=null;for(var p=0;p<f.length;p++)(0,f[p])()}}function Ay(f,p){var O=[],D={status:"pending",value:null,reason:null,then:function(Q){O.push(Q)}};return f.then(function(){D.status="fulfilled",D.value=p;for(var Q=0;Q<O.length;Q++)(0,O[Q])(p)},function(Q){for(D.status="rejected",D.reason=Q,Q=0;Q<O.length;Q++)(0,O[Q])(void 0)}),D}var Yo=G.S;G.S=function(f,p){Hp=Ze(),typeof p=="object"&&p!==null&&typeof p.then=="function"&&Xo(f,p),Yo!==null&&Yo(f,p)};var gd=K(null);function Ac(){var f=gd.current;return f!==null?f:ii.pooledCache}function Fp(f,p){p===null?B(gd,gd.current):B(gd,p.pool)}function Dg(){var f=Ac();return f===null?null:{parent:yn._currentValue,pool:f}}var vd=Error(r(460)),Np=Error(r(474)),Go=Error(r(542)),im={then:function(){}};function Lb(f){return f=f.status,f==="fulfilled"||f==="rejected"}function am(f,p,O){switch(O=f[O],O===void 0?f.push(p):O!==p&&(p.then(lo,lo),p=O),p.status){case"fulfilled":return p.value;case"rejected":throw f=p.reason,Cg(f),f;default:if(typeof p.status=="string")p.then(lo,lo);else{if(f=ii,f!==null&&100<f.shellSuspendCounter)throw Error(r(482));f=p,f.status="pending",f.then(function(D){if(p.status==="pending"){var Q=p;Q.status="fulfilled",Q.value=D}},function(D){if(p.status==="pending"){var Q=p;Q.status="rejected",Q.reason=D}})}switch(p.status){case"fulfilled":return p.value;case"rejected":throw f=p.reason,Cg(f),f}throw _n=p,vd}}function Bs(f){try{var p=f._init;return p(f._payload)}catch(O){throw O!==null&&typeof O=="object"&&typeof O.then=="function"?(_n=O,vd):O}}var _n=null;function $g(){if(_n===null)throw Error(r(459));var f=_n;return _n=null,f}function Cg(f){if(f===vd||f===Go)throw Error(r(483))}var yd=null,Ju=0;function Ip(f){var p=Ju;return Ju+=1,yd===null&&(yd=[]),am(yd,f,p)}function Qs(f,p){p=p.props.ref,f.ref=p!==void 0?p:null}function el(f,p){throw p.$$typeof===h?Error(r(525)):(f=Object.prototype.toString.call(p),Error(r(31,f==="[object Object]"?"object with keys {"+Object.keys(p).join(", ")+"}":f)))}function Lp(f){function p(Ke,Ve){if(f){var it=Ke.deletions;it===null?(Ke.deletions=[Ve],Ke.flags|=16):it.push(Ve)}}function O(Ke,Ve){if(!f)return null;for(;Ve!==null;)p(Ke,Ve),Ve=Ve.sibling;return null}function D(Ke){for(var Ve=new Map;Ke!==null;)Ke.key!==null?Ve.set(Ke.key,Ke):Ve.set(Ke.index,Ke),Ke=Ke.sibling;return Ve}function Q(Ke,Ve){return Ke=Wu(Ke,Ve),Ke.index=0,Ke.sibling=null,Ke}function Y(Ke,Ve,it){return Ke.index=it,f?(it=Ke.alternate,it!==null?(it=it.index,it<Ve?(Ke.flags|=67108866,Ve):it):(Ke.flags|=67108866,Ve)):(Ke.flags|=1048576,Ve)}function ce(Ke){return f&&Ke.alternate===null&&(Ke.flags|=67108866),Ke}function Ee(Ke,Ve,it,yt){return Ve===null||Ve.tag!==6?(Ve=_f(it,Ke.mode,yt),Ve.return=Ke,Ve):(Ve=Q(Ve,it),Ve.return=Ke,Ve)}function Le(Ke,Ve,it,yt){var En=it.type;return En===v?mt(Ke,Ve,it.props.children,yt,it.key):Ve!==null&&(Ve.elementType===En||typeof En=="object"&&En!==null&&En.$$typeof===F&&Bs(En)===Ve.type)?(Ve=Q(Ve,it.props),Qs(Ve,it),Ve.return=Ke,Ve):(Ve=bh(it.type,it.key,it.props,null,Ke.mode,yt),Qs(Ve,it),Ve.return=Ke,Ve)}function at(Ke,Ve,it,yt){return Ve===null||Ve.tag!==4||Ve.stateNode.containerInfo!==it.containerInfo||Ve.stateNode.implementation!==it.implementation?(Ve=gu(it,Ke.mode,yt),Ve.return=Ke,Ve):(Ve=Q(Ve,it.children||[]),Ve.return=Ke,Ve)}function mt(Ke,Ve,it,yt,En){return Ve===null||Ve.tag!==7?(Ve=Fl(it,Ke.mode,yt,En),Ve.return=Ke,Ve):(Ve=Q(Ve,it),Ve.return=Ke,Ve)}function xt(Ke,Ve,it){if(typeof Ve=="string"&&Ve!==""||typeof Ve=="number"||typeof Ve=="bigint")return Ve=_f(""+Ve,Ke.mode,it),Ve.return=Ke,Ve;if(typeof Ve=="object"&&Ve!==null){switch(Ve.$$typeof){case m:return it=bh(Ve.type,Ve.key,Ve.props,null,Ke.mode,it),Qs(it,Ve),it.return=Ke,it;case y:return Ve=gu(Ve,Ke.mode,it),Ve.return=Ke,Ve;case F:return Ve=Bs(Ve),xt(Ke,Ve,it)}if(W(Ve)||q(Ve))return Ve=Fl(Ve,Ke.mode,it,null),Ve.return=Ke,Ve;if(typeof Ve.then=="function")return xt(Ke,Ip(Ve),it);if(Ve.$$typeof===C)return xt(Ke,mo(Ke,Ve),it);el(Ke,Ve)}return null}function lt(Ke,Ve,it,yt){var En=Ve!==null?Ve.key:null;if(typeof it=="string"&&it!==""||typeof it=="number"||typeof it=="bigint")return En!==null?null:Ee(Ke,Ve,""+it,yt);if(typeof it=="object"&&it!==null){switch(it.$$typeof){case m:return it.key===En?Le(Ke,Ve,it,yt):null;case y:return it.key===En?at(Ke,Ve,it,yt):null;case F:return it=Bs(it),lt(Ke,Ve,it,yt)}if(W(it)||q(it))return En!==null?null:mt(Ke,Ve,it,yt,null);if(typeof it.then=="function")return lt(Ke,Ve,Ip(it),yt);if(it.$$typeof===C)return lt(Ke,Ve,mo(Ke,it),yt);el(Ke,it)}return null}function ft(Ke,Ve,it,yt,En){if(typeof yt=="string"&&yt!==""||typeof yt=="number"||typeof yt=="bigint")return Ke=Ke.get(it)||null,Ee(Ve,Ke,""+yt,En);if(typeof yt=="object"&&yt!==null){switch(yt.$$typeof){case m:return Ke=Ke.get(yt.key===null?it:yt.key)||null,Le(Ve,Ke,yt,En);case y:return Ke=Ke.get(yt.key===null?it:yt.key)||null,at(Ve,Ke,yt,En);case F:return yt=Bs(yt),ft(Ke,Ve,it,yt,En)}if(W(yt)||q(yt))return Ke=Ke.get(it)||null,mt(Ve,Ke,yt,En,null);if(typeof yt.then=="function")return ft(Ke,Ve,it,Ip(yt),En);if(yt.$$typeof===C)return ft(Ke,Ve,it,mo(Ve,yt),En);el(Ve,yt)}return null}function fn(Ke,Ve,it,yt){for(var En=null,ai=null,mn=Ve,or=Ve=0,Pr=null;mn!==null&&or<it.length;or++){mn.index>or?(Pr=mn,mn=null):Pr=mn.sibling;var ui=lt(Ke,mn,it[or],yt);if(ui===null){mn===null&&(mn=Pr);break}f&&mn&&ui.alternate===null&&p(Ke,mn),Ve=Y(ui,Ve,or),ai===null?En=ui:ai.sibling=ui,ai=ui,mn=Pr}if(or===it.length)return O(Ke,mn),je&&I(Ke,or),En;if(mn===null){for(;or<it.length;or++)mn=xt(Ke,it[or],yt),mn!==null&&(Ve=Y(mn,Ve,or),ai===null?En=mn:ai.sibling=mn,ai=mn);return je&&I(Ke,or),En}for(mn=D(mn);or<it.length;or++)Pr=ft(mn,Ke,or,it[or],yt),Pr!==null&&(f&&Pr.alternate!==null&&mn.delete(Pr.key===null?or:Pr.key),Ve=Y(Pr,Ve,or),ai===null?En=Pr:ai.sibling=Pr,ai=Pr);return f&&mn.forEach(function(r0){return p(Ke,r0)}),je&&I(Ke,or),En}function An(Ke,Ve,it,yt){if(it==null)throw Error(r(151));for(var En=null,ai=null,mn=Ve,or=Ve=0,Pr=null,ui=it.next();mn!==null&&!ui.done;or++,ui=it.next()){mn.index>or?(Pr=mn,mn=null):Pr=mn.sibling;var r0=lt(Ke,mn,ui.value,yt);if(r0===null){mn===null&&(mn=Pr);break}f&&mn&&r0.alternate===null&&p(Ke,mn),Ve=Y(r0,Ve,or),ai===null?En=r0:ai.sibling=r0,ai=r0,mn=Pr}if(ui.done)return O(Ke,mn),je&&I(Ke,or),En;if(mn===null){for(;!ui.done;or++,ui=it.next())ui=xt(Ke,ui.value,yt),ui!==null&&(Ve=Y(ui,Ve,or),ai===null?En=ui:ai.sibling=ui,ai=ui);return je&&I(Ke,or),En}for(mn=D(mn);!ui.done;or++,ui=it.next())ui=ft(mn,Ke,or,ui.value,yt),ui!==null&&(f&&ui.alternate!==null&&mn.delete(ui.key===null?or:ui.key),Ve=Y(ui,Ve,or),ai===null?En=ui:ai.sibling=ui,ai=ui);return f&&mn.forEach(function(q5){return p(Ke,q5)}),je&&I(Ke,or),En}function Li(Ke,Ve,it,yt){if(typeof it=="object"&&it!==null&&it.type===v&&it.key===null&&(it=it.props.children),typeof it=="object"&&it!==null){switch(it.$$typeof){case m:e:{for(var En=it.key;Ve!==null;){if(Ve.key===En){if(En=it.type,En===v){if(Ve.tag===7){O(Ke,Ve.sibling),yt=Q(Ve,it.props.children),yt.return=Ke,Ke=yt;break e}}else if(Ve.elementType===En||typeof En=="object"&&En!==null&&En.$$typeof===F&&Bs(En)===Ve.type){O(Ke,Ve.sibling),yt=Q(Ve,it.props),Qs(yt,it),yt.return=Ke,Ke=yt;break e}O(Ke,Ve);break}else p(Ke,Ve);Ve=Ve.sibling}it.type===v?(yt=Fl(it.props.children,Ke.mode,yt,it.key),yt.return=Ke,Ke=yt):(yt=bh(it.type,it.key,it.props,null,Ke.mode,yt),Qs(yt,it),yt.return=Ke,Ke=yt)}return ce(Ke);case y:e:{for(En=it.key;Ve!==null;){if(Ve.key===En)if(Ve.tag===4&&Ve.stateNode.containerInfo===it.containerInfo&&Ve.stateNode.implementation===it.implementation){O(Ke,Ve.sibling),yt=Q(Ve,it.children||[]),yt.return=Ke,Ke=yt;break e}else{O(Ke,Ve);break}else p(Ke,Ve);Ve=Ve.sibling}yt=gu(it,Ke.mode,yt),yt.return=Ke,Ke=yt}return ce(Ke);case F:return it=Bs(it),Li(Ke,Ve,it,yt)}if(W(it))return fn(Ke,Ve,it,yt);if(q(it)){if(En=q(it),typeof En!="function")throw Error(r(150));return it=En.call(it),An(Ke,Ve,it,yt)}if(typeof it.then=="function")return Li(Ke,Ve,Ip(it),yt);if(it.$$typeof===C)return Li(Ke,Ve,mo(Ke,it),yt);el(Ke,it)}return typeof it=="string"&&it!==""||typeof it=="number"||typeof it=="bigint"?(it=""+it,Ve!==null&&Ve.tag===6?(O(Ke,Ve.sibling),yt=Q(Ve,it),yt.return=Ke,Ke=yt):(O(Ke,Ve),yt=_f(it,Ke.mode,yt),yt.return=Ke,Ke=yt),ce(Ke)):O(Ke,Ve)}return function(Ke,Ve,it,yt){try{Ju=0;var En=Li(Ke,Ve,it,yt);return yd=null,En}catch(mn){if(mn===vd||mn===Go)throw mn;var ai=na(29,mn,null,Ke.mode);return ai.lanes=yt,ai.return=Ke,ai}finally{}}}var bd=Lp(!0),Ty=Lp(!1),Ko=!1;function Tc(f){f.updateQueue={baseState:f.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function wg(f,p){f=f.updateQueue,p.updateQueue===f&&(p.updateQueue={baseState:f.baseState,firstBaseUpdate:f.firstBaseUpdate,lastBaseUpdate:f.lastBaseUpdate,shared:f.shared,callbacks:null})}function kc(f){return{lane:f,tag:0,payload:null,callback:null,next:null}}function Wo(f,p,O){var D=f.updateQueue;if(D===null)return null;if(D=D.shared,(Ar&2)!==0){var Q=D.pending;return Q===null?p.next=p:(p.next=Q.next,Q.next=p),D.pending=p,p=Cc(f),$c(f,null,O),p}return Gu(f,D,p,O),Cc(f)}function Od(f,p,O){if(p=p.updateQueue,p!==null&&(p=p.shared,(O&4194048)!==0)){var D=p.lanes;D&=f.pendingLanes,O|=D,p.lanes=O,$t(f,O)}}function um(f,p){var O=f.updateQueue,D=f.alternate;if(D!==null&&(D=D.updateQueue,O===D)){var Q=null,Y=null;if(O=O.firstBaseUpdate,O!==null){do{var ce={lane:O.lane,tag:O.tag,payload:O.payload,callback:null,next:null};Y===null?Q=Y=ce:Y=Y.next=ce,O=O.next}while(O!==null);Y===null?Q=Y=p:Y=Y.next=p}else Q=Y=p;O={baseState:D.baseState,firstBaseUpdate:Q,lastBaseUpdate:Y,shared:D.shared,callbacks:D.callbacks},f.updateQueue=O;return}f=O.lastBaseUpdate,f===null?O.firstBaseUpdate=p:f.next=p,O.lastBaseUpdate=p}var Wa=!1;function _h(){if(Wa){var f=Ls;if(f!==null)throw f}}function xd(f,p,O,D){Wa=!1;var Q=f.updateQueue;Ko=!1;var Y=Q.firstBaseUpdate,ce=Q.lastBaseUpdate,Ee=Q.shared.pending;if(Ee!==null){Q.shared.pending=null;var Le=Ee,at=Le.next;Le.next=null,ce===null?Y=at:ce.next=at,ce=Le;var mt=f.alternate;mt!==null&&(mt=mt.updateQueue,Ee=mt.lastBaseUpdate,Ee!==ce&&(Ee===null?mt.firstBaseUpdate=at:Ee.next=at,mt.lastBaseUpdate=Le))}if(Y!==null){var xt=Q.baseState;ce=0,mt=at=Le=null,Ee=Y;do{var lt=Ee.lane&-536870913,ft=lt!==Ee.lane;if(ft?(yr&lt)===lt:(D&lt)===lt){lt!==0&&lt===Ef&&(Wa=!0),mt!==null&&(mt=mt.next={lane:0,tag:Ee.tag,payload:Ee.payload,callback:null,next:null});e:{var fn=f,An=Ee;lt=p;var Li=O;switch(An.tag){case 1:if(fn=An.payload,typeof fn=="function"){xt=fn.call(Li,xt,lt);break e}xt=fn;break e;case 3:fn.flags=fn.flags&-65537|128;case 0:if(fn=An.payload,lt=typeof fn=="function"?fn.call(Li,xt,lt):fn,lt==null)break e;xt=d({},xt,lt);break e;case 2:Ko=!0}}lt=Ee.callback,lt!==null&&(f.flags|=64,ft&&(f.flags|=8192),ft=Q.callbacks,ft===null?Q.callbacks=[lt]:ft.push(lt))}else ft={lane:lt,tag:Ee.tag,payload:Ee.payload,callback:Ee.callback,next:null},mt===null?(at=mt=ft,Le=xt):mt=mt.next=ft,ce|=lt;if(Ee=Ee.next,Ee===null){if(Ee=Q.shared.pending,Ee===null)break;ft=Ee,Ee=ft.next,ft.next=null,Q.lastBaseUpdate=ft,Q.shared.pending=null}}while(!0);mt===null&&(Le=xt),Q.baseState=Le,Q.firstBaseUpdate=at,Q.lastBaseUpdate=mt,Y===null&&(Q.shared.lanes=0),Eo|=ce,f.lanes=ce,f.memoizedState=xt}}function Ja(f,p){if(typeof f!="function")throw Error(r(191,f));f.call(p)}function eu(f,p){var O=f.callbacks;if(O!==null)for(f.callbacks=null,f=0;f<O.length;f++)Ja(O[f],p)}var tl=K(null),wa=K(0);function Rg(f,p){f=ia,B(wa,f),B(tl,p),ia=f|p.baseLanes}function Iu(){B(wa,ia),B(tl,tl.current)}function yu(){ia=wa.current,X(tl),X(wa)}var tu=K(null),Jo=null;function Sd(f){var p=f.alternate;B(ha,ha.current&1),B(tu,f),Jo===null&&(p===null||tl.current!==null||p.memoizedState!==null)&&(Jo=f)}function lm(f){B(ha,ha.current),B(tu,f),Jo===null&&(Jo=f)}function Bb(f){f.tag===22?(B(ha,ha.current),B(tu,f),Jo===null&&(Jo=f)):go()}function go(){B(ha,ha.current),B(tu,tu.current)}function Ql(f){X(tu),Jo===f&&(Jo=null),X(ha)}var ha=K(0);function Ag(f){for(var p=f;p!==null;){if(p.tag===13){var O=p.memoizedState;if(O!==null&&(O=O.dehydrated,O===null||nO(O)||rv(O)))return p}else if(p.tag===19&&(p.memoizedProps.revealOrder==="forwards"||p.memoizedProps.revealOrder==="backwards"||p.memoizedProps.revealOrder==="unstable_legacy-backwards"||p.memoizedProps.revealOrder==="together")){if((p.flags&128)!==0)return p}else if(p.child!==null){p.child.return=p,p=p.child;continue}if(p===f)break;for(;p.sibling===null;){if(p.return===null||p.return===f)return null;p=p.return}p.sibling.return=p.return,p=p.sibling}return null}var bu=0,Tn=null,yi=null,pa=null,om=!1,Pc=!1,Eh=!1,Tg=0,Bp=0,es=null,y4=0;function Yi(){throw Error(r(321))}function kg(f,p){if(p===null)return!1;for(var O=0;O<p.length&&O<f.length;O++)if(!fr(f[O],p[O]))return!1;return!0}function Pg(f,p,O,D,Q,Y){return bu=Y,Tn=p,p.memoizedState=null,p.updateQueue=null,p.lanes=0,G.H=f===null||f.memoizedState===null?jb:wh,Eh=!1,Y=O(D,Q),Eh=!1,Pc&&(Y=sm(p,O,D,Q)),ky(f),Y}function ky(f){G.H=Cd;var p=yi!==null&&yi.next!==null;if(bu=0,pa=yi=Tn=null,om=!1,Bp=0,es=null,p)throw Error(r(300));f===null||bi||(f=f.dependencies,f!==null&&md(f)&&(bi=!0))}function sm(f,p,O,D){Tn=f;var Q=0;do{if(Pc&&(es=null),Bp=0,Pc=!1,25<=Q)throw Error(r(301));if(Q+=1,pa=yi=null,f.updateQueue!=null){var Y=f.updateQueue;Y.lastEffect=null,Y.events=null,Y.stores=null,Y.memoCache!=null&&(Y.memoCache.index=0)}G.H=wd,Y=p(O,D)}while(Pc);return Y}function b4(){var f=G.H,p=f.useState()[0];return p=typeof p.then=="function"?Qp(p):p,f=f.useState()[0],(yi!==null?yi.memoizedState:null)!==f&&(Tn.flags|=1024),p}function Mg(){var f=Tg!==0;return Tg=0,f}function Fg(f,p,O){p.updateQueue=f.updateQueue,p.flags&=-2053,f.lanes&=~O}function Py(f){if(om){for(f=f.memoizedState;f!==null;){var p=f.queue;p!==null&&(p.pending=null),f=f.next}om=!1}bu=0,pa=yi=Tn=null,Pc=!1,Bp=Tg=0,es=null}function nl(){var f={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return pa===null?Tn.memoizedState=pa=f:pa=pa.next=f,pa}function Ra(){if(yi===null){var f=Tn.alternate;f=f!==null?f.memoizedState:null}else f=yi.next;var p=pa===null?Tn.memoizedState:pa.next;if(p!==null)pa=p,yi=f;else{if(f===null)throw Tn.alternate===null?Error(r(467)):Error(r(310));yi=f,f={memoizedState:yi.memoizedState,baseState:yi.baseState,baseQueue:yi.baseQueue,queue:yi.queue,next:null},pa===null?Tn.memoizedState=pa=f:pa=pa.next=f}return pa}function Dh(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Qp(f){var p=Bp;return Bp+=1,es===null&&(es=[]),f=am(es,f,p),p=Tn,(pa===null?p.memoizedState:pa.next)===null&&(p=p.alternate,G.H=p===null||p.memoizedState===null?jb:wh),f}function zp(f){if(f!==null&&typeof f=="object"){if(typeof f.then=="function")return Qp(f);if(f.$$typeof===C)return vu(f)}throw Error(r(438,String(f)))}function My(f){var p=null,O=Tn.updateQueue;if(O!==null&&(p=O.memoCache),p==null){var D=Tn.alternate;D!==null&&(D=D.updateQueue,D!==null&&(D=D.memoCache,D!=null&&(p={data:D.data.map(function(Q){return Q.slice()}),index:0})))}if(p==null&&(p={data:[],index:0}),O===null&&(O=Dh(),Tn.updateQueue=O),O.memoCache=p,O=p.data[p.index],O===void 0)for(O=p.data[p.index]=Array(f),D=0;D<f;D++)O[D]=j;return p.index++,O}function zs(f,p){return typeof p=="function"?p(f):p}function Jn(f){var p=Ra();return Fy(p,yi,f)}function Fy(f,p,O){var D=f.queue;if(D===null)throw Error(r(311));D.lastRenderedReducer=O;var Q=f.baseQueue,Y=D.pending;if(Y!==null){if(Q!==null){var ce=Q.next;Q.next=Y.next,Y.next=ce}p.baseQueue=Q=Y,D.pending=null}if(Y=f.baseState,Q===null)f.memoizedState=Y;else{p=Q.next;var Ee=ce=null,Le=null,at=p,mt=!1;do{var xt=at.lane&-536870913;if(xt!==at.lane?(yr&xt)===xt:(bu&xt)===xt){var lt=at.revertLane;if(lt===0)Le!==null&&(Le=Le.next={lane:0,revertLane:0,gesture:null,action:at.action,hasEagerState:at.hasEagerState,eagerState:at.eagerState,next:null}),xt===Ef&&(mt=!0);else if((bu&lt)===lt){at=at.next,lt===Ef&&(mt=!0);continue}else xt={lane:0,revertLane:at.revertLane,gesture:null,action:at.action,hasEagerState:at.hasEagerState,eagerState:at.eagerState,next:null},Le===null?(Ee=Le=xt,ce=Y):Le=Le.next=xt,Tn.lanes|=lt,Eo|=lt;xt=at.action,Eh&&O(Y,xt),Y=at.hasEagerState?at.eagerState:O(Y,xt)}else lt={lane:xt,revertLane:at.revertLane,gesture:at.gesture,action:at.action,hasEagerState:at.hasEagerState,eagerState:at.eagerState,next:null},Le===null?(Ee=Le=lt,ce=Y):Le=Le.next=lt,Tn.lanes|=xt,Eo|=xt;at=at.next}while(at!==null&&at!==p);if(Le===null?ce=Y:Le.next=Ee,!fr(Y,f.memoizedState)&&(bi=!0,mt&&(O=Ls,O!==null)))throw O;f.memoizedState=Y,f.baseState=ce,f.baseQueue=Le,D.lastRenderedState=Y}return Q===null&&(D.lanes=0),[f.memoizedState,D.dispatch]}function Ng(f){var p=Ra(),O=p.queue;if(O===null)throw Error(r(311));O.lastRenderedReducer=f;var D=O.dispatch,Q=O.pending,Y=p.memoizedState;if(Q!==null){O.pending=null;var ce=Q=Q.next;do Y=f(Y,ce.action),ce=ce.next;while(ce!==Q);fr(Y,p.memoizedState)||(bi=!0),p.memoizedState=Y,p.baseQueue===null&&(p.baseState=Y),O.lastRenderedState=Y}return[Y,D]}function $h(f,p,O){var D=Tn,Q=Ra(),Y=je;if(Y){if(O===void 0)throw Error(r(407));O=O()}else O=p();var ce=!fr((yi||Q).memoizedState,O);if(ce&&(Q.memoizedState=O,bi=!0),Q=Q.queue,dm(Ly.bind(null,D,Q,f),[f]),Q.getSnapshot!==p||ce||pa!==null&&pa.memoizedState.tag&1){if(D.flags|=2048,vo(9,{destroy:void 0},Iy.bind(null,D,Q,O,p),null),ii===null)throw Error(r(349));Y||(bu&127)!==0||Ny(D,p,O)}return O}function Ny(f,p,O){f.flags|=16384,f={getSnapshot:p,value:O},p=Tn.updateQueue,p===null?(p=Dh(),Tn.updateQueue=p,p.stores=[f]):(O=p.stores,O===null?p.stores=[f]:O.push(f))}function Iy(f,p,O,D){p.value=O,p.getSnapshot=D,zl(p)&&Ig(f)}function Ly(f,p,O){return O(function(){zl(p)&&Ig(f)})}function zl(f){var p=f.getSnapshot;f=f.value;try{var O=p();return!fr(f,O)}catch{return!0}}function Ig(f){var p=Ku(f,2);p!==null&&b(p,f,2)}function _d(f){var p=nl();if(typeof f=="function"){var O=f;if(f=O(),Eh){rn(!0);try{O()}finally{rn(!1)}}}return p.memoizedState=p.baseState=f,p.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:zs,lastRenderedState:f},p}function Lg(f,p,O,D){return f.baseState=O,Fy(f,yi,typeof D=="function"?D:zs)}function Qb(f,p,O,D,Q){if(Fc(f))throw Error(r(485));if(f=p.action,f!==null){var Y={payload:Q,action:f,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(ce){Y.listeners.push(ce)}};G.T!==null?O(!0):Y.isTransition=!1,D(Y),O=p.pending,O===null?(Y.next=p.pending=Y,By(p,Y)):(Y.next=O.next,p.pending=O.next=Y)}}function By(f,p){var O=p.action,D=p.payload,Q=f.state;if(p.isTransition){var Y=G.T,ce={};G.T=ce;try{var Ee=O(Q,D),Le=G.S;Le!==null&&Le(ce,Ee),ql(f,p,Ee)}catch(at){qp(f,p,at)}finally{Y!==null&&ce.types!==null&&(Y.types=ce.types),G.T=Y}}else try{Y=O(Q,D),ql(f,p,Y)}catch(at){qp(f,p,at)}}function ql(f,p,O){O!==null&&typeof O=="object"&&typeof O.then=="function"?O.then(function(D){Mc(f,p,D)},function(D){return qp(f,p,D)}):Mc(f,p,O)}function Mc(f,p,O){p.status="fulfilled",p.value=O,Qy(p),f.state=O,p=f.pending,p!==null&&(O=p.next,O===p?f.pending=null:(O=O.next,p.next=O,By(f,O)))}function qp(f,p,O){var D=f.pending;if(f.pending=null,D!==null){D=D.next;do p.status="rejected",p.reason=O,Qy(p),p=p.next;while(p!==D)}f.action=null}function Qy(f){f=f.listeners;for(var p=0;p<f.length;p++)(0,f[p])()}function cm(f,p){return p}function zy(f,p){if(je){var O=ii.formState;if(O!==null){e:{var D=Tn;if(je){if(Be){t:{for(var Q=Be,Y=Kt;Q.nodeType!==8;){if(!Y){Q=null;break t}if(Q=Uc(Q.nextSibling),Q===null){Q=null;break t}}Y=Q.data,Q=Y==="F!"||Y==="F"?Q:null}if(Q){Be=Uc(Q.nextSibling),D=Q.data==="F!";break e}}cn(D)}D=!1}D&&(p=O[0])}}return O=nl(),O.memoizedState=O.baseState=p,D={pending:null,lanes:0,dispatch:null,lastRenderedReducer:cm,lastRenderedState:p},O.queue=D,O=Yy.bind(null,Tn,D),D.dispatch=O,D=_d(!1),Y=$d.bind(null,Tn,!1,D.queue),D=nl(),Q={state:p,dispatch:null,action:f,pending:null},D.queue=Q,O=Qb.bind(null,Tn,Q,Y,O),Q.dispatch=O,D.memoizedState=f,[p,O,!1]}function Bg(f){var p=Ra();return qy(p,yi,f)}function qy(f,p,O){if(p=Fy(f,p,cm)[0],f=Jn(zs)[0],typeof p=="object"&&p!==null&&typeof p.then=="function")try{var D=Qp(p)}catch(ce){throw ce===vd?Go:ce}else D=p;p=Ra();var Q=p.queue,Y=Q.dispatch;return O!==p.memoizedState&&(Tn.flags|=2048,vo(9,{destroy:void 0},Vy.bind(null,Q,O),null)),[D,Y,f]}function Vy(f,p){f.action=p}function Qg(f){var p=Ra(),O=yi;if(O!==null)return qy(p,O,f);Ra(),p=p.memoizedState,O=Ra();var D=O.queue.dispatch;return O.memoizedState=f,[p,D,!1]}function vo(f,p,O,D){return f={tag:f,create:O,deps:D,inst:p,next:null},p=Tn.updateQueue,p===null&&(p=Dh(),Tn.updateQueue=p),O=p.lastEffect,O===null?p.lastEffect=f.next=f:(D=O.next,O.next=f,f.next=D,p.lastEffect=f),f}function zb(){return Ra().memoizedState}function qs(f,p,O,D){var Q=nl();Tn.flags|=f,Q.memoizedState=vo(1|p,{destroy:void 0},O,D===void 0?null:D)}function fm(f,p,O,D){var Q=Ra();D=D===void 0?null:D;var Y=Q.memoizedState.inst;yi!==null&&D!==null&&kg(D,yi.memoizedState.deps)?Q.memoizedState=vo(p,Y,O,D):(Tn.flags|=f,Q.memoizedState=vo(1|p,Y,O,D))}function Uy(f,p){qs(8390656,8,f,p)}function dm(f,p){fm(2048,8,f,p)}function qb(f){Tn.flags|=4;var p=Tn.updateQueue;if(p===null)p=Dh(),Tn.updateQueue=p,p.events=[f];else{var O=p.events;O===null?p.events=[f]:O.push(f)}}function Vb(f){var p=Ra().memoizedState;return qb({ref:p,nextImpl:f}),function(){if((Ar&2)!==0)throw Error(r(440));return p.impl.apply(void 0,arguments)}}function Ub(f,p){return fm(4,2,f,p)}function Vl(f,p){return fm(4,4,f,p)}function zg(f,p){if(typeof p=="function"){f=f();var O=p(f);return function(){typeof O=="function"?O():p(null)}}if(p!=null)return f=f(),p.current=f,function(){p.current=null}}function qg(f,p,O){O=O!=null?O.concat([f]):null,fm(4,4,zg.bind(null,p,f),O)}function hm(){}function Vg(f,p){var O=Ra();p=p===void 0?null:p;var D=O.memoizedState;return p!==null&&kg(p,D[1])?D[0]:(O.memoizedState=[f,p],f)}function rl(f,p){var O=Ra();p=p===void 0?null:p;var D=O.memoizedState;if(p!==null&&kg(p,D[1]))return D[0];if(D=f(),Eh){rn(!0);try{f()}finally{rn(!1)}}return O.memoizedState=[D,p],D}function ts(f,p,O){return O===void 0||(bu&1073741824)!==0&&(yr&261930)===0?f.memoizedState=p:(f.memoizedState=O,f=g(),Tn.lanes|=f,Eo|=f,O)}function jy(f,p,O,D){return fr(O,p)?O:tl.current!==null?(f=ts(f,O,D),fr(f,p)||(bi=!0),f):(bu&42)===0||(bu&1073741824)!==0&&(yr&261930)===0?(bi=!0,f.memoizedState=O):(f=g(),Tn.lanes|=f,Eo|=f,p)}function Zy(f,p,O,D,Q){var Y=J.p;J.p=Y!==0&&8>Y?Y:8;var ce=G.T,Ee={};G.T=Ee,$d(f,!1,p,O);try{var Le=Q(),at=G.S;if(at!==null&&at(Ee,Le),Le!==null&&typeof Le=="object"&&typeof Le.then=="function"){var mt=Ay(Le,D);Ch(f,p,mt,_l(f))}else Ch(f,p,D,_l(f))}catch(xt){Ch(f,p,{then:function(){},status:"rejected",reason:xt},_l())}finally{J.p=Y,ce!==null&&Ee.types!==null&&(ce.types=Ee.types),G.T=ce}}function Ug(){}function Ed(f,p,O,D){if(f.tag!==5)throw Error(r(476));var Q=Hy(f).queue;Zy(f,Q,p,te,O===null?Ug:function(){return jg(f),O(D)})}function Hy(f){var p=f.memoizedState;if(p!==null)return p;p={memoizedState:te,baseState:te,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:zs,lastRenderedState:te},next:null};var O={};return p.next={memoizedState:O,baseState:O,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:zs,lastRenderedState:O},next:null},f.memoizedState=p,f=f.alternate,f!==null&&(f.memoizedState=p),p}function jg(f){var p=Hy(f);p.next===null&&(p=f.alternate.memoizedState),Ch(f,p.next.queue,{},_l())}function Xy(){return vu(sv)}function Ou(){return Ra().memoizedState}function Dd(){return Ra().memoizedState}function pm(f){for(var p=f.return;p!==null;){switch(p.tag){case 24:case 3:var O=_l();f=kc(O);var D=Wo(p,f,O);D!==null&&(b(D,p,O),Od(D,p,O)),p={cache:Is()},f.payload=p;return}p=p.return}}function O4(f,p,O){var D=_l();O={lane:D,revertLane:0,gesture:null,action:O,hasEagerState:!1,eagerState:null,next:null},Fc(f)?Nc(p,O):(O=Dc(f,p,O,D),O!==null&&(b(O,f,D),il(O,p,D)))}function Yy(f,p,O){var D=_l();Ch(f,p,O,D)}function Ch(f,p,O,D){var Q={lane:D,revertLane:0,gesture:null,action:O,hasEagerState:!1,eagerState:null,next:null};if(Fc(f))Nc(p,Q);else{var Y=f.alternate;if(f.lanes===0&&(Y===null||Y.lanes===0)&&(Y=p.lastRenderedReducer,Y!==null))try{var ce=p.lastRenderedState,Ee=Y(ce,O);if(Q.hasEagerState=!0,Q.eagerState=Ee,fr(Ee,ce))return Gu(f,p,Q,0),ii===null&&Ga(),!1}catch{}finally{}if(O=Dc(f,p,Q,D),O!==null)return b(O,f,D),il(O,p,D),!0}return!1}function $d(f,p,O,D){if(D={lane:2,revertLane:Gs(),gesture:null,action:D,hasEagerState:!1,eagerState:null,next:null},Fc(f)){if(p)throw Error(r(479))}else p=Dc(f,O,D,2),p!==null&&b(p,f,2)}function Fc(f){var p=f.alternate;return f===Tn||p!==null&&p===Tn}function Nc(f,p){Pc=om=!0;var O=f.pending;O===null?p.next=p:(p.next=O.next,O.next=p),f.pending=p}function il(f,p,O){if((O&4194048)!==0){var D=p.lanes;D&=f.pendingLanes,O|=D,p.lanes=O,$t(f,O)}}var Cd={readContext:vu,use:zp,useCallback:Yi,useContext:Yi,useEffect:Yi,useImperativeHandle:Yi,useLayoutEffect:Yi,useInsertionEffect:Yi,useMemo:Yi,useReducer:Yi,useRef:Yi,useState:Yi,useDebugValue:Yi,useDeferredValue:Yi,useTransition:Yi,useSyncExternalStore:Yi,useId:Yi,useHostTransitionStatus:Yi,useFormState:Yi,useActionState:Yi,useOptimistic:Yi,useMemoCache:Yi,useCacheRefresh:Yi};Cd.useEffectEvent=Yi;var jb={readContext:vu,use:zp,useCallback:function(f,p){return nl().memoizedState=[f,p===void 0?null:p],f},useContext:vu,useEffect:Uy,useImperativeHandle:function(f,p,O){O=O!=null?O.concat([f]):null,qs(4194308,4,zg.bind(null,p,f),O)},useLayoutEffect:function(f,p){return qs(4194308,4,f,p)},useInsertionEffect:function(f,p){qs(4,2,f,p)},useMemo:function(f,p){var O=nl();p=p===void 0?null:p;var D=f();if(Eh){rn(!0);try{f()}finally{rn(!1)}}return O.memoizedState=[D,p],D},useReducer:function(f,p,O){var D=nl();if(O!==void 0){var Q=O(p);if(Eh){rn(!0);try{O(p)}finally{rn(!1)}}}else Q=p;return D.memoizedState=D.baseState=Q,f={pending:null,lanes:0,dispatch:null,lastRenderedReducer:f,lastRenderedState:Q},D.queue=f,f=f.dispatch=O4.bind(null,Tn,f),[D.memoizedState,f]},useRef:function(f){var p=nl();return f={current:f},p.memoizedState=f},useState:function(f){f=_d(f);var p=f.queue,O=Yy.bind(null,Tn,p);return p.dispatch=O,[f.memoizedState,O]},useDebugValue:hm,useDeferredValue:function(f,p){var O=nl();return ts(O,f,p)},useTransition:function(){var f=_d(!1);return f=Zy.bind(null,Tn,f.queue,!0,!1),nl().memoizedState=f,[!1,f]},useSyncExternalStore:function(f,p,O){var D=Tn,Q=nl();if(je){if(O===void 0)throw Error(r(407));O=O()}else{if(O=p(),ii===null)throw Error(r(349));(yr&127)!==0||Ny(D,p,O)}Q.memoizedState=O;var Y={value:O,getSnapshot:p};return Q.queue=Y,Uy(Ly.bind(null,D,Y,f),[f]),D.flags|=2048,vo(9,{destroy:void 0},Iy.bind(null,D,Y,O,p),null),O},useId:function(){var f=nl(),p=ii.identifierPrefix;if(je){var O=ue,D=Ho;O=(D&~(1<<32-Fe(D)-1)).toString(32)+O,p="_"+p+"R_"+O,O=Tg++,0<O&&(p+="H"+O.toString(32)),p+="_"}else O=y4++,p="_"+p+"r_"+O.toString(32)+"_";return f.memoizedState=p},useHostTransitionStatus:Xy,useFormState:zy,useActionState:zy,useOptimistic:function(f){var p=nl();p.memoizedState=p.baseState=f;var O={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return p.queue=O,p=$d.bind(null,Tn,!0,O),O.dispatch=p,[f,p]},useMemoCache:My,useCacheRefresh:function(){return nl().memoizedState=pm.bind(null,Tn)},useEffectEvent:function(f){var p=nl(),O={impl:f};return p.memoizedState=O,function(){if((Ar&2)!==0)throw Error(r(440));return O.impl.apply(void 0,arguments)}}},wh={readContext:vu,use:zp,useCallback:Vg,useContext:vu,useEffect:dm,useImperativeHandle:qg,useInsertionEffect:Ub,useLayoutEffect:Vl,useMemo:rl,useReducer:Jn,useRef:zb,useState:function(){return Jn(zs)},useDebugValue:hm,useDeferredValue:function(f,p){var O=Ra();return jy(O,yi.memoizedState,f,p)},useTransition:function(){var f=Jn(zs)[0],p=Ra().memoizedState;return[typeof f=="boolean"?f:Qp(f),p]},useSyncExternalStore:$h,useId:Ou,useHostTransitionStatus:Xy,useFormState:Bg,useActionState:Bg,useOptimistic:function(f,p){var O=Ra();return Lg(O,yi,f,p)},useMemoCache:My,useCacheRefresh:Dd};wh.useEffectEvent=Vb;var wd={readContext:vu,use:zp,useCallback:Vg,useContext:vu,useEffect:dm,useImperativeHandle:qg,useInsertionEffect:Ub,useLayoutEffect:Vl,useMemo:rl,useReducer:Ng,useRef:zb,useState:function(){return Ng(zs)},useDebugValue:hm,useDeferredValue:function(f,p){var O=Ra();return yi===null?ts(O,f,p):jy(O,yi.memoizedState,f,p)},useTransition:function(){var f=Ng(zs)[0],p=Ra().memoizedState;return[typeof f=="boolean"?f:Qp(f),p]},useSyncExternalStore:$h,useId:Ou,useHostTransitionStatus:Xy,useFormState:Qg,useActionState:Qg,useOptimistic:function(f,p){var O=Ra();return yi!==null?Lg(O,yi,f,p):(O.baseState=f,[f,O.queue.dispatch])},useMemoCache:My,useCacheRefresh:Dd};wd.useEffectEvent=Vb;function Rh(f,p,O,D){p=f.memoizedState,O=O(D,p),O=O==null?p:d({},p,O),f.memoizedState=O,f.lanes===0&&(f.updateQueue.baseState=O)}var Ah={enqueueSetState:function(f,p,O){f=f._reactInternals;var D=_l(),Q=kc(D);Q.payload=p,O!=null&&(Q.callback=O),p=Wo(f,Q,D),p!==null&&(b(p,f,D),Od(p,f,D))},enqueueReplaceState:function(f,p,O){f=f._reactInternals;var D=_l(),Q=kc(D);Q.tag=1,Q.payload=p,O!=null&&(Q.callback=O),p=Wo(f,Q,D),p!==null&&(b(p,f,D),Od(p,f,D))},enqueueForceUpdate:function(f,p){f=f._reactInternals;var O=_l(),D=kc(O);D.tag=2,p!=null&&(D.callback=p),p=Wo(f,D,O),p!==null&&(b(p,f,O),Od(p,f,O))}};function Zb(f,p,O,D,Q,Y,ce){return f=f.stateNode,typeof f.shouldComponentUpdate=="function"?f.shouldComponentUpdate(D,Y,ce):p.prototype&&p.prototype.isPureReactComponent?!Of(O,D)||!Of(Q,Y):!0}function Gy(f,p,O,D){f=p.state,typeof p.componentWillReceiveProps=="function"&&p.componentWillReceiveProps(O,D),typeof p.UNSAFE_componentWillReceiveProps=="function"&&p.UNSAFE_componentWillReceiveProps(O,D),p.state!==f&&Ah.enqueueReplaceState(p,p.state,null)}function qi(f,p){var O=p;if("ref"in p){O={};for(var D in p)D!=="ref"&&(O[D]=p[D])}if(f=f.defaultProps){O===p&&(O=d({},O));for(var Q in f)O[Q]===void 0&&(O[Q]=f[Q])}return O}function Zg(f){Zo(f)}function Ky(f){console.error(f)}function Hg(f){Zo(f)}function mm(f,p){try{var O=f.onUncaughtError;O(p.value,{componentStack:p.stack})}catch(D){setTimeout(function(){throw D})}}function Hb(f,p,O){try{var D=f.onCaughtError;D(O.value,{componentStack:O.stack,errorBoundary:p.tag===1?p.stateNode:null})}catch(Q){setTimeout(function(){throw Q})}}function Wy(f,p,O){return O=kc(O),O.tag=3,O.payload={element:null},O.callback=function(){mm(f,p)},O}function Ul(f){return f=kc(f),f.tag=3,f}function al(f,p,O,D){var Q=O.type.getDerivedStateFromError;if(typeof Q=="function"){var Y=D.value;f.payload=function(){return Q(Y)},f.callback=function(){Hb(p,O,D)}}var ce=O.stateNode;ce!==null&&typeof ce.componentDidCatch=="function"&&(f.callback=function(){Hb(p,O,D),typeof Q!="function"&&(qc===null?qc=new Set([this]):qc.add(this));var Ee=D.stack;this.componentDidCatch(D.value,{componentStack:Ee!==null?Ee:""})})}function Ol(f,p,O,D,Q){if(O.flags|=32768,D!==null&&typeof D=="object"&&typeof D.then=="function"){if(p=O.alternate,p!==null&&Bl(p,O,Q,!0),O=tu.current,O!==null){switch(O.tag){case 31:case 13:return Jo===null?Hn():O.alternate===null&&Kr===0&&(Kr=3),O.flags&=-257,O.flags|=65536,O.lanes=Q,D===im?O.flags|=16384:(p=O.updateQueue,p===null?O.updateQueue=new Set([D]):p.add(D),_4(f,D,Q)),!1;case 22:return O.flags|=65536,D===im?O.flags|=16384:(p=O.updateQueue,p===null?(p={transitions:null,markerInstances:null,retryQueue:new Set([D])},O.updateQueue=p):(O=p.retryQueue,O===null?p.retryQueue=new Set([D]):O.add(D)),_4(f,D,Q)),!1}throw Error(r(435,O.tag))}return _4(f,D,Q),Hn(),!1}if(je)return p=tu.current,p!==null?((p.flags&65536)===0&&(p.flags|=256),p.flags|=65536,p.lanes=Q,D!==Qn&&(f=Error(r(422),{cause:D}),Il(Tu(f,O)))):(D!==Qn&&(p=Error(r(423),{cause:D}),Il(Tu(p,O))),f=f.current.alternate,f.flags|=65536,Q&=-Q,f.lanes|=Q,D=Tu(D,O),Q=Wy(f.stateNode,D,Q),um(f,Q),Kr!==4&&(Kr=2)),!1;var Y=Error(r(520),{cause:D});if(Y=Tu(Y,O),Xs===null?Xs=[Y]:Xs.push(Y),Kr!==4&&(Kr=2),p===null)return!0;D=Tu(D,O),O=p;do{switch(O.tag){case 3:return O.flags|=65536,f=Q&-Q,O.lanes|=f,f=Wy(O.stateNode,D,f),um(O,f),!1;case 1:if(p=O.type,Y=O.stateNode,(O.flags&128)===0&&(typeof p.getDerivedStateFromError=="function"||Y!==null&&typeof Y.componentDidCatch=="function"&&(qc===null||!qc.has(Y))))return O.flags|=65536,Q&=-Q,O.lanes|=Q,Q=Ul(Q),al(Q,f,O,D),um(O,Q),!1}O=O.return}while(O!==null);return!1}var Vp=Error(r(461)),bi=!1;function $i(f,p,O,D){p.child=f===null?Ty(p,null,O,D):bd(p,f.child,O,D)}function Sn(f,p,O,D,Q){O=O.render;var Y=p.ref;if("ref"in D){var ce={};for(var Ee in D)Ee!=="ref"&&(ce[Ee]=D[Ee])}else ce=D;return xh(p),D=Pg(f,p,O,ce,Y,Q),Ee=Mg(),f!==null&&!bi?(Fg(f,p,Q),is(f,p,Q)):(je&&Ee&&fe(p),p.flags|=1,$i(f,p,D,Q),p.child)}function Rd(f,p,O,D,Q){if(f===null){var Y=O.type;return typeof Y=="function"&&!Xi(Y)&&Y.defaultProps===void 0&&O.compare===null?(p.tag=15,p.type=Y,xl(f,p,Y,D,Q)):(f=bh(O.type,null,D,p,p.mode,Q),f.ref=p.ref,f.return=p,p.child=f)}if(Y=f.child,!$f(f,Q)){var ce=Y.memoizedProps;if(O=O.compare,O=O!==null?O:Of,O(ce,D)&&f.ref===p.ref)return is(f,p,Q)}return p.flags|=1,f=Wu(Y,D),f.ref=p.ref,f.return=p,p.child=f}function xl(f,p,O,D,Q){if(f!==null){var Y=f.memoizedProps;if(Of(Y,D)&&f.ref===p.ref)if(bi=!1,p.pendingProps=D=Y,$f(f,Q))(f.flags&131072)!==0&&(bi=!0);else return p.lanes=f.lanes,is(f,p,Q)}return Th(f,p,O,D,Q)}function nu(f,p,O,D){var Q=D.children,Y=f!==null?f.memoizedState:null;if(f===null&&p.stateNode===null&&(p.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),D.mode==="hidden"){if((p.flags&128)!==0){if(Y=Y!==null?Y.baseLanes|O:O,f!==null){for(D=p.child=f.child,Q=0;D!==null;)Q=Q|D.lanes|D.childLanes,D=D.sibling;D=Q&~Y}else D=0,p.child=null;return ns(f,p,Y,O,D)}if((O&536870912)!==0)p.memoizedState={baseLanes:0,cachePool:null},f!==null&&Fp(p,Y!==null?Y.cachePool:null),Y!==null?Rg(p,Y):Iu(),Bb(p);else return D=p.lanes=536870912,ns(f,p,Y!==null?Y.baseLanes|O:O,O,D)}else Y!==null?(Fp(p,Y.cachePool),Rg(p,Y),go(),p.memoizedState=null):(f!==null&&Fp(p,null),Iu(),go());return $i(f,p,Q,O),p.child}function Vs(f,p){return f!==null&&f.tag===22||p.stateNode!==null||(p.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),p.sibling}function ns(f,p,O,D,Q){var Y=Ac();return Y=Y===null?null:{parent:yn._currentValue,pool:Y},p.memoizedState={baseLanes:O,cachePool:Y},f!==null&&Fp(p,null),Iu(),Bb(p),f!==null&&Bl(f,p,D,!0),p.childLanes=Q,null}function yo(f,p){return p=Up({mode:p.mode,children:p.children},f.mode),p.ref=f.ref,f.child=p,p.return=f,p}function Ir(f,p,O){return bd(p,f.child,null,O),f=yo(p,p.pendingProps),f.flags|=2,Ql(p),p.memoizedState=null,f}function gm(f,p,O){var D=p.pendingProps,Q=(p.flags&128)!==0;if(p.flags&=-129,f===null){if(je){if(D.mode==="hidden")return f=yo(p,D),p.lanes=536870912,Vs(null,f);if(lm(p),(f=Be)?(f=t_(f,Kt),f=f!==null&&f.data==="&"?f:null,f!==null&&(p.memoizedState={dehydrated:f,treeContext:Pu!==null?{id:Ho,overflow:ue}:null,retryLane:536870912,hydrationErrors:null},O=Oh(f),O.return=p,p.child=O,Qe=p,Be=null)):f=null,f===null)throw cn(p);return p.lanes=536870912,null}return yo(p,D)}var Y=f.memoizedState;if(Y!==null){var ce=Y.dehydrated;if(lm(p),Q)if(p.flags&256)p.flags&=-257,p=Ir(f,p,O);else if(p.memoizedState!==null)p.child=f.child,p.flags|=128,p=null;else throw Error(r(558));else if(bi||Bl(f,p,O,!1),Q=(O&f.childLanes)!==0,bi||Q){if(D=ii,D!==null&&(ce=Ut(D,O),ce!==0&&ce!==Y.retryLane))throw Y.retryLane=ce,Ku(f,ce),b(D,f,ce),Vp;Hn(),p=Ir(f,p,O)}else f=Y.treeContext,Be=Uc(ce.nextSibling),Qe=p,je=!0,Ct=null,Kt=!1,f!==null&&Te(p,f),p=yo(p,D),p.flags|=4096;return p}return f=Wu(f.child,{mode:D.mode,children:D.children}),f.ref=p.ref,p.child=f,f.return=p,f}function Us(f,p){var O=p.ref;if(O===null)f!==null&&f.ref!==null&&(p.flags|=4194816);else{if(typeof O!="function"&&typeof O!="object")throw Error(r(284));(f===null||f.ref!==O)&&(p.flags|=4194816)}}function Th(f,p,O,D,Q){return xh(p),O=Pg(f,p,O,D,void 0,Q),D=Mg(),f!==null&&!bi?(Fg(f,p,Q),is(f,p,Q)):(je&&D&&fe(p),p.flags|=1,$i(f,p,O,Q),p.child)}function ul(f,p,O,D,Q,Y){return xh(p),p.updateQueue=null,O=sm(p,D,O,Q),ky(f),D=Mg(),f!==null&&!bi?(Fg(f,p,Y),is(f,p,Y)):(je&&D&&fe(p),p.flags|=1,$i(f,p,O,Y),p.child)}function xu(f,p,O,D,Q){if(xh(p),p.stateNode===null){var Y=pu,ce=O.contextType;typeof ce=="object"&&ce!==null&&(Y=vu(ce)),Y=new O(D,Y),p.memoizedState=Y.state!==null&&Y.state!==void 0?Y.state:null,Y.updater=Ah,p.stateNode=Y,Y._reactInternals=p,Y=p.stateNode,Y.props=D,Y.state=p.memoizedState,Y.refs={},Tc(p),ce=O.contextType,Y.context=typeof ce=="object"&&ce!==null?vu(ce):pu,Y.state=p.memoizedState,ce=O.getDerivedStateFromProps,typeof ce=="function"&&(Rh(p,O,ce,D),Y.state=p.memoizedState),typeof O.getDerivedStateFromProps=="function"||typeof Y.getSnapshotBeforeUpdate=="function"||typeof Y.UNSAFE_componentWillMount!="function"&&typeof Y.componentWillMount!="function"||(ce=Y.state,typeof Y.componentWillMount=="function"&&Y.componentWillMount(),typeof Y.UNSAFE_componentWillMount=="function"&&Y.UNSAFE_componentWillMount(),ce!==Y.state&&Ah.enqueueReplaceState(Y,Y.state,null),xd(p,D,Y,Q),_h(),Y.state=p.memoizedState),typeof Y.componentDidMount=="function"&&(p.flags|=4194308),D=!0}else if(f===null){Y=p.stateNode;var Ee=p.memoizedProps,Le=qi(O,Ee);Y.props=Le;var at=Y.context,mt=O.contextType;ce=pu,typeof mt=="object"&&mt!==null&&(ce=vu(mt));var xt=O.getDerivedStateFromProps;mt=typeof xt=="function"||typeof Y.getSnapshotBeforeUpdate=="function",Ee=p.pendingProps!==Ee,mt||typeof Y.UNSAFE_componentWillReceiveProps!="function"&&typeof Y.componentWillReceiveProps!="function"||(Ee||at!==ce)&&Gy(p,Y,D,ce),Ko=!1;var lt=p.memoizedState;Y.state=lt,xd(p,D,Y,Q),_h(),at=p.memoizedState,Ee||lt!==at||Ko?(typeof xt=="function"&&(Rh(p,O,xt,D),at=p.memoizedState),(Le=Ko||Zb(p,O,Le,D,lt,at,ce))?(mt||typeof Y.UNSAFE_componentWillMount!="function"&&typeof Y.componentWillMount!="function"||(typeof Y.componentWillMount=="function"&&Y.componentWillMount(),typeof Y.UNSAFE_componentWillMount=="function"&&Y.UNSAFE_componentWillMount()),typeof Y.componentDidMount=="function"&&(p.flags|=4194308)):(typeof Y.componentDidMount=="function"&&(p.flags|=4194308),p.memoizedProps=D,p.memoizedState=at),Y.props=D,Y.state=at,Y.context=ce,D=Le):(typeof Y.componentDidMount=="function"&&(p.flags|=4194308),D=!1)}else{Y=p.stateNode,wg(f,p),ce=p.memoizedProps,mt=qi(O,ce),Y.props=mt,xt=p.pendingProps,lt=Y.context,at=O.contextType,Le=pu,typeof at=="object"&&at!==null&&(Le=vu(at)),Ee=O.getDerivedStateFromProps,(at=typeof Ee=="function"||typeof Y.getSnapshotBeforeUpdate=="function")||typeof Y.UNSAFE_componentWillReceiveProps!="function"&&typeof Y.componentWillReceiveProps!="function"||(ce!==xt||lt!==Le)&&Gy(p,Y,D,Le),Ko=!1,lt=p.memoizedState,Y.state=lt,xd(p,D,Y,Q),_h();var ft=p.memoizedState;ce!==xt||lt!==ft||Ko||f!==null&&f.dependencies!==null&&md(f.dependencies)?(typeof Ee=="function"&&(Rh(p,O,Ee,D),ft=p.memoizedState),(mt=Ko||Zb(p,O,mt,D,lt,ft,Le)||f!==null&&f.dependencies!==null&&md(f.dependencies))?(at||typeof Y.UNSAFE_componentWillUpdate!="function"&&typeof Y.componentWillUpdate!="function"||(typeof Y.componentWillUpdate=="function"&&Y.componentWillUpdate(D,ft,Le),typeof Y.UNSAFE_componentWillUpdate=="function"&&Y.UNSAFE_componentWillUpdate(D,ft,Le)),typeof Y.componentDidUpdate=="function"&&(p.flags|=4),typeof Y.getSnapshotBeforeUpdate=="function"&&(p.flags|=1024)):(typeof Y.componentDidUpdate!="function"||ce===f.memoizedProps&&lt===f.memoizedState||(p.flags|=4),typeof Y.getSnapshotBeforeUpdate!="function"||ce===f.memoizedProps&&lt===f.memoizedState||(p.flags|=1024),p.memoizedProps=D,p.memoizedState=ft),Y.props=D,Y.state=ft,Y.context=Le,D=mt):(typeof Y.componentDidUpdate!="function"||ce===f.memoizedProps&&lt===f.memoizedState||(p.flags|=4),typeof Y.getSnapshotBeforeUpdate!="function"||ce===f.memoizedProps&&lt===f.memoizedState||(p.flags|=1024),D=!1)}return Y=D,Us(f,p),D=(p.flags&128)!==0,Y||D?(Y=p.stateNode,O=D&&typeof O.getDerivedStateFromError!="function"?null:Y.render(),p.flags|=1,f!==null&&D?(p.child=bd(p,f.child,null,Q),p.child=bd(p,null,O,Q)):$i(f,p,O,Q),p.memoizedState=Y.state,f=p.child):f=is(f,p,Q),f}function Lr(f,p,O,D){return Se(),p.flags|=256,$i(f,p,O,D),p.child}var bo={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function rs(f){return{baseLanes:f,cachePool:Dg()}}function Oo(f,p,O){return f=f!==null?f.childLanes&~O:0,p&&(f|=Tr),f}function Ci(f,p,O){var D=p.pendingProps,Q=!1,Y=(p.flags&128)!==0,ce;if((ce=Y)||(ce=f!==null&&f.memoizedState===null?!1:(ha.current&2)!==0),ce&&(Q=!0,p.flags&=-129),ce=(p.flags&32)!==0,p.flags&=-33,f===null){if(je){if(Q?Sd(p):go(),(f=Be)?(f=t_(f,Kt),f=f!==null&&f.data!=="&"?f:null,f!==null&&(p.memoizedState={dehydrated:f,treeContext:Pu!==null?{id:Ho,overflow:ue}:null,retryLane:536870912,hydrationErrors:null},O=Oh(f),O.return=p,p.child=O,Qe=p,Be=null)):f=null,f===null)throw cn(p);return rv(f)?p.lanes=32:p.lanes=536870912,null}var Ee=D.children;return D=D.fallback,Q?(go(),Q=p.mode,Ee=Up({mode:"hidden",children:Ee},Q),D=Fl(D,Q,O,null),Ee.return=p,D.return=p,Ee.sibling=D,p.child=Ee,D=p.child,D.memoizedState=rs(O),D.childLanes=Oo(f,ce,O),p.memoizedState=bo,Vs(null,D)):(Sd(p),Ic(p,Ee))}var Le=f.memoizedState;if(Le!==null&&(Ee=Le.dehydrated,Ee!==null)){if(Y)p.flags&256?(Sd(p),p.flags&=-257,p=Ad(f,p,O)):p.memoizedState!==null?(go(),p.child=f.child,p.flags|=128,p=null):(go(),Ee=D.fallback,Q=p.mode,D=Up({mode:"visible",children:D.children},Q),Ee=Fl(Ee,Q,O,null),Ee.flags|=2,D.return=p,Ee.return=p,D.sibling=Ee,p.child=D,bd(p,f.child,null,O),D=p.child,D.memoizedState=rs(O),D.childLanes=Oo(f,ce,O),p.memoizedState=bo,p=Vs(null,D));else if(Sd(p),rv(Ee)){if(ce=Ee.nextSibling&&Ee.nextSibling.dataset,ce)var at=ce.dgst;ce=at,D=Error(r(419)),D.stack="",D.digest=ce,Il({value:D,source:null,stack:null}),p=Ad(f,p,O)}else if(bi||Bl(f,p,O,!1),ce=(O&f.childLanes)!==0,bi||ce){if(ce=ii,ce!==null&&(D=Ut(ce,O),D!==0&&D!==Le.retryLane))throw Le.retryLane=D,Ku(f,D),b(ce,f,D),Vp;nO(Ee)||Hn(),p=Ad(f,p,O)}else nO(Ee)?(p.flags|=192,p.child=f.child,p=null):(f=Le.treeContext,Be=Uc(Ee.nextSibling),Qe=p,je=!0,Ct=null,Kt=!1,f!==null&&Te(p,f),p=Ic(p,D.children),p.flags|=4096);return p}return Q?(go(),Ee=D.fallback,Q=p.mode,Le=f.child,at=Le.sibling,D=Wu(Le,{mode:"hidden",children:D.children}),D.subtreeFlags=Le.subtreeFlags&65011712,at!==null?Ee=Wu(at,Ee):(Ee=Fl(Ee,Q,O,null),Ee.flags|=2),Ee.return=p,D.return=p,D.sibling=Ee,p.child=D,Vs(null,D),D=p.child,Ee=f.child.memoizedState,Ee===null?Ee=rs(O):(Q=Ee.cachePool,Q!==null?(Le=yn._currentValue,Q=Q.parent!==Le?{parent:Le,pool:Le}:Q):Q=Dg(),Ee={baseLanes:Ee.baseLanes|O,cachePool:Q}),D.memoizedState=Ee,D.childLanes=Oo(f,ce,O),p.memoizedState=bo,Vs(f.child,D)):(Sd(p),O=f.child,f=O.sibling,O=Wu(O,{mode:"visible",children:D.children}),O.return=p,O.sibling=null,f!==null&&(ce=p.deletions,ce===null?(p.deletions=[f],p.flags|=16):ce.push(f)),p.child=O,p.memoizedState=null,O)}function Ic(f,p){return p=Up({mode:"visible",children:p},f.mode),p.return=f,f.child=p}function Up(f,p){return f=na(22,f,null,p),f.lanes=0,f}function Ad(f,p,O){return bd(p,f.child,null,O),f=Ic(p,p.pendingProps.children),f.flags|=2,p.memoizedState=null,f}function kh(f,p,O){f.lanes|=p;var D=f.alternate;D!==null&&(D.lanes|=p),Fu(f.return,p,O)}function vm(f,p,O,D,Q,Y){var ce=f.memoizedState;ce===null?f.memoizedState={isBackwards:p,rendering:null,renderingStartTime:0,last:D,tail:O,tailMode:Q,treeForkCount:Y}:(ce.isBackwards=p,ce.rendering=null,ce.renderingStartTime=0,ce.last=D,ce.tail=O,ce.tailMode=Q,ce.treeForkCount=Y)}function Df(f,p,O){var D=p.pendingProps,Q=D.revealOrder,Y=D.tail;D=D.children;var ce=ha.current,Ee=(ce&2)!==0;if(Ee?(ce=ce&1|2,p.flags|=128):ce&=1,B(ha,ce),$i(f,p,D,O),D=je?Ei:0,!Ee&&f!==null&&(f.flags&128)!==0)e:for(f=p.child;f!==null;){if(f.tag===13)f.memoizedState!==null&&kh(f,O,p);else if(f.tag===19)kh(f,O,p);else if(f.child!==null){f.child.return=f,f=f.child;continue}if(f===p)break e;for(;f.sibling===null;){if(f.return===null||f.return===p)break e;f=f.return}f.sibling.return=f.return,f=f.sibling}switch(Q){case"forwards":for(O=p.child,Q=null;O!==null;)f=O.alternate,f!==null&&Ag(f)===null&&(Q=O),O=O.sibling;O=Q,O===null?(Q=p.child,p.child=null):(Q=O.sibling,O.sibling=null),vm(p,!1,Q,O,Y,D);break;case"backwards":case"unstable_legacy-backwards":for(O=null,Q=p.child,p.child=null;Q!==null;){if(f=Q.alternate,f!==null&&Ag(f)===null){p.child=Q;break}f=Q.sibling,Q.sibling=O,O=Q,Q=f}vm(p,!0,O,null,Y,D);break;case"together":vm(p,!1,null,null,void 0,D);break;default:p.memoizedState=null}return p.child}function is(f,p,O){if(f!==null&&(p.dependencies=f.dependencies),Eo|=p.lanes,(O&p.childLanes)===0)if(f!==null){if(Bl(f,p,O,!1),(O&p.childLanes)===0)return null}else return null;if(f!==null&&p.child!==f.child)throw Error(r(153));if(p.child!==null){for(f=p.child,O=Wu(f,f.pendingProps),p.child=O,O.return=p;f.sibling!==null;)f=f.sibling,O=O.sibling=Wu(f,f.pendingProps),O.return=p;O.sibling=null}return p.child}function $f(f,p){return(f.lanes&p)!==0?!0:(f=f.dependencies,!!(f!==null&&md(f)))}function ym(f,p,O){switch(p.tag){case 3:be(p,p.stateNode.containerInfo),Ns(p,yn,f.memoizedState.cache),Se();break;case 27:case 5:pe(p);break;case 4:be(p,p.stateNode.containerInfo);break;case 10:Ns(p,p.type,p.memoizedProps.value);break;case 31:if(p.memoizedState!==null)return p.flags|=128,lm(p),null;break;case 13:var D=p.memoizedState;if(D!==null)return D.dehydrated!==null?(Sd(p),p.flags|=128,null):(O&p.child.childLanes)!==0?Ci(f,p,O):(Sd(p),f=is(f,p,O),f!==null?f.sibling:null);Sd(p);break;case 19:var Q=(f.flags&128)!==0;if(D=(O&p.childLanes)!==0,D||(Bl(f,p,O,!1),D=(O&p.childLanes)!==0),Q){if(D)return Df(f,p,O);p.flags|=128}if(Q=p.memoizedState,Q!==null&&(Q.rendering=null,Q.tail=null,Q.lastEffect=null),B(ha,ha.current),D)break;return null;case 22:return p.lanes=0,nu(f,p,O,p.pendingProps);case 24:Ns(p,yn,f.memoizedState.cache)}return is(f,p,O)}function Xg(f,p,O){if(f!==null)if(f.memoizedProps!==p.pendingProps)bi=!0;else{if(!$f(f,O)&&(p.flags&128)===0)return bi=!1,ym(f,p,O);bi=(f.flags&131072)!==0}else bi=!1,je&&(p.flags&1048576)!==0&&re(p,Ei,p.index);switch(p.lanes=0,p.tag){case 16:e:{var D=p.pendingProps;if(f=Bs(p.elementType),p.type=f,typeof f=="function")Xi(f)?(D=qi(f,D),p.tag=1,p=xu(null,p,f,D,O)):(p.tag=0,p=Th(null,p,f,D,O));else{if(f!=null){var Q=f.$$typeof;if(Q===T){p.tag=11,p=Sn(null,p,f,D,O);break e}else if(Q===k){p.tag=14,p=Rd(null,p,f,D,O);break e}}throw p=U(f)||f,Error(r(306,p,""))}}return p;case 0:return Th(f,p,p.type,p.pendingProps,O);case 1:return D=p.type,Q=qi(D,p.pendingProps),xu(f,p,D,Q,O);case 3:e:{if(be(p,p.stateNode.containerInfo),f===null)throw Error(r(387));D=p.pendingProps;var Y=p.memoizedState;Q=Y.element,wg(f,p),xd(p,D,null,O);var ce=p.memoizedState;if(D=ce.cache,Ns(p,yn,D),D!==Y.cache&&Rc(p,[yn],O,!0),_h(),D=ce.element,Y.isDehydrated)if(Y={element:D,isDehydrated:!1,cache:ce.cache},p.updateQueue.baseState=Y,p.memoizedState=Y,p.flags&256){p=Lr(f,p,D,O);break e}else if(D!==Q){Q=Tu(Error(r(424)),p),Il(Q),p=Lr(f,p,D,O);break e}else{switch(f=p.stateNode.containerInfo,f.nodeType){case 9:f=f.body;break;default:f=f.nodeName==="HTML"?f.ownerDocument.body:f}for(Be=Uc(f.firstChild),Qe=p,je=!0,Ct=null,Kt=!0,O=Ty(p,null,D,O),p.child=O;O;)O.flags=O.flags&-3|4096,O=O.sibling}else{if(Se(),D===Q){p=is(f,p,O);break e}$i(f,p,D,O)}p=p.child}return p;case 26:return Us(f,p),f===null?(O=l_(p.type,null,p.pendingProps,null))?p.memoizedState=O:je||(O=p.type,f=p.pendingProps,D=l1(ie.current).createElement(O),D[Rt]=p,D[sn]=f,El(D,O,f),ti(D),p.stateNode=D):p.memoizedState=l_(p.type,f.memoizedProps,p.pendingProps,f.memoizedState),null;case 27:return pe(p),f===null&&je&&(D=p.stateNode=i_(p.type,p.pendingProps,ie.current),Qe=p,Kt=!0,Q=Be,qn(p.type)?(F4=Q,Be=Uc(D.firstChild)):Be=Q),$i(f,p,p.pendingProps.children,O),Us(f,p),f===null&&(p.flags|=4194304),p.child;case 5:return f===null&&je&&((Q=D=Be)&&(D=D5(D,p.type,p.pendingProps,Kt),D!==null?(p.stateNode=D,Qe=p,Be=Uc(D.firstChild),Kt=!1,Q=!0):Q=!1),Q||cn(p)),pe(p),Q=p.type,Y=p.pendingProps,ce=f!==null?f.memoizedProps:null,D=Y.children,Kp(Q,Y)?D=null:ce!==null&&Kp(Q,ce)&&(p.flags|=32),p.memoizedState!==null&&(Q=Pg(f,p,b4,null,null,O),sv._currentValue=Q),Us(f,p),$i(f,p,D,O),p.child;case 6:return f===null&&je&&((f=O=Be)&&(O=xi(O,p.pendingProps,Kt),O!==null?(p.stateNode=O,Qe=p,Be=null,f=!0):f=!1),f||cn(p)),null;case 13:return Ci(f,p,O);case 4:return be(p,p.stateNode.containerInfo),D=p.pendingProps,f===null?p.child=bd(p,null,D,O):$i(f,p,D,O),p.child;case 11:return Sn(f,p,p.type,p.pendingProps,O);case 7:return $i(f,p,p.pendingProps,O),p.child;case 8:return $i(f,p,p.pendingProps.children,O),p.child;case 12:return $i(f,p,p.pendingProps.children,O),p.child;case 10:return D=p.pendingProps,Ns(p,p.type,D.value),$i(f,p,D.children,O),p.child;case 9:return Q=p.type._context,D=p.pendingProps.children,xh(p),Q=vu(Q),D=D(Q),p.flags|=1,$i(f,p,D,O),p.child;case 14:return Rd(f,p,p.type,p.pendingProps,O);case 15:return xl(f,p,p.type,p.pendingProps,O);case 19:return Df(f,p,O);case 31:return gm(f,p,O);case 22:return nu(f,p,O,p.pendingProps);case 24:return xh(p),D=vu(yn),f===null?(Q=Ac(),Q===null&&(Q=ii,Y=Is(),Q.pooledCache=Y,Y.refCount++,Y!==null&&(Q.pooledCacheLanes|=O),Q=Y),p.memoizedState={parent:D,cache:Q},Tc(p),Ns(p,yn,Q)):((f.lanes&O)!==0&&(wg(f,p),xd(p,null,null,O),_h()),Q=f.memoizedState,Y=p.memoizedState,Q.parent!==D?(Q={parent:D,cache:D},p.memoizedState=Q,p.lanes===0&&(p.memoizedState=p.updateQueue.baseState=Q),Ns(p,yn,D)):(D=Y.cache,Ns(p,yn,D),D!==Q.cache&&Rc(p,[yn],O,!0))),$i(f,p,p.pendingProps.children,O),p.child;case 29:throw p.pendingProps}throw Error(r(156,p.tag))}function jl(f){f.flags|=4}function Td(f,p,O,D,Q){if((p=(f.mode&32)!==0)&&(p=!1),p){if(f.flags|=16777216,(Q&335544128)===Q)if(f.stateNode.complete)f.flags|=8192;else if(kt())f.flags|=8192;else throw _n=im,Np}else f.flags&=-16777217}function Lc(f,p){if(p.type!=="stylesheet"||(p.state.loading&4)!==0)f.flags&=-16777217;else if(f.flags|=16777216,!d_(p))if(kt())f.flags|=8192;else throw _n=im,Np}function Ph(f,p){p!==null&&(f.flags|=4),f.flags&16384&&(p=f.tag!==22?Vr():536870912,f.lanes|=p,Do|=p)}function bm(f,p){if(!je)switch(f.tailMode){case"hidden":p=f.tail;for(var O=null;p!==null;)p.alternate!==null&&(O=p),p=p.sibling;O===null?f.tail=null:O.sibling=null;break;case"collapsed":O=f.tail;for(var D=null;O!==null;)O.alternate!==null&&(D=O),O=O.sibling;D===null?p||f.tail===null?f.tail=null:f.tail.sibling=null:D.sibling=null}}function Xr(f){var p=f.alternate!==null&&f.alternate.child===f.child,O=0,D=0;if(p)for(var Q=f.child;Q!==null;)O|=Q.lanes|Q.childLanes,D|=Q.subtreeFlags&65011712,D|=Q.flags&65011712,Q.return=f,Q=Q.sibling;else for(Q=f.child;Q!==null;)O|=Q.lanes|Q.childLanes,D|=Q.subtreeFlags,D|=Q.flags,Q.return=f,Q=Q.sibling;return f.subtreeFlags|=D,f.childLanes=O,p}function Yg(f,p,O){var D=p.pendingProps;switch(xe(p),p.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Xr(p),null;case 1:return Xr(p),null;case 3:return O=p.stateNode,D=null,f!==null&&(D=f.memoizedState.cache),p.memoizedState.cache!==D&&(p.flags|=2048),Ll(yn),ve(),O.pendingContext&&(O.context=O.pendingContext,O.pendingContext=null),(f===null||f.child===null)&&(Qa(p)?jl(p):f===null||f.memoizedState.isDehydrated&&(p.flags&256)===0||(p.flags|=1024,bl())),Xr(p),null;case 26:var Q=p.type,Y=p.memoizedState;return f===null?(jl(p),Y!==null?(Xr(p),Lc(p,Y)):(Xr(p),Td(p,Q,null,D,O))):Y?Y!==f.memoizedState?(jl(p),Xr(p),Lc(p,Y)):(Xr(p),p.flags&=-16777217):(f=f.memoizedProps,f!==D&&jl(p),Xr(p),Td(p,Q,f,D,O)),null;case 27:if(_e(p),O=ie.current,Q=p.type,f!==null&&p.stateNode!=null)f.memoizedProps!==D&&jl(p);else{if(!D){if(p.stateNode===null)throw Error(r(166));return Xr(p),null}f=ne.current,Qa(p)?vn(p):(f=i_(Q,D,O),p.stateNode=f,jl(p))}return Xr(p),null;case 5:if(_e(p),Q=p.type,f!==null&&p.stateNode!=null)f.memoizedProps!==D&&jl(p);else{if(!D){if(p.stateNode===null)throw Error(r(166));return Xr(p),null}if(Y=ne.current,Qa(p))vn(p);else{var ce=l1(ie.current);switch(Y){case 1:Y=ce.createElementNS("http://www.w3.org/2000/svg",Q);break;case 2:Y=ce.createElementNS("http://www.w3.org/1998/Math/MathML",Q);break;default:switch(Q){case"svg":Y=ce.createElementNS("http://www.w3.org/2000/svg",Q);break;case"math":Y=ce.createElementNS("http://www.w3.org/1998/Math/MathML",Q);break;case"script":Y=ce.createElement("div"),Y.innerHTML="<script><\/script>",Y=Y.removeChild(Y.firstChild);break;case"select":Y=typeof D.is=="string"?ce.createElement("select",{is:D.is}):ce.createElement("select"),D.multiple?Y.multiple=!0:D.size&&(Y.size=D.size);break;default:Y=typeof D.is=="string"?ce.createElement(Q,{is:D.is}):ce.createElement(Q)}}Y[Rt]=p,Y[sn]=D;e:for(ce=p.child;ce!==null;){if(ce.tag===5||ce.tag===6)Y.appendChild(ce.stateNode);else if(ce.tag!==4&&ce.tag!==27&&ce.child!==null){ce.child.return=ce,ce=ce.child;continue}if(ce===p)break e;for(;ce.sibling===null;){if(ce.return===null||ce.return===p)break e;ce=ce.return}ce.sibling.return=ce.return,ce=ce.sibling}p.stateNode=Y;e:switch(El(Y,Q,D),Q){case"button":case"input":case"select":case"textarea":D=!!D.autoFocus;break e;case"img":D=!0;break e;default:D=!1}D&&jl(p)}}return Xr(p),Td(p,p.type,f===null?null:f.memoizedProps,p.pendingProps,O),null;case 6:if(f&&p.stateNode!=null)f.memoizedProps!==D&&jl(p);else{if(typeof D!="string"&&p.stateNode===null)throw Error(r(166));if(f=ie.current,Qa(p)){if(f=p.stateNode,O=p.memoizedProps,D=null,Q=Qe,Q!==null)switch(Q.tag){case 27:case 5:D=Q.memoizedProps}f[Rt]=p,f=!!(f.nodeValue===O||D!==null&&D.suppressHydrationWarning===!0||KS(f.nodeValue,O)),f||cn(p,!0)}else f=l1(f).createTextNode(D),f[Rt]=p,p.stateNode=f}return Xr(p),null;case 31:if(O=p.memoizedState,f===null||f.memoizedState!==null){if(D=Qa(p),O!==null){if(f===null){if(!D)throw Error(r(318));if(f=p.memoizedState,f=f!==null?f.dehydrated:null,!f)throw Error(r(557));f[Rt]=p}else Se(),(p.flags&128)===0&&(p.memoizedState=null),p.flags|=4;Xr(p),f=!1}else O=bl(),f!==null&&f.memoizedState!==null&&(f.memoizedState.hydrationErrors=O),f=!0;if(!f)return p.flags&256?(Ql(p),p):(Ql(p),null);if((p.flags&128)!==0)throw Error(r(558))}return Xr(p),null;case 13:if(D=p.memoizedState,f===null||f.memoizedState!==null&&f.memoizedState.dehydrated!==null){if(Q=Qa(p),D!==null&&D.dehydrated!==null){if(f===null){if(!Q)throw Error(r(318));if(Q=p.memoizedState,Q=Q!==null?Q.dehydrated:null,!Q)throw Error(r(317));Q[Rt]=p}else Se(),(p.flags&128)===0&&(p.memoizedState=null),p.flags|=4;Xr(p),Q=!1}else Q=bl(),f!==null&&f.memoizedState!==null&&(f.memoizedState.hydrationErrors=Q),Q=!0;if(!Q)return p.flags&256?(Ql(p),p):(Ql(p),null)}return Ql(p),(p.flags&128)!==0?(p.lanes=O,p):(O=D!==null,f=f!==null&&f.memoizedState!==null,O&&(D=p.child,Q=null,D.alternate!==null&&D.alternate.memoizedState!==null&&D.alternate.memoizedState.cachePool!==null&&(Q=D.alternate.memoizedState.cachePool.pool),Y=null,D.memoizedState!==null&&D.memoizedState.cachePool!==null&&(Y=D.memoizedState.cachePool.pool),Y!==Q&&(D.flags|=2048)),O!==f&&O&&(p.child.flags|=8192),Ph(p,p.updateQueue),Xr(p),null);case 4:return ve(),f===null&&w4(p.stateNode.containerInfo),Xr(p),null;case 10:return Ll(p.type),Xr(p),null;case 19:if(X(ha),D=p.memoizedState,D===null)return Xr(p),null;if(Q=(p.flags&128)!==0,Y=D.rendering,Y===null)if(Q)bm(D,!1);else{if(Kr!==0||f!==null&&(f.flags&128)!==0)for(f=p.child;f!==null;){if(Y=Ag(f),Y!==null){for(p.flags|=128,bm(D,!1),f=Y.updateQueue,p.updateQueue=f,Ph(p,f),p.subtreeFlags=0,f=O,O=p.child;O!==null;)mu(O,f),O=O.sibling;return B(ha,ha.current&1|2),je&&I(p,D.treeForkCount),p.child}f=f.sibling}D.tail!==null&&Ze()>cl&&(p.flags|=128,Q=!0,bm(D,!1),p.lanes=4194304)}else{if(!Q)if(f=Ag(Y),f!==null){if(p.flags|=128,Q=!0,f=f.updateQueue,p.updateQueue=f,Ph(p,f),bm(D,!0),D.tail===null&&D.tailMode==="hidden"&&!Y.alternate&&!je)return Xr(p),null}else 2*Ze()-D.renderingStartTime>cl&&O!==536870912&&(p.flags|=128,Q=!0,bm(D,!1),p.lanes=4194304);D.isBackwards?(Y.sibling=p.child,p.child=Y):(f=D.last,f!==null?f.sibling=Y:p.child=Y,D.last=Y)}return D.tail!==null?(f=D.tail,D.rendering=f,D.tail=f.sibling,D.renderingStartTime=Ze(),f.sibling=null,O=ha.current,B(ha,Q?O&1|2:O&1),je&&I(p,D.treeForkCount),f):(Xr(p),null);case 22:case 23:return Ql(p),yu(),D=p.memoizedState!==null,f!==null?f.memoizedState!==null!==D&&(p.flags|=8192):D&&(p.flags|=8192),D?(O&536870912)!==0&&(p.flags&128)===0&&(Xr(p),p.subtreeFlags&6&&(p.flags|=8192)):Xr(p),O=p.updateQueue,O!==null&&Ph(p,O.retryQueue),O=null,f!==null&&f.memoizedState!==null&&f.memoizedState.cachePool!==null&&(O=f.memoizedState.cachePool.pool),D=null,p.memoizedState!==null&&p.memoizedState.cachePool!==null&&(D=p.memoizedState.cachePool.pool),D!==O&&(p.flags|=2048),f!==null&&X(gd),null;case 24:return O=null,f!==null&&(O=f.memoizedState.cache),p.memoizedState.cache!==O&&(p.flags|=2048),Ll(yn),Xr(p),null;case 25:return null;case 30:return null}throw Error(r(156,p.tag))}function kd(f,p){switch(xe(p),p.tag){case 1:return f=p.flags,f&65536?(p.flags=f&-65537|128,p):null;case 3:return Ll(yn),ve(),f=p.flags,(f&65536)!==0&&(f&128)===0?(p.flags=f&-65537|128,p):null;case 26:case 27:case 5:return _e(p),null;case 31:if(p.memoizedState!==null){if(Ql(p),p.alternate===null)throw Error(r(340));Se()}return f=p.flags,f&65536?(p.flags=f&-65537|128,p):null;case 13:if(Ql(p),f=p.memoizedState,f!==null&&f.dehydrated!==null){if(p.alternate===null)throw Error(r(340));Se()}return f=p.flags,f&65536?(p.flags=f&-65537|128,p):null;case 19:return X(ha),null;case 4:return ve(),null;case 10:return Ll(p.type),null;case 22:case 23:return Ql(p),yu(),f!==null&&X(gd),f=p.flags,f&65536?(p.flags=f&-65537|128,p):null;case 24:return Ll(yn),null;case 25:return null;default:return null}}function Cf(f,p){switch(xe(p),p.tag){case 3:Ll(yn),ve();break;case 26:case 27:case 5:_e(p);break;case 4:ve();break;case 31:p.memoizedState!==null&&Ql(p);break;case 13:Ql(p);break;case 19:X(ha);break;case 10:Ll(p.type);break;case 22:case 23:Ql(p),yu(),f!==null&&X(gd);break;case 24:Ll(yn)}}function js(f,p){try{var O=p.updateQueue,D=O!==null?O.lastEffect:null;if(D!==null){var Q=D.next;O=Q;do{if((O.tag&f)===f){D=void 0;var Y=O.create,ce=O.inst;D=Y(),ce.destroy=D}O=O.next}while(O!==Q)}}catch(Ee){wi(p,p.return,Ee)}}function xo(f,p,O){try{var D=p.updateQueue,Q=D!==null?D.lastEffect:null;if(Q!==null){var Y=Q.next;D=Y;do{if((D.tag&f)===f){var ce=D.inst,Ee=ce.destroy;if(Ee!==void 0){ce.destroy=void 0,Q=p;var Le=O,at=Ee;try{at()}catch(mt){wi(Q,Le,mt)}}}D=D.next}while(D!==Y)}}catch(mt){wi(p,p.return,mt)}}function Zs(f){var p=f.updateQueue;if(p!==null){var O=f.stateNode;try{eu(p,O)}catch(D){wi(f,f.return,D)}}}function Gg(f,p,O){O.props=qi(f.type,f.memoizedProps),O.state=f.memoizedState;try{O.componentWillUnmount()}catch(D){wi(f,p,D)}}function ru(f,p){try{var O=f.ref;if(O!==null){switch(f.tag){case 26:case 27:case 5:var D=f.stateNode;break;case 30:D=f.stateNode;break;default:D=f.stateNode}typeof O=="function"?f.refCleanup=O(D):O.current=D}}catch(Q){wi(f,p,Q)}}function iu(f,p){var O=f.ref,D=f.refCleanup;if(O!==null)if(typeof D=="function")try{D()}catch(Q){wi(f,p,Q)}finally{f.refCleanup=null,f=f.alternate,f!=null&&(f.refCleanup=null)}else if(typeof O=="function")try{O(null)}catch(Q){wi(f,p,Q)}else O.current=null}function So(f){var p=f.type,O=f.memoizedProps,D=f.stateNode;try{e:switch(p){case"button":case"input":case"select":case"textarea":O.autoFocus&&D.focus();break e;case"img":O.src?D.src=O.src:O.srcSet&&(D.srcset=O.srcSet)}}catch(Q){wi(f,f.return,Q)}}function _o(f,p,O){try{var D=f.stateNode;S5(D,f.type,O,p),D[sn]=p}catch(Q){wi(f,f.return,Q)}}function za(f){return f.tag===5||f.tag===3||f.tag===26||f.tag===27&&qn(f.type)||f.tag===4}function Bc(f){e:for(;;){for(;f.sibling===null;){if(f.return===null||za(f.return))return null;f=f.return}for(f.sibling.return=f.return,f=f.sibling;f.tag!==5&&f.tag!==6&&f.tag!==18;){if(f.tag===27&&qn(f.type)||f.flags&2||f.child===null||f.tag===4)continue e;f.child.return=f,f=f.child}if(!(f.flags&2))return f.stateNode}}function er(f,p,O){var D=f.tag;if(D===5||D===6)f=f.stateNode,p?(O.nodeType===9?O.body:O.nodeName==="HTML"?O.ownerDocument.body:O).insertBefore(f,p):(p=O.nodeType===9?O.body:O.nodeName==="HTML"?O.ownerDocument.body:O,p.appendChild(f),O=O._reactRootContainer,O!=null||p.onclick!==null||(p.onclick=lo));else if(D!==4&&(D===27&&qn(f.type)&&(O=f.stateNode,p=null),f=f.child,f!==null))for(er(f,p,O),f=f.sibling;f!==null;)er(f,p,O),f=f.sibling}function Yr(f,p,O){var D=f.tag;if(D===5||D===6)f=f.stateNode,p?O.insertBefore(f,p):O.appendChild(f);else if(D!==4&&(D===27&&qn(f.type)&&(O=f.stateNode),f=f.child,f!==null))for(Yr(f,p,O),f=f.sibling;f!==null;)Yr(f,p,O),f=f.sibling}function Aa(f){var p=f.stateNode,O=f.memoizedProps;try{for(var D=f.type,Q=p.attributes;Q.length;)p.removeAttributeNode(Q[0]);El(p,D,O),p[Rt]=f,p[sn]=O}catch(Y){wi(f,f.return,Y)}}var as=!1,Vi=!1,wf=!1,Om=typeof WeakSet=="function"?WeakSet:Set,ma=null;function jp(f,p){if(f=f.containerInfo,u1=sO,f=rm(f),xf(f)){if("selectionStart"in f)var O={start:f.selectionStart,end:f.selectionEnd};else e:{O=(O=f.ownerDocument)&&O.defaultView||window;var D=O.getSelection&&O.getSelection();if(D&&D.rangeCount!==0){O=D.anchorNode;var Q=D.anchorOffset,Y=D.focusNode;D=D.focusOffset;try{O.nodeType,Y.nodeType}catch{O=null;break e}var ce=0,Ee=-1,Le=-1,at=0,mt=0,xt=f,lt=null;t:for(;;){for(var ft;xt!==O||Q!==0&&xt.nodeType!==3||(Ee=ce+Q),xt!==Y||D!==0&&xt.nodeType!==3||(Le=ce+D),xt.nodeType===3&&(ce+=xt.nodeValue.length),(ft=xt.firstChild)!==null;)lt=xt,xt=ft;for(;;){if(xt===f)break t;if(lt===O&&++at===Q&&(Ee=ce),lt===Y&&++mt===D&&(Le=ce),(ft=xt.nextSibling)!==null)break;xt=lt,lt=xt.parentNode}xt=ft}O=Ee===-1||Le===-1?null:{start:Ee,end:Le}}else O=null}O=O||{start:0,end:0}}else O=null;for(k4={focusedElem:f,selectionRange:O},sO=!1,ma=p;ma!==null;)if(p=ma,f=p.child,(p.subtreeFlags&1028)!==0&&f!==null)f.return=p,ma=f;else for(;ma!==null;){switch(p=ma,Y=p.alternate,f=p.flags,p.tag){case 0:if((f&4)!==0&&(f=p.updateQueue,f=f!==null?f.events:null,f!==null))for(O=0;O<f.length;O++)Q=f[O],Q.ref.impl=Q.nextImpl;break;case 11:case 15:break;case 1:if((f&1024)!==0&&Y!==null){f=void 0,O=p,Q=Y.memoizedProps,Y=Y.memoizedState,D=O.stateNode;try{var fn=qi(O.type,Q);f=D.getSnapshotBeforeUpdate(fn,Y),D.__reactInternalSnapshotBeforeUpdate=f}catch(An){wi(O,O.return,An)}}break;case 3:if((f&1024)!==0){if(f=p.stateNode.containerInfo,O=f.nodeType,O===9)tO(f);else if(O===1)switch(f.nodeName){case"HEAD":case"HTML":case"BODY":tO(f);break;default:f.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((f&1024)!==0)throw Error(r(163))}if(f=p.sibling,f!==null){f.return=p.return,ma=f;break}ma=p.return}}function Jy(f,p,O){var D=O.flags;switch(O.tag){case 0:case 11:case 15:Rf(f,O),D&4&&js(5,O);break;case 1:if(Rf(f,O),D&4)if(f=O.stateNode,p===null)try{f.componentDidMount()}catch(ce){wi(O,O.return,ce)}else{var Q=qi(O.type,p.memoizedProps);p=p.memoizedState;try{f.componentDidUpdate(Q,p,f.__reactInternalSnapshotBeforeUpdate)}catch(ce){wi(O,O.return,ce)}}D&64&&Zs(O),D&512&&ru(O,O.return);break;case 3:if(Rf(f,O),D&64&&(f=O.updateQueue,f!==null)){if(p=null,O.child!==null)switch(O.child.tag){case 27:case 5:p=O.child.stateNode;break;case 1:p=O.child.stateNode}try{eu(f,p)}catch(ce){wi(O,O.return,ce)}}break;case 27:p===null&&D&4&&Aa(O);case 26:case 5:Rf(f,O),p===null&&D&4&&So(O),D&512&&ru(O,O.return);break;case 12:Rf(f,O);break;case 31:Rf(f,O),D&4&&Sm(f,O);break;case 13:Rf(f,O),D&4&&e1(f,O),D&64&&(f=O.memoizedState,f!==null&&(f=f.dehydrated,f!==null&&(O=Gb.bind(null,O),$5(f,O))));break;case 22:if(D=O.memoizedState!==null||as,!D){p=p!==null&&p.memoizedState!==null||Vi,Q=as;var Y=Vi;as=D,(Vi=p)&&!Y?Gr(f,O,(O.subtreeFlags&8772)!==0):Rf(f,O),as=Q,Vi=Y}break;case 30:break;default:Rf(f,O)}}function xm(f){var p=f.alternate;p!==null&&(f.alternate=null,xm(p)),f.child=null,f.deletions=null,f.sibling=null,f.tag===5&&(p=f.stateNode,p!==null&&Al(p)),f.stateNode=null,f.return=null,f.dependencies=null,f.memoizedProps=null,f.memoizedState=null,f.pendingProps=null,f.stateNode=null,f.updateQueue=null}var Rr=null,qa=!1;function ll(f,p,O){for(O=O.child;O!==null;)Pd(f,p,O),O=O.sibling}function Pd(f,p,O){if(an&&typeof an.onCommitFiberUnmount=="function")try{an.onCommitFiberUnmount(zt,O)}catch{}switch(O.tag){case 26:Vi||iu(O,p),ll(f,p,O),O.memoizedState?O.memoizedState.count--:O.stateNode&&(O=O.stateNode,O.parentNode.removeChild(O));break;case 27:Vi||iu(O,p);var D=Rr,Q=qa;qn(O.type)&&(Rr=O.stateNode,qa=!1),ll(f,p,O),s1(O.stateNode),Rr=D,qa=Q;break;case 5:Vi||iu(O,p);case 6:if(D=Rr,Q=qa,Rr=null,ll(f,p,O),Rr=D,qa=Q,Rr!==null)if(qa)try{(Rr.nodeType===9?Rr.body:Rr.nodeName==="HTML"?Rr.ownerDocument.body:Rr).removeChild(O.stateNode)}catch(Y){wi(O,p,Y)}else try{Rr.removeChild(O.stateNode)}catch(Y){wi(O,p,Y)}break;case 18:Rr!==null&&(qa?(f=Rr,M4(f.nodeType===9?f.body:f.nodeName==="HTML"?f.ownerDocument.body:f,O.stateNode),fv(f)):M4(Rr,O.stateNode));break;case 4:D=Rr,Q=qa,Rr=O.stateNode.containerInfo,qa=!0,ll(f,p,O),Rr=D,qa=Q;break;case 0:case 11:case 14:case 15:xo(2,O,p),Vi||xo(4,O,p),ll(f,p,O);break;case 1:Vi||(iu(O,p),D=O.stateNode,typeof D.componentWillUnmount=="function"&&Gg(O,p,D)),ll(f,p,O);break;case 21:ll(f,p,O);break;case 22:Vi=(D=Vi)||O.memoizedState!==null,ll(f,p,O),Vi=D;break;default:ll(f,p,O)}}function Sm(f,p){if(p.memoizedState===null&&(f=p.alternate,f!==null&&(f=f.memoizedState,f!==null))){f=f.dehydrated;try{fv(f)}catch(O){wi(p,p.return,O)}}}function e1(f,p){if(p.memoizedState===null&&(f=p.alternate,f!==null&&(f=f.memoizedState,f!==null&&(f=f.dehydrated,f!==null))))try{fv(f)}catch(O){wi(p,p.return,O)}}function Xb(f){switch(f.tag){case 31:case 13:case 19:var p=f.stateNode;return p===null&&(p=f.stateNode=new Om),p;case 22:return f=f.stateNode,p=f._retryCache,p===null&&(p=f._retryCache=new Om),p;default:throw Error(r(435,f.tag))}}function Ta(f,p){var O=Xb(f);p.forEach(function(D){if(!O.has(D)){O.add(D);var Q=y5.bind(null,f,D);D.then(Q,Q)}})}function ol(f,p){var O=p.deletions;if(O!==null)for(var D=0;D<O.length;D++){var Q=O[D],Y=f,ce=p,Ee=ce;e:for(;Ee!==null;){switch(Ee.tag){case 27:if(qn(Ee.type)){Rr=Ee.stateNode,qa=!1;break e}break;case 5:Rr=Ee.stateNode,qa=!1;break e;case 3:case 4:Rr=Ee.stateNode.containerInfo,qa=!0;break e}Ee=Ee.return}if(Rr===null)throw Error(r(160));Pd(Y,ce,Q),Rr=null,qa=!1,Y=Q.alternate,Y!==null&&(Y.return=null),Q.return=null}if(p.subtreeFlags&13886)for(p=p.child;p!==null;)Md(p,f),p=p.sibling}var Zl=null;function Md(f,p){var O=f.alternate,D=f.flags;switch(f.tag){case 0:case 11:case 14:case 15:ol(p,f),Br(f),D&4&&(xo(3,f,f.return),js(3,f),xo(5,f,f.return));break;case 1:ol(p,f),Br(f),D&512&&(Vi||O===null||iu(O,O.return)),D&64&&as&&(f=f.updateQueue,f!==null&&(D=f.callbacks,D!==null&&(O=f.shared.hiddenCallbacks,f.shared.hiddenCallbacks=O===null?D:O.concat(D))));break;case 26:var Q=Zl;if(ol(p,f),Br(f),D&512&&(Vi||O===null||iu(O,O.return)),D&4){var Y=O!==null?O.memoizedState:null;if(D=f.memoizedState,O===null)if(D===null)if(f.stateNode===null){e:{D=f.type,O=f.memoizedProps,Q=Q.ownerDocument||Q;t:switch(D){case"title":Y=Q.getElementsByTagName("title")[0],(!Y||Y[wu]||Y[Rt]||Y.namespaceURI==="http://www.w3.org/2000/svg"||Y.hasAttribute("itemprop"))&&(Y=Q.createElement(D),Q.head.insertBefore(Y,Q.querySelector("head > title"))),El(Y,D,O),Y[Rt]=f,ti(Y),D=Y;break e;case"link":var ce=c_("link","href",Q).get(D+(O.href||""));if(ce){for(var Ee=0;Ee<ce.length;Ee++)if(Y=ce[Ee],Y.getAttribute("href")===(O.href==null||O.href===""?null:O.href)&&Y.getAttribute("rel")===(O.rel==null?null:O.rel)&&Y.getAttribute("title")===(O.title==null?null:O.title)&&Y.getAttribute("crossorigin")===(O.crossOrigin==null?null:O.crossOrigin)){ce.splice(Ee,1);break t}}Y=Q.createElement(D),El(Y,D,O),Q.head.appendChild(Y);break;case"meta":if(ce=c_("meta","content",Q).get(D+(O.content||""))){for(Ee=0;Ee<ce.length;Ee++)if(Y=ce[Ee],Y.getAttribute("content")===(O.content==null?null:""+O.content)&&Y.getAttribute("name")===(O.name==null?null:O.name)&&Y.getAttribute("property")===(O.property==null?null:O.property)&&Y.getAttribute("http-equiv")===(O.httpEquiv==null?null:O.httpEquiv)&&Y.getAttribute("charset")===(O.charSet==null?null:O.charSet)){ce.splice(Ee,1);break t}}Y=Q.createElement(D),El(Y,D,O),Q.head.appendChild(Y);break;default:throw Error(r(468,D))}Y[Rt]=f,ti(Y),D=Y}f.stateNode=D}else f_(Q,f.type,f.stateNode);else f.stateNode=s_(Q,D,f.memoizedProps);else Y!==D?(Y===null?O.stateNode!==null&&(O=O.stateNode,O.parentNode.removeChild(O)):Y.count--,D===null?f_(Q,f.type,f.stateNode):s_(Q,D,f.memoizedProps)):D===null&&f.stateNode!==null&&_o(f,f.memoizedProps,O.memoizedProps)}break;case 27:ol(p,f),Br(f),D&512&&(Vi||O===null||iu(O,O.return)),O!==null&&D&4&&_o(f,f.memoizedProps,O.memoizedProps);break;case 5:if(ol(p,f),Br(f),D&512&&(Vi||O===null||iu(O,O.return)),f.flags&32){Q=f.stateNode;try{Au(Q,"")}catch(fn){wi(f,f.return,fn)}}D&4&&f.stateNode!=null&&(Q=f.memoizedProps,_o(f,Q,O!==null?O.memoizedProps:Q)),D&1024&&(wf=!0);break;case 6:if(ol(p,f),Br(f),D&4){if(f.stateNode===null)throw Error(r(162));D=f.memoizedProps,O=f.stateNode;try{O.nodeValue=D}catch(fn){wi(f,f.return,fn)}}break;case 3:if(c1=null,Q=Zl,Zl=rO(p.containerInfo),ol(p,f),Zl=Q,Br(f),D&4&&O!==null&&O.memoizedState.isDehydrated)try{fv(p.containerInfo)}catch(fn){wi(f,f.return,fn)}wf&&(wf=!1,Yb(f));break;case 4:D=Zl,Zl=rO(f.stateNode.containerInfo),ol(p,f),Br(f),Zl=D;break;case 12:ol(p,f),Br(f);break;case 31:ol(p,f),Br(f),D&4&&(D=f.updateQueue,D!==null&&(f.updateQueue=null,Ta(f,D)));break;case 13:ol(p,f),Br(f),f.child.flags&8192&&f.memoizedState!==null!=(O!==null&&O.memoizedState!==null)&&(zc=Ze()),D&4&&(D=f.updateQueue,D!==null&&(f.updateQueue=null,Ta(f,D)));break;case 22:Q=f.memoizedState!==null;var Le=O!==null&&O.memoizedState!==null,at=as,mt=Vi;if(as=at||Q,Vi=mt||Le,ol(p,f),Vi=mt,as=at,Br(f),D&8192)e:for(p=f.stateNode,p._visibility=Q?p._visibility&-2:p._visibility|1,Q&&(O===null||Le||as||Vi||Mh(f)),O=null,p=f;;){if(p.tag===5||p.tag===26){if(O===null){Le=O=p;try{if(Y=Le.stateNode,Q)ce=Y.style,typeof ce.setProperty=="function"?ce.setProperty("display","none","important"):ce.display="none";else{Ee=Le.stateNode;var xt=Le.memoizedProps.style,lt=xt!=null&&xt.hasOwnProperty("display")?xt.display:null;Ee.style.display=lt==null||typeof lt=="boolean"?"":(""+lt).trim()}}catch(fn){wi(Le,Le.return,fn)}}}else if(p.tag===6){if(O===null){Le=p;try{Le.stateNode.nodeValue=Q?"":Le.memoizedProps}catch(fn){wi(Le,Le.return,fn)}}}else if(p.tag===18){if(O===null){Le=p;try{var ft=Le.stateNode;Q?Ws(ft,!0):Ws(Le.stateNode,!1)}catch(fn){wi(Le,Le.return,fn)}}}else if((p.tag!==22&&p.tag!==23||p.memoizedState===null||p===f)&&p.child!==null){p.child.return=p,p=p.child;continue}if(p===f)break e;for(;p.sibling===null;){if(p.return===null||p.return===f)break e;O===p&&(O=null),p=p.return}O===p&&(O=null),p.sibling.return=p.return,p=p.sibling}D&4&&(D=f.updateQueue,D!==null&&(O=D.retryQueue,O!==null&&(D.retryQueue=null,Ta(f,O))));break;case 19:ol(p,f),Br(f),D&4&&(D=f.updateQueue,D!==null&&(f.updateQueue=null,Ta(f,D)));break;case 30:break;case 21:break;default:ol(p,f),Br(f)}}function Br(f){var p=f.flags;if(p&2){try{for(var O,D=f.return;D!==null;){if(za(D)){O=D;break}D=D.return}if(O==null)throw Error(r(160));switch(O.tag){case 27:var Q=O.stateNode,Y=Bc(f);Yr(f,Y,Q);break;case 5:var ce=O.stateNode;O.flags&32&&(Au(ce,""),O.flags&=-33);var Ee=Bc(f);Yr(f,Ee,ce);break;case 3:case 4:var Le=O.stateNode.containerInfo,at=Bc(f);er(f,at,Le);break;default:throw Error(r(161))}}catch(mt){wi(f,f.return,mt)}f.flags&=-3}p&4096&&(f.flags&=-4097)}function Yb(f){if(f.subtreeFlags&1024)for(f=f.child;f!==null;){var p=f;Yb(p),p.tag===5&&p.flags&1024&&p.stateNode.reset(),f=f.sibling}}function Rf(f,p){if(p.subtreeFlags&8772)for(p=p.child;p!==null;)Jy(f,p.alternate,p),p=p.sibling}function Mh(f){for(f=f.child;f!==null;){var p=f;switch(p.tag){case 0:case 11:case 14:case 15:xo(4,p,p.return),Mh(p);break;case 1:iu(p,p.return);var O=p.stateNode;typeof O.componentWillUnmount=="function"&&Gg(p,p.return,O),Mh(p);break;case 27:s1(p.stateNode);case 26:case 5:iu(p,p.return),Mh(p);break;case 22:p.memoizedState===null&&Mh(p);break;case 30:Mh(p);break;default:Mh(p)}f=f.sibling}}function Gr(f,p,O){for(O=O&&(p.subtreeFlags&8772)!==0,p=p.child;p!==null;){var D=p.alternate,Q=f,Y=p,ce=Y.flags;switch(Y.tag){case 0:case 11:case 15:Gr(Q,Y,O),js(4,Y);break;case 1:if(Gr(Q,Y,O),D=Y,Q=D.stateNode,typeof Q.componentDidMount=="function")try{Q.componentDidMount()}catch(at){wi(D,D.return,at)}if(D=Y,Q=D.updateQueue,Q!==null){var Ee=D.stateNode;try{var Le=Q.shared.hiddenCallbacks;if(Le!==null)for(Q.shared.hiddenCallbacks=null,Q=0;Q<Le.length;Q++)Ja(Le[Q],Ee)}catch(at){wi(D,D.return,at)}}O&&ce&64&&Zs(Y),ru(Y,Y.return);break;case 27:Aa(Y);case 26:case 5:Gr(Q,Y,O),O&&D===null&&ce&4&&So(Y),ru(Y,Y.return);break;case 12:Gr(Q,Y,O);break;case 31:Gr(Q,Y,O),O&&ce&4&&Sm(Q,Y);break;case 13:Gr(Q,Y,O),O&&ce&4&&e1(Q,Y);break;case 22:Y.memoizedState===null&&Gr(Q,Y,O),ru(Y,Y.return);break;case 30:break;default:Gr(Q,Y,O)}p=p.sibling}}function Kg(f,p){var O=null;f!==null&&f.memoizedState!==null&&f.memoizedState.cachePool!==null&&(O=f.memoizedState.cachePool.pool),f=null,p.memoizedState!==null&&p.memoizedState.cachePool!==null&&(f=p.memoizedState.cachePool.pool),f!==O&&(f!=null&&f.refCount++,O!=null&&Nu(O))}function Af(f,p){f=null,p.alternate!==null&&(f=p.alternate.memoizedState.cache),p=p.memoizedState.cache,p!==f&&(p.refCount++,f!=null&&Nu(f))}function au(f,p,O,D){if(p.subtreeFlags&10256)for(p=p.child;p!==null;)ra(f,p,O,D),p=p.sibling}function ra(f,p,O,D){var Q=p.flags;switch(p.tag){case 0:case 11:case 15:au(f,p,O,D),Q&2048&&js(9,p);break;case 1:au(f,p,O,D);break;case 3:au(f,p,O,D),Q&2048&&(f=null,p.alternate!==null&&(f=p.alternate.memoizedState.cache),p=p.memoizedState.cache,p!==f&&(p.refCount++,f!=null&&Nu(f)));break;case 12:if(Q&2048){au(f,p,O,D),f=p.stateNode;try{var Y=p.memoizedProps,ce=Y.id,Ee=Y.onPostCommit;typeof Ee=="function"&&Ee(ce,p.alternate===null?"mount":"update",f.passiveEffectDuration,-0)}catch(Le){wi(p,p.return,Le)}}else au(f,p,O,D);break;case 31:au(f,p,O,D);break;case 13:au(f,p,O,D);break;case 23:break;case 22:Y=p.stateNode,ce=p.alternate,p.memoizedState!==null?Y._visibility&2?au(f,p,O,D):Zp(f,p):Y._visibility&2?au(f,p,O,D):(Y._visibility|=2,Qc(f,p,O,D,(p.subtreeFlags&10256)!==0||!1)),Q&2048&&Kg(ce,p);break;case 24:au(f,p,O,D),Q&2048&&Af(p.alternate,p);break;default:au(f,p,O,D)}}function Qc(f,p,O,D,Q){for(Q=Q&&((p.subtreeFlags&10256)!==0||!1),p=p.child;p!==null;){var Y=f,ce=p,Ee=O,Le=D,at=ce.flags;switch(ce.tag){case 0:case 11:case 15:Qc(Y,ce,Ee,Le,Q),js(8,ce);break;case 23:break;case 22:var mt=ce.stateNode;ce.memoizedState!==null?mt._visibility&2?Qc(Y,ce,Ee,Le,Q):Zp(Y,ce):(mt._visibility|=2,Qc(Y,ce,Ee,Le,Q)),Q&&at&2048&&Kg(ce.alternate,ce);break;case 24:Qc(Y,ce,Ee,Le,Q),Q&&at&2048&&Af(ce.alternate,ce);break;default:Qc(Y,ce,Ee,Le,Q)}p=p.sibling}}function Zp(f,p){if(p.subtreeFlags&10256)for(p=p.child;p!==null;){var O=f,D=p,Q=D.flags;switch(D.tag){case 22:Zp(O,D),Q&2048&&Kg(D.alternate,D);break;case 24:Zp(O,D),Q&2048&&Af(D.alternate,D);break;default:Zp(O,D)}p=p.sibling}}var ga=8192;function Fh(f,p,O){if(f.subtreeFlags&ga)for(f=f.child;f!==null;)ka(f,p,O),f=f.sibling}function ka(f,p,O){switch(f.tag){case 26:Fh(f,p,O),f.flags&ga&&f.memoizedState!==null&&ov(O,Zl,f.memoizedState,f.memoizedProps);break;case 5:Fh(f,p,O);break;case 3:case 4:var D=Zl;Zl=rO(f.stateNode.containerInfo),Fh(f,p,O),Zl=D;break;case 22:f.memoizedState===null&&(D=f.alternate,D!==null&&D.memoizedState!==null?(D=ga,ga=16777216,Fh(f,p,O),ga=D):Fh(f,p,O));break;default:Fh(f,p,O)}}function Hl(f){var p=f.alternate;if(p!==null&&(f=p.child,f!==null)){p.child=null;do p=f.sibling,f.sibling=null,f=p;while(f!==null)}}function Sl(f){var p=f.deletions;if((f.flags&16)!==0){if(p!==null)for(var O=0;O<p.length;O++){var D=p[O];ma=D,_m(D,f)}Hl(f)}if(f.subtreeFlags&10256)for(f=f.child;f!==null;)Nh(f),f=f.sibling}function Nh(f){switch(f.tag){case 0:case 11:case 15:Sl(f),f.flags&2048&&xo(9,f,f.return);break;case 3:Sl(f);break;case 12:Sl(f);break;case 22:var p=f.stateNode;f.memoizedState!==null&&p._visibility&2&&(f.return===null||f.return.tag!==13)?(p._visibility&=-3,Wg(f)):Sl(f);break;default:Sl(f)}}function Wg(f){var p=f.deletions;if((f.flags&16)!==0){if(p!==null)for(var O=0;O<p.length;O++){var D=p[O];ma=D,_m(D,f)}Hl(f)}for(f=f.child;f!==null;){switch(p=f,p.tag){case 0:case 11:case 15:xo(8,p,p.return),Wg(p);break;case 22:O=p.stateNode,O._visibility&2&&(O._visibility&=-3,Wg(p));break;default:Wg(p)}f=f.sibling}}function _m(f,p){for(;ma!==null;){var O=ma;switch(O.tag){case 0:case 11:case 15:xo(8,O,p);break;case 23:case 22:if(O.memoizedState!==null&&O.memoizedState.cachePool!==null){var D=O.memoizedState.cachePool.pool;D!=null&&D.refCount++}break;case 24:Nu(O.memoizedState.cache)}if(D=O.child,D!==null)D.return=O,ma=D;else e:for(O=f;ma!==null;){D=ma;var Q=D.sibling,Y=D.return;if(xm(D),D===O){ma=null;break e}if(Q!==null){Q.return=Y,ma=Q;break e}ma=Y}}}var Jg={getCacheForType:function(f){var p=vu(yn),O=p.data.get(f);return O===void 0&&(O=f(),p.data.set(f,O)),O},cacheSignal:function(){return vu(yn).controller.signal}},ev=typeof WeakMap=="function"?WeakMap:Map,Ar=0,ii=null,tr=null,yr=0,bn=0,dr=null,Yn=!1,lr=!1,Oi=!1,ia=0,Kr=0,Eo=0,Tf=0,Hs=0,Tr=0,Do=0,Xs=null,sl=null,Xl=!1,zc=0,Hp=0,cl=1/0,Xp=null,qc=null,aa=0,Ys=null,$o=null,us=0,kf=0,Ih=null,tv=null,Lh=0,Bh=null;function _l(){return(Ar&2)!==0&&yr!==0?yr&-yr:G.T!==null?Gs():Vt()}function g(){if(Tr===0)if((yr&536870912)===0||je){var f=Ln;Ln<<=1,(Ln&3932160)===0&&(Ln=262144),Tr=f}else Tr=536870912;return f=tu.current,f!==null&&(f.flags|=32),Tr}function b(f,p,O){(f===ii&&(bn===2||bn===9)||f.cancelPendingCommit!==null)&&(We(f,0),le(f,yr,Tr,!1)),He(f,O),((Ar&2)===0||f!==ii)&&(f===ii&&((Ar&2)===0&&(Tf|=O),Kr===4&&le(f,yr,Tr,!1)),Fd(f))}function A(f,p,O){if((Ar&6)!==0)throw Error(r(327));var D=!O&&(p&127)===0&&(p&f.expiredLanes)===0||ur(f,p),Q=D?Qh(f,p):Yl(f,p,!0),Y=D;do{if(Q===0){lr&&!D&&le(f,p,0,!1);break}else{if(O=f.current.alternate,Y&&!ee(O)){Q=Yl(f,p,!1),Y=!1;continue}if(Q===2){if(Y=p,f.errorRecoveryDisabledLanes&Y)var ce=0;else ce=f.pendingLanes&-536870913,ce=ce!==0?ce:ce&536870912?536870912:0;if(ce!==0){p=ce;e:{var Ee=f;Q=Xs;var Le=Ee.current.memoizedState.isDehydrated;if(Le&&(We(Ee,ce).flags|=256),ce=Yl(Ee,ce,!1),ce!==2){if(Oi&&!Le){Ee.errorRecoveryDisabledLanes|=Y,Tf|=Y,Q=4;break e}Y=sl,sl=Q,Y!==null&&(sl===null?sl=Y:sl.push.apply(sl,Y))}Q=ce}if(Y=!1,Q!==2)continue}}if(Q===1){We(f,0),le(f,p,0,!0);break}e:{switch(D=f,Y=Q,Y){case 0:case 1:throw Error(r(345));case 4:if((p&4194048)!==p)break;case 6:le(D,p,Tr,!Yn);break e;case 2:sl=null;break;case 3:case 5:break;default:throw Error(r(329))}if((p&62914560)===p&&(Q=zc+0-Ze(),10<Q)){if(le(D,p,Tr,!Yn),cr(D,0,!0)!==0)break e;us=p,D.timeoutHandle=WS(z.bind(null,D,O,sl,Xp,Xl,p,Tr,Tf,Do,Yn,Y,"Throttled",-0,0),Q);break e}z(D,O,sl,Xp,Xl,p,Tr,Tf,Do,Yn,Y,null,-0,0)}}break}while(!0);Fd(f)}function z(f,p,O,D,Q,Y,ce,Ee,Le,at,mt,xt,lt,ft){if(f.timeoutHandle=-1,xt=p.subtreeFlags,xt&8192||(xt&16785408)===16785408){xt={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:lo},ka(p,Y,xt);var fn=(Y&62914560)===Y?zc-Ze():(Y&4194048)===Y?Hp-Ze():0;if(fn=F5(xt,fn),fn!==null){us=Y,f.cancelPendingCommit=fn(kn.bind(null,f,p,Y,O,D,Q,ce,Ee,Le,mt,xt,null,lt,ft)),le(f,Y,ce,!at);return}}kn(f,p,Y,O,D,Q,ce,Ee,Le)}function ee(f){for(var p=f;;){var O=p.tag;if((O===0||O===11||O===15)&&p.flags&16384&&(O=p.updateQueue,O!==null&&(O=O.stores,O!==null)))for(var D=0;D<O.length;D++){var Q=O[D],Y=Q.getSnapshot;Q=Q.value;try{if(!fr(Y(),Q))return!1}catch{return!1}}if(O=p.child,p.subtreeFlags&16384&&O!==null)O.return=p,p=O;else{if(p===f)break;for(;p.sibling===null;){if(p.return===null||p.return===f)return!0;p=p.return}p.sibling.return=p.return,p=p.sibling}}return!0}function le(f,p,O,D){p&=~Hs,p&=~Tf,f.suspendedLanes|=p,f.pingedLanes&=~p,D&&(f.warmLanes|=p),D=f.expirationTimes;for(var Q=p;0<Q;){var Y=31-Fe(Q),ce=1<<Y;D[Y]=-1,Q&=~ce}O!==0&&dt(f,O,p)}function De(){return(Ar&6)===0?(n1(0),!1):!0}function Ie(){if(tr!==null){if(bn===0)var f=tr.return;else f=tr,Ka=zn=null,Py(f),yd=null,Ju=0,f=tr;for(;f!==null;)Cf(f.alternate,f),f=f.return;tr=null}}function We(f,p){var O=f.timeoutHandle;O!==-1&&(f.timeoutHandle=-1,E5(O)),O=f.cancelPendingCommit,O!==null&&(f.cancelPendingCommit=null,O()),us=0,Ie(),ii=f,tr=O=Wu(f.current,null),yr=p,bn=0,dr=null,Yn=!1,lr=ur(f,p),Oi=!1,Do=Tr=Hs=Tf=Eo=Kr=0,sl=Xs=null,Xl=!1,(p&8)!==0&&(p|=p&32);var D=f.entangledLanes;if(D!==0)for(f=f.entanglements,D&=p;0<D;){var Q=31-Fe(D),Y=1<<Q;p|=f[Q],D&=~Y}return ia=p,Ga(),O}function vt(f,p){Tn=null,G.H=Cd,p===vd||p===Go?(p=$g(),bn=3):p===Np?(p=$g(),bn=4):bn=p===Vp?8:p!==null&&typeof p=="object"&&typeof p.then=="function"?6:1,dr=p,tr===null&&(Kr=1,mm(f,Tu(p,f.current)))}function kt(){var f=tu.current;return f===null?!0:(yr&4194048)===yr?Jo===null:(yr&62914560)===yr||(yr&536870912)!==0?f===Jo:!1}function Ht(){var f=G.H;return G.H=Cd,f===null?Cd:f}function Wt(){var f=G.A;return G.A=Jg,f}function Hn(){Kr=4,Yn||(yr&4194048)!==yr&&tu.current!==null||(lr=!0),(Eo&134217727)===0&&(Tf&134217727)===0||ii===null||le(ii,yr,Tr,!1)}function Yl(f,p,O){var D=Ar;Ar|=2;var Q=Ht(),Y=Wt();(ii!==f||yr!==p)&&(Xp=null,We(f,p)),p=!1;var ce=Kr;e:do try{if(bn!==0&&tr!==null){var Ee=tr,Le=dr;switch(bn){case 8:Ie(),ce=6;break e;case 3:case 2:case 9:case 6:tu.current===null&&(p=!0);var at=bn;if(bn=0,dr=null,At(f,Ee,Le,at),O&&lr){ce=0;break e}break;default:at=bn,bn=0,dr=null,At(f,Ee,Le,at)}}Em(),ce=Kr;break}catch(mt){vt(f,mt)}while(!0);return p&&f.shellSuspendCounter++,Ka=zn=null,Ar=D,G.H=Q,G.A=Y,tr===null&&(ii=null,yr=0,Ga()),ce}function Em(){for(;tr!==null;)Ge(tr)}function Qh(f,p){var O=Ar;Ar|=2;var D=Ht(),Q=Wt();ii!==f||yr!==p?(Xp=null,cl=Ze()+500,We(f,p)):lr=ur(f,p);e:do try{if(bn!==0&&tr!==null){p=tr;var Y=dr;t:switch(bn){case 1:bn=0,dr=null,At(f,p,Y,1);break;case 2:case 9:if(Lb(Y)){bn=0,dr=null,ct(p);break}p=function(){bn!==2&&bn!==9||ii!==f||(bn=7),Fd(f)},Y.then(p,p);break e;case 3:bn=7;break e;case 4:bn=5;break e;case 7:Lb(Y)?(bn=0,dr=null,ct(p)):(bn=0,dr=null,At(f,p,Y,7));break;case 5:var ce=null;switch(tr.tag){case 26:ce=tr.memoizedState;case 5:case 27:var Ee=tr;if(ce?d_(ce):Ee.stateNode.complete){bn=0,dr=null;var Le=Ee.sibling;if(Le!==null)tr=Le;else{var at=Ee.return;at!==null?(tr=at,gn(at)):tr=null}break t}}bn=0,dr=null,At(f,p,Y,5);break;case 6:bn=0,dr=null,At(f,p,Y,6);break;case 8:Ie(),Kr=6;break e;default:throw Error(r(462))}}ut();break}catch(mt){vt(f,mt)}while(!0);return Ka=zn=null,G.H=D,G.A=Q,Ar=O,tr!==null?0:(ii=null,yr=0,Ga(),Kr)}function ut(){for(;tr!==null&&!Ae();)Ge(tr)}function Ge(f){var p=Xg(f.alternate,f,ia);f.memoizedProps=f.pendingProps,p===null?gn(f):tr=p}function ct(f){var p=f,O=p.alternate;switch(p.tag){case 15:case 0:p=ul(O,p,p.pendingProps,p.type,void 0,yr);break;case 11:p=ul(O,p,p.pendingProps,p.type.render,p.ref,yr);break;case 5:Py(p);default:Cf(O,p),p=tr=mu(p,ia),p=Xg(O,p,ia)}f.memoizedProps=f.pendingProps,p===null?gn(f):tr=p}function At(f,p,O,D){Ka=zn=null,Py(p),yd=null,Ju=0;var Q=p.return;try{if(Ol(f,Q,p,O,yr)){Kr=1,mm(f,Tu(O,f.current)),tr=null;return}}catch(Y){if(Q!==null)throw tr=Q,Y;Kr=1,mm(f,Tu(O,f.current)),tr=null;return}p.flags&32768?(je||D===1?f=!0:lr||(yr&536870912)!==0?f=!1:(Yn=f=!0,(D===2||D===9||D===3||D===6)&&(D=tu.current,D!==null&&D.tag===13&&(D.flags|=16384))),fi(p,f)):gn(p)}function gn(f){var p=f;do{if((p.flags&32768)!==0){fi(p,Yn);return}f=p.return;var O=Yg(p.alternate,p,ia);if(O!==null){tr=O;return}if(p=p.sibling,p!==null){tr=p;return}tr=p=f}while(p!==null);Kr===0&&(Kr=5)}function fi(f,p){do{var O=kd(f.alternate,f);if(O!==null){O.flags&=32767,tr=O;return}if(O=f.return,O!==null&&(O.flags|=32768,O.subtreeFlags=0,O.deletions=null),!p&&(f=f.sibling,f!==null)){tr=f;return}tr=f=O}while(f!==null);Kr=6,tr=null}function kn(f,p,O,D,Q,Y,ce,Ee,Le){f.cancelPendingCommit=null;do Dm();while(aa!==0);if((Ar&6)!==0)throw Error(r(327));if(p!==null){if(p===f.current)throw Error(r(177));if(Y=p.lanes|p.childLanes,Y|=Fs,nt(f,O,Y,ce,Ee,Le),f===ii&&(tr=ii=null,yr=0),$o=p,Ys=f,us=O,kf=Y,Ih=Q,tv=D,(p.subtreeFlags&10256)!==0||(p.flags&10256)!==0?(f.callbackNode=null,f.callbackPriority=0,b5(st,function(){return x4(),null})):(f.callbackNode=null,f.callbackPriority=0),D=(p.flags&13878)!==0,(p.subtreeFlags&13878)!==0||D){D=G.T,G.T=null,Q=J.p,J.p=2,ce=Ar,Ar|=4;try{jp(f,p,O)}finally{Ar=ce,J.p=Q,G.T=D}}aa=1,kr(),Va(),Er()}}function kr(){if(aa===1){aa=0;var f=Ys,p=$o,O=(p.flags&13878)!==0;if((p.subtreeFlags&13878)!==0||O){O=G.T,G.T=null;var D=J.p;J.p=2;var Q=Ar;Ar|=4;try{Md(p,f);var Y=k4,ce=rm(f.containerInfo),Ee=Y.focusedElem,Le=Y.selectionRange;if(ce!==Ee&&Ee&&Ee.ownerDocument&&vr(Ee.ownerDocument.documentElement,Ee)){if(Le!==null&&xf(Ee)){var at=Le.start,mt=Le.end;if(mt===void 0&&(mt=at),"selectionStart"in Ee)Ee.selectionStart=at,Ee.selectionEnd=Math.min(mt,Ee.value.length);else{var xt=Ee.ownerDocument||document,lt=xt&&xt.defaultView||window;if(lt.getSelection){var ft=lt.getSelection(),fn=Ee.textContent.length,An=Math.min(Le.start,fn),Li=Le.end===void 0?An:Math.min(Le.end,fn);!ft.extend&&An>Li&&(ce=Li,Li=An,An=ce);var Ke=nm(Ee,An),Ve=nm(Ee,Li);if(Ke&&Ve&&(ft.rangeCount!==1||ft.anchorNode!==Ke.node||ft.anchorOffset!==Ke.offset||ft.focusNode!==Ve.node||ft.focusOffset!==Ve.offset)){var it=xt.createRange();it.setStart(Ke.node,Ke.offset),ft.removeAllRanges(),An>Li?(ft.addRange(it),ft.extend(Ve.node,Ve.offset)):(it.setEnd(Ve.node,Ve.offset),ft.addRange(it))}}}}for(xt=[],ft=Ee;ft=ft.parentNode;)ft.nodeType===1&&xt.push({element:ft,left:ft.scrollLeft,top:ft.scrollTop});for(typeof Ee.focus=="function"&&Ee.focus(),Ee=0;Ee<xt.length;Ee++){var yt=xt[Ee];yt.element.scrollLeft=yt.left,yt.element.scrollTop=yt.top}}sO=!!u1,k4=u1=null}finally{Ar=Q,J.p=D,G.T=O}}f.current=p,aa=2}}function Va(){if(aa===2){aa=0;var f=Ys,p=$o,O=(p.flags&8772)!==0;if((p.subtreeFlags&8772)!==0||O){O=G.T,G.T=null;var D=J.p;J.p=2;var Q=Ar;Ar|=4;try{Jy(f,p.alternate,p)}finally{Ar=Q,J.p=D,G.T=O}}aa=3}}function Er(){if(aa===4||aa===3){aa=0,Ue();var f=Ys,p=$o,O=us,D=tv;(p.subtreeFlags&10256)!==0||(p.flags&10256)!==0?aa=5:(aa=0,$o=Ys=null,Vc(f,f.pendingLanes));var Q=f.pendingLanes;if(Q===0&&(qc=null),Lt(O),p=p.stateNode,an&&typeof an.onCommitFiberRoot=="function")try{an.onCommitFiberRoot(zt,p,void 0,(p.current.flags&128)===128)}catch{}if(D!==null){p=G.T,Q=J.p,J.p=2,G.T=null;try{for(var Y=f.onRecoverableError,ce=0;ce<D.length;ce++){var Ee=D[ce];Y(Ee.value,{componentStack:Ee.stack})}}finally{G.T=p,J.p=Q}}(us&3)!==0&&Dm(),Fd(f),Q=f.pendingLanes,(O&261930)!==0&&(Q&42)!==0?f===Bh?Lh++:(Lh=0,Bh=f):Lh=0,n1(0)}}function Vc(f,p){(f.pooledCacheLanes&=p)===0&&(p=f.pooledCache,p!=null&&(f.pooledCache=null,Nu(p)))}function Dm(){return kr(),Va(),Er(),x4()}function x4(){if(aa!==5)return!1;var f=Ys,p=kf;kf=0;var O=Lt(us),D=G.T,Q=J.p;try{J.p=32>O?32:O,G.T=null,O=Ih,Ih=null;var Y=Ys,ce=us;if(aa=0,$o=Ys=null,us=0,(Ar&6)!==0)throw Error(r(331));var Ee=Ar;if(Ar|=4,Nh(Y.current),ra(Y,Y.current,ce,O),Ar=Ee,n1(0,!1),an&&typeof an.onPostCommitFiberRoot=="function")try{an.onPostCommitFiberRoot(zt,Y)}catch{}return!0}finally{J.p=Q,G.T=D,Vc(f,p)}}function S4(f,p,O){p=Tu(O,p),p=Wy(f.stateNode,p,2),f=Wo(f,p,2),f!==null&&(He(f,2),Fd(f))}function wi(f,p,O){if(f.tag===3)S4(f,f,O);else for(;p!==null;){if(p.tag===3){S4(p,f,O);break}else if(p.tag===1){var D=p.stateNode;if(typeof p.type.getDerivedStateFromError=="function"||typeof D.componentDidCatch=="function"&&(qc===null||!qc.has(D))){f=Tu(O,f),O=Ul(2),D=Wo(p,O,2),D!==null&&(al(O,D,p,f),He(D,2),Fd(D));break}}p=p.return}}function _4(f,p,O){var D=f.pingCache;if(D===null){D=f.pingCache=new ev;var Q=new Set;D.set(p,Q)}else Q=D.get(p),Q===void 0&&(Q=new Set,D.set(p,Q));Q.has(O)||(Oi=!0,Q.add(O),f=v5.bind(null,f,p,O),p.then(f,f))}function v5(f,p,O){var D=f.pingCache;D!==null&&D.delete(p),f.pingedLanes|=f.suspendedLanes&O,f.warmLanes&=~O,ii===f&&(yr&O)===O&&(Kr===4||Kr===3&&(yr&62914560)===yr&&0>Ze()-zc?(Ar&2)===0&&We(f,0):Hs|=O,Do===yr&&(Do=0)),Fd(f)}function t1(f,p){p===0&&(p=Vr()),f=Ku(f,p),f!==null&&(He(f,p),Fd(f))}function Gb(f){var p=f.memoizedState,O=0;p!==null&&(O=p.retryLane),t1(f,O)}function y5(f,p){var O=0;switch(f.tag){case 31:case 13:var D=f.stateNode,Q=f.memoizedState;Q!==null&&(O=Q.retryLane);break;case 19:D=f.stateNode;break;case 22:D=f.stateNode._retryCache;break;default:throw Error(r(314))}D!==null&&D.delete(p),t1(f,O)}function b5(f,p){return Oe(f,p)}var nv=null,$m=null,E4=!1,Kb=!1,D4=!1,Yp=0;function Fd(f){f!==$m&&f.next===null&&($m===null?nv=$m=f:$m=$m.next=f),Kb=!0,E4||(E4=!0,x5())}function n1(f,p){if(!D4&&Kb){D4=!0;do for(var O=!1,D=nv;D!==null;){if(f!==0){var Q=D.pendingLanes;if(Q===0)var Y=0;else{var ce=D.suspendedLanes,Ee=D.pingedLanes;Y=(1<<31-Fe(42|f)+1)-1,Y&=Q&~(ce&~Ee),Y=Y&201326741?Y&201326741|1:Y?Y|2:0}Y!==0&&(O=!0,jS(D,Y))}else Y=yr,Y=cr(D,D===ii?Y:0,D.cancelPendingCommit!==null||D.timeoutHandle!==-1),(Y&3)===0||ur(D,Y)||(O=!0,jS(D,Y));D=D.next}while(O);D4=!1}}function O5(){qS()}function qS(){Kb=E4=!1;var f=0;Yp!==0&&_5()&&(f=Yp);for(var p=Ze(),O=null,D=nv;D!==null;){var Q=D.next,Y=VS(D,p);Y===0?(D.next=null,O===null?nv=Q:O.next=Q,Q===null&&($m=O)):(O=D,(f!==0||(Y&3)!==0)&&(Kb=!0)),D=Q}aa!==0&&aa!==5||n1(f),Yp!==0&&(Yp=0)}function VS(f,p){for(var O=f.suspendedLanes,D=f.pingedLanes,Q=f.expirationTimes,Y=f.pendingLanes&-62914561;0<Y;){var ce=31-Fe(Y),Ee=1<<ce,Le=Q[ce];Le===-1?((Ee&O)===0||(Ee&D)!==0)&&(Q[ce]=Cr(Ee,p)):Le<=p&&(f.expiredLanes|=Ee),Y&=~Ee}if(p=ii,O=yr,O=cr(f,f===p?O:0,f.cancelPendingCommit!==null||f.timeoutHandle!==-1),D=f.callbackNode,O===0||f===p&&(bn===2||bn===9)||f.cancelPendingCommit!==null)return D!==null&&D!==null&&$e(D),f.callbackNode=null,f.callbackPriority=0;if((O&3)===0||ur(f,O)){if(p=O&-O,p===f.callbackPriority)return p;switch(D!==null&&$e(D),Lt(O)){case 2:case 8:O=ze;break;case 32:O=st;break;case 268435456:O=Nt;break;default:O=st}return D=US.bind(null,f),O=Oe(O,D),f.callbackPriority=p,f.callbackNode=O,p}return D!==null&&D!==null&&$e(D),f.callbackPriority=2,f.callbackNode=null,2}function US(f,p){if(aa!==0&&aa!==5)return f.callbackNode=null,f.callbackPriority=0,null;var O=f.callbackNode;if(Dm()&&f.callbackNode!==O)return null;var D=yr;return D=cr(f,f===ii?D:0,f.cancelPendingCommit!==null||f.timeoutHandle!==-1),D===0?null:(A(f,D,p),VS(f,Ze()),f.callbackNode!=null&&f.callbackNode===O?US.bind(null,f):null)}function jS(f,p){if(Dm())return null;A(f,p,!0)}function x5(){e_(function(){(Ar&6)!==0?Oe(Me,O5):qS()})}function Gs(){if(Yp===0){var f=Ef;f===0&&(f=un,un<<=1,(un&261888)===0&&(un=256)),Yp=f}return Yp}function ZS(f){return f==null||typeof f=="symbol"||typeof f=="boolean"?null:typeof f=="function"?f:vf(""+f)}function HS(f,p){var O=p.ownerDocument.createElement("input");return O.name=p.name,O.value=p.value,f.id&&O.setAttribute("form",f.id),p.parentNode.insertBefore(O,p),f=new FormData(f),O.parentNode.removeChild(O),f}function Cm(f,p,O,D,Q){if(p==="submit"&&O&&O.stateNode===Q){var Y=ZS((Q[sn]||null).action),ce=D.submitter;ce&&(p=(p=ce[sn]||null)?ZS(p.formAction):ce.getAttribute("formAction"),p!==null&&(Y=p,ce=null));var Ee=new rd("action","action",null,D,Q);f.push({event:Ee,listeners:[{instance:null,listener:function(){if(D.defaultPrevented){if(Yp!==0){var Le=ce?HS(Q,ce):new FormData(Q);Ed(O,{pending:!0,data:Le,method:Q.method,action:Y},null,Le)}}else typeof Y=="function"&&(Ee.preventDefault(),Le=ce?HS(Q,ce):new FormData(Q),Ed(O,{pending:!0,data:Le,method:Q.method,action:Y},Y,Le))},currentTarget:Q}]})}}for(var Wn=0;Wn<yh.length;Wn++){var $4=yh[Wn],ls=$4.toLowerCase(),uu=$4[0].toUpperCase()+$4.slice(1);da(ls,"on"+uu)}da(_i,"onAnimationEnd"),da(hd,"onAnimationIteration"),da(Ml,"onAnimationStart"),da("dblclick","onDoubleClick"),da("focusin","onFocus"),da("focusout","onBlur"),da(fo,"onTransitionRun"),da(ho,"onTransitionStart"),da(Sf,"onTransitionCancel"),da(_r,"onTransitionEnd"),gi("onMouseEnter",["mouseout","mouseover"]),gi("onMouseLeave",["mouseout","mouseover"]),gi("onPointerEnter",["pointerout","pointerover"]),gi("onPointerLeave",["pointerout","pointerover"]),Xn("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Xn("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Xn("onBeforeInput",["compositionend","keypress","textInput","paste"]),Xn("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Xn("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Xn("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var r1="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Gp=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(r1));function XS(f,p){p=(p&4)!==0;for(var O=0;O<f.length;O++){var D=f[O],Q=D.event;D=D.listeners;e:{var Y=void 0;if(p)for(var ce=D.length-1;0<=ce;ce--){var Ee=D[ce],Le=Ee.instance,at=Ee.currentTarget;if(Ee=Ee.listener,Le!==Y&&Q.isPropagationStopped())break e;Y=Ee,Q.currentTarget=at;try{Y(Q)}catch(mt){Zo(mt)}Q.currentTarget=null,Y=Le}else for(ce=0;ce<D.length;ce++){if(Ee=D[ce],Le=Ee.instance,at=Ee.currentTarget,Ee=Ee.listener,Le!==Y&&Q.isPropagationStopped())break e;Y=Ee,Q.currentTarget=at;try{Y(Q)}catch(mt){Zo(mt)}Q.currentTarget=null,Y=Le}}}}function Dr(f,p){var O=p[Pi];O===void 0&&(O=p[Pi]=new Set);var D=f+"__bubble";O.has(D)||(Jb(p,f,2,!1),O.add(D))}function C4(f,p,O){var D=0;p&&(D|=4),Jb(O,f,D,p)}var Wb="_reactListening"+Math.random().toString(36).slice(2);function w4(f){if(!f[Wb]){f[Wb]=!0,Ru.forEach(function(O){O!=="selectionchange"&&(Gp.has(O)||C4(O,!1,f),C4(O,!0,f))});var p=f.nodeType===9?f:f.ownerDocument;p===null||p[Wb]||(p[Wb]=!0,C4("selectionchange",!1,p))}}function Jb(f,p,O,D){switch(O_(p)){case 2:var Q=I5;break;case 8:Q=L5;break;default:Q=Q4}O=Q.bind(null,p,O,f),Q=void 0,!Ep||p!=="touchstart"&&p!=="touchmove"&&p!=="wheel"||(Q=!0),D?Q!==void 0?f.addEventListener(p,O,{capture:!0,passive:Q}):f.addEventListener(p,O,!0):Q!==void 0?f.addEventListener(p,O,{passive:Q}):f.addEventListener(p,O,!1)}function R4(f,p,O,D,Q){var Y=D;if((p&1)===0&&(p&2)===0&&D!==null)e:for(;;){if(D===null)return;var ce=D.tag;if(ce===3||ce===4){var Ee=D.stateNode.containerInfo;if(Ee===Q)break;if(ce===4)for(ce=D.return;ce!==null;){var Le=ce.tag;if((Le===3||Le===4)&&ce.stateNode.containerInfo===Q)return;ce=ce.return}for(;Ee!==null;){if(ce=Hr(Ee),ce===null)return;if(Le=ce.tag,Le===5||Le===6||Le===26||Le===27){D=Y=ce;continue e}Ee=Ee.parentNode}}D=D.return}_p(function(){var at=Y,mt=ch(O),xt=[];e:{var lt=jo.get(f);if(lt!==void 0){var ft=rd,fn=f;switch(f){case"keypress":if(bc(O)===0)break e;case"keydown":case"keyup":ft=Vo;break;case"focusin":fn="focus",ft=ud;break;case"focusout":fn="blur",ft=ud;break;case"beforeblur":case"afterblur":ft=ud;break;case"click":if(O.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":ft=Dp;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":ft=Y0;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":ft=ks;break;case _i:case hd:case Ml:ft=xc;break;case _r:ft=Dy;break;case"scroll":case"scrollend":ft=id;break;case"wheel":ft=oo;break;case"copy":case"cut":case"paste":ft=fa;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":ft=wp;break;case"toggle":case"beforetoggle":ft=J0}var An=(p&4)!==0,Li=!An&&(f==="scroll"||f==="scrollend"),Ke=An?lt!==null?lt+"Capture":null:lt;An=[];for(var Ve=at,it;Ve!==null;){var yt=Ve;if(it=yt.stateNode,yt=yt.tag,yt!==5&&yt!==26&&yt!==27||it===null||Ke===null||(yt=ws(Ve,Ke),yt!=null&&An.push(Ks(Ve,yt,it))),Li)break;Ve=Ve.return}0<An.length&&(lt=new ft(lt,fn,null,O,mt),xt.push({event:lt,listeners:An}))}}if((p&7)===0){e:{if(lt=f==="mouseover"||f==="pointerover",ft=f==="mouseout"||f==="pointerout",lt&&O!==sh&&(fn=O.relatedTarget||O.fromElement)&&(Hr(fn)||fn[gr]))break e;if((ft||lt)&&(lt=mt.window===mt?mt:(lt=mt.ownerDocument)?lt.defaultView||lt.parentWindow:window,ft?(fn=O.relatedTarget||O.toElement,ft=at,fn=fn?Hr(fn):null,fn!==null&&(Li=a(fn),An=fn.tag,fn!==Li||An!==5&&An!==27&&An!==6)&&(fn=null)):(ft=null,fn=at),ft!==fn)){if(An=Dp,yt="onMouseLeave",Ke="onMouseEnter",Ve="mouse",(f==="pointerout"||f==="pointerover")&&(An=wp,yt="onPointerLeave",Ke="onPointerEnter",Ve="pointer"),Li=ft==null?lt:ca(ft),it=fn==null?lt:ca(fn),lt=new An(yt,Ve+"leave",ft,O,mt),lt.target=Li,lt.relatedTarget=it,yt=null,Hr(mt)===at&&(An=new An(Ke,Ve+"enter",fn,O,mt),An.target=it,An.relatedTarget=Li,yt=An),Li=yt,ft&&fn)t:{for(An=eO,Ke=ft,Ve=fn,it=0,yt=Ke;yt;yt=An(yt))it++;yt=0;for(var En=Ve;En;En=An(En))yt++;for(;0<it-yt;)Ke=An(Ke),it--;for(;0<yt-it;)Ve=An(Ve),yt--;for(;it--;){if(Ke===Ve||Ve!==null&&Ke===Ve.alternate){An=Ke;break t}Ke=An(Ke),Ve=An(Ve)}An=null}else An=null;ft!==null&&va(xt,lt,ft,An,!1),fn!==null&&Li!==null&&va(xt,Li,fn,An,!0)}}e:{if(lt=at?ca(at):window,ft=lt.nodeName&&lt.nodeName.toLowerCase(),ft==="select"||ft==="input"&&lt.type==="file")var ai=em;else if(kp(lt))if(du)ai=Mi;else{ai=yl;var mn=Kn}else ft=lt.nodeName,!ft||ft.toLowerCase()!=="input"||lt.type!=="checkbox"&&lt.type!=="radio"?at&&gf(at.elementType)&&(ai=em):ai=Eg;if(ai&&(ai=ai(f,at))){fd(xt,ai,O,mt);break e}mn&&mn(f,lt,at),f==="focusout"&&at&&lt.type==="number"&&at.memoizedProps.value!=null&&nd(lt,"number",lt.value)}switch(mn=at?ca(at):window,f){case"focusin":(kp(mn)||mn.contentEditable==="true")&&(Xe=mn,pt=at,rt=null);break;case"focusout":rt=pt=Xe=null;break;case"mousedown":Bt=!0;break;case"contextmenu":case"mouseup":case"dragend":Bt=!1,Dn(xt,O,mt);break;case"selectionchange":if(_c)break;case"keydown":case"keyup":Dn(xt,O,mt)}var or;if(Sc)e:{switch(f){case"compositionstart":var Pr="onCompositionStart";break e;case"compositionend":Pr="onCompositionEnd";break e;case"compositionupdate":Pr="onCompositionUpdate";break e}Pr=void 0}else Ms?sd(f,O)&&(Pr="onCompositionEnd"):f==="keydown"&&O.keyCode===229&&(Pr="onCompositionStart");Pr&&(Ba&&O.locale!=="ko"&&(Ms||Pr!=="onCompositionStart"?Pr==="onCompositionEnd"&&Ms&&(or=Bn()):(yc=mt,dh="value"in yc?yc.value:yc.textContent,Ms=!0)),mn=i1(at,Pr),0<mn.length&&(Pr=new La(Pr,f,null,O,mt),xt.push({event:Pr,listeners:mn}),or?Pr.data=or:(or=cd(O),or!==null&&(Pr.data=or)))),(or=Ps?fu(f,O):Tp(f,O))&&(Pr=i1(at,"onBeforeInput"),0<Pr.length&&(mn=new La("onBeforeInput","beforeinput",null,O,mt),xt.push({event:mn,listeners:Pr}),mn.data=or)),Cm(xt,f,at,O,mt)}XS(xt,p)})}function Ks(f,p,O){return{instance:f,listener:p,currentTarget:O}}function i1(f,p){for(var O=p+"Capture",D=[];f!==null;){var Q=f,Y=Q.stateNode;if(Q=Q.tag,Q!==5&&Q!==26&&Q!==27||Y===null||(Q=ws(f,O),Q!=null&&D.unshift(Ks(f,Q,Y)),Q=ws(f,p),Q!=null&&D.push(Ks(f,Q,Y))),f.tag===3)return D;f=f.return}return[]}function eO(f){if(f===null)return null;do f=f.return;while(f&&f.tag!==5&&f.tag!==27);return f||null}function va(f,p,O,D,Q){for(var Y=p._reactName,ce=[];O!==null&&O!==D;){var Ee=O,Le=Ee.alternate,at=Ee.stateNode;if(Ee=Ee.tag,Le!==null&&Le===D)break;Ee!==5&&Ee!==26&&Ee!==27||at===null||(Le=at,Q?(at=ws(O,Y),at!=null&&ce.unshift(Ks(O,at,Le))):Q||(at=ws(O,Y),at!=null&&ce.push(Ks(O,at,Le)))),O=O.return}ce.length!==0&&f.push({event:p,listeners:ce})}var Ua=/\r\n?/g,YS=/\u0000|\uFFFD/g;function GS(f){return(typeof f=="string"?f:""+f).replace(Ua,`
`).replace(YS,"")}function KS(f,p){return p=GS(p),GS(f)===p}function Ii(f,p,O,D,Q,Y){switch(O){case"children":typeof D=="string"?p==="body"||p==="textarea"&&D===""||Au(f,D):(typeof D=="number"||typeof D=="bigint")&&p!=="body"&&Au(f,""+D);break;case"className":pc(f,"class",D);break;case"tabIndex":pc(f,"tabindex",D);break;case"dir":case"role":case"viewBox":case"width":case"height":pc(f,O,D);break;case"style":Z0(f,D,Y);break;case"data":if(p!=="object"){pc(f,"data",D);break}case"src":case"href":if(D===""&&(p!=="a"||O!=="href")){f.removeAttribute(O);break}if(D==null||typeof D=="function"||typeof D=="symbol"||typeof D=="boolean"){f.removeAttribute(O);break}D=vf(""+D),f.setAttribute(O,D);break;case"action":case"formAction":if(typeof D=="function"){f.setAttribute(O,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof Y=="function"&&(O==="formAction"?(p!=="input"&&Ii(f,p,"name",Q.name,Q,null),Ii(f,p,"formEncType",Q.formEncType,Q,null),Ii(f,p,"formMethod",Q.formMethod,Q,null),Ii(f,p,"formTarget",Q.formTarget,Q,null)):(Ii(f,p,"encType",Q.encType,Q,null),Ii(f,p,"method",Q.method,Q,null),Ii(f,p,"target",Q.target,Q,null)));if(D==null||typeof D=="symbol"||typeof D=="boolean"){f.removeAttribute(O);break}D=vf(""+D),f.setAttribute(O,D);break;case"onClick":D!=null&&(f.onclick=lo);break;case"onScroll":D!=null&&Dr("scroll",f);break;case"onScrollEnd":D!=null&&Dr("scrollend",f);break;case"dangerouslySetInnerHTML":if(D!=null){if(typeof D!="object"||!("__html"in D))throw Error(r(61));if(O=D.__html,O!=null){if(Q.children!=null)throw Error(r(60));f.innerHTML=O}}break;case"multiple":f.multiple=D&&typeof D!="function"&&typeof D!="symbol";break;case"muted":f.muted=D&&typeof D!="function"&&typeof D!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(D==null||typeof D=="function"||typeof D=="boolean"||typeof D=="symbol"){f.removeAttribute("xlink:href");break}O=vf(""+D),f.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",O);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":D!=null&&typeof D!="function"&&typeof D!="symbol"?f.setAttribute(O,""+D):f.removeAttribute(O);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":D&&typeof D!="function"&&typeof D!="symbol"?f.setAttribute(O,""):f.removeAttribute(O);break;case"capture":case"download":D===!0?f.setAttribute(O,""):D!==!1&&D!=null&&typeof D!="function"&&typeof D!="symbol"?f.setAttribute(O,D):f.removeAttribute(O);break;case"cols":case"rows":case"size":case"span":D!=null&&typeof D!="function"&&typeof D!="symbol"&&!isNaN(D)&&1<=D?f.setAttribute(O,D):f.removeAttribute(O);break;case"rowSpan":case"start":D==null||typeof D=="function"||typeof D=="symbol"||isNaN(D)?f.removeAttribute(O):f.setAttribute(O,D);break;case"popover":Dr("beforetoggle",f),Dr("toggle",f),$a(f,"popover",D);break;case"xlinkActuate":Fr(f,"http://www.w3.org/1999/xlink","xlink:actuate",D);break;case"xlinkArcrole":Fr(f,"http://www.w3.org/1999/xlink","xlink:arcrole",D);break;case"xlinkRole":Fr(f,"http://www.w3.org/1999/xlink","xlink:role",D);break;case"xlinkShow":Fr(f,"http://www.w3.org/1999/xlink","xlink:show",D);break;case"xlinkTitle":Fr(f,"http://www.w3.org/1999/xlink","xlink:title",D);break;case"xlinkType":Fr(f,"http://www.w3.org/1999/xlink","xlink:type",D);break;case"xmlBase":Fr(f,"http://www.w3.org/XML/1998/namespace","xml:base",D);break;case"xmlLang":Fr(f,"http://www.w3.org/XML/1998/namespace","xml:lang",D);break;case"xmlSpace":Fr(f,"http://www.w3.org/XML/1998/namespace","xml:space",D);break;case"is":$a(f,"is",D);break;case"innerText":case"textContent":break;default:(!(2<O.length)||O[0]!=="o"&&O[0]!=="O"||O[1]!=="n"&&O[1]!=="N")&&(O=H0.get(O)||O,$a(f,O,D))}}function A4(f,p,O,D,Q,Y){switch(O){case"style":Z0(f,D,Y);break;case"dangerouslySetInnerHTML":if(D!=null){if(typeof D!="object"||!("__html"in D))throw Error(r(61));if(O=D.__html,O!=null){if(Q.children!=null)throw Error(r(60));f.innerHTML=O}}break;case"children":typeof D=="string"?Au(f,D):(typeof D=="number"||typeof D=="bigint")&&Au(f,""+D);break;case"onScroll":D!=null&&Dr("scroll",f);break;case"onScrollEnd":D!=null&&Dr("scrollend",f);break;case"onClick":D!=null&&(f.onclick=lo);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!uo.hasOwnProperty(O))e:{if(O[0]==="o"&&O[1]==="n"&&(Q=O.endsWith("Capture"),p=O.slice(2,Q?O.length-7:void 0),Y=f[sn]||null,Y=Y!=null?Y[O]:null,typeof Y=="function"&&f.removeEventListener(p,Y,Q),typeof D=="function")){typeof Y!="function"&&Y!==null&&(O in f?f[O]=null:f.hasAttribute(O)&&f.removeAttribute(O)),f.addEventListener(p,D,Q);break e}O in f?f[O]=D:D===!0?f.setAttribute(O,""):$a(f,O,D)}}}function El(f,p,O){switch(p){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":Dr("error",f),Dr("load",f);var D=!1,Q=!1,Y;for(Y in O)if(O.hasOwnProperty(Y)){var ce=O[Y];if(ce!=null)switch(Y){case"src":D=!0;break;case"srcSet":Q=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(r(137,p));default:Ii(f,p,Y,ce,O,null)}}Q&&Ii(f,p,"srcSet",O.srcSet,O,null),D&&Ii(f,p,"src",O.src,O,null);return;case"input":Dr("invalid",f);var Ee=Y=ce=Q=null,Le=null,at=null;for(D in O)if(O.hasOwnProperty(D)){var mt=O[D];if(mt!=null)switch(D){case"name":Q=mt;break;case"type":ce=mt;break;case"checked":Le=mt;break;case"defaultChecked":at=mt;break;case"value":Y=mt;break;case"defaultValue":Ee=mt;break;case"children":case"dangerouslySetInnerHTML":if(mt!=null)throw Error(r(137,p));break;default:Ii(f,p,D,mt,O,null)}}Es(f,Y,Ee,Le,at,ce,Q,!1);return;case"select":Dr("invalid",f),D=ce=Y=null;for(Q in O)if(O.hasOwnProperty(Q)&&(Ee=O[Q],Ee!=null))switch(Q){case"value":Y=Ee;break;case"defaultValue":ce=Ee;break;case"multiple":D=Ee;default:Ii(f,p,Q,Ee,O,null)}p=Y,O=ce,f.multiple=!!D,p!=null?mc(f,!!D,p,!1):O!=null&&mc(f,!!D,O,!0);return;case"textarea":Dr("invalid",f),Y=Q=D=null;for(ce in O)if(O.hasOwnProperty(ce)&&(Ee=O[ce],Ee!=null))switch(ce){case"value":D=Ee;break;case"defaultValue":Q=Ee;break;case"children":Y=Ee;break;case"dangerouslySetInnerHTML":if(Ee!=null)throw Error(r(91));break;default:Ii(f,p,ce,Ee,O,null)}Bo(f,D,Q,Y);return;case"option":for(Le in O)if(O.hasOwnProperty(Le)&&(D=O[Le],D!=null))switch(Le){case"selected":f.selected=D&&typeof D!="function"&&typeof D!="symbol";break;default:Ii(f,p,Le,D,O,null)}return;case"dialog":Dr("beforetoggle",f),Dr("toggle",f),Dr("cancel",f),Dr("close",f);break;case"iframe":case"object":Dr("load",f);break;case"video":case"audio":for(D=0;D<r1.length;D++)Dr(r1[D],f);break;case"image":Dr("error",f),Dr("load",f);break;case"details":Dr("toggle",f);break;case"embed":case"source":case"link":Dr("error",f),Dr("load",f);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(at in O)if(O.hasOwnProperty(at)&&(D=O[at],D!=null))switch(at){case"children":case"dangerouslySetInnerHTML":throw Error(r(137,p));default:Ii(f,p,at,D,O,null)}return;default:if(gf(p)){for(mt in O)O.hasOwnProperty(mt)&&(D=O[mt],D!==void 0&&A4(f,p,mt,D,O,void 0));return}}for(Ee in O)O.hasOwnProperty(Ee)&&(D=O[Ee],D!=null&&Ii(f,p,Ee,D,O,null))}function S5(f,p,O,D){switch(p){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var Q=null,Y=null,ce=null,Ee=null,Le=null,at=null,mt=null;for(ft in O){var xt=O[ft];if(O.hasOwnProperty(ft)&&xt!=null)switch(ft){case"checked":break;case"value":break;case"defaultValue":Le=xt;default:D.hasOwnProperty(ft)||Ii(f,p,ft,null,D,xt)}}for(var lt in D){var ft=D[lt];if(xt=O[lt],D.hasOwnProperty(lt)&&(ft!=null||xt!=null))switch(lt){case"type":Y=ft;break;case"name":Q=ft;break;case"checked":at=ft;break;case"defaultChecked":mt=ft;break;case"value":ce=ft;break;case"defaultValue":Ee=ft;break;case"children":case"dangerouslySetInnerHTML":if(ft!=null)throw Error(r(137,p));break;default:ft!==xt&&Ii(f,p,lt,ft,D,xt)}}td(f,ce,Ee,Le,at,mt,Y,Q);return;case"select":ft=ce=Ee=lt=null;for(Y in O)if(Le=O[Y],O.hasOwnProperty(Y)&&Le!=null)switch(Y){case"value":break;case"multiple":ft=Le;default:D.hasOwnProperty(Y)||Ii(f,p,Y,null,D,Le)}for(Q in D)if(Y=D[Q],Le=O[Q],D.hasOwnProperty(Q)&&(Y!=null||Le!=null))switch(Q){case"value":lt=Y;break;case"defaultValue":Ee=Y;break;case"multiple":ce=Y;default:Y!==Le&&Ii(f,p,Q,Y,D,Le)}p=Ee,O=ce,D=ft,lt!=null?mc(f,!!O,lt,!1):!!D!=!!O&&(p!=null?mc(f,!!O,p,!0):mc(f,!!O,O?[]:"",!1));return;case"textarea":ft=lt=null;for(Ee in O)if(Q=O[Ee],O.hasOwnProperty(Ee)&&Q!=null&&!D.hasOwnProperty(Ee))switch(Ee){case"value":break;case"children":break;default:Ii(f,p,Ee,null,D,Q)}for(ce in D)if(Q=D[ce],Y=O[ce],D.hasOwnProperty(ce)&&(Q!=null||Y!=null))switch(ce){case"value":lt=Q;break;case"defaultValue":ft=Q;break;case"children":break;case"dangerouslySetInnerHTML":if(Q!=null)throw Error(r(91));break;default:Q!==Y&&Ii(f,p,ce,Q,D,Y)}gc(f,lt,ft);return;case"option":for(var fn in O)if(lt=O[fn],O.hasOwnProperty(fn)&&lt!=null&&!D.hasOwnProperty(fn))switch(fn){case"selected":f.selected=!1;break;default:Ii(f,p,fn,null,D,lt)}for(Le in D)if(lt=D[Le],ft=O[Le],D.hasOwnProperty(Le)&&lt!==ft&&(lt!=null||ft!=null))switch(Le){case"selected":f.selected=lt&&typeof lt!="function"&&typeof lt!="symbol";break;default:Ii(f,p,Le,lt,D,ft)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var An in O)lt=O[An],O.hasOwnProperty(An)&&lt!=null&&!D.hasOwnProperty(An)&&Ii(f,p,An,null,D,lt);for(at in D)if(lt=D[at],ft=O[at],D.hasOwnProperty(at)&&lt!==ft&&(lt!=null||ft!=null))switch(at){case"children":case"dangerouslySetInnerHTML":if(lt!=null)throw Error(r(137,p));break;default:Ii(f,p,at,lt,D,ft)}return;default:if(gf(p)){for(var Li in O)lt=O[Li],O.hasOwnProperty(Li)&&lt!==void 0&&!D.hasOwnProperty(Li)&&A4(f,p,Li,void 0,D,lt);for(mt in D)lt=D[mt],ft=O[mt],!D.hasOwnProperty(mt)||lt===ft||lt===void 0&&ft===void 0||A4(f,p,mt,lt,D,ft);return}}for(var Ke in O)lt=O[Ke],O.hasOwnProperty(Ke)&&lt!=null&&!D.hasOwnProperty(Ke)&&Ii(f,p,Ke,null,D,lt);for(xt in D)lt=D[xt],ft=O[xt],!D.hasOwnProperty(xt)||lt===ft||lt==null&&ft==null||Ii(f,p,xt,lt,D,ft)}function T4(f){switch(f){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function a1(){if(typeof performance.getEntriesByType=="function"){for(var f=0,p=0,O=performance.getEntriesByType("resource"),D=0;D<O.length;D++){var Q=O[D],Y=Q.transferSize,ce=Q.initiatorType,Ee=Q.duration;if(Y&&Ee&&T4(ce)){for(ce=0,Ee=Q.responseEnd,D+=1;D<O.length;D++){var Le=O[D],at=Le.startTime;if(at>Ee)break;var mt=Le.transferSize,xt=Le.initiatorType;mt&&T4(xt)&&(Le=Le.responseEnd,ce+=mt*(Le<Ee?1:(Ee-at)/(Le-at)))}if(--D,p+=8*(Y+ce)/(Q.duration/1e3),f++,10<f)break}}if(0<f)return p/f/1e6}return navigator.connection&&(f=navigator.connection.downlink,typeof f=="number")?f:5}var u1=null,k4=null;function l1(f){return f.nodeType===9?f:f.ownerDocument}function o1(f){switch(f){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function os(f,p){if(f===0)switch(p){case"svg":return 1;case"math":return 2;default:return 0}return f===1&&p==="foreignObject"?0:f}function Kp(f,p){return f==="textarea"||f==="noscript"||typeof p.children=="string"||typeof p.children=="number"||typeof p.children=="bigint"||typeof p.dangerouslySetInnerHTML=="object"&&p.dangerouslySetInnerHTML!==null&&p.dangerouslySetInnerHTML.__html!=null}var P4=null;function _5(){var f=window.event;return f&&f.type==="popstate"?f===P4?!1:(P4=f,!0):(P4=null,!1)}var WS=typeof setTimeout=="function"?setTimeout:void 0,E5=typeof clearTimeout=="function"?clearTimeout:void 0,JS=typeof Promise=="function"?Promise:void 0,e_=typeof queueMicrotask=="function"?queueMicrotask:typeof JS<"u"?function(f){return JS.resolve(null).then(f).catch(zh)}:WS;function zh(f){setTimeout(function(){throw f})}function qn(f){return f==="head"}function M4(f,p){var O=p,D=0;do{var Q=O.nextSibling;if(f.removeChild(O),Q&&Q.nodeType===8)if(O=Q.data,O==="/$"||O==="/&"){if(D===0){f.removeChild(Q),fv(p);return}D--}else if(O==="$"||O==="$?"||O==="$~"||O==="$!"||O==="&")D++;else if(O==="html")s1(f.ownerDocument.documentElement);else if(O==="head"){O=f.ownerDocument.head,s1(O);for(var Y=O.firstChild;Y;){var ce=Y.nextSibling,Ee=Y.nodeName;Y[wu]||Ee==="SCRIPT"||Ee==="STYLE"||Ee==="LINK"&&Y.rel.toLowerCase()==="stylesheet"||O.removeChild(Y),Y=ce}}else O==="body"&&s1(f.ownerDocument.body);O=Q}while(O);fv(p)}function Ws(f,p){var O=f;f=0;do{var D=O.nextSibling;if(O.nodeType===1?p?(O._stashedDisplay=O.style.display,O.style.display="none"):(O.style.display=O._stashedDisplay||"",O.getAttribute("style")===""&&O.removeAttribute("style")):O.nodeType===3&&(p?(O._stashedText=O.nodeValue,O.nodeValue=""):O.nodeValue=O._stashedText||""),D&&D.nodeType===8)if(O=D.data,O==="/$"){if(f===0)break;f--}else O!=="$"&&O!=="$?"&&O!=="$~"&&O!=="$!"||f++;O=D}while(O)}function tO(f){var p=f.firstChild;for(p&&p.nodeType===10&&(p=p.nextSibling);p;){var O=p;switch(p=p.nextSibling,O.nodeName){case"HTML":case"HEAD":case"BODY":tO(O),Al(O);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(O.rel.toLowerCase()==="stylesheet")continue}f.removeChild(O)}}function D5(f,p,O,D){for(;f.nodeType===1;){var Q=O;if(f.nodeName.toLowerCase()!==p.toLowerCase()){if(!D&&(f.nodeName!=="INPUT"||f.type!=="hidden"))break}else if(D){if(!f[wu])switch(p){case"meta":if(!f.hasAttribute("itemprop"))break;return f;case"link":if(Y=f.getAttribute("rel"),Y==="stylesheet"&&f.hasAttribute("data-precedence"))break;if(Y!==Q.rel||f.getAttribute("href")!==(Q.href==null||Q.href===""?null:Q.href)||f.getAttribute("crossorigin")!==(Q.crossOrigin==null?null:Q.crossOrigin)||f.getAttribute("title")!==(Q.title==null?null:Q.title))break;return f;case"style":if(f.hasAttribute("data-precedence"))break;return f;case"script":if(Y=f.getAttribute("src"),(Y!==(Q.src==null?null:Q.src)||f.getAttribute("type")!==(Q.type==null?null:Q.type)||f.getAttribute("crossorigin")!==(Q.crossOrigin==null?null:Q.crossOrigin))&&Y&&f.hasAttribute("async")&&!f.hasAttribute("itemprop"))break;return f;default:return f}}else if(p==="input"&&f.type==="hidden"){var Y=Q.name==null?null:""+Q.name;if(Q.type==="hidden"&&f.getAttribute("name")===Y)return f}else return f;if(f=Uc(f.nextSibling),f===null)break}return null}function xi(f,p,O){if(p==="")return null;for(;f.nodeType!==3;)if((f.nodeType!==1||f.nodeName!=="INPUT"||f.type!=="hidden")&&!O||(f=Uc(f.nextSibling),f===null))return null;return f}function t_(f,p){for(;f.nodeType!==8;)if((f.nodeType!==1||f.nodeName!=="INPUT"||f.type!=="hidden")&&!p||(f=Uc(f.nextSibling),f===null))return null;return f}function nO(f){return f.data==="$?"||f.data==="$~"}function rv(f){return f.data==="$!"||f.data==="$?"&&f.ownerDocument.readyState!=="loading"}function $5(f,p){var O=f.ownerDocument;if(f.data==="$~")f._reactRetry=p;else if(f.data!=="$?"||O.readyState!=="loading")p();else{var D=function(){p(),O.removeEventListener("DOMContentLoaded",D)};O.addEventListener("DOMContentLoaded",D),f._reactRetry=D}}function Uc(f){for(;f!=null;f=f.nextSibling){var p=f.nodeType;if(p===1||p===3)break;if(p===8){if(p=f.data,p==="$"||p==="$!"||p==="$?"||p==="$~"||p==="&"||p==="F!"||p==="F")break;if(p==="/$"||p==="/&")return null}}return f}var F4=null;function n_(f){f=f.nextSibling;for(var p=0;f;){if(f.nodeType===8){var O=f.data;if(O==="/$"||O==="/&"){if(p===0)return Uc(f.nextSibling);p--}else O!=="$"&&O!=="$!"&&O!=="$?"&&O!=="$~"&&O!=="&"||p++}f=f.nextSibling}return null}function r_(f){f=f.previousSibling;for(var p=0;f;){if(f.nodeType===8){var O=f.data;if(O==="$"||O==="$!"||O==="$?"||O==="$~"||O==="&"){if(p===0)return f;p--}else O!=="/$"&&O!=="/&"||p++}f=f.previousSibling}return null}function i_(f,p,O){switch(p=l1(O),f){case"html":if(f=p.documentElement,!f)throw Error(r(452));return f;case"head":if(f=p.head,!f)throw Error(r(453));return f;case"body":if(f=p.body,!f)throw Error(r(454));return f;default:throw Error(r(451))}}function s1(f){for(var p=f.attributes;p.length;)f.removeAttributeNode(p[0]);Al(f)}var jc=new Map,a_=new Set;function rO(f){return typeof f.getRootNode=="function"?f.getRootNode():f.nodeType===9?f:f.ownerDocument}var qh=J.d;J.d={f:C5,r:w5,D:N4,C:R5,L:A5,m:T5,X:ss,S:fl,M:k5};function C5(){var f=qh.f(),p=De();return f||p}function w5(f){var p=Pt(f);p!==null&&p.tag===5&&p.type==="form"?jg(p):qh.r(f)}var Wp=typeof document>"u"?null:document;function u_(f,p,O){var D=Wp;if(D&&typeof p=="string"&&p){var Q=Ha(p);Q='link[rel="'+f+'"][href="'+Q+'"]',typeof O=="string"&&(Q+='[crossorigin="'+O+'"]'),a_.has(Q)||(a_.add(Q),f={rel:f,crossOrigin:O,href:p},D.querySelector(Q)===null&&(p=D.createElement("link"),El(p,"link",f),ti(p),D.head.appendChild(p)))}}function N4(f){qh.D(f),u_("dns-prefetch",f,null)}function R5(f,p){qh.C(f,p),u_("preconnect",f,p)}function A5(f,p,O){qh.L(f,p,O);var D=Wp;if(D&&f&&p){var Q='link[rel="preload"][as="'+Ha(p)+'"]';p==="image"&&O&&O.imageSrcSet?(Q+='[imagesrcset="'+Ha(O.imageSrcSet)+'"]',typeof O.imageSizes=="string"&&(Q+='[imagesizes="'+Ha(O.imageSizes)+'"]')):Q+='[href="'+Ha(f)+'"]';var Y=Q;switch(p){case"style":Y=iv(f);break;case"script":Y=uv(f)}jc.has(Y)||(f=d({rel:"preload",href:p==="image"&&O&&O.imageSrcSet?void 0:f,as:p},O),jc.set(Y,f),D.querySelector(Q)!==null||p==="style"&&D.querySelector(av(Y))||p==="script"&&D.querySelector(lv(Y))||(p=D.createElement("link"),El(p,"link",f),ti(p),D.head.appendChild(p)))}}function T5(f,p){qh.m(f,p);var O=Wp;if(O&&f){var D=p&&typeof p.as=="string"?p.as:"script",Q='link[rel="modulepreload"][as="'+Ha(D)+'"][href="'+Ha(f)+'"]',Y=Q;switch(D){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":Y=uv(f)}if(!jc.has(Y)&&(f=d({rel:"modulepreload",href:f},p),jc.set(Y,f),O.querySelector(Q)===null)){switch(D){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(O.querySelector(lv(Y)))return}D=O.createElement("link"),El(D,"link",f),ti(D),O.head.appendChild(D)}}}function fl(f,p,O){qh.S(f,p,O);var D=Wp;if(D&&f){var Q=Wi(D).hoistableStyles,Y=iv(f);p=p||"default";var ce=Q.get(Y);if(!ce){var Ee={loading:0,preload:null};if(ce=D.querySelector(av(Y)))Ee.loading=5;else{f=d({rel:"stylesheet",href:f,"data-precedence":p},O),(O=jc.get(Y))&&I4(f,O);var Le=ce=D.createElement("link");ti(Le),El(Le,"link",f),Le._p=new Promise(function(at,mt){Le.onload=at,Le.onerror=mt}),Le.addEventListener("load",function(){Ee.loading|=1}),Le.addEventListener("error",function(){Ee.loading|=2}),Ee.loading|=4,iO(ce,p,D)}ce={type:"stylesheet",instance:ce,count:1,state:Ee},Q.set(Y,ce)}}}function ss(f,p){qh.X(f,p);var O=Wp;if(O&&f){var D=Wi(O).hoistableScripts,Q=uv(f),Y=D.get(Q);Y||(Y=O.querySelector(lv(Q)),Y||(f=d({src:f,async:!0},p),(p=jc.get(Q))&&aO(f,p),Y=O.createElement("script"),ti(Y),El(Y,"link",f),O.head.appendChild(Y)),Y={type:"script",instance:Y,count:1,state:null},D.set(Q,Y))}}function k5(f,p){qh.M(f,p);var O=Wp;if(O&&f){var D=Wi(O).hoistableScripts,Q=uv(f),Y=D.get(Q);Y||(Y=O.querySelector(lv(Q)),Y||(f=d({src:f,async:!0,type:"module"},p),(p=jc.get(Q))&&aO(f,p),Y=O.createElement("script"),ti(Y),El(Y,"link",f),O.head.appendChild(Y)),Y={type:"script",instance:Y,count:1,state:null},D.set(Q,Y))}}function l_(f,p,O,D){var Q=(Q=ie.current)?rO(Q):null;if(!Q)throw Error(r(446));switch(f){case"meta":case"title":return null;case"style":return typeof O.precedence=="string"&&typeof O.href=="string"?(p=iv(O.href),O=Wi(Q).hoistableStyles,D=O.get(p),D||(D={type:"style",instance:null,count:0,state:null},O.set(p,D)),D):{type:"void",instance:null,count:0,state:null};case"link":if(O.rel==="stylesheet"&&typeof O.href=="string"&&typeof O.precedence=="string"){f=iv(O.href);var Y=Wi(Q).hoistableStyles,ce=Y.get(f);if(ce||(Q=Q.ownerDocument||Q,ce={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},Y.set(f,ce),(Y=Q.querySelector(av(f)))&&!Y._p&&(ce.instance=Y,ce.state.loading=5),jc.has(f)||(O={rel:"preload",as:"style",href:O.href,crossOrigin:O.crossOrigin,integrity:O.integrity,media:O.media,hrefLang:O.hrefLang,referrerPolicy:O.referrerPolicy},jc.set(f,O),Y||P5(Q,f,O,ce.state))),p&&D===null)throw Error(r(528,""));return ce}if(p&&D!==null)throw Error(r(529,""));return null;case"script":return p=O.async,O=O.src,typeof O=="string"&&p&&typeof p!="function"&&typeof p!="symbol"?(p=uv(O),O=Wi(Q).hoistableScripts,D=O.get(p),D||(D={type:"script",instance:null,count:0,state:null},O.set(p,D)),D):{type:"void",instance:null,count:0,state:null};default:throw Error(r(444,f))}}function iv(f){return'href="'+Ha(f)+'"'}function av(f){return'link[rel="stylesheet"]['+f+"]"}function o_(f){return d({},f,{"data-precedence":f.precedence,precedence:null})}function P5(f,p,O,D){f.querySelector('link[rel="preload"][as="style"]['+p+"]")?D.loading=1:(p=f.createElement("link"),D.preload=p,p.addEventListener("load",function(){return D.loading|=1}),p.addEventListener("error",function(){return D.loading|=2}),El(p,"link",O),ti(p),f.head.appendChild(p))}function uv(f){return'[src="'+Ha(f)+'"]'}function lv(f){return"script[async]"+f}function s_(f,p,O){if(p.count++,p.instance===null)switch(p.type){case"style":var D=f.querySelector('style[data-href~="'+Ha(O.href)+'"]');if(D)return p.instance=D,ti(D),D;var Q=d({},O,{"data-href":O.href,"data-precedence":O.precedence,href:null,precedence:null});return D=(f.ownerDocument||f).createElement("style"),ti(D),El(D,"style",Q),iO(D,O.precedence,f),p.instance=D;case"stylesheet":Q=iv(O.href);var Y=f.querySelector(av(Q));if(Y)return p.state.loading|=4,p.instance=Y,ti(Y),Y;D=o_(O),(Q=jc.get(Q))&&I4(D,Q),Y=(f.ownerDocument||f).createElement("link"),ti(Y);var ce=Y;return ce._p=new Promise(function(Ee,Le){ce.onload=Ee,ce.onerror=Le}),El(Y,"link",D),p.state.loading|=4,iO(Y,O.precedence,f),p.instance=Y;case"script":return Y=uv(O.src),(Q=f.querySelector(lv(Y)))?(p.instance=Q,ti(Q),Q):(D=O,(Q=jc.get(Y))&&(D=d({},O),aO(D,Q)),f=f.ownerDocument||f,Q=f.createElement("script"),ti(Q),El(Q,"link",D),f.head.appendChild(Q),p.instance=Q);case"void":return null;default:throw Error(r(443,p.type))}else p.type==="stylesheet"&&(p.state.loading&4)===0&&(D=p.instance,p.state.loading|=4,iO(D,O.precedence,f));return p.instance}function iO(f,p,O){for(var D=O.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),Q=D.length?D[D.length-1]:null,Y=Q,ce=0;ce<D.length;ce++){var Ee=D[ce];if(Ee.dataset.precedence===p)Y=Ee;else if(Y!==Q)break}Y?Y.parentNode.insertBefore(f,Y.nextSibling):(p=O.nodeType===9?O.head:O,p.insertBefore(f,p.firstChild))}function I4(f,p){f.crossOrigin==null&&(f.crossOrigin=p.crossOrigin),f.referrerPolicy==null&&(f.referrerPolicy=p.referrerPolicy),f.title==null&&(f.title=p.title)}function aO(f,p){f.crossOrigin==null&&(f.crossOrigin=p.crossOrigin),f.referrerPolicy==null&&(f.referrerPolicy=p.referrerPolicy),f.integrity==null&&(f.integrity=p.integrity)}var c1=null;function c_(f,p,O){if(c1===null){var D=new Map,Q=c1=new Map;Q.set(O,D)}else Q=c1,D=Q.get(O),D||(D=new Map,Q.set(O,D));if(D.has(f))return D;for(D.set(f,null),O=O.getElementsByTagName(f),Q=0;Q<O.length;Q++){var Y=O[Q];if(!(Y[wu]||Y[Rt]||f==="link"&&Y.getAttribute("rel")==="stylesheet")&&Y.namespaceURI!=="http://www.w3.org/2000/svg"){var ce=Y.getAttribute(p)||"";ce=f+ce;var Ee=D.get(ce);Ee?Ee.push(Y):D.set(ce,[Y])}}return D}function f_(f,p,O){f=f.ownerDocument||f,f.head.insertBefore(O,p==="title"?f.querySelector("head > title"):null)}function M5(f,p,O){if(O===1||p.itemProp!=null)return!1;switch(f){case"meta":case"title":return!0;case"style":if(typeof p.precedence!="string"||typeof p.href!="string"||p.href==="")break;return!0;case"link":if(typeof p.rel!="string"||typeof p.href!="string"||p.href===""||p.onLoad||p.onError)break;switch(p.rel){case"stylesheet":return f=p.disabled,typeof p.precedence=="string"&&f==null;default:return!0}case"script":if(p.async&&typeof p.async!="function"&&typeof p.async!="symbol"&&!p.onLoad&&!p.onError&&p.src&&typeof p.src=="string")return!0}return!1}function d_(f){return!(f.type==="stylesheet"&&(f.state.loading&3)===0)}function ov(f,p,O,D){if(O.type==="stylesheet"&&(typeof D.media!="string"||matchMedia(D.media).matches!==!1)&&(O.state.loading&4)===0){if(O.instance===null){var Q=iv(D.href),Y=p.querySelector(av(Q));if(Y){p=Y._p,p!==null&&typeof p=="object"&&typeof p.then=="function"&&(f.count++,f=uO.bind(f),p.then(f,f)),O.state.loading|=4,O.instance=Y,ti(Y);return}Y=p.ownerDocument||p,D=o_(D),(Q=jc.get(Q))&&I4(D,Q),Y=Y.createElement("link"),ti(Y);var ce=Y;ce._p=new Promise(function(Ee,Le){ce.onload=Ee,ce.onerror=Le}),El(Y,"link",D),O.instance=Y}f.stylesheets===null&&(f.stylesheets=new Map),f.stylesheets.set(O,p),(p=O.state.preload)&&(O.state.loading&3)===0&&(f.count++,O=uO.bind(f),p.addEventListener("load",O),p.addEventListener("error",O))}}var L4=0;function F5(f,p){return f.stylesheets&&f.count===0&&oO(f,f.stylesheets),0<f.count||0<f.imgCount?function(O){var D=setTimeout(function(){if(f.stylesheets&&oO(f,f.stylesheets),f.unsuspend){var Y=f.unsuspend;f.unsuspend=null,Y()}},6e4+p);0<f.imgBytes&&L4===0&&(L4=62500*a1());var Q=setTimeout(function(){if(f.waitingForImages=!1,f.count===0&&(f.stylesheets&&oO(f,f.stylesheets),f.unsuspend)){var Y=f.unsuspend;f.unsuspend=null,Y()}},(f.imgBytes>L4?50:800)+p);return f.unsuspend=O,function(){f.unsuspend=null,clearTimeout(D),clearTimeout(Q)}}:null}function uO(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)oO(this,this.stylesheets);else if(this.unsuspend){var f=this.unsuspend;this.unsuspend=null,f()}}}var lO=null;function oO(f,p){f.stylesheets=null,f.unsuspend!==null&&(f.count++,lO=new Map,p.forEach(h_,f),lO=null,uO.call(f))}function h_(f,p){if(!(p.state.loading&4)){var O=lO.get(f);if(O)var D=O.get(null);else{O=new Map,lO.set(f,O);for(var Q=f.querySelectorAll("link[data-precedence],style[data-precedence]"),Y=0;Y<Q.length;Y++){var ce=Q[Y];(ce.nodeName==="LINK"||ce.getAttribute("media")!=="not all")&&(O.set(ce.dataset.precedence,ce),D=ce)}D&&O.set(null,D)}Q=p.instance,ce=Q.getAttribute("data-precedence"),Y=O.get(ce)||D,Y===D&&O.set(null,Q),O.set(ce,Q),this.count++,D=uO.bind(this),Q.addEventListener("load",D),Q.addEventListener("error",D),Y?Y.parentNode.insertBefore(Q,Y.nextSibling):(f=f.nodeType===9?f.head:f,f.insertBefore(Q,f.firstChild)),p.state.loading|=4}}var sv={$$typeof:C,Provider:null,Consumer:null,_currentValue:te,_currentValue2:te,_threadCount:0};function N5(f,p,O,D,Q,Y,ce,Ee,Le){this.tag=1,this.containerInfo=f,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=ke(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=ke(0),this.hiddenUpdates=ke(null),this.identifierPrefix=D,this.onUncaughtError=Q,this.onCaughtError=Y,this.onRecoverableError=ce,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=Le,this.incompleteTransitions=new Map}function p_(f,p,O,D,Q,Y,ce,Ee,Le,at,mt,xt){return f=new N5(f,p,O,ce,Le,at,mt,xt,Ee),p=1,Y===!0&&(p|=24),Y=na(3,null,null,p),f.current=Y,Y.stateNode=f,p=Is(),p.refCount++,f.pooledCache=p,p.refCount++,Y.memoizedState={element:D,isDehydrated:O,cache:p},Tc(Y),f}function m_(f){return f?(f=pu,f):pu}function g_(f,p,O,D,Q,Y){Q=m_(Q),D.context===null?D.context=Q:D.pendingContext=Q,D=kc(p),D.payload={element:O},Y=Y===void 0?null:Y,Y!==null&&(D.callback=Y),O=Wo(f,D,p),O!==null&&(b(O,f,p),Od(O,f,p))}function v_(f,p){if(f=f.memoizedState,f!==null&&f.dehydrated!==null){var O=f.retryLane;f.retryLane=O!==0&&O<p?O:p}}function B4(f,p){v_(f,p),(f=f.alternate)&&v_(f,p)}function y_(f){if(f.tag===13||f.tag===31){var p=Ku(f,67108864);p!==null&&b(p,f,67108864),B4(f,67108864)}}function b_(f){if(f.tag===13||f.tag===31){var p=_l();p=Zt(p);var O=Ku(f,p);O!==null&&b(O,f,p),B4(f,p)}}var sO=!0;function I5(f,p,O,D){var Q=G.T;G.T=null;var Y=J.p;try{J.p=2,Q4(f,p,O,D)}finally{J.p=Y,G.T=Q}}function L5(f,p,O,D){var Q=G.T;G.T=null;var Y=J.p;try{J.p=8,Q4(f,p,O,D)}finally{J.p=Y,G.T=Q}}function Q4(f,p,O,D){if(sO){var Q=z4(D);if(Q===null)R4(f,p,D,cO,O),x_(f,D);else if(S_(Q,f,p,O,D))D.stopPropagation();else if(x_(f,D),p&4&&-1<B5.indexOf(f)){for(;Q!==null;){var Y=Pt(Q);if(Y!==null)switch(Y.tag){case 3:if(Y=Y.stateNode,Y.current.memoizedState.isDehydrated){var ce=Zn(Y.pendingLanes);if(ce!==0){var Ee=Y;for(Ee.pendingLanes|=2,Ee.entangledLanes|=2;ce;){var Le=1<<31-Fe(ce);Ee.entanglements[1]|=Le,ce&=~Le}Fd(Y),(Ar&6)===0&&(cl=Ze()+500,n1(0))}}break;case 31:case 13:Ee=Ku(Y,2),Ee!==null&&b(Ee,Y,2),De(),B4(Y,2)}if(Y=z4(D),Y===null&&R4(f,p,D,cO,O),Y===Q)break;Q=Y}Q!==null&&D.stopPropagation()}else R4(f,p,D,null,O)}}function z4(f){return f=ch(f),q4(f)}var cO=null;function q4(f){if(cO=null,f=Hr(f),f!==null){var p=a(f);if(p===null)f=null;else{var O=p.tag;if(O===13){if(f=u(p),f!==null)return f;f=null}else if(O===31){if(f=l(p),f!==null)return f;f=null}else if(O===3){if(p.stateNode.current.memoizedState.isDehydrated)return p.tag===3?p.stateNode.containerInfo:null;f=null}else p!==f&&(f=null)}}return cO=f,null}function O_(f){switch(f){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Ye()){case Me:return 2;case ze:return 8;case st:case Ot:return 32;case Nt:return 268435456;default:return 32}default:return 32}}var V4=!1,Jp=null,e0=null,t0=null,f1=new Map,d1=new Map,n0=[],B5="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function x_(f,p){switch(f){case"focusin":case"focusout":Jp=null;break;case"dragenter":case"dragleave":e0=null;break;case"mouseover":case"mouseout":t0=null;break;case"pointerover":case"pointerout":f1.delete(p.pointerId);break;case"gotpointercapture":case"lostpointercapture":d1.delete(p.pointerId)}}function wm(f,p,O,D,Q,Y){return f===null||f.nativeEvent!==Y?(f={blockedOn:p,domEventName:O,eventSystemFlags:D,nativeEvent:Y,targetContainers:[Q]},p!==null&&(p=Pt(p),p!==null&&y_(p)),f):(f.eventSystemFlags|=D,p=f.targetContainers,Q!==null&&p.indexOf(Q)===-1&&p.push(Q),f)}function S_(f,p,O,D,Q){switch(p){case"focusin":return Jp=wm(Jp,f,p,O,D,Q),!0;case"dragenter":return e0=wm(e0,f,p,O,D,Q),!0;case"mouseover":return t0=wm(t0,f,p,O,D,Q),!0;case"pointerover":var Y=Q.pointerId;return f1.set(Y,wm(f1.get(Y)||null,f,p,O,D,Q)),!0;case"gotpointercapture":return Y=Q.pointerId,d1.set(Y,wm(d1.get(Y)||null,f,p,O,D,Q)),!0}return!1}function U4(f){var p=Hr(f.target);if(p!==null){var O=a(p);if(O!==null){if(p=O.tag,p===13){if(p=u(O),p!==null){f.blockedOn=p,tn(f.priority,function(){b_(O)});return}}else if(p===31){if(p=l(O),p!==null){f.blockedOn=p,tn(f.priority,function(){b_(O)});return}}else if(p===3&&O.stateNode.current.memoizedState.isDehydrated){f.blockedOn=O.tag===3?O.stateNode.containerInfo:null;return}}}f.blockedOn=null}function fO(f){if(f.blockedOn!==null)return!1;for(var p=f.targetContainers;0<p.length;){var O=z4(f.nativeEvent);if(O===null){O=f.nativeEvent;var D=new O.constructor(O.type,O);sh=D,O.target.dispatchEvent(D),sh=null}else return p=Pt(O),p!==null&&y_(p),f.blockedOn=O,!1;p.shift()}return!0}function __(f,p,O){fO(f)&&O.delete(p)}function Q5(){V4=!1,Jp!==null&&fO(Jp)&&(Jp=null),e0!==null&&fO(e0)&&(e0=null),t0!==null&&fO(t0)&&(t0=null),f1.forEach(__),d1.forEach(__)}function cv(f,p){f.blockedOn===p&&(f.blockedOn=null,V4||(V4=!0,e.unstable_scheduleCallback(e.unstable_NormalPriority,Q5)))}var dO=null;function E_(f){dO!==f&&(dO=f,e.unstable_scheduleCallback(e.unstable_NormalPriority,function(){dO===f&&(dO=null);for(var p=0;p<f.length;p+=3){var O=f[p],D=f[p+1],Q=f[p+2];if(typeof D!="function"){if(q4(D||O)===null)continue;break}var Y=Pt(O);Y!==null&&(f.splice(p,3),p-=3,Ed(Y,{pending:!0,data:Q,method:O.method,action:D},D,Q))}}))}function fv(f){function p(Le){return cv(Le,f)}Jp!==null&&cv(Jp,f),e0!==null&&cv(e0,f),t0!==null&&cv(t0,f),f1.forEach(p),d1.forEach(p);for(var O=0;O<n0.length;O++){var D=n0[O];D.blockedOn===f&&(D.blockedOn=null)}for(;0<n0.length&&(O=n0[0],O.blockedOn===null);)U4(O),O.blockedOn===null&&n0.shift();if(O=(f.ownerDocument||f).$$reactFormReplay,O!=null)for(D=0;D<O.length;D+=3){var Q=O[D],Y=O[D+1],ce=Q[sn]||null;if(typeof Y=="function")ce||E_(O);else if(ce){var Ee=null;if(Y&&Y.hasAttribute("formAction")){if(Q=Y,ce=Y[sn]||null)Ee=ce.formAction;else if(q4(Q)!==null)continue}else Ee=ce.action;typeof Ee=="function"?O[D+1]=Ee:(O.splice(D,3),D-=3),E_(O)}}}function Co(){function f(Y){Y.canIntercept&&Y.info==="react-transition"&&Y.intercept({handler:function(){return new Promise(function(ce){return Q=ce})},focusReset:"manual",scroll:"manual"})}function p(){Q!==null&&(Q(),Q=null),D||setTimeout(O,20)}function O(){if(!D&&!navigation.transition){var Y=navigation.currentEntry;Y&&Y.url!=null&&navigation.navigate(Y.url,{state:Y.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var D=!1,Q=null;return navigation.addEventListener("navigate",f),navigation.addEventListener("navigatesuccess",p),navigation.addEventListener("navigateerror",p),setTimeout(O,100),function(){D=!0,navigation.removeEventListener("navigate",f),navigation.removeEventListener("navigatesuccess",p),navigation.removeEventListener("navigateerror",p),Q!==null&&(Q(),Q=null)}}}function h1(f){this._internalRoot=f}hO.prototype.render=h1.prototype.render=function(f){var p=this._internalRoot;if(p===null)throw Error(r(409));var O=p.current,D=_l();g_(O,D,f,p,null,null)},hO.prototype.unmount=h1.prototype.unmount=function(){var f=this._internalRoot;if(f!==null){this._internalRoot=null;var p=f.containerInfo;g_(f.current,2,null,f,null,null),De(),p[gr]=null}};function hO(f){this._internalRoot=f}hO.prototype.unstable_scheduleHydration=function(f){if(f){var p=Vt();f={blockedOn:null,target:f,priority:p};for(var O=0;O<n0.length&&p!==0&&p<n0[O].priority;O++);n0.splice(O,0,f),O===0&&U4(f)}};var D_=t.version;if(D_!=="19.2.0")throw Error(r(527,D_,"19.2.0"));J.findDOMNode=function(f){var p=f._reactInternals;if(p===void 0)throw typeof f.render=="function"?Error(r(188)):(f=Object.keys(f).join(","),Error(r(268,f)));return f=s(p),f=f!==null?c(f):null,f=f===null?null:f.stateNode,f};var z5={bundleType:0,version:"19.2.0",rendererPackageName:"react-dom",currentDispatcherRef:G,reconcilerVersion:"19.2.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var pO=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!pO.isDisabled&&pO.supportsFiber)try{zt=pO.inject(z5),an=pO}catch{}}return H4.createRoot=function(f,p){if(!i(f))throw Error(r(299));var O=!1,D="",Q=Zg,Y=Ky,ce=Hg;return p!=null&&(p.unstable_strictMode===!0&&(O=!0),p.identifierPrefix!==void 0&&(D=p.identifierPrefix),p.onUncaughtError!==void 0&&(Q=p.onUncaughtError),p.onCaughtError!==void 0&&(Y=p.onCaughtError),p.onRecoverableError!==void 0&&(ce=p.onRecoverableError)),p=p_(f,1,!1,null,null,O,D,null,Q,Y,ce,Co),f[gr]=p.current,w4(f),new h1(p)},H4.hydrateRoot=function(f,p,O){if(!i(f))throw Error(r(299));var D=!1,Q="",Y=Zg,ce=Ky,Ee=Hg,Le=null;return O!=null&&(O.unstable_strictMode===!0&&(D=!0),O.identifierPrefix!==void 0&&(Q=O.identifierPrefix),O.onUncaughtError!==void 0&&(Y=O.onUncaughtError),O.onCaughtError!==void 0&&(ce=O.onCaughtError),O.onRecoverableError!==void 0&&(Ee=O.onRecoverableError),O.formState!==void 0&&(Le=O.formState)),p=p_(f,1,!0,p,O??null,D,Q,Le,Y,ce,Ee,Co),p.context=m_(null),O=p.current,D=_l(),D=Zt(D),Q=kc(D),Q.callback=null,Wo(O,Q,D),O=D,p.current.lanes=O,He(p,O),Fd(p),f[gr]=p.current,w4(f),new hO(p)},H4.version="19.2.0",H4}var aQ;function _3e(){if(aQ)return G5.exports;aQ=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),G5.exports=S3e(),G5.exports}var xJ=_3e();const knt=sa(xJ);var e6,uQ;function oy(){if(uQ)return e6;uQ=1;var e={ACTOR_CHANGE:"ActorChange",CATCH_FIELD:"CatchField",CONDITION:"Condition",CLIENT_COMPONENT:"ClientComponent",CLIENT_EDGE_TO_SERVER_OBJECT:"ClientEdgeToServerObject",CLIENT_EDGE_TO_CLIENT_OBJECT:"ClientEdgeToClientObject",CLIENT_EXTENSION:"ClientExtension",DEFER:"Defer",CONNECTION:"Connection",FRAGMENT:"Fragment",FRAGMENT_SPREAD:"FragmentSpread",INLINE_DATA_FRAGMENT_SPREAD:"InlineDataFragmentSpread",INLINE_DATA_FRAGMENT:"InlineDataFragment",INLINE_FRAGMENT:"InlineFragment",LINKED_FIELD:"LinkedField",LINKED_HANDLE:"LinkedHandle",LITERAL:"Literal",LIST_VALUE:"ListValue",LOCAL_ARGUMENT:"LocalArgument",MODULE_IMPORT:"ModuleImport",ALIASED_FRAGMENT_SPREAD:"AliasedFragmentSpread",ALIASED_INLINE_FRAGMENT_SPREAD:"AliasedInlineFragmentSpread",RELAY_RESOLVER:"RelayResolver",RELAY_LIVE_RESOLVER:"RelayLiveResolver",REQUIRED_FIELD:"RequiredField",OBJECT_VALUE:"ObjectValue",OPERATION:"Operation",REQUEST:"Request",ROOT_ARGUMENT:"RootArgument",SCALAR_FIELD:"ScalarField",SCALAR_HANDLE:"ScalarHandle",SPLIT_OPERATION:"SplitOperation",STREAM:"Stream",TYPE_DISCRIMINATOR:"TypeDiscriminator",UPDATABLE_QUERY:"UpdatableQuery",VARIABLE:"Variable"};return e6=e,e6}var t6,lQ;function on(){if(lQ)return t6;lQ=1;var e=function(t,n,r,i,a,u,l,o){if(!t){var s;if(n===void 0)s=new Error("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var c=[r,i,a,u,l,o],d=0;s=new Error(n.replace(/%s/g,function(){return c[d++]})),s.name="Invariant Violation"}throw s.framesToPop=1,s}};return t6=e,t6}var n6,oQ;function E3e(){if(oQ)return n6;oQ=1;function e(n){return function(){return n}}var t=function(){};return t.thatReturns=e,t.thatReturnsFalse=e(!1),t.thatReturnsTrue=e(!0),t.thatReturnsNull=e(null),t.thatReturnsThis=function(){return this},t.thatReturnsArgument=function(n){return n},n6=t,n6}var r6,sQ;function Qi(){if(sQ)return r6;sQ=1;var e=E3e(),t=e;return r6=t,r6}var i6,cQ;function fp(){if(cQ)return i6;cQ=1;var e=oy(),t=on();Qi();function n(y){t(!1)}function r(y){var v=y;return typeof v=="function"?v=v():v.default&&(v=v.default),v}function i(y){var v=r(y);return typeof v=="object"&&v!==null&&v.kind===e.FRAGMENT}function a(y){var v=r(y);return typeof v=="object"&&v!==null&&v.kind===e.REQUEST}function u(y){var v=r(y);return typeof v=="object"&&v!==null&&v.kind===e.UPDATABLE_QUERY}function l(y){var v=r(y);return typeof v=="object"&&v!==null&&v.kind===e.INLINE_DATA_FRAGMENT}function o(y){var v=r(y);return i(v)||t(!1),v}function s(y){var v,_=o(y),S=(v=_.metadata)===null||v===void 0?void 0:v.refetch,E=S==null?void 0:S.connection;return S===null||typeof S!="object"||E===null||typeof E!="object"?null:_}function c(y){var v,_=o(y),S=(v=_.metadata)===null||v===void 0?void 0:v.refetch;return S===null||typeof S!="object"?null:_}function d(y){var v=r(y);return a(v)||t(!1),v}function h(y){var v=r(y);return u(v)||t(!1),v}function m(y){var v=r(y);return l(v)||t(!1),v}return i6={getFragment:o,getNode:r,getPaginationFragment:s,getRefetchableFragment:c,getRequest:d,getUpdatableQuery:h,getInlineDataFragment:m,graphql:n,isFragment:i,isRequest:a,isUpdatableQuery:u,isInlineDataFragment:l},i6}var a6={exports:{}},fQ;function Cn(){return fQ||(fQ=1,(function(e){function t(n){return n&&n.__esModule?n:{default:n}}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports})(a6)),a6.exports}var u6={exports:{}},l6={exports:{}},o6={exports:{}},s6={exports:{}},dQ;function SJ(){return dQ||(dQ=1,(function(e){function t(n){"@babel/helpers - typeof";return e.exports=t=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(r){return typeof r}:function(r){return r&&typeof Symbol=="function"&&r.constructor===Symbol&&r!==Symbol.prototype?"symbol":typeof r},e.exports.__esModule=!0,e.exports.default=e.exports,t(n)}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports})(s6)),s6.exports}var c6={exports:{}},hQ;function D3e(){return hQ||(hQ=1,(function(e){var t=SJ().default;function n(r,i){if(t(r)!="object"||!r)return r;var a=r[Symbol.toPrimitive];if(a!==void 0){var u=a.call(r,i||"default");if(t(u)!="object")return u;throw new TypeError("@@toPrimitive must return a primitive value.")}return(i==="string"?String:Number)(r)}e.exports=n,e.exports.__esModule=!0,e.exports.default=e.exports})(c6)),c6.exports}var pQ;function _J(){return pQ||(pQ=1,(function(e){var t=SJ().default,n=D3e();function r(i){var a=n(i,"string");return t(a)=="symbol"?a:a+""}e.exports=r,e.exports.__esModule=!0,e.exports.default=e.exports})(o6)),o6.exports}var mQ;function hc(){return mQ||(mQ=1,(function(e){var t=_J();function n(r,i,a){return(i=t(i))in r?Object.defineProperty(r,i,{value:a,enumerable:!0,configurable:!0,writable:!0}):r[i]=a,r}e.exports=n,e.exports.__esModule=!0,e.exports.default=e.exports})(l6)),l6.exports}var gQ;function zi(){return gQ||(gQ=1,(function(e){var t=hc();function n(i,a){var u=Object.keys(i);if(Object.getOwnPropertySymbols){var l=Object.getOwnPropertySymbols(i);a&&(l=l.filter(function(o){return Object.getOwnPropertyDescriptor(i,o).enumerable})),u.push.apply(u,l)}return u}function r(i){for(var a=1;a<arguments.length;a++){var u=arguments[a]!=null?arguments[a]:{};a%2?n(Object(u),!0).forEach(function(l){t(i,l,u[l])}):Object.getOwnPropertyDescriptors?Object.defineProperties(i,Object.getOwnPropertyDescriptors(u)):n(Object(u)).forEach(function(l){Object.defineProperty(i,l,Object.getOwnPropertyDescriptor(u,l))})}return i}e.exports=r,e.exports.__esModule=!0,e.exports.default=e.exports})(u6)),u6.exports}var f6={exports:{}},d6={exports:{}},h6={exports:{}},vQ;function EJ(){return vQ||(vQ=1,(function(e){function t(n,r){(r==null||r>n.length)&&(r=n.length);for(var i=0,a=Array(r);i<r;i++)a[i]=n[i];return a}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports})(h6)),h6.exports}var yQ;function DJ(){return yQ||(yQ=1,(function(e){var t=EJ();function n(r,i){if(r){if(typeof r=="string")return t(r,i);var a={}.toString.call(r).slice(8,-1);return a==="Object"&&r.constructor&&(a=r.constructor.name),a==="Map"||a==="Set"?Array.from(r):a==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(a)?t(r,i):void 0}}e.exports=n,e.exports.__esModule=!0,e.exports.default=e.exports})(d6)),d6.exports}var bQ;function Du(){return bQ||(bQ=1,(function(e){var t=DJ();function n(r,i){var a=typeof Symbol<"u"&&r[Symbol.iterator]||r["@@iterator"];if(!a){if(Array.isArray(r)||(a=t(r))||i&&r&&typeof r.length=="number"){a&&(r=a);var u=0,l=function(){};return{s:l,n:function(){return u>=r.length?{done:!0}:{done:!1,value:r[u++]}},e:function(h){throw h},f:l}}throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}var o,s=!0,c=!1;return{s:function(){a=a.call(r)},n:function(){var h=a.next();return s=h.done,h},e:function(h){c=!0,o=h},f:function(){try{s||a.return==null||a.return()}finally{if(c)throw o}}}}e.exports=n,e.exports.__esModule=!0,e.exports.default=e.exports})(f6)),f6.exports}var p6,OQ;function rS(){if(OQ)return p6;OQ=1;var e=Cn().default,t=e(zi()),n=e(Du()),r=on();function i(l,o,s){var c=(0,n.default)(o),d;try{for(c.s();!(d=c.n()).done;){var h=d.value;l.relayFieldLogger((0,t.default)((0,t.default)({},h),{},{uiContext:s}))}}catch(_){c.e(_)}finally{c.f()}var m=(0,n.default)(o),y;try{for(m.s();!(y=m.n()).done;){var v=y.value;if(a(v))switch(v.kind){case"relay_resolver.error":throw new Error("Relay: Resolver error at path '".concat(v.fieldPath,"' in '").concat(v.owner,"'. Message: ").concat(v.error.message));case"relay_field_payload.error":throw new Error("Relay: Unexpected response payload - check server logs for details.");case"missing_expected_data.throw":throw new Error("Relay: Missing expected data at path '".concat(v.fieldPath,"' in '").concat(v.owner,"'."));case"missing_required_field.throw":throw new Error("Relay: Missing @required value at path '".concat(v.fieldPath,"' in '").concat(v.owner,"'."));case"missing_required_field.log":case"missing_expected_data.log":break;default:v.kind,r(!1)}}}catch(_){m.e(_)}finally{m.f()}}function a(l){switch(l.kind){case"relay_resolver.error":case"relay_field_payload.error":return l.shouldThrow&&!l.handled;case"missing_expected_data.throw":case"missing_required_field.throw":return!l.handled;case"missing_required_field.log":case"missing_expected_data.log":return!1;default:throw l.kind,new Error("Relay: Unexpected event kind")}}function u(l,o,s){o!=null&&i(l,o,s)}return p6={handlePotentialSnapshotErrors:u,eventShouldThrow:a},p6}var m6={exports:{}},g6={exports:{}},xQ;function $3e(){return xQ||(xQ=1,(function(e){var t=EJ();function n(r){if(Array.isArray(r))return t(r)}e.exports=n,e.exports.__esModule=!0,e.exports.default=e.exports})(g6)),g6.exports}var v6={exports:{}},SQ;function C3e(){return SQ||(SQ=1,(function(e){function t(n){if(typeof Symbol<"u"&&n[Symbol.iterator]!=null||n["@@iterator"]!=null)return Array.from(n)}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports})(v6)),v6.exports}var y6={exports:{}},_Q;function w3e(){return _Q||(_Q=1,(function(e){function t(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports})(y6)),y6.exports}var EQ;function sy(){return EQ||(EQ=1,(function(e){var t=$3e(),n=C3e(),r=DJ(),i=w3e();function a(u){return t(u)||n(u)||r(u)||i()}e.exports=a,e.exports.__esModule=!0,e.exports.default=e.exports})(m6)),m6.exports}var b6,DQ;function $J(){return DQ||(DQ=1,b6={DEFAULT_HANDLE_KEY:""}),b6}var O6,$Q;function NF(){if($Q)return O6;$Q=1;var e=$J(),t=e.DEFAULT_HANDLE_KEY,n=on();function r(i,a,u){return a&&a!==t?"__".concat(a,"_").concat(i):(u==null&&n(!1),"__".concat(u,"_").concat(i))}return O6=r,O6}var x6,CQ;function th(){if(CQ)return x6;CQ=1;var e={ENABLE_VARIABLE_CONNECTION_KEY:!1,ENABLE_RELAY_RESOLVERS:!1,ENABLE_GETFRAGMENTIDENTIFIER_OPTIMIZATION:!1,ENABLE_FRIENDLY_QUERY_NAME_GQL_URL:!1,ENABLE_DO_NOT_WRAP_LIVE_QUERY:!1,ENABLE_NOTIFY_SUBSCRIPTION:!1,BATCH_ASYNC_MODULE_UPDATES_FN:null,ENABLE_CONTAINERS_SUBSCRIBE_ON_COMMIT:!1,MAX_DATA_ID_LENGTH:null,STRING_INTERN_LEVEL:0,LOG_MISSING_RECORDS_IN_PROD:!1,ENABLE_STORE_ID_COLLISION_LOGGING:!1,ENABLE_NONCOMPLIANT_ERROR_HANDLING_ON_LISTS:!1,ENABLE_LOOSE_SUBSCRIPTION_ATTRIBUTION:!1,ENABLE_OPERATION_TRACKER_OPTIMISTIC_UPDATES:!1,ENABLE_RELAY_OPERATION_TRACKER_SUSPENSE:!1,PROCESS_OPTIMISTIC_UPDATE_BEFORE_SUBSCRIPTION:!1,MARK_RESOLVER_VALUES_AS_CLEAN_AFTER_FRAGMENT_REREAD:!1,ENABLE_CYLE_DETECTION_IN_VARIABLES:!1,ENABLE_ACTIVITY_COMPATIBILITY:!1,ENABLE_READ_TIME_RESOLVER_STORAGE_KEY_PREFIX:!0,ENABLE_USE_PAGINATION_IS_LOADING_FIX:!1,DISALLOW_NESTED_UPDATES:!1,ENABLE_TYPENAME_PREFIXED_DATA_ID:!1,ENABLE_UI_CONTEXT_ON_RELAY_LOGGER:!1,CHECK_ALL_FRAGMENTS_FOR_MISSING_CLIENT_EDGES:!1};return x6=e,x6}var S6,wQ;function Sb(){if(wQ)return S6;wQ=1;function e(n){if(!n||typeof n!="object")return n;if(Array.isArray(n))return n.map(e);for(var r=Object.keys(n).sort(),i={},a=0;a<r.length;a++)i[r[a]]=e(n[r[a]]);return i}function t(n){var r=arguments.length>1&&arguments[1]!==void 0?arguments[1]:new Set;if(!n||typeof n!="object")return!1;if(r.has(n))return!0;var i=new Set(r);i.add(n);var a=Array.isArray(n)?n:Object.values(n);return a.some(function(u){return t(u,i)})}return S6={stableCopy:e,hasCycle:t},S6}var _6,RQ;function _a(){if(RQ)return _6;RQ=1;var e=Cn().default,t=e(sy()),n=NF(),r=oy(),i=th(),a=Sb(),u=a.stableCopy,l=on(),o=r.VARIABLE,s=r.LITERAL,c=r.OBJECT_VALUE,d=r.LIST_VALUE,h="__errors",m="__module_component_",y="__module_operation_",v="$r:";function _(q,N){if(q.kind===o)return F(q.variableName,N);if(q.kind===s)return q.value;if(q.kind===c){var U={};return q.fields.forEach(function(G){U[G.name]=_(G,N)}),U}else if(q.kind===d){var W=[];return q.items.forEach(function(G){G!=null&&W.push(_(G,N))}),W}}function S(q,N,U){var W={};return U&&(W[V.FRAGMENT_POINTER_IS_WITHIN_UNMATCHED_TYPE_REFINEMENT]=!0),q&&q.forEach(function(G){W[G.name]=_(G,N)}),W}function E(q,N){var U=q.dynamicKey,W=q.handle,G=q.key,J=q.name,te=q.args,H=q.filters,M=n(W,G,J),K=null;return te&&H&&te.length!==0&&H.length!==0&&(K=te.filter(function(X){return H.indexOf(X.name)>-1})),U&&(K=K!=null?[U].concat((0,t.default)(K)):[U]),K===null?M:k(M,S(K,N))}function C(q,N){if(q.storageKey)return q.storageKey;var U=R(q),W=q.name;return U&&U.length!==0?k(W,S(U,N)):W}function T(q,N){var U=C(q,N);return i.ENABLE_READ_TIME_RESOLVER_STORAGE_KEY_PREFIX?"$r:"+U:U}function R(q){if(q.kind==="RelayResolver"||q.kind==="RelayLiveResolver"){var N;if(q.args==null){var U;return(U=q.fragment)===null||U===void 0?void 0:U.args}return((N=q.fragment)===null||N===void 0?void 0:N.args)==null?q.args:q.args.concat(q.fragment.args)}var W=typeof q.args>"u"?void 0:q.args;return W}function $(q,N){return k(q,u(N))}function k(q,N){if(!N)return q;var U=[];for(var W in N)if(N.hasOwnProperty(W)){var G=N[W];if(G!=null){var J;U.push(W+":"+((J=JSON.stringify(G))!==null&&J!==void 0?J:"undefined"))}}return U.length===0?q:q+"(".concat(U.join(","),")")}function F(q,N){return N.hasOwnProperty(q)||l(!1),u(N[q])}function L(q){return"".concat(m).concat(q)}function j(q){return"".concat(y).concat(q)}var V={ACTOR_IDENTIFIER_KEY:"__actorIdentifier",CLIENT_EDGE_TRAVERSAL_PATH:"__clientEdgeTraversalPath",FRAGMENTS_KEY:"__fragments",FRAGMENT_OWNER_KEY:"__fragmentOwner",FRAGMENT_POINTER_IS_WITHIN_UNMATCHED_TYPE_REFINEMENT:"$isWithinUnmatchedTypeRefinement",FRAGMENT_PROP_NAME_KEY:"__fragmentPropName",MODULE_COMPONENT_KEY:"__module_component",ERRORS_KEY:h,ID_KEY:"__id",REF_KEY:"__ref",REFS_KEY:"__refs",ROOT_ID:"client:root",ROOT_TYPE:"__Root",TYPENAME_KEY:"__typename",INVALIDATED_AT_KEY:"__invalidated_at",RELAY_RESOLVER_VALUE_KEY:"__resolverValue",RELAY_RESOLVER_INVALIDATION_KEY:"__resolverValueMayBeInvalid",RELAY_RESOLVER_SNAPSHOT_KEY:"__resolverSnapshot",RELAY_RESOLVER_ERROR_KEY:"__resolverError",RELAY_RESOLVER_OUTPUT_TYPE_RECORD_IDS:"__resolverOutputTypeRecordIDs",RELAY_READ_TIME_RESOLVER_KEY_PREFIX:v,formatStorageKey:k,getArgumentValue:_,getArgumentValues:S,getHandleStorageKey:E,getStorageKey:C,getReadTimeResolverStorageKey:T,getStableStorageKey:$,getModuleComponentKey:L,getModuleOperationKey:j};return _6=V,_6}var E6,AQ;function cy(){if(AQ)return E6;AQ=1;var e=Cn().default,t=e(zi()),n=_a(),r=n.getArgumentValues,i=on();function a(o,s,c){if(o.argumentDefinitions==null)return c;var d;return o.argumentDefinitions.forEach(function(h){if(!c.hasOwnProperty(h.name))switch(d=d||(0,t.default)({},c),h.kind){case"LocalArgument":d[h.name]=h.defaultValue;break;case"RootArgument":if(!s.hasOwnProperty(h.name)){d[h.name]=void 0;break}d[h.name]=s[h.name];break;default:i(!1)}}),d||c}function u(o,s,c){var d={};return o.argumentDefinitions.forEach(function(h){var m=h.defaultValue;c[h.name]!=null&&(m=c[h.name]),d[h.name]=m}),s!=null&&Object.keys(s).forEach(function(h){d[h]=s[h].get()}),d}function l(o,s,c){if(s==null)return o;var d=(0,t.default)({},o),h=c?r(c,o):{};return s.forEach(function(m){var y,v=(y=h[m.name])!==null&&y!==void 0?y:m.defaultValue;d[m.name]=v}),d}return E6={getLocalVariables:l,getFragmentVariables:a,getOperationVariables:u},E6}var D6,TQ;function Jf(){if(TQ)return D6;TQ=1;var e=[],t=[];/**
 * Checks if two values are equal. Values may be primitives, arrays, or objects.
 * Returns true if both arguments have the same keys and values.
 *
 * @see http://underscorejs.org
 * @copyright 2009-2013 Jeremy Ashkenas, DocumentCloud Inc.
 * @license MIT
 */function n(i,a){var u=e.length?e.pop():[],l=t.length?t.pop():[],o=r(i,a,u,l);return u.length=0,l.length=0,e.push(u),t.push(l),o}function r(i,a,u,l){if(i===a)return i!==0||1/i==1/a;if(i==null||a==null||typeof i!="object"||typeof a!="object")return!1;var o=Object.prototype.toString,s=o.call(i);if(s!=o.call(a))return!1;switch(s){case"[object String]":return i==String(a);case"[object Number]":return isNaN(i)||isNaN(a)?!1:i==Number(a);case"[object Date]":case"[object Boolean]":return+i==+a;case"[object RegExp]":return i.source==a.source&&i.global==a.global&&i.multiline==a.multiline&&i.ignoreCase==a.ignoreCase}for(var c=u.length;c--;)if(u[c]==i)return l[c]==a;u.push(i),l.push(a);var d=0;if(s==="[object Array]"){if(d=i.length,d!==a.length)return!1;for(;d--;)if(!r(i[d],a[d],u,l))return!1}else{if(i.constructor!==a.constructor)return!1;if(i.hasOwnProperty("valueOf")&&a.hasOwnProperty("valueOf"))return i.valueOf()==a.valueOf();var h=Object.keys(i);if(h.length!=Object.keys(a).length)return!1;for(var m=0;m<h.length;m++)if(!r(i[h[m]],a[h[m]],u,l))return!1}return u.pop(),l.pop(),!0}return D6=n,D6}var $6,kQ;function dp(){if(kQ)return $6;kQ=1;var e=cy(),t=e.getFragmentVariables,n=_a(),r=n.CLIENT_EDGE_TRAVERSAL_PATH,i=n.FRAGMENT_OWNER_KEY,a=n.FRAGMENT_POINTER_IS_WITHIN_UNMATCHED_TYPE_REFINEMENT,u=n.FRAGMENTS_KEY,l=n.ID_KEY,o=Jf(),s=on();Qi();function c(q,N){typeof N=="object"&&N!==null&&!Array.isArray(N)||s(!1);var U=N[l],W=N[u],G=N[i],J=N[r];if(typeof U=="string"&&typeof W=="object"&&W!==null&&typeof W[q.name]=="object"&&W[q.name]!==null&&typeof G=="object"&&G!==null&&(J==null||Array.isArray(J))){var te=G,H=J,M=W[q.name],K=t(q,te.variables,M),X=M[a]===!0;return j(q,U,K,te,X,H)}return null}function d(q,N){var U=null;return N.forEach(function(W,G){var J=W!=null?c(q,W):null;J!=null&&(U=U||[],U.push(J))}),U==null?null:{kind:"PluralReaderSelector",selectors:U}}function h(q,N){return N==null?N:q.metadata&&q.metadata.plural===!0?(Array.isArray(N)||s(!1),d(q,N)):(Array.isArray(N)&&s(!1),c(q,N))}function m(q,N){var U={};for(var W in q)if(q.hasOwnProperty(W)){var G=q[W],J=N[W];U[W]=h(G,J)}return U}function y(q,N){var U={};for(var W in q)if(q.hasOwnProperty(W)){var G=q[W],J=N[W];U[W]=v(G,J)}return U}function v(q,N){return N==null?N:q.metadata&&q.metadata.plural===!0?(Array.isArray(N)||s(!1),_(q,N)):(Array.isArray(N)&&s(!1),S(q,N))}function _(q,N){var U=null;return N.forEach(function(W){var G=W!=null?S(q,W):null;G!=null&&(U=U||[],U.push(G))}),U}function S(q,N){typeof N=="object"&&N!==null&&!Array.isArray(N)||s(!1);var U=N[l];return typeof U=="string"?U:null}function E(q,N){var U={};for(var W in q)if(q.hasOwnProperty(W)){var G=q[W],J=N[W],te=C(G,J);Object.assign(U,te)}return U}function C(q,N){var U;return N==null?{}:((U=q.metadata)===null||U===void 0?void 0:U.plural)===!0?(Array.isArray(N)||s(!1),R(q,N)):(Array.isArray(N)&&s(!1),T(q,N)||{})}function T(q,N){var U=c(q,N);return U?U.variables:null}function R(q,N){var U={};return N.forEach(function(W,G){if(W!=null){var J=T(q,W);J!=null&&Object.assign(U,J)}}),U}function $(q,N){return q.dataID===N.dataID&&q.node===N.node&&o(q.variables,N.variables)&&k(q.owner,N.owner)&&q.isWithinUnmatchedTypeRefinement===N.isWithinUnmatchedTypeRefinement&&F(q.clientEdgeTraversalPath,N.clientEdgeTraversalPath)}function k(q,N){return q===N?!0:q.identifier===N.identifier&&o(q.cacheConfig,N.cacheConfig)}function F(q,N){if(q===N)return!0;if(q==null||N==null||q.length!==N.length)return!1;for(var U=q.length;U--;){var W=q[U],G=N[U];if(W!==G&&(W==null||G==null||W.clientEdgeDestinationID!==G.clientEdgeDestinationID||W.readerClientEdge!==G.readerClientEdge))return!1}return!0}function L(q,N){return q===N?!0:q==null?N==null:N==null?q==null:q.kind==="SingularReaderSelector"&&N.kind==="SingularReaderSelector"?$(q,N):q.kind==="PluralReaderSelector"&&N.kind==="PluralReaderSelector"?q.selectors.length===N.selectors.length&&q.selectors.every(function(U,W){return $(U,N.selectors[W])}):!1}function j(q,N,U,W){var G=arguments.length>4&&arguments[4]!==void 0?arguments[4]:!1,J=arguments.length>5?arguments[5]:void 0;return{kind:"SingularReaderSelector",dataID:N,isWithinUnmatchedTypeRefinement:G,clientEdgeTraversalPath:J??null,node:q,variables:U,owner:W}}function V(q,N,U){return{dataID:N,node:q,variables:U}}return $6={areEqualSelectors:L,createReaderSelector:j,createNormalizationSelector:V,getDataIDsFromFragment:v,getDataIDsFromObject:y,getSingularSelector:c,getPluralSelector:d,getSelector:h,getSelectorsFromObject:m,getVariablesFromSingularFragment:T,getVariablesFromPluralFragment:R,getVariablesFromFragment:C,getVariablesFromObject:E},$6}var C6,PQ;function IF(){if(PQ)return C6;PQ=1;var e=fp(),t=e.getFragment,n=rS(),r=n.eventShouldThrow,i=dp(),a=i.getSelector,u=on(),l=[];function o(d,h){l.push(d);try{return h()}finally{l.pop()}}function s(d,h){if(!l.length)throw new Error("readFragment should be called only from within a Relay Resolver function.");var m=l[l.length-1],y=t(d),v=a(y,h);v==null&&u(!1),v.kind!=="SingularReaderSelector"&&u(!1);var _=m.getDataForResolverFragment(v,h),S=_.data,E=_.isMissingData,C=_.fieldErrors;if(E||C!=null&&C.some(r))throw c;return S}var c={};return C6={readFragment:s,withResolverContext:o,RESOLVER_FRAGMENT_ERRORED_SENTINEL:c},C6}var w6,MQ;function R3e(){if(MQ)return w6;MQ=1;var e=IF(),t=e.readFragment,n=on();function r(i,a,u,l){var o=a;return function(s,c,d){var h=t(i,s);if(u!=null){if(h==null)if(l===!0)n(!1);else return o(null,c,d);if(u in h)return l===!0&&h[u]==null&&n(!1),o(h[u],c,d);n(!1)}else return o(null,c,d)}}return w6=r,w6}var R6={exports:{}},FQ;function CJ(){return FQ||(FQ=1,(function(e){function t(r,i,a,u,l,o,s){try{var c=r[o](s),d=c.value}catch(h){return void a(h)}c.done?i(d):Promise.resolve(d).then(u,l)}function n(r){return function(){var i=this,a=arguments;return new Promise(function(u,l){var o=r.apply(i,a);function s(d){t(o,u,l,s,c,"next",d)}function c(d){t(o,u,l,s,c,"throw",d)}s(void 0)})}}e.exports=n,e.exports.__esModule=!0,e.exports.default=e.exports})(R6)),R6.exports}var A6,NQ;function wJ(){if(NQ)return A6;NQ=1;function e(t){return t!=null&&typeof t=="object"&&typeof t.then=="function"}return A6=e,A6}var T6,IQ;function fy(){if(IQ)return T6;IQ=1;var e=wJ(),t=o,n=(function(){s.create=function(h){return new s(h)};function s(d){this._source=d}s.onUnhandledError=function(h){t=h},s.from=function(h){return r(h)?i(h):e(h)?a(h):u(h)};var c=s.prototype;return c.catch=function(h){var m=this;return s.create(function(y){var v;return m.subscribe({start:function(S){v=S},next:y.next,complete:y.complete,error:function(S){try{h(S).subscribe({start:function(C){v=C},next:y.next,complete:y.complete,error:y.error})}catch(E){y.error(E,!0)}}}),function(){return v.unsubscribe()}})},c.concat=function(h){var m=this;return s.create(function(y){var v;return m.subscribe({start:function(S){v=S},next:y.next,error:y.error,complete:function(){v=h.subscribe(y)}}),function(){v&&v.unsubscribe()}})},c.do=function(h){var m=this;return s.create(function(y){var v=function(S){return function(){try{h[S]&&h[S].apply(h,arguments)}catch(E){t(E,!0)}y[S]&&y[S].apply(y,arguments)}};return m.subscribe({start:v("start"),next:v("next"),error:v("error"),complete:v("complete"),unsubscribe:v("unsubscribe")})})},c.finally=function(h){var m=this;return s.create(function(y){var v=m.subscribe(y);return function(){v.unsubscribe(),h()}})},c.ifEmpty=function(h){var m=this;return s.create(function(y){var v=!1,_;return _=m.subscribe({next:function(E){v=!0,y.next(E)},error:y.error,complete:function(){v?y.complete():_=h.subscribe(y)}}),function(){_&&_.unsubscribe()}})},c.subscribe=function(h){return l(this._source,h)},c.map=function(h){var m=this;return s.create(function(y){var v=m.subscribe({complete:y.complete,error:y.error,next:function(S){try{var E=h(S);y.next(E)}catch(C){y.error(C,!0)}}});return function(){v.unsubscribe()}})},c.mergeMap=function(h){var m=this;return s.create(function(y){var v=[];function _(E){this._sub=E,v.push(E)}function S(){v.splice(v.indexOf(this._sub),1),v.length===0&&y.complete()}return m.subscribe({start:_,next:function(C){try{y.closed||s.from(h(C)).subscribe({start:_,next:y.next,error:y.error,complete:S})}catch(T){y.error(T,!0)}},error:y.error,complete:S}),function(){v.forEach(function(E){return E.unsubscribe()}),v.length=0}})},c.poll=function(h){var m=this;return s.create(function(y){var v,_,S=function E(){v=m.subscribe({next:y.next,error:y.error,complete:function(){_=setTimeout(E,h)}})};return S(),function(){clearTimeout(_),v.unsubscribe()}})},c.toPromise=function(){var h=this;return new Promise(function(m,y){var v=!1;h.subscribe({next:function(S){v||(v=!0,m(S))},error:y,complete:m})})},s})();function r(s){return typeof s=="object"&&s!==null&&typeof s.subscribe=="function"}function i(s){return s instanceof n?s:n.create(function(c){return s.subscribe(c)})}function a(s){return n.create(function(c){s.then(function(d){c.next(d),c.complete()},c.error)})}function u(s){return n.create(function(c){c.next(s),c.complete()})}function l(s,c){var d=!1,h,m=function(E){return Object.defineProperty(E,"closed",{get:function(){return d}})};function y(){if(h){if(h.unsubscribe)h.unsubscribe();else try{h()}catch(S){t(S,!0)}h=void 0}}var v=m({unsubscribe:function(){if(!d){d=!0;try{c.unsubscribe&&c.unsubscribe(v)}catch(E){t(E,!0)}finally{y()}}}});try{c.start&&c.start(v)}catch(S){t(S,!0)}if(d)return v;var _=m({next:function(E){if(!d&&c.next)try{c.next(E)}catch(C){t(C,!0)}},error:function(E,C){if(d||!c.error)d=!0,t(E,C||!1),y();else{d=!0;try{c.error(E)}catch(T){t(T,!0)}finally{y()}}},complete:function(){if(!d){d=!0;try{c.complete&&c.complete()}catch(E){t(E,!0)}finally{y()}}}});try{h=s(_)}catch(S){_.error(S,!0)}return d&&y(),v}function o(s,c){}return T6=n,T6}var k6,LQ;function RJ(){if(LQ)return k6;LQ=1;var e=Cn().default,t=e(Du()),n=e(hc()),r=fy(),i=on(),a=(function(){function u(){var o=this;(0,n.default)(this,"_complete",!1),(0,n.default)(this,"_events",[]),(0,n.default)(this,"_sinks",new Set),(0,n.default)(this,"_subscription",[]),this._observable=r.create(function(s){o._sinks.add(s);for(var c=o._events,d=0;d<c.length&&!s.closed;d++){var h=c[d];switch(h.kind){case"complete":s.complete();break;case"error":s.error(h.error);break;case"next":s.next(h.data);break;default:h.kind,i(!1)}}return function(){o._sinks.delete(s)}})}var l=u.prototype;return l.complete=function(){this._complete!==!0&&(this._complete=!0,this._events.push({kind:"complete"}),this._sinks.forEach(function(s){return s.complete()}))},l.error=function(s){this._complete!==!0&&(this._complete=!0,this._events.push({kind:"error",error:s}),this._sinks.forEach(function(c){return c.error(s)}))},l.next=function(s){this._complete!==!0&&(this._events.push({kind:"next",data:s}),this._sinks.forEach(function(c){return c.next(s)}))},l.subscribe=function(s){var c=this._observable.subscribe(s);return this._subscription.push(c),c},l.unsubscribe=function(){var s=(0,t.default)(this._subscription),c;try{for(s.s();!(c=s.n()).done;){var d=c.value;d.unsubscribe()}}catch(h){s.e(h)}finally{s.f()}this._subscription=[]},l.getObserverCount=function(){return this._sinks.size},u})();return k6=a,k6}var P6,BQ;function bC(){if(BQ)return P6;BQ=1;var e=fy(),t=RJ(),n=on(),r=typeof WeakMap=="function",i=r?new WeakMap:new Map;function a(m,y){return u(m,y.request.identifier,function(){return m.execute({operation:y})})}function u(m,y,v){return e.create(function(_){var S=d(m),E=S.get(y);return E||v().finally(function(){return S.delete(y)}).subscribe({start:function(T){E={identifier:y,subject:new t,subjectForInFlightStatus:new t,subscription:T,promise:null},S.set(y,E)},next:function(T){var R=h(S,y);R.subject.next(T),R.subjectForInFlightStatus.next(T)},error:function(T){var R=h(S,y);R.subject.error(T),R.subjectForInFlightStatus.error(T)},complete:function(){var T=h(S,y);T.subject.complete(),T.subjectForInFlightStatus.complete()},unsubscribe:function(T){var R=h(S,y);R.subject.unsubscribe(),R.subjectForInFlightStatus.unsubscribe()}}),E==null&&n(!1),l(S,E).subscribe(_)})}function l(m,y){return e.create(function(v){var _=y.subject.subscribe(v);return function(){_.unsubscribe();var S=m.get(y.identifier);if(S){var E=S.subscription;E!=null&&S.subject.getObserverCount()===0&&(E.unsubscribe(),m.delete(y.identifier))}}})}function o(m,y,v){return e.create(function(_){var S=v.subjectForInFlightStatus.subscribe({error:_.error,next:function(C){if(!m.isRequestActive(v.identifier)){_.complete();return}_.next()},complete:_.complete,unsubscribe:_.complete});return function(){S.unsubscribe()}})}function s(m,y){var v=d(m),_=v.get(y.identifier);if(!_||!m.isRequestActive(_.identifier))return null;var S=new Promise(function(E,C){var T=!1;o(m,v,_).subscribe({complete:E,error:C,next:function($){T&&E($)}}),T=!0});return S}function c(m,y){var v=d(m),_=v.get(y.identifier);return!_||!m.isRequestActive(_.identifier)?null:o(m,v,_)}function d(m){var y=i.get(m);if(y!=null)return y;var v=new Map;return i.set(m,v),v}function h(m,y){var v=m.get(y);return v==null&&n(!1),v}return P6={fetchQuery:a,fetchQueryDeduped:u,getPromiseForActiveRequest:s,getObservableForActiveRequest:c},P6}var M6,QQ;function LF(){if(QQ)return M6;QQ=1;var e=Cn().default,t=CJ().default,n=e(Du()),r=fy(),i=bC(),a=i.getObservableForActiveRequest,u=fp(),l=u.getFragment,o=rS(),s=o.handlePotentialSnapshotErrors,c=dp(),d=c.getSelector,h=on();function m(T,R,$){return y.apply(this,arguments)}function y(){return y=t(function*(T,R,$){var k;try{var F,L=yield new Promise(function(V,q){k=v(T,R,$).subscribe({next:function(U){U.state==="ok"?V(U.value):U.state==="error"&&q(U.error)}})});return(F=k)===null||F===void 0||F.unsubscribe(),L}catch(V){var j;throw(j=k)===null||j===void 0||j.unsubscribe(),V}}),y.apply(this,arguments)}function v(T,R,$){var k,F=l(R),L=d(F,$);switch(((k=F.metadata)===null||k===void 0?void 0:k.hasClientEdges)!=null&&h(!1),L==null&&h(!1),L.kind){case"SingularReaderSelector":return _(T,R,L);case"PluralReaderSelector":return S(T,R,L)}h(!1)}function _(T,R,$){var k=T.lookup($);return r.create(function(F){F.next(E(T,R,$.owner,k));var L=T.subscribe(k,function(j){F.next(E(T,R,$.owner,j))});return function(){return L.dispose()}})}function S(T,R,$){var k=$.selectors.map(function(F){return T.lookup(F)});return r.create(function(F){var L=k.map(function(V,q){return E(T,R,$.selectors[q].owner,V)});F.next(C(L));var j=k.map(function(V,q){return T.subscribe(V,function(N){L[q]=E(T,R,$.selectors[q].owner,N),F.next(C(L))})});return function(){return j.forEach(function(V){return V.dispose()})}})}function E(T,R,$,k){var F=k.missingLiveResolverFields!=null&&k.missingLiveResolverFields.length>0,L=k.missingClientEdges!=null&&k.missingClientEdges.length>0;if(F||L)return{state:"loading"};if(k.isMissingData&&(a(T,$)!=null||T.getOperationTracker().getPendingOperationsAffectingOwner($)!=null))return{state:"loading"};try{s(T,k.fieldErrors)}catch(j){return{error:j,state:"error"}}return k.data==null&&h(!1),{state:"ok",value:k.data}}function C(T){var R=[],$=(0,n.default)(T),k;try{for($.s();!(k=$.n()).done;){var F=k.value;if(F.state==="ok")R.push(F.value);else return F}}catch(L){$.e(L)}finally{$.f()}return{state:"ok",value:R}}return M6={observeFragment:v,waitForFragmentData:m},M6}var F6,zQ;function iS(){if(zQ)return F6;zQ=1;function e(n){return t(n)&&(Object.freeze(n),Object.getOwnPropertyNames(n).forEach(function(r){var i=n[r];i&&typeof i=="object"&&!Object.isFrozen(i)&&e(i)})),n}function t(n){return n!=null&&(Array.isArray(n)||typeof n=="object"&&n.constructor===Object)}return F6=e,F6}var N6,qQ;function AJ(){if(qQ)return N6;qQ=1;var e=Sb(),t=e.stableCopy,n=on();function r(i,a){var u=i.cacheID!=null?i.cacheID:i.id;return u==null&&n(!1),u+JSON.stringify(t(a))}return N6=r,N6}var I6,VQ;function dy(){if(VQ)return I6;VQ=1,iS();var e=AJ(),t=th(),n=Sb(),r=n.hasCycle,i=cy(),a=i.getOperationVariables,u=dp(),l=u.createNormalizationSelector,o=u.createReaderSelector,s=_a(),c=s.ROOT_ID,d=on();function h(y,v,_){var S=arguments.length>3&&arguments[3]!==void 0?arguments[3]:c,E=y.operation,C=a(E,y.params.providedVariables,v);t.ENABLE_CYLE_DETECTION_IN_VARIABLES&&r(C)&&d(!1);var T=m(y,C,_),R={fragment:o(y.fragment,S,C,T),request:T,root:l(E,S,C)};return R}function m(y,v,_){var S={identifier:e(y.params,v),node:y,variables:v,cacheConfig:_};return S}return I6={createOperationDescriptor:h,createRequestDescriptor:m},I6}var L6,UQ;function A3e(){if(UQ)return L6;UQ=1;var e=Cn().default,t=e(hc()),n=LF(),r=n.observeFragment,i=dy(),a=i.createOperationDescriptor;function u(l,o,s){var c=a(o,s),d={__id:c.fragment.dataID,__fragments:(0,t.default)({},c.fragment.node.name,c.request.variables),__fragmentOwner:c.request},h=c.request.node.fragment;return r(l,h,d)}return L6={observeQuery:u},L6}var B6,jQ;function T3e(){if(jQ)return B6;jQ=1;var e=CJ().default,t=LF(),n=t.observeFragment;function r(a,u,l){return i.apply(this,arguments)}function i(){return i=e(function*(a,u,l){var o;try{var s,c=yield new Promise(function(h,m){o=n(a,u,l).subscribe({next:function(v){v.state==="ok"?h(v.value):v.state==="error"&&m(v.error)}})});return(s=o)===null||s===void 0||s.unsubscribe(),c}catch(h){var d;throw(d=o)===null||d===void 0||d.unsubscribe(),h}}),i.apply(this,arguments)}return B6={waitForFragmentData:r},B6}var Q6,ZQ;function k3e(){if(ZQ)return Q6;ZQ=1;var e=R3e(),t=LF(),n=t.observeFragment,r=A3e(),i=r.observeQuery,a=T3e(),u=a.waitForFragmentData;function l(s){return s.ok===!0}function o(s){return s.ok===!1}return Q6={resolverDataInjector:e,isValueResult:l,isErrorResult:o,observeQuery:i,observeFragment:n,waitForFragmentData:u},Q6}var z6,HQ;function TJ(){if(HQ)return z6;HQ=1;var e=new Map,t=1,n=a(),r="	",i="\v";function a(){for(var o=new Set,s=0;s<10;++s)o.add(s.toString());return o}function u(o){return o[0]===r&&n.has(o[1])||o[0]===i?i+o:o}function l(o,s){if(s==null||o.length<s)return u(o);var c=e.get(o);return c!=null||(c=r+t++,e.set(o,c)),c}return z6={intern:l},z6}var q6,XQ;function I0(){if(XQ)return q6;XQ=1;var e=th(),t=TJ(),n=t.intern,r="client:";function i(s,c,d){var h=e.STRING_INTERN_LEVEL<=0?s:n(s,e.MAX_DATA_ID_LENGTH),m=h+":"+c;return d!=null&&(m+=":"+d),m.indexOf(r)!==0&&(m=r+m),m}function a(s){return s.indexOf(r)===0}var u=0;function l(){return"".concat(r,"local:").concat(u++)}function o(s,c,d){var h="".concat(r).concat(s,":").concat(c);return d!=null&&(h+=":"+d),h}return q6={generateClientID:i,generateClientObjectClientID:o,generateUniqueClientID:l,isClientID:a},q6}var V6,YQ;function BF(){if(YQ)return V6;YQ=1;var e={after:!0,before:!0,find:!0,first:!0,last:!0,surrounds:!0},t={CURSOR:"cursor",EDGES:"edges",END_CURSOR:"endCursor",HAS_NEXT_PAGE:"hasNextPage",HAS_PREV_PAGE:"hasPreviousPage",NODE:"node",PAGE_INFO_TYPE:"PageInfo",PAGE_INFO:"pageInfo",START_CURSOR:"startCursor"},n={inject:function(i){t=i},get:function(){return t},isConnectionCall:function(i){return e.hasOwnProperty(i.name)}};return V6=n,V6}var U6,GQ;function OC(){if(GQ)return U6;GQ=1;var e=I0(),t=e.generateClientID,n=_a(),r=n.getStableStorageKey,i=NF(),a=BF(),u=on();Qi();var l="connection",o="__connection_next_edge_index";function s(E,C){var T=E.get(C.dataID);if(T){var R=a.get(),$=R.EDGES,k=R.END_CURSOR,F=R.HAS_NEXT_PAGE,L=R.HAS_PREV_PAGE,j=R.PAGE_INFO,V=R.PAGE_INFO_TYPE,q=R.START_CURSOR,N=T.getLinkedRecord(C.fieldKey),U=N&&N.getLinkedRecord(j);if(!N){T.setValue(null,C.handleKey,void 0,T.getErrors(C.fieldKey));return}var W=t(T.getDataID(),C.handleKey),G=T.getLinkedRecord(C.handleKey),J=G??E.get(W),te=J&&J.getLinkedRecord(j);if(J){G==null&&T.setLinkedRecord(J,C.handleKey);var K=J,X=N.getLinkedRecords($);X&&(X=X.map(function(Ne){return _(E,K,Ne)}));var B=K.getLinkedRecords($),ne=K.getLinkedRecord(j);K.copyFieldsFrom(N),B&&K.setLinkedRecords(B,$),ne&&K.setLinkedRecord(ne,j);var oe=[],ie=C.args;if(B&&X)if(ie.after!=null){var de,be=(de=te)===null||de===void 0?void 0:de.getValue(k),ve=U==null?void 0:U.getValue(k),pe=te&&ie.after===be,_e=te&&be===ve;if(pe||_e){var se=new Set;S(B,oe,se),S(X,oe,se)}else return}else if(ie.before!=null)if(te&&ie.before===te.getValue(q)){var me=new Set;S(X,oe,me),S(B,oe,me)}else return;else oe=X;else X?oe=X:oe=B;if(oe!=null&&oe!==B&&K.setLinkedRecords(oe,$),te&&U){if(ie.after==null&&ie.before==null)te.copyFieldsFrom(U);else if(ie.before!=null||ie.after==null&&ie.last){te.setValue(!!U.getValue(L),L);var ge=U.getValue(q);typeof ge=="string"&&te.setValue(ge,q)}else if(ie.after!=null||ie.before==null&&ie.first){te.setValue(!!U.getValue(F),F);var we=U.getValue(k);typeof we=="string"&&te.setValue(we,k)}}}else{var H=E.create(W,N.getType());H.setValue(0,o),H.copyFieldsFrom(N);var M=N.getLinkedRecords($);M&&(M=M.map(function(Ne){return _(E,H,Ne)}),H.setLinkedRecords(M,$)),T.setLinkedRecord(H,C.handleKey),te=E.create(t(H.getDataID(),j),V),te.setValue(!1,F),te.setValue(!1,L),te.setValue(null,k),te.setValue(null,q),U&&te.copyFieldsFrom(U),H.setLinkedRecord(te,j)}}}function c(E,C,T){var R=i(l,C,null);return E.getLinkedRecord(R,T)}function d(E,C,T){var R=i(l,C,null),$=r(R,T);return t(E,$)}function h(E,C,T){var R=a.get(),$=R.CURSOR,k=R.EDGES,F=E.getLinkedRecords(k);if(!F){E.setLinkedRecords([C],k);return}var L;if(T==null)L=F.concat(C);else{L=[];for(var j=!1,V=0;V<F.length;V++){var q=F[V];if(L.push(q),q!=null){var N=q.getValue($);T===N&&(L.push(C),j=!0)}}j||L.push(C)}E.setLinkedRecords(L,k)}function m(E,C,T,R){var $=a.get(),k=$.NODE,F=t(C.getDataID(),T.getDataID()),L=E.get(F);return L||(L=E.create(F,R)),L.setLinkedRecord(T,k),L.getValue("cursor")==null&&L.setValue(null,"cursor"),L}function y(E,C,T){var R=a.get(),$=R.CURSOR,k=R.EDGES,F=E.getLinkedRecords(k);if(!F){E.setLinkedRecords([C],k);return}var L;if(T==null)L=[C].concat(F);else{L=[];for(var j=!1,V=0;V<F.length;V++){var q=F[V];if(q!=null){var N=q.getValue($);T===N&&(L.push(C),j=!0)}L.push(q)}j||L.unshift(C)}E.setLinkedRecords(L,k)}function v(E,C){var T=a.get(),R=T.EDGES,$=T.NODE,k=E.getLinkedRecords(R);if(k){for(var F,L=0;L<k.length;L++){var j=k[L],V=j&&j.getLinkedRecord($);V!=null&&V.getDataID()===C?F===void 0&&(F=k.slice(0,L)):F!==void 0&&F.push(j)}F!==void 0&&E.setLinkedRecords(F,R)}}function _(E,C,T){if(T==null)return T;var R=a.get(),$=R.EDGES,k=C.getValue(o);typeof k!="number"&&u(!1);var F=t(C.getDataID(),$,k),L=E.create(F,T.getType());return L.copyFieldsFrom(T),L.getValue("cursor")==null&&L.setValue(null,"cursor"),C.setValue(k+1,o),L}function S(E,C,T){for(var R=a.get(),$=R.NODE,k=0;k<E.length;k++){var F=E[k];if(F){var L=F.getLinkedRecord($),j=L&&L.getDataID();if(j){if(T.has(j))continue;T.add(j)}C.push(F)}}}return U6={buildConnectionEdge:_,createEdge:m,deleteNode:v,getConnection:c,getConnectionID:d,insertEdgeAfter:h,insertEdgeBefore:y,update:s},U6}var j6,KQ;function kJ(){if(KQ)return j6;KQ=1;var e=Cn().default,t=e(Du()),n=OC(),r=BF(),i=on(),a=Qi(),u={update:function(v,_){var S=v.get(_.dataID);if(S!=null){var E=S.getValue(_.fieldKey);typeof E=="string"?v.delete(E):Array.isArray(E)&&E.forEach(function(C){typeof C=="string"&&v.delete(C)})}}},l={update:function(v,_){var S=v.get(_.dataID);if(S!=null){var E=_.handleArgs.connections;E==null&&i(!1);var C=S.getValue(_.fieldKey),T=Array.isArray(C)?C:[C];T.forEach(function(R){if(typeof R=="string"){var $=(0,t.default)(E),k;try{for($.s();!(k=$.n()).done;){var F=k.value,L=v.get(F);L!=null&&n.deleteNode(L,R)}}catch(j){$.e(j)}finally{$.f()}}})}}},o={update:h(n.insertEdgeAfter)},s={update:h(n.insertEdgeBefore)},c={update:m(n.insertEdgeAfter)},d={update:m(n.insertEdgeBefore)};function h(y){return function(v,_){var S,E=v.get(_.dataID);if(E!=null){var C=_.handleArgs.connections;C==null&&i(!1);var T,R;try{T=E.getLinkedRecord(_.fieldKey)}catch{}if(!T)try{R=E.getLinkedRecords(_.fieldKey)}catch{}if(!(T==null&&R==null)){var $=r.get(),k=$.NODE,F=$.EDGES,L=(S=R)!==null&&S!==void 0?S:[T],j=(0,t.default)(L),V;try{var q=function(){var G=V.value;if(G==null)return"continue";var J=G.getLinkedRecord("node");if(!J)return"continue";var te=J.getDataID(),H=(0,t.default)(C),M;try{for(H.s();!(M=H.n()).done;){var K=M.value,X=v.get(K);if(X!=null){var B=(N=X.getLinkedRecords(F))===null||N===void 0?void 0:N.some(function(oe){var ie;return(oe==null||(ie=oe.getLinkedRecord(k))===null||ie===void 0?void 0:ie.getDataID())===te});if(!B){var ne=n.buildConnectionEdge(v,X,G);ne==null&&i(!1),y(X,ne)}}}}catch(oe){H.e(oe)}finally{H.f()}};for(j.s();!(V=j.n()).done;)var N,U=q()}catch(W){j.e(W)}finally{j.f()}}}}}function m(y){return function(v,_){var S,E=v.get(_.dataID);if(E!=null){var C=_.handleArgs,T=C.connections,R=C.edgeTypeName;T==null&&i(!1),R==null&&i(!1);var $,k;try{$=E.getLinkedRecord(_.fieldKey)}catch{}if(!$)try{k=E.getLinkedRecords(_.fieldKey)}catch{}if(!($==null&&k==null)){var F=r.get(),L=F.NODE,j=F.EDGES,V=(S=k)!==null&&S!==void 0?S:[$],q=(0,t.default)(V),N;try{var U=function(){var te=N.value;if(te==null)return"continue";var H=te.getDataID(),M=(0,t.default)(T),K;try{for(M.s();!(K=M.n()).done;){var X=K.value,B=v.get(X);if(B!=null){var ne=(W=B.getLinkedRecords(j))===null||W===void 0?void 0:W.some(function(ie){var de;return(ie==null||(de=ie.getLinkedRecord(L))===null||de===void 0?void 0:de.getDataID())===H});if(!ne){var oe=n.createEdge(v,B,te,R);oe==null&&i(!1),y(B,oe)}}}}catch(ie){M.e(ie)}finally{M.f()}};for(q.s();!(N=q.n()).done;)var W,G=U()}catch(J){q.e(J)}finally{q.f()}}}}}return j6={AppendEdgeHandler:o,DeleteRecordHandler:u,PrependEdgeHandler:s,AppendNodeHandler:c,PrependNodeHandler:d,DeleteEdgeHandler:l},j6}var Z6,WQ;function PJ(){if(WQ)return Z6;WQ=1;var e=OC(),t=kJ(),n=on();function r(i){switch(i){case"connection":return e;case"deleteRecord":return t.DeleteRecordHandler;case"deleteEdge":return t.DeleteEdgeHandler;case"appendEdge":return t.AppendEdgeHandler;case"prependEdge":return t.PrependEdgeHandler;case"appendNode":return t.AppendNodeHandler;case"prependNode":return t.PrependNodeHandler}n(!1)}return Z6=r,Z6}var H6,JQ;function QF(){if(JQ)return H6;JQ=1;function e(t){return!!(t&&t["@@RelayModernEnvironment"])}return H6=e,H6}var X6,ez;function xC(){if(ez)return X6;ez=1;var e=Cn().default,t=e(Du()),n=OC(),r=Qi(),i=Object.freeze({RANGE_ADD:"RANGE_ADD",RANGE_DELETE:"RANGE_DELETE",NODE_DELETE:"NODE_DELETE"}),a=Object.freeze({APPEND:"append",PREPEND:"prepend"});function u(h,m,y,v){var _=y?[y]:[],S=v?[v]:[];return h.forEach(function(E){switch(E.type){case"NODE_DELETE":var C=l(E,m);C&&(_.push(C),S.push(C));break;case"RANGE_ADD":var T=o(E,m);T&&(_.push(T),S.push(T));break;case"RANGE_DELETE":var R=s(E,m);R&&(_.push(R),S.push(R));break}}),{optimisticUpdater:function(C,T){_.forEach(function(R){R(C,T)})},updater:function(C,T){S.forEach(function(R){R(C,T)})}}}function l(h,m){var y=h.deletedIDFieldName,v=d(m);return v?function(_,S){var E=_.getRootField(v);if(E){var C=E.getValue(y),T=Array.isArray(C)?C:[C];T.forEach(function(R){R&&typeof R=="string"&&_.delete(R)})}}:null}function o(h,m){var y=h.parentID,v=h.connectionInfo,_=h.edgeName;if(!y)return null;var S=d(m);return!v||!S?null:function(E,C){var T=E.get(y);if(T){var R=E.getRootField(S);if(R){var $=R.getLinkedRecord(_),k=(0,t.default)(v),F;try{for(k.s();!(F=k.n()).done;){var L=F.value;if($){var j=n.getConnection(T,L.key,L.filters);if(j){var V=n.buildConnectionEdge(E,j,$);if(V)switch(L.rangeBehavior){case"append":n.insertEdgeAfter(j,V);break;case"prepend":n.insertEdgeBefore(j,V);break;default:break}}}}}catch(q){k.e(q)}finally{k.f()}}}}}function s(h,m){var y=h.parentID,v=h.connectionKeys,_=h.pathToConnection,S=h.deletedIDFieldName;if(!y)return null;var E=d(m);return E?function(C,T){if(T){var R=[],$=T[E];if($&&Array.isArray(S)){var k=(0,t.default)(S),F;try{for(k.s();!(F=k.n()).done;){var L=F.value;$&&typeof $=="object"&&($=$[L])}}catch(j){k.e(j)}finally{k.f()}Array.isArray($)?$.forEach(function(j){j&&j.id&&typeof j=="object"&&typeof j.id=="string"&&R.push(j.id)}):$&&$.id&&typeof $.id=="string"&&R.push($.id)}else $&&typeof S=="string"&&typeof $=="object"&&($=$[S],typeof $=="string"?R.push($):Array.isArray($)&&$.forEach(function(j){typeof j=="string"&&R.push(j)}));c(y,v,_,C,R)}}:null}function c(h,m,y,v,_){var S=v.get(h);if(S&&!(y.length<2)){for(var E=S,C=1;C<y.length-1;C++)E&&(E=E.getLinkedRecord(y[C]));if(!(!m||!E)){var T=(0,t.default)(m),R;try{var $=function(){var F=R.value,L=n.getConnection(E,F.key,F.filters);L&&_.forEach(function(j){n.deleteNode(L,j)})};for(T.s();!(R=T.n()).done;)$()}catch(k){T.e(k)}finally{T.f()}}}}function d(h){return h.fragment.selections&&h.fragment.selections.length>0&&h.fragment.selections[0].kind==="LinkedField"?h.fragment.selections[0].name:null}return X6={MutationTypes:i,RangeOperations:a,convert:u},X6}var Y6,tz;function P3e(){if(tz)return Y6;tz=1;var e=fp(),t=e.getRequest,n=QF(),r=dy(),i=r.createOperationDescriptor,a=xC(),u=on();function l(o,s){n(o)||u(!1);var c=t(s.mutation);if(c.params.operationKind!=="mutation")throw new Error("commitMutation: Expected mutation operation");var d=s.optimisticUpdater,h=s.configs,m=s.optimisticResponse,y=s.variables,v=i(c,y);if(h){var _=a.convert(h,c,d);d=_.optimisticUpdater}return o.applyMutation({operation:v,response:m,updater:d})}return Y6=l,Y6}var G6,nz;function M3e(){if(nz)return G6;nz=1;function e(t,n){t.commitUpdate(n)}return G6=e,G6}var K6,rz;function F3e(){if(rz)return K6;rz=1;var e=Cn().default;e(zi()),Qi();var t=function(){};return K6=t,K6}var W6,iz;function N3e(){if(iz)return W6;iz=1;var e=Cn().default,t=e(sy()),n=fp(),r=n.getRequest,i=I0(),a=i.generateUniqueClientID,u=QF(),l=dy(),o=l.createOperationDescriptor,s=xC();F3e();var c=on();Qi();function d(h,m){u(h)||c(!1);var y=r(m.mutation);if(y.params.operationKind!=="mutation")throw new Error("commitMutation: Expected mutation operation");if(y.kind!=="Request")throw new Error("commitMutation: Expected mutation to be of type request");var v=m.optimisticResponse,_=m.optimisticUpdater,S=m.updater,E=m.configs,C=m.cacheConfig,T=m.onError,R=m.onUnsubscribe,$=m.variables,k=m.uploadables,F=o(y,$,C,a());if(typeof v=="function"&&(v=v()),E){var L=s.convert(E,y,_,S);_=L.optimisticUpdater,S=L.updater}var j=[],V=h.executeMutation({operation:F,optimisticResponse:v,optimisticUpdater:_,updater:S,uploadables:k}).subscribe({next:function(N){var U;Array.isArray(N)?N.forEach(function(W){W.errors&&j.push.apply(j,(0,t.default)(W.errors))}):N.errors&&j.push.apply(j,(0,t.default)(N.errors)),(U=m.onNext)===null||U===void 0||U.call(m)},complete:function(){var N=m.onCompleted;if(N){var U=h.lookup(F.fragment);N(U.data,j.length!==0?j:null)}},error:T,unsubscribe:R});return{dispose:V.unsubscribe}}return W6=d,W6}var J6,az;function MJ(){if(az)return J6;az=1,Jf(),Qi();var e=typeof WeakMap=="function",t=e?new WeakMap:new Map;function n(r,i){if(i!=null){var a={};return Object.assign(a,r),Object.keys(i).forEach(function(u){var l=i[u].get,o=l();if(!t.has(l))t.set(l,o),a[u]=o;else{var s=t.get(l);a[u]=s}}),a}else return r}return n.tests_only_resetDebugCache=void 0,J6=n,J6}var eR,uz;function I3e(){if(uz)return eR;uz=1;var e=fy();function t(n){return function(i,a,u,l,o){var s=n(i,a,u,l,o);return s instanceof Error?e.create(function(c){return c.error(s)}):e.from(s)}}return eR={convertFetch:t},eR}var tR,lz;function L3e(){if(lz)return tR;lz=1;var e=MJ(),t=I3e(),n=t.convertFetch,r=on();function i(a,u){var l=n(a);function o(s,c,d,h,m){var y=e(c,s.providedVariables);if(s.operationKind==="subscription")return u||r(!1),h&&r(!1),u(s,y,d);var v=d.poll;return v!=null?(h&&r(!1),l(s,y,{force:!0}).poll(v)):l(s,y,d,h,m)}return{execute:o}}return tR={create:i},tR}var nR,oz;function B3e(){if(oz)return nR;oz=1;var e=Cn().default,t=e(zi()),n=Sb(),r=n.stableCopy,i=on(),a=(function(){function o(c){var d=c.size,h=c.ttl;d>0||i(!1),h>0||i(!1),this._responses=new Map,this._size=d,this._ttl=h}var s=o.prototype;return s.clear=function(){this._responses.clear()},s.get=function(d,h){var m=this,y=u(d,h);this._responses.forEach(function(_,S){l(_.fetchTime,m._ttl)||m._responses.delete(S)});var v=this._responses.get(y);return v==null?null:Array.isArray(v.payload)?v.payload.map(function(_){return(0,t.default)((0,t.default)({},_),{},{extensions:(0,t.default)((0,t.default)({},_.extensions),{},{cacheTimestamp:v.fetchTime})})}):(0,t.default)((0,t.default)({},v.payload),{},{extensions:(0,t.default)((0,t.default)({},v.payload.extensions),{},{cacheTimestamp:v.fetchTime})})},s.set=function(d,h,m){var y=Date.now(),v=u(d,h);if(this._responses.delete(v),this._responses.set(v,{fetchTime:y,payload:m}),this._responses.size>this._size){var _=this._responses.keys().next();_.done||this._responses.delete(_.value)}},o})();function u(o,s){return JSON.stringify(r({queryID:o,variables:s}))}function l(o,s){return o+s>=Date.now()}return nR=a,nR}var rR,sz;function Q3e(){if(sz)return rR;sz=1;var e=Cn().default,t=e(zi()),n=fy(),r=dy(),i=r.createOperationDescriptor,a=rS(),u=a.handlePotentialSnapshotErrors,l=bC(),o=fp(),s=o.getRequest,c=on();function d(m,y,v,_){var S,E=s(y);E.params.operationKind!=="query"&&c(!1);var C=(0,t.default)({force:!0},_==null?void 0:_.networkCacheConfig),T=i(E,v,C),R=(S=_==null?void 0:_.fetchPolicy)!==null&&S!==void 0?S:"network-only";function $(k){return u(m,k.fieldErrors),k.data}switch(R){case"network-only":return h(m,T).map($);case"store-or-network":return m.check(T).status==="available"?n.from(m.lookup(T.fragment)).map($):h(m,T).map($);default:throw new Error("fetchQuery: Invalid fetchPolicy "+R)}}function h(m,y){return l.fetchQuery(m,y).map(function(){return m.lookup(y.fragment)})}return rR=d,rR}var iR,cz;function z3e(){if(cz)return iR;cz=1;var e=dy(),t=e.createOperationDescriptor,n=fp(),r=n.getRequest;function i(a,u,l,o){var s=r(u);if(s.params.operationKind!=="query")throw new Error("fetchQuery: Expected query operation");var c=t(s,l,o);return a.execute({operation:c}).map(function(){return a.lookup(c.fragment).data}).toPromise()}return iR=i,iR}var aR,fz;function q3e(){if(fz)return aR;fz=1;var e=(function(){function n(){this._preloadableQueries=new Map,this._callbacks=new Map}var r=n.prototype;return r.set=function(a,u){this._preloadableQueries.set(a,u);var l=this._callbacks.get(a);l!=null&&l.forEach(function(o){try{o(u)}catch(s){setTimeout(function(){throw s},0)}})},r.get=function(a){return this._preloadableQueries.get(a)},r.onLoad=function(a,u){var l,o=(l=this._callbacks.get(a))!==null&&l!==void 0?l:new Set;o.add(u);var s=function(){o.delete(u)};return this._callbacks.set(a,o),{dispose:s}},r.clear=function(){this._preloadableQueries.clear()},n})(),t=new e;return aR=t,aR}var uR,dz;function FJ(){if(dz)return uR;dz=1;var e=bC(),t=e.getPromiseForActiveRequest;function n(r,i,a){var u,l,o=[],s=t(r,a);if(s!=null)o=[a];else{var c,d,h=r.getOperationTracker(),m=h.getPendingOperationsAffectingOwner(a);o=(c=m==null?void 0:m.pendingOperations)!==null&&c!==void 0?c:[],s=(d=m==null?void 0:m.promise)!==null&&d!==void 0?d:null}if(!s)return null;var y=(u=(l=o)===null||l===void 0?void 0:l.map(function(S){return S.node.params.name}).join(","))!==null&&u!==void 0?u:null;(y==null||y.length===0)&&(y="Unknown pending operation");var v=i.name,_=y===v?"Relay(".concat(y,")"):"Relay(".concat(y,":").concat(v,")");return s.displayName=_,r.__log({name:"pendingoperation.found",fragment:i,fragmentOwner:a,pendingOperations:o}),{promise:s,pendingOperations:o}}return uR=n,uR}var lR,hz;function NJ(){if(hz)return lR;hz=1;function e(t,n){return t===n&&(t===null||typeof t!="object")}return lR=e,lR}var oR,pz;function SC(){if(pz)return oR;pz=1;function e(n,r){return t(n,r,!0)}function t(n,r,i){if(n===r||typeof n!="object"||!n||n.constructor!==Object&&!Array.isArray(n)||typeof r!="object"||!r||r.constructor!==Object&&!Array.isArray(r))return r;var a=!1,u=Array.isArray(n)?n:null,l=Array.isArray(r)?r:null;if(u&&l){var o=i&&!Object.isFrozen(l);a=l.reduce(function(y,v,_){var S=u[_],E=t(S,v,o);return E!==l[_]&&o&&(l[_]=E),y&&E===u[_]},!0)&&u.length===l.length}else if(!u&&!l){var s=n,c=r,d=Object.keys(s),h=Object.keys(c),m=i&&!Object.isFrozen(c);a=h.reduce(function(y,v){var _=s[v],S=t(_,c[v],m);return S!==c[v]&&m&&(c[v]=S),y&&S===s[v]},!0)&&d.length===h.length}return a?n:r}return oR=e,oR}var sR,mz;function V3e(){if(mz)return sR;mz=1;var e=Cn().default,t=e(zi()),n=e(hc()),r=FJ(),i=rS(),a=i.handlePotentialSnapshotErrors,u=NJ(),l=SC(),o=th(),s=dy(),c=s.createRequestDescriptor,d=dp(),h=d.areEqualSelectors,m=d.createReaderSelector,y=d.getSelectorsFromObject,v=Jf(),_=on();Qi();var S=(function(){function R(k,F,L,j,V){var q=this;(0,n.default)(this,"_onChange",function(){q._stale=!0,typeof q._callback=="function"&&q._callback()}),this._callback=j,this._context=k,this._data={},this._fragments=F,this._props={},this._resolvers={},this._stale=!1,this._rootIsQueryRenderer=V,this.setProps(L)}var $=R.prototype;return $.dispose=function(){for(var F in this._resolvers)this._resolvers.hasOwnProperty(F)&&T(this._resolvers[F])},$.resolve=function(){if(this._stale){var F=this._data,L;for(var j in this._resolvers)if(this._resolvers.hasOwnProperty(j)){var V=this._resolvers[j],q=F[j];if(V){var N=V.resolve();(L||N!==q)&&(L=L||(0,t.default)({},F),L[j]=N)}else{var U=this._props[j],W=U!==void 0?U:null;(L||!u(W,q))&&(L=L||(0,t.default)({},F),L[j]=W)}}this._data=L||F,this._stale=!1}return this._data},$.setCallback=function(F,L){this._callback=L,o.ENABLE_CONTAINERS_SUBSCRIBE_ON_COMMIT===!0&&this.setProps(F)},$.setProps=function(F){this._props={};var L=y(this._fragments,F);for(var j in L)if(L.hasOwnProperty(j)){var V=L[j],q=this._resolvers[j];V==null?(q!=null&&q.dispose(),q=null):V.kind==="PluralReaderSelector"?q==null?q=new C(this._context.environment,this._rootIsQueryRenderer,V,this._callback!=null,this._onChange):(q instanceof C||_(!1),q.setSelector(V)):q==null?q=new E(this._context.environment,this._rootIsQueryRenderer,V,this._callback!=null,this._onChange):(q instanceof E||_(!1),q.setSelector(V)),this._props[j]=F[j],this._resolvers[j]=q}this._stale=!0},$.setVariables=function(F,L){for(var j in this._resolvers)if(this._resolvers.hasOwnProperty(j)){var V=this._resolvers[j];V&&V.setVariables(F,L)}this._stale=!0},R})(),E=(function(){function R(k,F,L,j,V){var q=this;(0,n.default)(this,"_onChange",function(U){q._data=U.data,q._isMissingData=U.isMissingData,q._fieldErrors=U.fieldErrors,q._callback()});var N=k.lookup(L);this._callback=V,this._data=N.data,this._isMissingData=N.isMissingData,this._fieldErrors=N.fieldErrors,this._environment=k,this._rootIsQueryRenderer=F,this._selector=L,o.ENABLE_CONTAINERS_SUBSCRIBE_ON_COMMIT===!0?j&&(this._subscription=k.subscribe(N,this._onChange)):this._subscription=k.subscribe(N,this._onChange)}var $=R.prototype;return $.dispose=function(){this._subscription&&(this._subscription.dispose(),this._subscription=null)},$.resolve=function(){if(this._isMissingData===!0){var F=r(this._environment,this._selector.node,this._selector.owner),L=F==null?void 0:F.promise;if(L!=null&&!this._rootIsQueryRenderer){var j,V=(j=F==null?void 0:F.pendingOperations)!==null&&j!==void 0?j:[];throw this._environment.__log({name:"suspense.fragment",data:this._data,fragment:this._selector.node,isRelayHooks:!1,isMissingData:this._isMissingData,isPromiseCached:!1,pendingOperations:V}),L}}return a(this._environment,this._fieldErrors),this._data},$.setSelector=function(F){if(!(this._subscription!=null&&h(F,this._selector))){this.dispose();var L=this._environment.lookup(F);this._data=l(this._data,L.data),this._isMissingData=L.isMissingData,this._fieldErrors=L.fieldErrors,this._selector=F,this._subscription=this._environment.subscribe(L,this._onChange)}},$.setVariables=function(F,L){if(!v(F,this._selector.variables)){var j=c(L,F),V=m(this._selector.node,this._selector.dataID,F,j);this.setSelector(V)}},R})(),C=(function(){function R(k,F,L,j,V){var q=this;(0,n.default)(this,"_onChange",function(N){q._stale=!0,q._callback()}),this._callback=V,this._data=[],this._environment=k,this._resolvers=[],this._stale=!0,this._rootIsQueryRenderer=F,this._subscribeOnConstruction=j,this.setSelector(L)}var $=R.prototype;return $.dispose=function(){this._resolvers.forEach(T)},$.resolve=function(){if(this._stale){for(var F=this._data,L,j=0;j<this._resolvers.length;j++){var V=F[j],q=this._resolvers[j].resolve();(L||q!==V)&&(L=L||F.slice(0,j),L.push(q))}!L&&this._resolvers.length!==F.length&&(L=F.slice(0,this._resolvers.length)),this._data=L||F,this._stale=!1}return this._data},$.setSelector=function(F){for(var L=F.selectors;this._resolvers.length>L.length;){var j=this._resolvers.pop();j.dispose()}for(var V=0;V<L.length;V++)V<this._resolvers.length?this._resolvers[V].setSelector(L[V]):this._resolvers[V]=new E(this._environment,this._rootIsQueryRenderer,L[V],this._subscribeOnConstruction,this._onChange);this._stale=!0},$.setVariables=function(F,L){this._resolvers.forEach(function(j){return j.setVariables(F,L)}),this._stale=!0},R})();function T(R){R&&R.dispose()}return sR=S,sR}var cR,gz;function U3e(){if(gz)return cR;gz=1;var e=V3e();Qi();function t(n,r,i,a,u,l){return new e(n,i,a,l,u)}return cR=t,cR}var fR,vz;function j3e(){if(vz)return fR;vz=1;var e=on(),t,n;function r(i){return t||(t=i.createContext(null),n=i),i!==n&&e(!1),t}return fR=r,fR}var dR,yz;function Z3e(){if(yz)return dR;yz=1;var e=on(),t,n;function r(i){return t||(t=i.createContext(null),n=i),i!==n&&e(!1),t}return dR=r,dR}var hR,bz;function _C(){if(bz)return hR;bz=1;var e=Object.freeze({__LIVE_RESOLVER_SUSPENSE_SENTINEL:!0});function t(){return e}function n(r){return r===e}return hR={isSuspenseSentinel:n,suspenseSentinel:t},hR}var pR={exports:{}},Oz;function j3(){return Oz||(Oz=1,(function(e){function t(n,r){if(n==null)return{};var i={};for(var a in n)if({}.hasOwnProperty.call(n,a)){if(r.indexOf(a)!==-1)continue;i[a]=n[a]}return i}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports})(pR)),pR.exports}var mR,xz;function df(){if(xz)return mR;xz=1;var e=Cn().default,t=e(hc()),n=e(j3()),r=e(_J()),i=e(zi()),a=iS(),u=I0(),l=u.generateClientObjectClientID;u.isClientID;var o=_C(),s=o.isSuspenseSentinel,c=_a(),d=c.ACTOR_IDENTIFIER_KEY,h=c.ERRORS_KEY,m=c.ID_KEY,y=c.INVALIDATED_AT_KEY,v=c.REF_KEY,_=c.REFS_KEY,S=c.RELAY_RESOLVER_VALUE_KEY;c.ROOT_ID;var E=c.TYPENAME_KEY,C=Jf(),T=on();Qi();function R(se){return(0,i.default)({},se)}function $(se,me){for(var ge in se)se.hasOwnProperty(ge)&&ge!==m&&ge!==E&&(me[ge]=se[ge])}function k(se,me){var ge={};return ge[m]=se,ge[E]=me,ge}function F(se){return se}function L(se){return se[m]}function j(se){return h in se?Object.keys(se).filter(function(me){return me!==h}):Object.keys(se)}function V(se){return se[E]}function q(se,me){var ge;return(ge=se[h])===null||ge===void 0?void 0:ge[me]}function N(se,me){var ge=se[me];return ge&&typeof ge=="object"&&(!ge.hasOwnProperty(v)&&!ge.hasOwnProperty(_)||T(!1)),ge}function U(se,me){return me in se}function W(se,me){var ge=se[me];if(ge==null)return ge;var we=ge;return typeof we=="object"&&we&&typeof we[v]=="string"||T(!1),we[v]}function G(se,me){var ge=se[me];if(ge==null)return!1;var we=ge;return typeof we=="object"&&we&&typeof we[v]=="string"}function J(se,me){var ge=se[me];return ge==null?ge:(typeof ge=="object"&&Array.isArray(ge[_])||T(!1),ge[_])}function te(se,me){var ge=se[me];return ge==null?!1:typeof ge=="object"&&Array.isArray(ge[_])&&ge[_].every(function(we){return typeof we=="string"})}function H(se){if(se==null)return null;var me=se[y];return typeof me!="number"?null:me}function M(se,me){var ge,we=se[h],Ne=me[h],Re=null;if(we==null&&Ne==null){var et;for(var tt in me)(Re||!C(se[tt],me[tt]))&&(Re=Re!==null?Re:(0,i.default)({},se),Re[tt]=me[tt]);return(et=Re)!==null&&et!==void 0?et:se}for(var Oe in me)if(Oe!==h){var $e=me[Oe],Ae=Ne==null?void 0:Ne[Oe];if(Re==null){var Ue=se[Oe],Ze=we==null?void 0:we[Oe];if(C(Ue,$e)&&C(Ze,Ae))continue;Re=(0,i.default)({},se),we!=null&&(Re[h]=(0,i.default)({},we))}ne(Re,Oe,$e),B(Re,Oe,Ae)}return(ge=Re)!==null&&ge!==void 0?ge:se}function K(se,me){if(h in se||h in me){var ge=se[h],we=(0,n.default)(se,[h].map(r.default)),Ne=me[h],Re=(0,n.default)(me,[h].map(r.default)),et=(0,i.default)((0,i.default)({},we),Re);if(ge==null&&Ne==null)return et;var tt={};for(var Oe in ge)Re.hasOwnProperty(Oe)||(tt[Oe]=ge[Oe]);for(var $e in Ne)tt[$e]=Ne[$e];for(var Ae in tt){et[h]=tt;break}return et}else return(0,i.default)((0,i.default)({},se),me)}function X(se){a(se)}function B(se,me,ge){var we=se[h];if(ge!=null&&ge.length>0)we==null?se[h]=(0,t.default)({},me,ge):we[me]=ge;else if(we!=null&&delete we[me]){for(var Ne in we)if(we.hasOwnProperty(Ne))return;delete se[h]}}function ne(se,me,ge){se[me]=ge}function oe(se,me,ge){var we={};we[v]=ge,se[me]=we}function ie(se,me,ge){var we={};we[_]=ge,se[me]=we}function de(se,me,ge,we){var Ne={};Ne[v]=we,Ne[d]=ge,se[me]=Ne}function be(se,me){var ge=se[me];return ge==null?ge:(typeof ge=="object"&&typeof ge[v]=="string"&&ge[d]!=null||T(!1),[ge[d],ge[v]])}function ve(se,me){var ge=N(se,S);return ge==null||s(ge)?null:(typeof ge=="object"&&(ge=ge.id),typeof ge!="string"&&T(!1),l(me,ge))}function pe(se,me){var ge=N(se,S);return ge==null||s(ge)?null:(Array.isArray(ge)||T(!1),ge.map(function(we){return we==null?null:(typeof we=="object"&&(we=we.id),typeof we!="string"&&T(!1),l(me,we))}))}function _e(se){return se}return mR={clone:R,copyFields:$,create:k,freeze:X,fromObject:F,getDataID:L,getErrors:q,getFields:j,getInvalidationEpoch:H,getLinkedRecordID:W,getLinkedRecordIDs:J,getType:V,getValue:N,hasValue:U,hasLinkedRecordID:G,hasLinkedRecordIDs:te,merge:K,setErrors:B,setValue:ne,setLinkedRecordID:oe,setLinkedRecordIDs:ie,update:M,getActorLinkedRecordID:be,setActorLinkedRecordID:de,getResolverLinkedRecordID:ve,getResolverLinkedRecordIDs:pe,toJSON:_e},mR}var gR,Sz;function EC(){if(Sz)return gR;Sz=1;var e={EXISTENT:"EXISTENT",NONEXISTENT:"NONEXISTENT",UNKNOWN:"UNKNOWN"};return gR=e,gR}var vR,_z;function _b(){if(_z)return vR;_z=1;var e=Cn().default,t=e(Du()),n=df(),r=EC(),i=r.EXISTENT,a=r.NONEXISTENT,u=r.UNKNOWN,l=(function(){function o(c){var d=this;this._records=new Map,c!=null&&Object.keys(c).forEach(function(h){var m=c[h],y=n.fromObject(m);d._records.set(h,y)})}o.create=function(d){return new o(d)};var s=o.prototype;return s.clear=function(){this._records=new Map},s.delete=function(d){this._records.set(d,null)},s.get=function(d){return this._records.get(d)},s.getRecordIDs=function(){return Array.from(this._records.keys())},s.getStatus=function(d){return this._records.has(d)?this._records.get(d)==null?a:i:u},s.has=function(d){return this._records.has(d)},s.remove=function(d){this._records.delete(d)},s.set=function(d,h){this._records.set(d,h)},s.size=function(){return this._records.size},s.toJSON=function(){var d={},h=(0,t.default)(this._records),m;try{for(h.s();!(m=h.n()).done;){var y=m.value,v=y[0],_=y[1];d[v]=n.toJSON(_)}}catch(S){h.e(S)}finally{h.f()}return d},o})();return vR=l,vR}var yR,Ez;function zF(){if(Ez)return yR;Ez=1;var e=on(),t="INTERNAL_ACTOR_IDENTIFIER_DO_NOT_USE";function n(r){r!==t&&e(!1)}return yR={assertInternalActorIdentifier:n,getActorIdentifier:function(i){return i},getDefaultActorIdentifier:function(){throw new Error("Not Implemented")},INTERNAL_ACTOR_IDENTIFIER_DO_NOT_USE:t},yR}var bR,Dz;function H3e(){if(Dz)return bR;Dz=1;var e="actor_key",t=zF(),n=t.getActorIdentifier;function r(i){if(i!=null&&typeof i=="object"&&typeof i[e]=="string")return n(i[e])}return bR={ACTOR_IDENTIFIER_FIELD_NAME:e,getActorIdentifierFromPayload:r},bR}var OR,$z;function X3e(){if($z)return OR;$z=1;var e=Cn().default,t=e(zi()),n=e(j3()),r=e(Du()),i=e(sy()),a=["path","locations"],u=Symbol("$SELF");function l(d){if(d==null)return null;var h=new Map,m=(0,r.default)(d),y;try{for(m.s();!(y=m.n()).done;){var v=y.value,_=v.path,S=v.locations,E=(0,n.default)(v,a);if(_!=null){var C=_.length;if(C!==0){for(var T=C-1,R=h,$=0;$<T;$++){var k=_[$],F=R.get(k);if(F instanceof Map){R=F;continue}var L=new Map;Array.isArray(F)&&L.set(u,F),R.set(k,L),R=L}var j=_[T],V=R.get(j);V instanceof Map&&(R=V,V=R.get(j),j=u),Array.isArray(V)?V.push(E):R.set(j,[E])}}}}catch(q){m.e(q)}finally{m.f()}return h}function o(d,h){var m=d.get(h);if(m==null)return null;if(Array.isArray(m))return m;var y=[];return s(m,y),y}function s(d,h){var m=(0,r.default)(d),y;try{for(m.s();!(y=m.n()).done;){var v=y.value,_=v[0],S=v[1],E=h.length;if(Array.isArray(S)?h.push.apply(h,(0,i.default)(S)):s(S,h),_!==u)for(var C=h.length,T=E;T<C;T++){var R=h[T];R.path==null?h[T]=(0,t.default)((0,t.default)({},R),{},{path:[_]}):R.path.unshift(_)}}}catch($){m.e($)}finally{m.f()}}function c(d,h){var m=d.get(h);return m instanceof Map?m:null}return OR={SELF:u,buildErrorTrie:l,getNestedErrorTrieByKey:c,getErrorsByKey:o},OR}var xR,Cz;function DC(){if(Cz)return xR;Cz=1;var e="client:__type:",t="__TypeSchema";function n(i){return e+i}function r(i){return i.indexOf(e)===0}return xR={generateTypeID:n,isTypeID:r,TYPE_SCHEMA_TYPE:t},xR}var SR,wz;function IJ(){if(wz)return SR;wz=1;var e=Cn().default,t=e(Du()),n=e(sy()),r=H3e();r.ACTOR_IDENTIFIER_FIELD_NAME;var i=r.getActorIdentifierFromPayload,a=th(),u=I0(),l=u.generateClientID,o=u.isClientID,s=cy(),c=s.getLocalVariables,d=X3e(),h=d.buildErrorTrie,m=d.getErrorsByKey,y=d.getNestedErrorTrieByKey,v=df(),_=dp(),S=_.createNormalizationSelector,E=_a(),C=E.ROOT_ID,T=E.TYPENAME_KEY,R=E.getArgumentValues,$=E.getHandleStorageKey,k=E.getModuleComponentKey,F=E.getModuleOperationKey,L=E.getStorageKey,j=DC(),V=j.TYPE_SCHEMA_TYPE,q=j.generateTypeID;Jf();var N=on();Qi();function U(G,J,te,H,M,K){var X=J.dataID,B=J.node,ne=J.variables,oe=new W(G,ne,H,K??!1);return oe.normalizeResponse(B,X,te,M)}var W=(function(){function G(te,H,M,K){this._actorIdentifier=M.actorIdentifier,this._getDataId=M.getDataID,this._handleFieldPayloads=[],this._treatMissingFieldsAsNull=M.treatMissingFieldsAsNull,this._incrementalPlaceholders=[],this._isClientExtension=!1,this._isUnmatchedAbstractType=!1,this._useExecTimeResolvers=K,this._followupPayloads=[],this._path=M.path?(0,n.default)(M.path):[],this._recordSource=te,this._variables=H,this._shouldProcessClientComponents=M.shouldProcessClientComponents,this._log=M.log}var J=G.prototype;return J.normalizeResponse=function(H,M,K,X){var B=this._recordSource.get(M);return B||N(!1),this._assignClientAbstractTypes(H),this._errorTrie=h(X),this._traverseSelections(H,B,K),{errors:X,fieldPayloads:this._handleFieldPayloads,incrementalPlaceholders:this._incrementalPlaceholders,followupPayloads:this._followupPayloads,source:this._recordSource,isFinal:!1}},J._assignClientAbstractTypes=function(H){var M=H.clientAbstractTypes;if(M!=null)for(var K=0,X=Object.keys(M);K<X.length;K++){var B=X[K],ne=(0,t.default)(M[B]),oe;try{for(ne.s();!(oe=ne.n()).done;){var ie=oe.value,de=q(ie),be=this._recordSource.get(de);be==null&&(be=v.create(de,V),this._recordSource.set(de,be)),v.setValue(be,B,!0)}}catch(ve){ne.e(ve)}finally{ne.f()}}},J._getVariableValue=function(H){return this._variables.hasOwnProperty(H)||N(!1),this._variables[H]},J._getRecordType=function(H){var M=H[T];return M==null&&N(!1),M},J._traverseSelections=function(H,M,K){for(var X=0;X<H.selections.length;X++){var B=H.selections[X];switch(B.kind){case"ScalarField":case"LinkedField":this._normalizeField(B,M,K);break;case"Condition":var ne=!!this._getVariableValue(B.condition);ne===B.passingValue&&this._traverseSelections(B,M,K);break;case"FragmentSpread":{var oe=this._variables;this._variables=c(this._variables,B.fragment.argumentDefinitions,B.args),this._traverseSelections(B.fragment,M,K),this._variables=oe;break}case"InlineFragment":{var ie=B.abstractKey;if(ie==null){var de=v.getType(M);de===B.type&&this._traverseSelections(B,M,K)}else{var be=Object.prototype.hasOwnProperty.call(K,ie),ve=v.getType(M),pe=q(ve),_e=this._recordSource.get(pe);_e==null&&(_e=v.create(pe,V),this._recordSource.set(pe,_e)),v.setValue(_e,ie,be),be&&this._traverseSelections(B,M,K)}break}case"TypeDiscriminator":{var se=B.abstractKey,me=Object.prototype.hasOwnProperty.call(K,se),ge=v.getType(M),we=q(ge),Ne=this._recordSource.get(we);Ne==null&&(Ne=v.create(we,V),this._recordSource.set(we,Ne)),v.setValue(Ne,se,me);break}case"LinkedHandle":case"ScalarHandle":var Re=B.args?R(B.args,this._variables):{},et=L(B,this._variables),tt=$(B,this._variables);this._handleFieldPayloads.push({args:Re,dataID:v.getDataID(M),fieldKey:et,handle:B.handle,handleKey:tt,handleArgs:B.handleArgs?R(B.handleArgs,this._variables):{}});break;case"ModuleImport":this._normalizeModuleImport(B,M,K);break;case"Defer":this._normalizeDefer(B,M,K);break;case"Stream":this._normalizeStream(B,M,K);break;case"ClientExtension":var Oe=this._isClientExtension;this._isClientExtension=!0,this._traverseSelections(B,M,K),this._isClientExtension=Oe;break;case"ClientComponent":if(this._shouldProcessClientComponents===!1)break;this._traverseSelections(B.fragment,M,K);break;case"ActorChange":this._normalizeActorChange(B,M,K);break;case"RelayResolver":case"RelayLiveResolver":this._useExecTimeResolvers||this._normalizeResolver(B,M,K);break;case"ClientEdgeToClientObject":this._useExecTimeResolvers||this._normalizeResolver(B.backingField,M,K);break;default:N(!1)}}},J._normalizeResolver=function(H,M,K){H.fragment!=null&&this._traverseSelections(H.fragment,M,K)},J._normalizeDefer=function(H,M,K){var X=H.if===null||this._getVariableValue(H.if);X===!1?this._traverseSelections(H,M,K):this._incrementalPlaceholders.push({kind:"defer",data:K,label:H.label,path:(0,n.default)(this._path),selector:S(H,v.getDataID(M),this._variables),typeName:v.getType(M),actorIdentifier:this._actorIdentifier})},J._normalizeStream=function(H,M,K){this._traverseSelections(H,M,K);var X=H.if===null||this._getVariableValue(H.if);X===!0&&this._incrementalPlaceholders.push({kind:"stream",label:H.label,path:(0,n.default)(this._path),parentID:v.getDataID(M),node:H,variables:this._variables,actorIdentifier:this._actorIdentifier})},J._normalizeModuleImport=function(H,M,K){typeof K=="object"&&K||N(!1);var X=v.getType(M),B=k(H.documentName),ne=H.componentModuleProvider||K[B];v.setValue(M,B,ne??null);var oe=F(H.documentName),ie=H.operationModuleProvider||K[oe];v.setValue(M,oe,ie??null),ie!=null&&this._followupPayloads.push({kind:"ModuleImportPayload",args:H.args,data:K,dataID:v.getDataID(M),operationReference:ie,path:(0,n.default)(this._path),typeName:X,variables:this._variables,actorIdentifier:this._actorIdentifier})},J._normalizeField=function(H,M,K){typeof K=="object"&&K||N(!1);var X=H.alias||H.name,B=L(H,this._variables),ne=K[X],oe=a.ENABLE_NONCOMPLIANT_ERROR_HANDLING_ON_LISTS&&Array.isArray(ne)&&ne.length===0;if(ne==null||oe){if(ne===void 0){var ie=this._isClientExtension||this._isUnmatchedAbstractType;if(ie)return;if(!this._treatMissingFieldsAsNull)return}H.kind==="ScalarField"&&this._validateConflictingFieldsWithIdenticalId(M,B,null),oe?H.kind==="LinkedField"?v.setLinkedRecordIDs(M,B,[]):v.setValue(M,B,[]):v.setValue(M,B,null);var de=this._errorTrie;if(de!=null){var be=m(de,X);be!=null&&v.setErrors(M,B,be)}return}if(H.kind==="ScalarField")this._validateConflictingFieldsWithIdenticalId(M,B,ne),v.setValue(M,B,ne);else if(H.kind==="LinkedField"){this._path.push(X);var ve=this._errorTrie;this._errorTrie=ve==null?null:y(ve,X),H.plural?this._normalizePluralLink(H,M,B,ne):this._normalizeLink(H,M,B,ne),this._errorTrie=ve,this._path.pop()}else N(!1)},J._normalizeActorChange=function(H,M,K){var X,B=H.linkedField;typeof K=="object"&&K||N(!1);var ne=B.alias||B.name,oe=L(B,this._variables),ie=K[ne];if(ie==null){if(ie===void 0){var de=this._isClientExtension||this._isUnmatchedAbstractType;if(de)return;if(!this._treatMissingFieldsAsNull)return}v.setValue(M,oe,null);return}var be=i(ie);if(be==null){v.setValue(M,oe,null);return}var ve=(X=B.concreteType)!==null&&X!==void 0?X:this._getRecordType(ie),pe=this._getDataId(ie,ve)||v.getLinkedRecordID(M,oe)||l(v.getDataID(M),oe);typeof pe!="string"&&N(!1),v.setActorLinkedRecordID(M,oe,be,pe),this._followupPayloads.push({kind:"ActorPayload",data:ie,dataID:pe,path:[].concat((0,n.default)(this._path),[ne]),typeName:ve,variables:this._variables,node:B,actorIdentifier:be})},J._normalizeLink=function(H,M,K,X){var B;typeof X=="object"&&X||N(!1);var ne=this._getDataId(X,(B=H.concreteType)!==null&&B!==void 0?B:this._getRecordType(X))||v.getLinkedRecordID(M,K)||l(v.getDataID(M),K);typeof ne!="string"&&N(!1),this._validateConflictingLinkedFieldsWithIdenticalId(v.getLinkedRecordID(M,K),ne,K),v.setLinkedRecordID(M,K,ne);var oe=this._recordSource.get(ne);if(oe)this._validateRecordType(oe,H,X);else{var ie=H.concreteType||this._getRecordType(X);oe=v.create(ne,ie),this._recordSource.set(ne,oe)}this._traverseSelections(H,oe,X)},J._normalizePluralLink=function(H,M,K,X){var B=this;Array.isArray(X)||N(!1);var ne=v.getLinkedRecordIDs(M,K),oe=[];X.forEach(function(ie,de){var be;if(ie==null){oe.push(ie);return}B._path.push(String(de));var ve=B._errorTrie;B._errorTrie=ve==null?null:y(ve,de),typeof ie!="object"&&N(!1);var pe=B._getDataId(ie,(be=H.concreteType)!==null&&be!==void 0?be:B._getRecordType(ie))||ne&&ne[de]||l(v.getDataID(M),K,de);typeof pe!="string"&&N(!1),oe.push(pe);var _e=B._recordSource.get(pe);if(_e)B._validateRecordType(_e,H,ie);else{var se=H.concreteType||B._getRecordType(ie);_e=v.create(pe,se),B._recordSource.set(pe,_e)}ne&&B._validateConflictingLinkedFieldsWithIdenticalId(ne[de],pe,K),B._traverseSelections(H,_e,ie),B._errorTrie=ve,B._path.pop()}),v.setLinkedRecordIDs(M,K,oe)},J._validateRecordType=function(H,M,K){if(a.ENABLE_STORE_ID_COLLISION_LOGGING){var X,B=(X=M.concreteType)!==null&&X!==void 0?X:this._getRecordType(K),ne=v.getDataID(H),oe=o(ne)&&ne!==C||v.getType(H)===B;if(!oe){var ie={name:"idCollision.typename",previous_typename:v.getType(H),new_typename:B};this._log!=null&&this._log(ie)}}},J._validateConflictingFieldsWithIdenticalId=function(H,M,K){},J._validateConflictingLinkedFieldsWithIdenticalId=function(H,M,K){},G})();return SR={normalize:U},SR}var _R,Rz;function LJ(){if(Rz)return _R;Rz=1;var e=Cn().default,t=e(zi()),n=e(df()),r=e(_b()),i=e(IJ());function a(u,l,o,s,c){var d,h=u.data,m=u.errors,y=r.default.create(),v=n.default.create(l.dataID,o);y.set(l.dataID,v);var _=i.default.normalize(y,l,h,s,m,c);return(0,t.default)((0,t.default)({},_),{},{isFinal:((d=u.extensions)===null||d===void 0?void 0:d.is_final)===!0})}return _R=a,_R}var ER,Az;function Y3e(){if(Az)return ER;Az=1;var e=fp(),t=e.getInlineDataFragment,n=_a(),r=n.FRAGMENTS_KEY,i=on();function a(u,l){var o,s=t(u);if(l==null)return l;typeof l!="object"&&i(!1);var c=(o=l[r])===null||o===void 0?void 0:o[s.name];return c==null&&i(!1),c}return ER=a,ER}var DR,Tz;function BJ(){if(Tz)return DR;Tz=1;var e=1e5;function t(){return e++}return DR=t,DR}var $R,kz;function G3e(){if(kz)return $R;kz=1;var e=BJ();function t(n,r){return{execute:function(a,u,l,o,s,c,d,h){var m=e(),y={start:function(S){n.__log({name:"network.start",networkRequestId:m,params:a,variables:u,cacheConfig:l})},next:function(S){n.__log({name:"network.next",networkRequestId:m,response:S})},error:function(S){n.__log({name:"network.error",networkRequestId:m,error:S})},complete:function(){n.__log({name:"network.complete",networkRequestId:m})},unsubscribe:function(){n.__log({name:"network.unsubscribe",networkRequestId:m})}},v=function(S){n.__log({name:"network.info",networkRequestId:m,info:S})};return r.execute(a,u,l,o,v,c,d,h).do(y)}}}return $R=t,$R}var CR,Pz;function QJ(){if(Pz)return CR;Pz=1;var e=Cn().default,t=e(Du()),n=on(),r=(function(){function i(){this._ownersToPendingOperations=new Map,this._pendingOperationsToOwners=new Map,this._ownersToPendingPromise=new Map}var a=i.prototype;return a.update=function(l,o){if(o.size!==0){var s=l.identifier,c=new Set,d=(0,t.default)(o),h;try{for(d.s();!(h=d.n()).done;){var m=h.value,y=m.identifier,v=this._ownersToPendingOperations.get(y);v!=null?v.has(s)||(v.set(s,l),c.add(y)):(this._ownersToPendingOperations.set(y,new Map([[s,l]])),c.add(y))}}catch(T){d.e(T)}finally{d.f()}if(c.size!==0){var _=this._pendingOperationsToOwners.get(s)||new Set,S=(0,t.default)(c),E;try{for(S.s();!(E=S.n()).done;){var C=E.value;this._resolveOwnerResolvers(C),_.add(C)}}catch(T){S.e(T)}finally{S.f()}this._pendingOperationsToOwners.set(s,_)}}},a.complete=function(l){var o=l.identifier,s=this._pendingOperationsToOwners.get(o);if(s!=null){var c=new Set,d=new Set,h=(0,t.default)(s),m;try{for(h.s();!(m=h.n()).done;){var y=m.value,v=this._ownersToPendingOperations.get(y);v&&(v.delete(o),v.size>0?d.add(y):c.add(y))}}catch($){h.e($)}finally{h.f()}var _=(0,t.default)(c),S;try{for(_.s();!(S=_.n()).done;){var E=S.value;this._resolveOwnerResolvers(E),this._ownersToPendingOperations.delete(E)}}catch($){_.e($)}finally{_.f()}var C=(0,t.default)(d),T;try{for(C.s();!(T=C.n()).done;){var R=T.value;this._resolveOwnerResolvers(R)}}catch($){C.e($)}finally{C.f()}this._pendingOperationsToOwners.delete(o)}},a._resolveOwnerResolvers=function(l){var o=this._ownersToPendingPromise.get(l);o!=null&&o.resolve(),this._ownersToPendingPromise.delete(l)},a.getPendingOperationsAffectingOwner=function(l){var o=l.identifier,s=this._ownersToPendingOperations.get(o);if(s==null||s.size===0)return null;var c=this._ownersToPendingPromise.get(o);if(c!=null)return{promise:c.promise,pendingOperations:c.pendingOperations};var d,h=new Promise(function(y){d=y});d==null&&n(!1);var m=Array.from(s.values());return this._ownersToPendingPromise.set(o,{promise:h,resolve:d,pendingOperations:m}),{promise:h,pendingOperations:m}},i})();return CR=r,CR}var wR,Mz;function K3e(){if(Mz)return wR;Mz=1;function e(t){var n=typeof Hd<"u"?Hd:typeof window<"u"?window:void 0,r=n&&n.__RELAY_DEVTOOLS_HOOK__;r&&r.registerEnvironment(t)}return wR=e,wR}var RR,Fz;function qF(){if(Fz)return RR;Fz=1;var e=I0(),t=e.generateClientID,n=_a(),r=n.ROOT_ID,i=t(r,"viewer"),a="Viewer";return RR={VIEWER_ID:i,VIEWER_TYPE:a},RR}var AR,Nz;function zJ(){if(Nz)return AR;Nz=1;var e=qF(),t=e.VIEWER_ID,n=e.VIEWER_TYPE;function r(i,a){return a===n&&i.id==null?t:i.id}return AR=r,AR}var TR,Iz;function W3e(){if(Iz)return TR;Iz=1;var e=function(n){};return TR=e,TR}var kR,Lz;function VF(){if(Lz)return kR;Lz=1;var e=oy(),t=e.REQUEST,n=e.SPLIT_OPERATION;function r(i){switch(i.kind){case t:return i.operation;case n:default:return i}}return kR=r,kR}var PR,Bz;function qJ(){if(Bz)return PR;Bz=1;function e(t,n,r){for(var i=arguments.length,a=new Array(i>3?i-3:0),u=3;u<i;u++)a[u-3]=arguments[u];var l=0,o=r.replace(/%s/g,function(){return String(a[l++])}),s=new Error(o),c=Object.assign(s,{name:n,messageFormat:r,messageParams:a,type:t,taalOpcodes:[2,2]});if(c.stack===void 0)try{throw c}catch{}return c}return PR={create:function(n,r){for(var i=arguments.length,a=new Array(i>2?i-2:0),u=2;u<i;u++)a[u-2]=arguments[u];return e.apply(void 0,["error",n,r].concat(a))},createWarning:function(n,r){for(var i=arguments.length,a=new Array(i>2?i-2:0),u=2;u<i;u++)a[u-2]=arguments[u];return e.apply(void 0,["warn",n,r].concat(a))}},PR}var MR,Qz;function J3e(){if(Qz)return MR;Qz=1;var e,t,n=typeof window<"u"&&typeof((e=window)===null||e===void 0||(t=e.performance)===null||t===void 0?void 0:t.now)=="function";function r(){return n?window.performance.now():Date.now()}function i(a){var u=r(),l=a();return[u,r()-u,l]}return MR=i,MR}var FR,zz;function e4e(){if(zz)return FR;zz=1;var e=Cn().default,t=e(Du()),n=e(sy()),r=fy(),i=BJ(),a=VF(),u=qJ(),l=th(),o=Sb(),s=o.stableCopy,c=J3e(),d=I0(),h=d.generateClientID,m=d.generateUniqueClientID,y=cy(),v=y.getLocalVariables,_=df(),S=dp(),E=S.createNormalizationSelector,C=S.createReaderSelector,T=_b(),R=_a(),$=R.ROOT_TYPE,k=R.TYPENAME_KEY,F=R.getStorageKey,L=on(),j=Qi();function V(G){return new q(G)}var q=(function(){function G(te){var H=this,M,K,X,B=te.actorIdentifier,ne=te.getDataID,oe=te.getPublishQueue,ie=te.getStore,de=te.isClientPayload,be=te.operation,ve=te.operationExecutions,pe=te.operationLoader,_e=te.operationTracker,se=te.optimisticConfig,me=te.scheduler,ge=te.shouldProcessClientComponents,we=te.sink,Ne=te.source,Re=te.treatMissingFieldsAsNull,et=te.updater,tt=te.log,Oe=te.normalizeResponse;this._actorIdentifier=B,this._getDataID=ne,this._treatMissingFieldsAsNull=Re,this._incrementalPayloadsPending=!1,this._incrementalResults=new Map,this._log=tt,this._executeId=i(),this._nextSubscriptionId=0,this._operation=be,this._operationExecutions=ve,this._operationLoader=pe,this._operationTracker=_e,this._operationUpdateEpochs=new Map,this._optimisticUpdates=null,this._useExecTimeResolvers=(M=(K=this._operation.request.node.operation.use_exec_time_resolvers)!==null&&K!==void 0?K:((X=this._operation.request.node.operation.exec_time_resolvers_enabled_provider)===null||X===void 0?void 0:X.get())===!0)!==null&&M!==void 0?M:!1,this._execTimeResolverResponseComplete=!1,this._pendingModulePayloadsCount=0,this._getPublishQueue=oe,this._scheduler=me,this._sink=we,this._source=new Map,this._state="started",this._getStore=ie,this._subscriptions=new Map,this._updater=et,this._isClientPayload=de===!0,this._isSubscriptionOperation=this._operation.request.node.params.operationKind==="subscription",this._shouldProcessClientComponents=ge,this._retainDisposables=new Map,this._seenActors=new Set,this._completeFns=[],this._normalizeResponse=Oe;var $e=this._nextSubscriptionId++;l.PROCESS_OPTIMISTIC_UPDATE_BEFORE_SUBSCRIPTION&&se!=null&&this._processOptimisticResponse(se.response!=null?{data:se.response}:null,se.updater,!1),Ne.subscribe({complete:function(){return H._complete($e)},error:function(Ue){return H._error(Ue)},next:function(Ue){try{H._next($e,Ue)}catch(Ze){we.error(Ze)}},start:function(Ue){var Ze;H._start($e,Ue),H._log({name:"execute.start",executeId:H._executeId,params:H._operation.request.node.params,variables:H._operation.request.variables,cacheConfig:(Ze=H._operation.request.cacheConfig)!==null&&Ze!==void 0?Ze:{}})},unsubscribe:function(){H._log({name:"execute.unsubscribe",executeId:H._executeId})}}),!l.PROCESS_OPTIMISTIC_UPDATE_BEFORE_SUBSCRIPTION&&se!=null&&this._processOptimisticResponse(se.response!=null?{data:se.response}:null,se.updater,!1)}var J=G.prototype;return J.cancel=function(){var H=this;if(this._state!=="completed"){this._state="completed",this._operationExecutions.delete(this._operation.request.identifier),this._subscriptions.size!==0&&(this._subscriptions.forEach(function(K){return K.unsubscribe()}),this._subscriptions.clear());var M=this._optimisticUpdates;M!==null&&(this._optimisticUpdates=null,M.forEach(function(K){return H._getPublishQueueAndSaveActor().revertUpdate(K)}),this._runPublishQueue()),this._incrementalResults.clear(),this._asyncStoreUpdateDisposable!=null&&(this._asyncStoreUpdateDisposable.dispose(),this._asyncStoreUpdateDisposable=null),this._completeFns=[],this._completeOperationTracker(),this._disposeRetainedData()}},J._updateActiveState=function(){var H;switch(this._state){case"started":{H="active";break}case"loading_incremental":{H="active";break}case"completed":{H="inactive";break}case"loading_final":{H=this._pendingModulePayloadsCount>0||this._useExecTimeResolvers&&!this._execTimeResolverResponseComplete?"active":"inactive";break}default:this._state,L(!1)}this._operationExecutions.set(this._operation.request.identifier,H)},J._schedule=function(H,M){var K=this,X=this._scheduler;if(X!=null){var B=this._nextSubscriptionId++;r.create(function(ne){var oe=X.schedule(function(){try{H(),ne.complete()}catch(ie){ne.error(ie)}},M);return function(){return X.cancel(oe)}}).subscribe({complete:function(){return K._complete(B)},error:function(oe){return K._error(oe)},start:function(oe){return K._start(B,oe)}})}else H()},J._complete=function(H){this._subscriptions.delete(H),this._subscriptions.size===0&&(this.cancel(),this._sink.complete(),this._log({name:"execute.complete",executeId:this._executeId}))},J._error=function(H){this.cancel(),this._sink.error(H),this._log({name:"execute.error",executeId:this._executeId,error:H})},J._start=function(H,M){this._subscriptions.set(H,M),this._updateActiveState()},J._next=function(H,M){var K=this,X=this._state==="loading_incremental"?"low":"default";this._schedule(function(){K._log({name:"execute.next.start",executeId:K._executeId,response:M,operation:K._operation}),K._handleNext(M),K._maybeCompleteSubscriptionOperationTracking(),K._log({name:"execute.next.end",executeId:K._executeId,response:M,operation:K._operation})},X)},J._handleErrorResponse=function(H){var M=this,K=[];return H.forEach(function(X){if(!(X.data===null&&X.extensions!=null&&!X.hasOwnProperty("errors")))if(X.data==null){var B=X.hasOwnProperty("errors")&&X.errors!=null?X.errors:null,ne=B?B.map(function(de){var be=de.message;return be}).join(`
`):"(No errors)",oe=u.create("RelayNetwork","No data returned for operation `"+M._operation.request.node.params.name+"`, got error(s):\n"+ne+"\n\nSee the error `source` property for more information.");throw oe.source={errors:B,operation:M._operation.request.node,variables:M._operation.request.variables},oe.stack,oe}else{var ie=X;K.push(ie)}}),K},J._handleOptimisticResponses=function(H){var M;if(H.length>1)return H.some(function(B){var ne;return((ne=B.extensions)===null||ne===void 0?void 0:ne.isOptimistic)===!0})&&L(!1),!1;var K=H[0],X=((M=K.extensions)===null||M===void 0?void 0:M.isOptimistic)===!0;return X&&this._state!=="started"&&L(!1),X?(this._processOptimisticResponse(K,null,this._treatMissingFieldsAsNull),this._sink.next(K),!0):!1},J._handleNext=function(H){if(this._state!=="completed"){this._seenActors.clear();var M=Array.isArray(H)?H:[H],K=this._handleErrorResponse(M);if(K.length===0){var X=M.some(function(Oe){var $e;return(($e=Oe.extensions)===null||$e===void 0?void 0:$e.is_final)===!0});X&&(this._state="loading_final",this._updateActiveState(),this._incrementalPayloadsPending=!1),this._sink.next(H);return}var B=this._handleOptimisticResponses(K);if(!B){var ne=N(K),oe=ne[0],ie=ne[1],de=ne[2],be=oe.length>0,ve=de.length>0;if(be){if(this._isSubscriptionOperation){var pe=m();this._operation={request:this._operation.request,fragment:C(this._operation.fragment.node,pe,this._operation.fragment.variables,this._operation.fragment.owner),root:E(this._operation.root.node,pe,this._operation.root.variables)}}var _e=this._processResponses(oe);this._processPayloadFollowups(_e)}if(ve)for(var se=[],me=0;me<de.length;me++){var ge,we=de[me],Ne=new T(we.data),X=((ge=we.extensions)===null||ge===void 0?void 0:ge.is_final)===!0,Re={errors:[],fieldPayloads:[],followupPayloads:[],incrementalPlaceholders:[],isFinal:X,source:Ne};this._getPublishQueueAndSaveActor().commitPayload(this._operation,Re,this._updater),se.push(Re),this._execTimeResolverResponseComplete=X,X&&this._updateActiveState()}if(ie.length>0){var et=this._processIncrementalResponses(ie);this._processPayloadFollowups(et)}this._isSubscriptionOperation&&(K[0].extensions==null?K[0].extensions={__relay_subscription_root_id:this._operation.fragment.dataID}:K[0].extensions.__relay_subscription_root_id=this._operation.fragment.dataID);var tt=this._runPublishQueue(be||ve?this._operation:void 0);be&&this._incrementalPayloadsPending&&this._retainData(),this._updateOperationTracker(tt),this._sink.next(H)}}},J._processOptimisticResponse=function(H,M,K){var X=this;if(this._optimisticUpdates!==null&&L(!1),!(H==null&&M==null)){var B=[];if(H){var ne=this._normalizeResponse(H,this._operation.root,$,{actorIdentifier:this._actorIdentifier,getDataID:this._getDataID,log:this._log,path:[],shouldProcessClientComponents:this._shouldProcessClientComponents,treatMissingFieldsAsNull:K},this._useExecTimeResolvers);W(ne),B.push({operation:this._operation,payload:ne,updater:M}),this._processOptimisticFollowups(ne,B)}else M&&B.push({operation:this._operation,payload:{errors:null,fieldPayloads:null,incrementalPlaceholders:null,followupPayloads:null,source:T.create(),isFinal:!1},updater:M});this._optimisticUpdates=B,B.forEach(function(ie){return X._getPublishQueueAndSaveActor().applyUpdate(ie)});var oe=this._runPublishQueue();l.ENABLE_OPERATION_TRACKER_OPTIMISTIC_UPDATES&&this._updateOperationTracker(oe)}},J._processOptimisticFollowups=function(H,M){if(H.followupPayloads&&H.followupPayloads.length){var K=H.followupPayloads,X=(0,t.default)(K),B;try{for(X.s();!(B=X.n()).done;){var ne=B.value;switch(ne.kind){case"ModuleImportPayload":var oe=this._expectOperationLoader(),ie=oe.get(ne.operationReference);if(ie==null)this._processAsyncOptimisticModuleImport(ne);else{var de=this._processOptimisticModuleImport(ie,ne);M.push.apply(M,(0,n.default)(de))}break;case"ActorPayload":break;default:L(!1)}}}catch(be){X.e(be)}finally{X.f()}}},J._normalizeFollowupPayload=function(H,M){var K;M.kind==="SplitOperation"&&H.kind==="ModuleImportPayload"?K=v(H.variables,M.argumentDefinitions,H.args):K=H.variables;var X=E(M,H.dataID,K),B={data:H.data,extensions:this._state==="loading_final"?{is_final:!0}:void 0};return this._normalizeResponse(B,X,H.typeName,{actorIdentifier:this._actorIdentifier,getDataID:this._getDataID,log:this._log,path:H.path,treatMissingFieldsAsNull:this._treatMissingFieldsAsNull,shouldProcessClientComponents:this._shouldProcessClientComponents},this._useExecTimeResolvers)},J._processOptimisticModuleImport=function(H,M){var K=a(H),X=[],B=this._normalizeFollowupPayload(M,K);return W(B),X.push({operation:this._operation,payload:B,updater:null}),this._processOptimisticFollowups(B,X),X},J._processAsyncOptimisticModuleImport=function(H){var M=this;this._expectOperationLoader().load(H.operationReference).then(function(K){if(!(K==null||M._state!=="started")){var X=M._processOptimisticModuleImport(K,H);if(X.forEach(function(ne){return M._getPublishQueueAndSaveActor().applyUpdate(ne)}),M._optimisticUpdates!=null){var B;(B=M._optimisticUpdates).push.apply(B,(0,n.default)(X)),M._runPublishQueue()}}})},J._processResponses=function(H){var M=this;return this._log({name:"execute.normalize.start",operation:this._operation}),this._optimisticUpdates!==null&&(this._optimisticUpdates.forEach(function(K){M._getPublishQueueAndSaveActor().revertUpdate(K)}),this._optimisticUpdates=null),this._incrementalPayloadsPending=!1,this._incrementalResults.clear(),this._source.clear(),H.map(function(K){var X=M._normalizeResponse(K,M._operation.root,$,{actorIdentifier:M._actorIdentifier,getDataID:M._getDataID,log:M._log,path:[],treatMissingFieldsAsNull:M._treatMissingFieldsAsNull,shouldProcessClientComponents:M._shouldProcessClientComponents},M._useExecTimeResolvers);return M._getPublishQueueAndSaveActor().commitPayload(M._operation,X,M._updater),M._log({name:"execute.normalize.end",operation:M._operation}),X})},J._processPayloadFollowups=function(H){var M=this;this._state!=="completed"&&H.forEach(function(K){var X=K.incrementalPlaceholders,B=K.followupPayloads,ne=K.isFinal;if(M._state=ne?"loading_final":"loading_incremental",M._updateActiveState(),ne&&(M._incrementalPayloadsPending=!1),B&&B.length!==0&&B.forEach(function(ie){var de,be=M._actorIdentifier;M._actorIdentifier=(de=ie.actorIdentifier)!==null&&de!==void 0?de:M._actorIdentifier,M._processFollowupPayload(ie),M._actorIdentifier=be}),X&&X.length!==0&&(M._incrementalPayloadsPending=M._state!=="loading_final",X.forEach(function(ie){var de,be=M._actorIdentifier;M._actorIdentifier=(de=ie.actorIdentifier)!==null&&de!==void 0?de:M._actorIdentifier,M._processIncrementalPlaceholder(K,ie),M._actorIdentifier=be}),M._isClientPayload||M._state==="loading_final")){var oe=[];X.forEach(function(ie){ie.kind==="defer"&&oe.push(M._processDeferResponse(ie.label,ie.path,ie,{data:ie.data,extensions:{is_final:!0}}))}),oe.length>0&&M._processPayloadFollowups(oe)}})},J._maybeCompleteSubscriptionOperationTracking=function(){!this._isSubscriptionOperation&&!(this._useExecTimeResolvers&&this._execTimeResolverResponseComplete&&this._state==="loading_final")||this._pendingModulePayloadsCount===0&&this._incrementalPayloadsPending===!1&&this._completeOperationTracker()},J._processFollowupPayload=function(H){var M=this;switch(H.kind){case"ModuleImportPayload":var K=this._expectOperationLoader(),X=K.get(H.operationReference);if(X!=null)this._processFollowupPayloadWithNormalizationNode(H,a(X));else{var B=this._nextSubscriptionId++;this._pendingModulePayloadsCount++;var ne=function(){M._pendingModulePayloadsCount--,M._maybeCompleteSubscriptionOperationTracking()},oe=r.from(new Promise(function(ie,de){K.load(H.operationReference).then(ie,de)}));r.create(function(ie){var de,be=oe.subscribe({next:function(pe){if(pe!=null){var _e=function(){try{var ge=a(pe),we=l.BATCH_ASYNC_MODULE_UPDATES_FN,Ne=we!=null&&M._pendingModulePayloadsCount>1,Re=c(function(){if(M._handleFollowupPayload(H,ge),Ne)M._scheduleAsyncStoreUpdate(we,ie.complete);else{var Oe=M._runPublishQueue();M._updateOperationTracker(Oe)}}),et=Re[0],tt=Re[1];M._log({name:"execute.async.module",executeId:M._executeId,operationName:ge.name,duration:tt}),Ne||ie.complete()}catch(Oe){ie.error(Oe)}},se=M._scheduler;se==null?_e():de=se.schedule(_e)}else ie.complete()},error:ie.error});return function(){be.unsubscribe(),M._scheduler!=null&&de!=null&&M._scheduler.cancel(de)}}).subscribe({complete:function(){M._complete(B),ne()},error:function(de){M._error(de),ne()},start:function(de){return M._start(B,de)}})}break;case"ActorPayload":this._processFollowupPayloadWithNormalizationNode(H,H.node);break;default:L(!1)}},J._processFollowupPayloadWithNormalizationNode=function(H,M){this._handleFollowupPayload(H,M),this._maybeCompleteSubscriptionOperationTracking()},J._handleFollowupPayload=function(H,M){var K=this._normalizeFollowupPayload(H,M);this._getPublishQueueAndSaveActor().commitPayload(this._operation,K),this._processPayloadFollowups([K])},J._processIncrementalPlaceholder=function(H,M){var K,X=M.label,B=M.path,ne=B.map(String).join("."),oe=this._incrementalResults.get(X);oe==null&&(oe=new Map,this._incrementalResults.set(X,oe));var ie=oe.get(ne),de=ie!=null&&ie.kind==="response"?ie.responses:null;oe.set(ne,{kind:"placeholder",placeholder:M});var be;M.kind==="stream"?be=M.parentID:M.kind==="defer"?be=M.selector.dataID:L(!1);var ve=H.source.get(be),pe=((K=H.fieldPayloads)!==null&&K!==void 0?K:[]).filter(function(Re){var et=h(Re.dataID,Re.fieldKey);return Re.dataID===be||et===be});ve==null&&L(!1);var _e,se,me=this._source.get(be);if(me!=null){_e=_.update(me.record,ve);var ge=new Map,we=function(et){var tt=U(et);ge.set(tt,et)};me.fieldPayloads.forEach(we),pe.forEach(we),se=Array.from(ge.values())}else _e=ve,se=pe;if(this._source.set(be,{record:_e,fieldPayloads:se}),de!=null){var Ne=this._processIncrementalResponses(de);this._processPayloadFollowups(Ne)}},J._processIncrementalResponses=function(H){var M=this,K=[];return H.forEach(function(X){var B=X.label,ne=X.path,oe=X.response,ie=M._incrementalResults.get(B);if(ie==null&&(ie=new Map,M._incrementalResults.set(B,ie)),B.indexOf("$defer$")!==-1){var de=ne.map(String).join("."),be=ie.get(de);if(be==null){be={kind:"response",responses:[X]},ie.set(de,be);return}else if(be.kind==="response"){be.responses.push(X);return}var ve=be.placeholder;ve.kind!=="defer"&&L(!1),K.push(M._processDeferResponse(B,ne,ve,oe))}else{var pe=ne.slice(0,-2).map(String).join("."),_e=ie.get(pe);if(_e==null){_e={kind:"response",responses:[X]},ie.set(pe,_e);return}else if(_e.kind==="response"){_e.responses.push(X);return}var se=_e.placeholder;se.kind!=="stream"&&L(!1),K.push(M._processStreamResponse(B,ne,se,oe))}}),K},J._processDeferResponse=function(H,M,K,X){var B,ne=K.selector.dataID,oe=this._actorIdentifier;this._actorIdentifier=(B=K.actorIdentifier)!==null&&B!==void 0?B:this._actorIdentifier;var ie=this._normalizeResponse(X,K.selector,K.typeName,{actorIdentifier:this._actorIdentifier,getDataID:this._getDataID,log:this._log,path:K.path,treatMissingFieldsAsNull:this._treatMissingFieldsAsNull,shouldProcessClientComponents:this._shouldProcessClientComponents},this._useExecTimeResolvers);this._getPublishQueueAndSaveActor().commitPayload(this._operation,ie);var de=this._source.get(ne);de==null&&L(!1);var be=de.fieldPayloads;if(be.length!==0){var ve,pe={errors:null,fieldPayloads:be,incrementalPlaceholders:null,followupPayloads:null,source:T.create(),isFinal:((ve=X.extensions)===null||ve===void 0?void 0:ve.is_final)===!0};this._getPublishQueueAndSaveActor().commitPayload(this._operation,pe)}return this._actorIdentifier=oe,ie},J._processStreamResponse=function(H,M,K,X){var B=K.parentID,ne=K.node,oe=K.variables,ie=K.actorIdentifier,de=this._actorIdentifier;this._actorIdentifier=ie??this._actorIdentifier;var be=ne.selections[0];be!=null&&be.kind==="LinkedField"&&be.plural===!0||L(!1);var ve=this._normalizeStreamItem(X,B,be,oe,M,K.path),pe=ve.fieldPayloads,_e=ve.itemID,se=ve.itemIndex,me=ve.prevIDs,ge=ve.relayPayload,we=ve.storageKey;if(this._getPublishQueueAndSaveActor().commitPayload(this._operation,ge,function(Re){var et=Re.get(B);if(et!=null){var tt=et.getLinkedRecords(we);if(tt!=null&&!(tt.length!==me.length||tt.some(function($e,Ae){return me[Ae]!==($e&&$e.getDataID())}))){var Oe=(0,n.default)(tt);Oe[se]=Re.get(_e),et.setLinkedRecords(Oe,we)}}}),pe.length!==0){var Ne={errors:null,fieldPayloads:pe,incrementalPlaceholders:null,followupPayloads:null,source:T.create(),isFinal:!1};this._getPublishQueueAndSaveActor().commitPayload(this._operation,Ne)}return this._actorIdentifier=de,ge},J._normalizeStreamItem=function(H,M,K,X,B,ne){var oe,ie,de,be,ve=H.data;typeof ve!="object"&&L(!1);var pe=(oe=K.alias)!==null&&oe!==void 0?oe:K.name,_e=F(K,X),se=this._source.get(M);se==null&&L(!1);var me=se.record,ge=se.fieldPayloads,we=_.getLinkedRecordIDs(me,_e);we==null&&L(!1);var Ne=B[B.length-1],Re=parseInt(Ne,10);Re===Ne&&Re>=0||L(!1);var et=(ie=K.concreteType)!==null&&ie!==void 0?ie:ve[k];typeof et!="string"&&L(!1);var tt=(de=(be=this._getDataID(ve,et))!==null&&be!==void 0?be:we==null?void 0:we[Re])!==null&&de!==void 0?de:h(M,_e,Re);typeof tt!="string"&&L(!1);var Oe=E(K,tt,X),$e=_.clone(me),Ae=(0,n.default)(we);Ae[Re]=tt,_.setLinkedRecordIDs($e,_e,Ae),this._source.set(M,{record:$e,fieldPayloads:ge});var Ue=this._normalizeResponse(H,Oe,et,{actorIdentifier:this._actorIdentifier,getDataID:this._getDataID,log:this._log,path:[].concat((0,n.default)(ne),[pe,String(Re)]),treatMissingFieldsAsNull:this._treatMissingFieldsAsNull,shouldProcessClientComponents:this._shouldProcessClientComponents},this._useExecTimeResolvers);return{fieldPayloads:ge,itemID:tt,itemIndex:Re,prevIDs:we,relayPayload:Ue,storageKey:_e}},J._scheduleAsyncStoreUpdate=function(H,M){var K=this;this._completeFns.push(M),this._asyncStoreUpdateDisposable==null&&(this._asyncStoreUpdateDisposable=H(function(){K._asyncStoreUpdateDisposable=null;var X=K._runPublishQueue();K._updateOperationTracker(X);var B=(0,t.default)(K._completeFns),ne;try{for(B.s();!(ne=B.n()).done;){var oe=ne.value;oe()}}catch(ie){B.e(ie)}finally{B.f()}K._completeFns=[]}))},J._updateOperationTracker=function(H){H!=null&&H.length>0&&this._operationTracker.update(this._operation.request,new Set(H))},J._completeOperationTracker=function(){this._operationTracker.complete(this._operation.request)},J._getPublishQueueAndSaveActor=function(){return this._seenActors.add(this._actorIdentifier),this._getPublishQueue(this._actorIdentifier)},J._getActorsToVisit=function(){return this._seenActors.size===0?new Set([this._actorIdentifier]):this._seenActors},J._runPublishQueue=function(H){var M=new Set,K=(0,t.default)(this._getActorsToVisit()),X;try{for(K.s();!(X=K.n()).done;){var B=X.value,ne=this._getPublishQueue(B).run(H);ne.forEach(function(oe){return M.add(oe)})}}catch(oe){K.e(oe)}finally{K.f()}return Array.from(M)},J._retainData=function(){var H=(0,t.default)(this._getActorsToVisit()),M;try{for(H.s();!(M=H.n()).done;){var K=M.value;this._retainDisposables.has(K)||this._retainDisposables.set(K,this._getStore(K).retain(this._operation))}}catch(X){H.e(X)}finally{H.f()}},J._disposeRetainedData=function(){var H=(0,t.default)(this._retainDisposables.values()),M;try{for(H.s();!(M=H.n()).done;){var K=M.value;K.dispose()}}catch(X){H.e(X)}finally{H.f()}this._retainDisposables.clear()},J._expectOperationLoader=function(){var H=this._operationLoader;return H||L(!1),H},G})();function N(G){var J=[],te=[],H=[];return G.forEach(function(M){var K;if(M.path!=null||M.label!=null){var X=M.label,B=M.path;(X==null||B==null)&&L(!1),te.push({label:X,path:B,response:M})}else((K=M.extensions)===null||K===void 0?void 0:K.is_normalized)===!0?H.push(M):J.push(M)}),[J,te,H]}function U(G){var J;return(J=JSON.stringify(s(G)))!==null&&J!==void 0?J:""}function W(G){var J=G.incrementalPlaceholders;J!=null&&J.length!==0&&L(!1)}return FR={execute:V},FR}var NR,qz;function t4e(){if(qz)return NR;qz=1;var e=Promise.resolve();function t(r){e.then(r).catch(n)}function n(r){setTimeout(function(){throw r},0)}return NR=t,NR}var IR,Vz;function VJ(){if(Vz)return IR;Vz=1;var e=df(),t=EC(),n=t.EXISTENT,r=on(),i=(function(){function a(l,o){this.__sources=[o,l],this._base=l,this._sink=o}var u=a.prototype;return u.unstable_getRawRecordWithChanges=function(o){var s=this._base.get(o),c=this._sink.get(o);if(c===void 0){if(s==null)return s;var d=e.clone(s);return d}else{if(c===null)return null;if(s!=null){var h=e.update(s,c);return h}else{var m=e.clone(c);return m}}},u._getSinkRecord=function(o){var s=this._sink.get(o);if(!s){var c=this._base.get(o);c||r(!1),s=e.create(o,e.getType(c)),this._sink.set(o,s)}return s},u.copyFields=function(o,s){var c=this._sink.get(o),d=this._base.get(o);c||d||r(!1);var h=this._getSinkRecord(s);d&&e.copyFields(d,h),c&&e.copyFields(c,h)},u.copyFieldsFromRecord=function(o,s){var c=this._getSinkRecord(s);e.copyFields(o,c)},u.create=function(o,s){this._base.getStatus(o)!==n&&this._sink.getStatus(o)!==n||r(!1);var c=e.create(o,s);this._sink.set(o,c)},u.delete=function(o){this._sink.delete(o)},u.getStatus=function(o){return this._sink.has(o)?this._sink.getStatus(o):this._base.getStatus(o)},u.getType=function(o){for(var s=0;s<this.__sources.length;s++){var c=this.__sources[s].get(o);if(c)return e.getType(c);if(c===null)return null}},u.getValue=function(o,s){for(var c=0;c<this.__sources.length;c++){var d=this.__sources[c].get(o);if(d){var h=e.getValue(d,s);if(h!==void 0)return h}else if(d===null)return null}},u.setValue=function(o,s,c){var d=this._getSinkRecord(o);e.setValue(d,s,c)},u.getErrors=function(o,s){for(var c=0;c<this.__sources.length;c++){var d=this.__sources[c].get(o);if(d){var h=e.getErrors(d,s);if(h!==void 0)return h}else if(d===null)return null}},u.setErrors=function(o,s,c){var d=this._getSinkRecord(o);e.setErrors(d,s,c)},u.getLinkedRecordID=function(o,s){for(var c=0;c<this.__sources.length;c++){var d=this.__sources[c].get(o);if(d){var h=e.getLinkedRecordID(d,s);if(h!==void 0)return h}else if(d===null)return null}},u.setLinkedRecordID=function(o,s,c){var d=this._getSinkRecord(o);e.setLinkedRecordID(d,s,c)},u.getLinkedRecordIDs=function(o,s){for(var c=0;c<this.__sources.length;c++){var d=this.__sources[c].get(o);if(d){var h=e.getLinkedRecordIDs(d,s);if(h!==void 0)return h}else if(d===null)return null}},u.setLinkedRecordIDs=function(o,s,c){var d=this._getSinkRecord(o);e.setLinkedRecordIDs(d,s,c)},a})();return IR=i,IR}var LR,Uz;function UJ(){if(Uz)return LR;Uz=1;var e=Cn().default,t=e(Du()),n=_a(),r=n.getArgumentValues,i=["id","__id","__typename","js"];function a(y,v,_,S,E){var C={};return u(C,y,v,_,S,E),C}function u(y,v,_,S,E,C){var T,R=(0,t.default)(S),$;try{var k=function(){var V=$.value;switch(V.kind){case"LinkedField":V.plural?Object.defineProperty(y,(F=V.alias)!==null&&F!==void 0?F:V.name,{get:s(V,_,v,E,C),set:l(V,_,v,E)}):Object.defineProperty(y,(L=V.alias)!==null&&L!==void 0?L:V.name,{get:c(V,_,v,E,C),set:o(V,_,v,E)});break;case"ScalarField":var q=(T=V.alias)!==null&&T!==void 0?T:V.name;Object.defineProperty(y,q,{get:function(){var U,W=r((U=V.args)!==null&&U!==void 0?U:[],_),G=v.getValue(V.name,W);return G==null&&(G=m(V,W,v,E,C)),G},set:i.includes(V.name)?void 0:function(N){var U,W=r((U=V.args)!==null&&U!==void 0?U:[],_);v.setValue__UNSAFE(N,V.name,W)}});break;case"InlineFragment":v.getType()===V.type&&u(y,v,_,V.selections,E,C);break;case"ClientExtension":u(y,v,_,V.selections,E,C);break;case"FragmentSpread":break;case"Condition":case"ActorChange":case"InlineDataFragmentSpread":case"AliasedInlineFragmentSpread":case"ClientEdgeToClientObject":case"ClientEdgeToServerObject":case"Defer":case"ModuleImport":case"RequiredField":case"CatchField":case"Stream":case"RelayResolver":case"RelayLiveResolver":throw new Error("Encountered an unexpected ReaderSelection variant in RelayRecordSourceProxy. This indicates a bug in Relay.");default:throw V.kind,new Error("Encountered an unexpected ReaderSelection variant in RelayRecordSourceProxy. This indicates a bug in Relay.")}};for(R.s();!($=R.n()).done;){var F,L;k()}}catch(j){R.e(j)}finally{R.f()}}function l(y,v,_,S){return function(C){var T,R=r((T=y.args)!==null&&T!==void 0?T:[],v);if(C==null)throw new Error("Do not assign null to plural linked fields; assign an empty array instead.");var $=C.map(function(k){if(k==null)throw new Error("When assigning an array of items, none of the items should be null or undefined.");var F=k.__id;if(F==null)throw new Error("The __id field must be present on each item passed to the setter. This indicates a bug in Relay.");var L=S.get(F);if(L==null)throw new Error("Did not find item with data id ".concat(F," in the store."));return L});_.setLinkedRecords($,y.name,R)}}function o(y,v,_,S){return function(C){var T,R=r((T=y.args)!==null&&T!==void 0?T:[],v);if(C==null)_.setValue(C,y.name,R);else{var $=C.__id;if($==null)throw new Error("The __id field must be present on the argument. This indicates a bug in Relay.");var k=S.get($);if(k==null)throw new Error("Did not find item with data id ".concat($," in the store."));_.setLinkedRecord(k,y.name,R)}}}function s(y,v,_,S,E){return function(){var C,T=r((C=y.args)!==null&&C!==void 0?C:[],v),R=_.getLinkedRecords(y.name,T);return R===void 0&&(R=h(y,T,_,S,E)),R!=null?R.map(function($){if($!=null){var k={};return u(k,$,v,y.selections,S,E),k}else return $}):R}}function c(y,v,_,S,E){return function(){var C,T=r((C=y.args)!==null&&C!==void 0?C:[],v),R=_.getLinkedRecord(y.name,T);if(R===void 0&&(R=d(y,T,_,S,E)),R!=null){var $={};return u($,R,v,y.selections,S,E),$}else return R}}function d(y,v,_,S,E){var C=(0,t.default)(E),T;try{for(C.s();!(T=C.n()).done;){var R=T.value;if(R.kind==="linked"){var $=R.handle(y,_,v,S);if($!=null)return S.get($)}}}catch(k){C.e(k)}finally{C.f()}}function h(y,v,_,S,E){var C=(0,t.default)(E),T;try{for(C.s();!(T=C.n()).done;){var R=T.value;if(R.kind==="pluralLinked"){var $=R.handle(y,_,v,S);if($!=null)return $.map(function(k){if(k!=null)return S.get(k)})}}}catch(k){C.e(k)}finally{C.f()}}function m(y,v,_,S,E){var C=(0,t.default)(E),T;try{for(C.s();!(T=C.n()).done;){var R=T.value;if(R.kind==="scalar"){var $=R.handle(y,_,v,S);if($!==void 0)return $}}}catch(k){C.e(k)}finally{C.f()}}return LR={createUpdatableProxy:a},LR}var BR,jz;function jJ(){if(jz)return BR;jz=1;var e=fp(),t=e.getFragment,n=dp(),r=n.getVariablesFromFragment,i=_a(),a=i.ID_KEY,u=UJ(),l=u.createUpdatableProxy,o=on();function s(c,d,h,m){var y=t(c),v=r(y,d),_=d[a],S=h.get(_);return S==null&&o(!1),{updatableData:l(S,v,y.selections,h,m)}}return BR={readUpdatableFragment:s},BR}var QR,Zz;function ZJ(){if(Zz)return QR;Zz=1;var e=fp(),t=e.getUpdatableQuery,n=UJ(),r=n.createUpdatableProxy;function i(a,u,l,o){var s=t(a);return{updatableData:r(l.getRoot(),u,s.fragment.selections,l,o)}}return QR={readUpdatableQuery:i},QR}var zR,Hz;function n4e(){if(Hz)return zR;Hz=1;var e=I0(),t=e.generateClientID,n=_a(),r=n.getStableStorageKey,i=on(),a=(function(){function l(s,c,d){this._dataID=d,this._mutator=c,this._source=s}var o=l.prototype;return o.copyFieldsFrom=function(c){this._mutator.copyFields(c.getDataID(),this._dataID)},o.getDataID=function(){return this._dataID},o.getType=function(){var c=this._mutator.getType(this._dataID);return c==null&&i(!1),c},o.getValue=function(c,d){var h=r(c,d);return this._mutator.getValue(this._dataID,h)},o.setValue=function(c,d,h,m){return u(c)||i(!1),this.setValue__UNSAFE(c,d,h,m)},o.getErrors=function(c,d){var h=r(c,d);return this._mutator.getErrors(this._dataID,h)},o.setValue__UNSAFE=function(c,d,h,m){var y=r(d,h);return this._mutator.setValue(this._dataID,y,c),m!=null&&(m.length===0?this._mutator.setErrors(this._dataID,y):this._mutator.setErrors(this._dataID,y,m)),this},o.getLinkedRecord=function(c,d){var h=r(c,d),m=this._mutator.getLinkedRecordID(this._dataID,h);return m!=null?this._source.get(m):m},o.setLinkedRecord=function(c,d,h){c instanceof l||i(!1);var m=r(d,h),y=c.getDataID();return this._mutator.setLinkedRecordID(this._dataID,m,y),this},o.getOrCreateLinkedRecord=function(c,d,h){var m=this.getLinkedRecord(c,h);if(!m){var y,v=r(c,h),_=t(this.getDataID(),v);m=(y=this._source.get(_))!==null&&y!==void 0?y:this._source.create(_,d),this.setLinkedRecord(m,c,h)}return m},o.getLinkedRecords=function(c,d){var h=this,m=r(c,d),y=this._mutator.getLinkedRecordIDs(this._dataID,m);return y==null?y:y.map(function(v){return v!=null?h._source.get(v):v})},o.setLinkedRecords=function(c,d,h){Array.isArray(c)||i(!1);var m=r(d,h),y=c.map(function(v){return v&&v.getDataID()});return this._mutator.setLinkedRecordIDs(this._dataID,m,y),this},o.invalidateRecord=function(){this._source.markIDForInvalidation(this._dataID)},l})();function u(l){return l==null||typeof l!="object"||Array.isArray(l)&&l.every(u)}return zR=a,zR}var qR,Xz;function HJ(){if(Xz)return qR;Xz=1;var e=df(),t=EC(),n=t.EXISTENT,r=t.NONEXISTENT,i=_a(),a=i.ROOT_ID,u=i.ROOT_TYPE,l=jJ(),o=l.readUpdatableFragment,s=ZJ(),c=s.readUpdatableQuery,d=n4e(),h=on(),m=(function(){function y(_,S,E,C,T){this.__mutator=_,this._handlerProvider=E||null,this._proxies={},this._getDataID=S,this._invalidatedStore=!1,this._idsMarkedForInvalidation=new Set,this._missingFieldHandlers=C,this._log=T??function(R){}}var v=y.prototype;return v.publishSource=function(S,E){var C=this,T=S.getRecordIDs();T.forEach(function(R){var $=S.getStatus(R);if($===n){var k=S.get(R);k&&(C.__mutator.getStatus(R)!==n&&C.create(R,e.getType(k)),C.__mutator.copyFieldsFromRecord(k,R))}else $===r&&C.delete(R)}),E&&E.length&&E.forEach(function(R){var $=C._handlerProvider&&C._handlerProvider(R.handle);$||h(!1),$.update(C,R)})},v.create=function(S,E){this.__mutator.create(S,E),delete this._proxies[S];var C=this.get(S);return C||h(!1),C},v.delete=function(S){S===a&&h(!1),delete this._proxies[S],this.__mutator.delete(S)},v.get=function(S){if(!this._proxies.hasOwnProperty(S)){var E=this.__mutator.getStatus(S);E===n?this._proxies[S]=new d(this,this.__mutator,S):this._proxies[S]=E===r?null:void 0}return this._proxies[S]},v.getRoot=function(){var S=this.get(a);return S||(S=this.create(a,u)),S&&S.getType()===u||h(!1),S},v.invalidateStore=function(){this._invalidatedStore=!0},v.isStoreMarkedForInvalidation=function(){return this._invalidatedStore},v.markIDForInvalidation=function(S){this._idsMarkedForInvalidation.add(S)},v.getIDsMarkedForInvalidation=function(){return this._idsMarkedForInvalidation},v.readUpdatableQuery=function(S,E){return c(S,E,this,this._missingFieldHandlers)},v.readUpdatableFragment=function(S,E){return o(S,E,this,this._missingFieldHandlers)},y})();return qR=m,qR}var VR,Yz;function XJ(){if(Yz)return VR;Yz=1;var e=oy(),t=e.LINKED_FIELD,n=_a(),r=n.getHandleStorageKey,i=Jf(),a=on();function u(l,o,s){var c=o.find(function(h){return h.kind===t&&h.name===l.name&&h.alias===l.alias&&i(h.args,l.args)});c&&c.kind===t||a(!1);var d=r(l,s);return{kind:"LinkedField",alias:c.alias,name:d,storageKey:d,args:null,concreteType:c.concreteType,plural:c.plural,selections:c.selections}}return VR=u,VR}var UR,Gz;function r4e(){if(Gz)return UR;Gz=1;var e=oy(),t=e.SCALAR_FIELD,n=_a(),r=n.getHandleStorageKey,i=Jf(),a=on();function u(l,o,s){var c=o.find(function(h){return h.kind===t&&h.name===l.name&&h.alias===l.alias&&i(h.args,l.args)});c&&c.kind===t||a(!1);var d=r(l,s);return{kind:"ScalarField",alias:c.alias,name:d,storageKey:d,args:null}}return UR=u,UR}var jR,Kz;function i4e(){if(Kz)return jR;Kz=1;var e=Cn().default,t=e(Du()),n=VJ(),r=HJ(),i=VF(),a=I0(),u=a.isClientID,l=XJ(),o=r4e(),s=cy(),c=s.getLocalVariables,d=df(),h=EC(),m=h.EXISTENT,y=h.UNKNOWN,v=_a(),_=DC(),S=_.TYPE_SCHEMA_TYPE,E=_.generateTypeID,C=on(),T=v.getModuleOperationKey,R=v.getStorageKey,$=v.getArgumentValues;function k(L,j,V,q,N,U,W,G,J,te){J!=null&&J({name:"store.datachecker.start",selector:q});var H=q.dataID,M=q.node,K=q.variables,X=new F(L,j,V,K,N,U,W,G,J,te),B=X.check(M,H);return J!=null&&J({name:"store.datachecker.end",selector:q}),B}var F=(function(){function L(V,q,N,U,W,G,J,te,H,M){this._getSourceForActor=V,this._getTargetForActor=q,this._getDataID=J,this._source=V(N),this._mutatorRecordSourceProxyCache=new Map;var K=this._getMutatorAndRecordProxyForActor(N),X=K[0],B=K[1];this._useExecTimeResolvers=M??!1,this._mostRecentlyInvalidatedAt=null,this._handlers=W,this._mutator=X,this._operationLoader=G??null,this._recordSourceProxy=B,this._recordWasMissing=!1,this._variables=U,this._shouldProcessClientComponents=te,this._log=H}var j=L.prototype;return j._getMutatorAndRecordProxyForActor=function(q){var N=this._mutatorRecordSourceProxyCache.get(q);if(N==null){var U=this._getTargetForActor(q),W=new n(this._getSourceForActor(q),U),G=new r(W,this._getDataID,void 0,this._handlers,this._log);N=[W,G],this._mutatorRecordSourceProxyCache.set(q,N)}return N},j.check=function(q,N){return this._assignClientAbstractTypes(q),this._traverse(q,N),this._recordWasMissing===!0?{status:"missing",mostRecentlyInvalidatedAt:this._mostRecentlyInvalidatedAt}:{status:"available",mostRecentlyInvalidatedAt:this._mostRecentlyInvalidatedAt}},j._getVariableValue=function(q){return this._variables.hasOwnProperty(q)||C(!1),this._variables[q]},j._handleMissing=function(){this._recordWasMissing=!0},j._handleMissingScalarField=function(q,N){if(!(q.name==="id"&&q.alias==null&&u(N))){var U=q.args!=null?$(q.args,this._variables):{},W=(0,t.default)(this._handlers),G;try{for(W.s();!(G=W.n()).done;){var J=G.value;if(J.kind==="scalar"){var te=J.handle(q,this._recordSourceProxy.get(N),U,this._recordSourceProxy);if(te!==void 0)return te}}}catch(H){W.e(H)}finally{W.f()}this._handleMissing()}},j._handleMissingLinkField=function(q,N){var U=q.args!=null?$(q.args,this._variables):{},W=(0,t.default)(this._handlers),G;try{for(W.s();!(G=W.n()).done;){var J=G.value;if(J.kind==="linked"){var te=J.handle(q,this._recordSourceProxy.get(N),U,this._recordSourceProxy);if(te!==void 0&&(te===null||this._mutator.getStatus(te)===m))return te}}}catch(H){W.e(H)}finally{W.f()}this._handleMissing()},j._handleMissingPluralLinkField=function(q,N){var U=this,W=q.args!=null?$(q.args,this._variables):{},G=(0,t.default)(this._handlers),J;try{for(G.s();!(J=G.n()).done;){var te=J.value;if(te.kind==="pluralLinked"){var H=te.handle(q,this._recordSourceProxy.get(N),W,this._recordSourceProxy);if(H!=null){var M=H.every(function(K){return K!=null&&U._mutator.getStatus(K)===m});if(M)return H}else if(H===null)return null}}}catch(K){G.e(K)}finally{G.f()}this._handleMissing()},j._traverse=function(q,N){var U=this._mutator.getStatus(N);if(U===y&&this._handleMissing(),U===m){var W=this._source.get(N),G=d.getInvalidationEpoch(W);G!=null&&(this._mostRecentlyInvalidatedAt=this._mostRecentlyInvalidatedAt!=null?Math.max(this._mostRecentlyInvalidatedAt,G):G),this._traverseSelections(q.selections,N)}},j._traverseSelections=function(q,N){var U=this;q.forEach(function(W){switch(W.kind){case"ScalarField":U._checkScalar(W,N);break;case"LinkedField":W.plural?U._checkPluralLink(W,N):U._checkLink(W,N);break;case"ActorChange":U._checkActorChange(W.linkedField,N);break;case"Condition":var G=!!U._getVariableValue(W.condition);G===W.passingValue&&U._traverseSelections(W.selections,N);break;case"InlineFragment":{var J=W.abstractKey;if(J==null){var te=U._mutator.getType(N);te===W.type&&U._traverseSelections(W.selections,N)}else{var H=U._mutator.getType(N);H==null&&C(!1);var M=E(H),K=U._mutator.getValue(M,J);K===!0?U._traverseSelections(W.selections,N):K==null&&U._handleMissing()}break}case"LinkedHandle":{var X=l(W,q,U._variables);X.plural?U._checkPluralLink(X,N):U._checkLink(X,N);break}case"ScalarHandle":{var B=o(W,q,U._variables);U._checkScalar(B,N);break}case"ModuleImport":U._checkModuleImport(W,N);break;case"Defer":case"Stream":U._traverseSelections(W.selections,N);break;case"FragmentSpread":var ne=U._variables;U._variables=c(U._variables,W.fragment.argumentDefinitions,W.args),U._traverseSelections(W.fragment.selections,N),U._variables=ne;break;case"ClientExtension":var oe=U._recordWasMissing;U._traverseSelections(W.selections,N),U._recordWasMissing=oe;break;case"TypeDiscriminator":var ie=W.abstractKey,de=U._mutator.getType(N);de==null&&C(!1);var be=E(de),ve=U._mutator.getValue(be,ie);ve==null&&U._handleMissing();break;case"ClientComponent":if(U._shouldProcessClientComponents===!1)break;U._traverseSelections(W.fragment.selections,N);break;case"RelayResolver":case"RelayLiveResolver":U._useExecTimeResolvers||U._checkResolver(W,N);break;case"ClientEdgeToClientObject":U._useExecTimeResolvers||U._checkResolver(W.backingField,N);break;default:C(!1)}})},j._checkResolver=function(q,N){q.fragment&&this._traverseSelections([q.fragment],N)},j._checkModuleImport=function(q,N){var U=this._operationLoader;U===null&&C(!1);var W=T(q.documentName),G=this._mutator.getValue(N,W);if(G==null){G===void 0&&this._handleMissing();return}var J=U.get(G);if(J!=null){var te=i(J),H=this._variables;this._variables=c(this._variables,te.argumentDefinitions,q.args),this._traverse(te,N),this._variables=H}else this._handleMissing()},j._checkScalar=function(q,N){var U=R(q,this._variables),W=this._mutator.getValue(N,U);W===void 0&&(W=this._handleMissingScalarField(q,N),W!==void 0&&this._mutator.setValue(N,U,W))},j._checkLink=function(q,N){var U=R(q,this._variables),W=this._mutator.getLinkedRecordID(N,U);W===void 0&&(W=this._handleMissingLinkField(q,N),W!=null?this._mutator.setLinkedRecordID(N,U,W):W===null&&this._mutator.setValue(N,U,null)),W!=null&&this._traverse(q,W)},j._checkPluralLink=function(q,N){var U=this,W=R(q,this._variables),G=this._mutator.getLinkedRecordIDs(N,W);G===void 0&&(G=this._handleMissingPluralLinkField(q,N),G!=null?this._mutator.setLinkedRecordIDs(N,W,G):G===null&&this._mutator.setValue(N,W,null)),G&&G.forEach(function(J){J!=null&&U._traverse(q,J)})},j._checkActorChange=function(q,N){var U=R(q,this._variables),W=this._source.get(N),G=W!=null?d.getActorLinkedRecordID(W,U):W;if(G==null)G===void 0&&this._handleMissing();else{var J=G[0],te=G[1],H=this._source,M=this._mutator,K=this._recordSourceProxy,X=this._getMutatorAndRecordProxyForActor(J),B=X[0],ne=X[1];this._source=this._getSourceForActor(J),this._mutator=B,this._recordSourceProxy=ne,this._assignClientAbstractTypes(q),this._traverse(q,te),this._source=H,this._mutator=M,this._recordSourceProxy=K}},j._assignClientAbstractTypes=function(q){var N=q.clientAbstractTypes;if(N!=null)for(var U=0,W=Object.keys(N);U<W.length;U++){var G=W[U],J=(0,t.default)(N[G]),te;try{for(J.s();!(te=J.n()).done;){var H=te.value,M=E(H);this._source.get(M)==null&&this._mutator.create(M,S),this._mutator.getValue(M,G)==null&&this._mutator.setValue(M,G,!0)}}catch(K){J.e(K)}finally{J.f()}}},L})();return jR={check:k},jR}var ZR,Wz;function a4e(){return Wz||(Wz=1,ZR=function(t){typeof t=="object"&&t!=null&&(Array.isArray(t)||t.constructor===Object)&&Object.freeze(t)}),ZR}var HR,Jz;function YJ(){if(Jz)return HR;Jz=1;var e=df(),t=_a(),n=t.RELAY_RESOLVER_OUTPUT_TYPE_RECORD_IDS,r=on();function i(a){var u=e.getValue(a,n);return u==null?null:(u instanceof Set||r(!1),u)}return HR=i,HR}var XR,eq;function u4e(){if(eq)return XR;eq=1;function e(t){return t!=null&&typeof t=="object"&&typeof t.read=="function"&&typeof t.subscribe=="function"}return XR=e,XR}var YR,tq;function l4e(){if(tq)return YR;tq=1;var e=Cn().default,t=e(Du()),n=SC(),r=oy(),i=r.RELAY_LIVE_RESOLVER,a=th(),u=a4e(),l=I0(),o=l.generateClientID,s=l.generateClientObjectClientID,c=df(),d=dp(),h=d.createNormalizationSelector,m=_b(),y=IJ(),v=y.normalize,_=_a(),S=_.RELAY_RESOLVER_ERROR_KEY,E=_.RELAY_RESOLVER_INVALIDATION_KEY,C=_.RELAY_RESOLVER_OUTPUT_TYPE_RECORD_IDS,T=_.RELAY_RESOLVER_SNAPSHOT_KEY,R=_.RELAY_RESOLVER_VALUE_KEY,$=_.getReadTimeResolverStorageKey,k=_.getStorageKey,F=YJ(),L=u4e(),j=_C(),V=j.isSuspenseSentinel,q=on();Qi();var N="__resolverLiveStateSubscription",U="__resolverLiveStateValue",W="__resolverLiveStateDirty",G="__RELAY_RESOLVER__",J="__relay_model_instance";function te(pe,_e,se){var me=pe.get(_e);me||(me=new Set,pe.set(_e,me)),me.add(se)}var H=(function(){function pe(se,me){this._resolverIDToRecordIDs=new Map,this._recordIDToResolverIDs=new Map,this._getRecordSource=se,this._store=me,this._handlingBatch=!1,this._liveResolverBatchRecordSource=null}var _e=pe.prototype;return _e.readFromCacheOrEvaluate=function(me,ge,we,Ne,Re){var et=this._getRecordSource(),tt=de(et,me),Oe=$(ge,we),$e=c.getLinkedRecordID(tt,Oe),Ae=$e==null?null:et.get($e),Ue;if(Ae==null||this._isInvalid(Ae,Re)){var Ze;Ae!=null&&ie(Ae),$e=(Ze=$e)!==null&&Ze!==void 0?Ze:o(me,Oe),Ae=c.create($e,G);var Ye=Ne();if(c.setValue(Ae,T,Ye.snapshot),c.setValue(Ae,S,Ye.error),ge.kind===i){if(Ye.resolverResult!=null){Ye.error!=null&&q(!1);var Me=Ye.resolverResult;Ue=this._setLiveStateValue(Ae,$e,Me,ge,we)}}else Ue=this._setResolverValue(Ae,Ye.resolverResult,ge,we);et.set($e,Ae);var ze=de(et,me),st=c.clone(ze);if(c.setLinkedRecordID(st,Oe,$e),et.set(me,st),ge.fragment!=null){var Ot,Nt=k(ge.fragment,we),gt=o(me,Nt);te(this._resolverIDToRecordIDs,gt,$e),te(this._recordIDToResolverIDs,me,gt);var qt=(Ot=Ye.snapshot)===null||Ot===void 0?void 0:Ot.seenRecords;if(qt!=null){var zt=(0,t.default)(qt),an;try{for(zt.s();!(an=zt.n()).done;){var rn=an.value;te(this._recordIDToResolverIDs,rn,gt)}}catch(Zn){zt.e(Zn)}finally{zt.f()}}}}else if(ge.kind===i&&c.getValue(Ae,W)){var Fe;$e=(Fe=$e)!==null&&Fe!==void 0?Fe:o(me,Oe),Ae=c.clone(Ae);var ht=c.getValue(Ae,U);L(ht)||q(!1),Ue=this._setLiveResolverValue(Ae,ht,ge,we),c.setValue(Ae,W,!1),et.set($e,Ae)}var Tt=this._getResolverValue(Ae),Qt=c.getValue(Ae,T),un=c.getValue(Ae,S),Ln=null;if(V(Tt)){var ln;Ln=(ln=$e)!==null&&ln!==void 0?ln:o(me,Oe)}return[Tt,$e,un,Qt,Ln,Ue]},_e.getLiveResolverPromise=function(me){var ge=this._getRecordSource(),we=ge.get(me);we==null&&q(!1);var Ne=c.getValue(we,U);return new Promise(function(Re){var et=Ne.subscribe(function(){et(),Re()})})},_e._setLiveStateValue=function(me,ge,we,Ne,Re){var et=this._makeLiveStateHandler(ge),tt=we.subscribe(et);c.setValue(me,U,we);var Oe=this._setLiveResolverValue(me,we,Ne,Re);return c.setValue(me,W,!1),c.setValue(me,N,tt),Oe},_e._makeLiveStateHandler=function(me){var ge=this;return function(){var we=ge._getRecordSource(),Ne=we.get(me);if(Ne&&c.hasValue(Ne,U)){var Re=c.clone(Ne);c.setValue(Re,W,!0),ge._setLiveResolverUpdate(me,Re)}}},_e._setLiveResolverUpdate=function(me,ge){if(this._handlingBatch)this._liveResolverBatchRecordSource==null&&(this._liveResolverBatchRecordSource=m.create()),this._liveResolverBatchRecordSource.set(me,ge);else{var we=m.create();we.set(me,ge),this._store.publish(we),this._store.notify()}},_e.batchLiveStateUpdates=function(me){this._handlingBatch&&q(!1),this._handlingBatch=!0;try{me()}finally{this._liveResolverBatchRecordSource!=null&&(this._store.publish(this._liveResolverBatchRecordSource),this._store.notify()),this._liveResolverBatchRecordSource=null,this._handlingBatch=!1}},_e._setLiveResolverValue=function(me,ge,we,Ne){var Re=null,et=null;try{Re=ge.read()}catch(tt){et=tt}return c.setValue(me,S,et),this._setResolverValue(me,Re,we,Ne)},_e._setResolverValue=function(me,ge,we,Ne){var Re=we.normalizationInfo,et=null;if(ge!=null&&Re!=null&&!V(ge)){var tt,Oe=F(me),$e=new Set,Ae=this._getRecordSource();if(Re.plural){Array.isArray(ge)||q(!1),tt=[];for(var Ue=m.create(),Ze=0;Ze<ge.length;Ze++){var Ye=ge[Ze];if(Ye!=null){typeof Ye!="object"&&q(!1);var Me=ve(Re,Ye),ze=s(Me,c.getDataID(me),Ze),st=this._normalizeOutputTypeValue(ze,Ye,Ne,Re,[we.path,String(Ze)],Me),Ot=(0,t.default)(st.getRecordIDs()),Nt;try{for(Ot.s();!(Nt=Ot.n()).done;){var gt=Nt.value;Ue.set(gt,de(st,gt)),$e.add(gt)}}catch(Tt){Ot.e(Tt)}finally{Ot.f()}tt.push(ze)}}et=M(Ae,Ue,Oe)}else{typeof ge!="object"&&q(!1);var qt=ve(Re,ge),zt=s(qt,c.getDataID(me)),an=this._normalizeOutputTypeValue(zt,ge,Ne,Re,[we.path],qt),rn=(0,t.default)(an.getRecordIDs()),Fe;try{for(rn.s();!(Fe=rn.n()).done;){var ht=Fe.value;$e.add(ht)}}catch(Tt){rn.e(Tt)}finally{rn.f()}tt=zt,et=M(Ae,an,Oe)}c.setValue(me,C,$e),u(tt),c.setValue(me,R,tt)}else u(ge),c.setValue(me,R,ge);return et},_e.notifyUpdatedSubscribers=function(me){this._store.__notifyUpdatedSubscribers(me)},_e._getResolverValue=function(me){return c.getValue(me,R)},_e.invalidateDataIDs=function(me){for(var ge=this._getRecordSource(),we=new Set,Ne=Array.from(me);Ne.length;){var Re=Ne.pop();we.add(Re),me.add(Re);var et=this._recordIDToResolverIDs.get(Re);if(et!=null){var tt=(0,t.default)(et),Oe;try{for(tt.s();!(Oe=tt.n()).done;){var $e=Oe.value;if(!we.has($e)){we.add($e);var Ae=this._resolverIDToRecordIDs.get($e);if(Ae==null)continue;var Ue=(0,t.default)(Ae),Ze;try{for(Ue.s();!(Ze=Ue.n()).done;){var Ye=Ze.value;X(Ye,ge),we.has(Ye)||(we.add(Ye),Ne.push(Ye))}}catch(Me){Ue.e(Me)}finally{Ue.f()}}}}catch(Me){tt.e(Me)}finally{tt.f()}}}},_e._isInvalid=function(me,ge){if(!c.getValue(me,E))return!1;var we=c.getValue(me,T),Ne=we==null?void 0:we.data,Re=we==null?void 0:we.selector;if(Ne==null||Re==null)return!0;var et=ge(Re),tt=et.data,Oe=n(Ne,tt);if(Oe!==Ne)return!0;if(a.MARK_RESOLVER_VALUES_AS_CLEAN_AFTER_FRAGMENT_REREAD){var $e=c.clone(me);c.setValue($e,E,!1);var Ae=this._getRecordSource();Ae.set(c.getDataID(me),$e)}return!1},_e._normalizeOutputTypeValue=function(me,ge,we,Ne,Re,et){var tt=m.create();switch(Ne.kind){case"OutputType":{var Oe=c.create(me,et);tt.set(me,Oe);var $e=h(Ne.normalizationNode,me,we),Ae=!1,Ue=this._store.__getNormalizationOptions(Re);return v(tt,$e,ge,Ue,void 0,Ae).source}case"WeakModel":{var Ze=c.create(me,et);return c.setValue(Ze,J,ge),tt.set(me,Ze),tt}default:Ne.kind,q(!1)}},_e.ensureClientRecord=function(me,ge){var we=s(ge,me),Ne=this._getRecordSource();if(!Ne.has(we)){var Re=c.create(we,ge);c.setValue(Re,"id",me),Ne.set(we,Re)}return we},_e.unsubscribeFromLiveResolverRecords=function(me){return ne(this._getRecordSource(),me)},_e.invalidateResolverRecords=function(me){if(me.size!==0){var ge=(0,t.default)(me),we;try{for(ge.s();!(we=ge.n()).done;){var Ne=we.value,Re=this._getRecordSource().get(Ne);Re!=null&&oe(Re)&&this._getRecordSource().delete(Ne)}}catch(et){ge.e(et)}finally{ge.f()}}},pe})();function M(pe,_e,se){var me=new Set;if(se!=null){var ge=(0,t.default)(se),we;try{for(ge.s();!(we=ge.n()).done;){var Ne=we.value;_e.has(Ne)||(me.add(Ne),pe.remove(Ne))}}catch(Ue){ge.e(Ue)}finally{ge.f()}}var Re=(0,t.default)(_e.getRecordIDs()),et;try{for(Re.s();!(et=Re.n()).done;){var tt=et.value,Oe=de(_e,tt);if(pe.has(tt)){var $e=de(pe,tt),Ae=c.update($e,Oe);Ae!==$e&&(me.add(tt),pe.set(tt,Ae),B($e,pe))}else pe.set(tt,Oe)}}catch(Ue){Re.e(Ue)}finally{Re.f()}return me}function K(pe){var _e=new Set;return c.getFields(pe).forEach(function(se){if(c.hasLinkedRecordID(pe,se)){var me=c.getLinkedRecordID(pe,se);me!=null&&_e.add(me)}else if(c.hasLinkedRecordIDs(pe,se)){var ge;(ge=c.getLinkedRecordIDs(pe,se))===null||ge===void 0||ge.forEach(function(we){we!=null&&_e.add(we)})}}),_e}function X(pe,_e){var se=_e.get(pe);if(se){var me=c.clone(se);c.setValue(me,E,!0),_e.set(pe,me)}}function B(pe,_e){var se=K(pe),me=(0,t.default)(se),ge;try{for(me.s();!(ge=me.n()).done;){var we=ge.value,Ne=_e.get(we);Ne!=null&&oe(Ne)&&X(we,_e)}}catch(Re){me.e(Re)}finally{me.f()}}function ne(pe,_e){if(_e.size!==0){var se=(0,t.default)(_e),me;try{for(se.s();!(me=se.n()).done;){var ge=me.value,we=pe.get(ge);we!=null&&oe(we)&&ie(we)}}catch(Ne){se.e(Ne)}finally{se.f()}}}function oe(pe){return c.getType(pe)===G}function ie(pe){var _e=c.getValue(pe,N);_e!=null&&_e()}function de(pe,_e){var se=pe.get(_e);return se==null&&q(!1),se}function be(pe){return pe}function ve(pe,_e){var se,me=(se=pe.concreteType)!==null&&se!==void 0?se:_e.__typename;return me==null&&q(!1),me}return YR={LiveResolverCache:H,getUpdatedDataIDs:be,RELAY_RESOLVER_LIVE_STATE_SUBSCRIPTION_KEY:N},YR}var GR,nq;function o4e(){if(nq)return GR;nq=1;var e=Cn().default,t=e(zi()),n=df(),r=_b(),i=on(),a=n.fromObject(Object.freeze({__UNPUBLISH_RECORD_SENTINEL:!0})),u=(function(){function s(d){this._base=d,this._sink=r.create()}var c=s.prototype;return c.has=function(h){if(this._sink.has(h)){var m=this._sink.get(h);return m!==a}else return this._base.has(h)},c.get=function(h){if(this._sink.has(h)){var m=this._sink.get(h);return m===a?void 0:m}else return this._base.get(h)},c.getStatus=function(h){var m=this.get(h);return m===void 0?"UNKNOWN":m===null?"NONEXISTENT":"EXISTENT"},c.clear=function(){this._base=r.create(),this._sink.clear()},c.delete=function(h){this._sink.delete(h)},c.remove=function(h){this._sink.set(h,a)},c.set=function(h,m){this._sink.set(h,m)},c.getRecordIDs=function(){return Object.keys(this.toJSON())},c.size=function(){return Object.keys(this.toJSON()).length},c.toJSON=function(){var h=this,m=(0,t.default)({},this._base.toJSON());return this._sink.getRecordIDs().forEach(function(y){var v=h.get(y);v===void 0?delete m[y]:m[y]=n.toJSON(v)}),m},c.getOptimisticRecordIDs=function(){return new Set(this._sink.getRecordIDs())},s})();function l(s){return new u(s)}function o(s){return s instanceof u||i(!1),s.getOptimisticRecordIDs()}return GR={create:l,getOptimisticRecordIDs:o},GR}var KR,rq;function s4e(){if(rq)return KR;rq=1;var e=oy(),t=e.RELAY_LIVE_RESOLVER,n=on(),r=(function(){function i(){}var a=i.prototype;return a.readFromCacheOrEvaluate=function(l,o,s,c,d){o.kind===t&&n(!1);var h=c(),m=h.resolverResult,y=h.snapshot,v=h.error;return[m,void 0,v,y,void 0,void 0]},a.invalidateDataIDs=function(l){},a.ensureClientRecord=function(l,o){n(!1)},a.notifyUpdatedSubscribers=function(l){},i})();return KR={NoopResolverCache:r},KR}var WR,iq;function UF(){if(iq)return WR;iq=1;var e=Cn().default,t=e(zi()),n=e(hc()),r=e(j3()),i=e(sy()),a=["message"],u=th(),l=_C(),o=l.isSuspenseSentinel,s=cy(),c=df(),d=_a(),h=d.CLIENT_EDGE_TRAVERSAL_PATH,m=d.FRAGMENT_OWNER_KEY,y=d.FRAGMENT_PROP_NAME_KEY,v=d.FRAGMENTS_KEY,_=d.ID_KEY,S=d.MODULE_COMPONENT_KEY,E=d.ROOT_ID,C=d.getArgumentValues,T=d.getModuleComponentKey,R=d.getStorageKey,$=s4e(),k=$.NoopResolverCache,F=IF(),L=F.RESOLVER_FRAGMENT_ERRORED_SENTINEL,j=F.withResolverContext,V=DC(),q=V.generateTypeID,N=on();function U(H,M,K,X){var B=new W(H,M,K??new k,X);return B.read()}var W=(function(){function H(K,X,B,ne){var oe,ie,de,be;this._clientEdgeTraversalPath=(oe=X.clientEdgeTraversalPath)!==null&&oe!==void 0&&oe.length?(0,i.default)(X.clientEdgeTraversalPath):[],this._missingClientEdges=[],this._missingLiveResolverFields=[],this._isMissingData=!1,this._isWithinUnmatchedTypeRefinement=!1,this._fieldErrors=null,this._owner=X.owner,this._useExecTimeResolvers=(ie=(de=this._owner.node.operation.use_exec_time_resolvers)!==null&&de!==void 0?de:((be=this._owner.node.operation.exec_time_resolvers_enabled_provider)===null||be===void 0?void 0:be.get())===!0)!==null&&ie!==void 0?ie:!1,this._recordSource=K,this._seenRecords=new Set,this._selector=X,this._variables=X.variables,this._resolverCache=B,this._fragmentName=X.node.name,this._updatedDataIDs=new Set,this._resolverContext=ne}var M=H.prototype;return M.read=function(){var X,B=this._selector,ne=B.node,oe=B.dataID,ie=B.isWithinUnmatchedTypeRefinement,de=ne.abstractKey,be=this._recordSource.get(oe),ve=!ie;if(ve&&de==null&&be!=null&&(this._recordMatchesTypeCondition(be,ne.type)||(ve=!1)),ve&&de!=null&&be!=null){var pe=this._implementsInterface(be,de);pe===!1&&(ve=!1)}this._isWithinUnmatchedTypeRefinement=!ve;var _e=this._traverse(ne,oe,null),se=(X=this._selector.node.metadata)===null||X===void 0?void 0:X.catchTo;return se!=null&&(_e=this._catchErrors(_e,se,null)),this._updatedDataIDs.size>0&&(this._resolverCache.notifyUpdatedSubscribers(this._updatedDataIDs),this._updatedDataIDs.clear()),{data:_e,isMissingData:this._isMissingData&&ve,missingClientEdges:this._missingClientEdges.length?this._missingClientEdges:null,missingLiveResolverFields:this._missingLiveResolverFields,seenRecords:this._seenRecords,selector:this._selector,fieldErrors:this._fieldErrors}},M._maybeAddFieldErrors=function(X,B){var ne=c.getErrors(X,B);if(ne!=null){var oe=this._fragmentName;this._fieldErrors==null&&(this._fieldErrors=[]);for(var ie=0;ie<ne.length;ie++){var de,be,ve,pe=ne[ie];this._fieldErrors.push({kind:"relay_field_payload.error",owner:oe,fieldPath:((de=pe.path)!==null&&de!==void 0?de:[]).join("."),error:pe,shouldThrow:(be=(ve=this._selector.node.metadata)===null||ve===void 0?void 0:ve.throwOnFieldError)!==null&&be!==void 0?be:!1,handled:!1,uiContext:void 0})}}},M._markDataAsMissing=function(X){var B,ne;if(!this._isWithinUnmatchedTypeRefinement){this._fieldErrors==null&&(this._fieldErrors=[]);var oe=this._fragmentName;if(this._fieldErrors.push((B=(ne=this._selector.node.metadata)===null||ne===void 0?void 0:ne.throwOnFieldError)!==null&&B!==void 0&&B?{kind:"missing_expected_data.throw",owner:oe,fieldPath:X,handled:!1,uiContext:void 0}:{kind:"missing_expected_data.log",owner:oe,fieldPath:X,uiContext:void 0}),this._isMissingData=!0,this._clientEdgeTraversalPath.length){var ie=this._clientEdgeTraversalPath[this._clientEdgeTraversalPath.length-1];ie!==null&&this._missingClientEdges.push({request:ie.readerClientEdge.operation,clientEdgeDestinationID:ie.clientEdgeDestinationID})}}},M._traverse=function(X,B,ne){var oe=this._recordSource.get(B);if(this._seenRecords.add(B),oe==null)return oe===void 0&&this._markDataAsMissing("<record>"),oe;var ie=ne||{},de=this._traverseSelections(X.selections,oe,ie);return de?ie:null},M._getVariableValue=function(X){return this._variables.hasOwnProperty(X)||N(!1),this._variables[X]},M._maybeReportUnexpectedNull=function(X){if(X.action!=="NONE"){var B=this._fragmentName;this._fieldErrors==null&&(this._fieldErrors=[]);var ne;if(X.field.linkedField!=null){var oe;ne=(oe=X.field.linkedField.alias)!==null&&oe!==void 0?oe:X.field.linkedField.name}else{var ie;ne=(ie=X.field.alias)!==null&&ie!==void 0?ie:X.field.name}switch(X.action){case"THROW":this._fieldErrors.push({kind:"missing_required_field.throw",fieldPath:ne,owner:B,handled:!1,uiContext:void 0});return;case"LOG":this._fieldErrors.push({kind:"missing_required_field.log",fieldPath:ne,owner:B,uiContext:void 0});return;default:X.action}}},M._handleRequiredFieldValue=function(X,B){return B==null?(this._maybeReportUnexpectedNull(X),!1):!0},M._catchErrors=function(X,B,ne){var oe=X;switch(B){case"RESULT":oe=this._asResult(X);break;case"NULL":this._fieldErrors!=null&&this._fieldErrors.length>0&&(oe=null);break}var ie=this._fieldErrors;if(this._fieldErrors=ne,ie!=null){this._fieldErrors==null&&(this._fieldErrors=[]);for(var de=0;de<ie.length;de++)this._fieldErrors.push(G(ie[de]))}return oe},M._asResult=function(X){if(this._fieldErrors==null||this._fieldErrors.length===0)return{ok:!0,value:X};var B=this._fieldErrors.map(function(ne){switch(ne.kind){case"relay_field_payload.error":var oe=ne.error;oe.message;var ie=(0,r.default)(oe,a);return ie;case"missing_expected_data.throw":case"missing_expected_data.log":return{path:ne.fieldPath.split(".")};case"relay_resolver.error":return{message:"Relay: Error in resolver for field at ".concat(ne.fieldPath," in ").concat(ne.owner)};case"missing_required_field.throw":return{message:"Relay: Missing @required value at path '".concat(ne.fieldPath,"' in '").concat(ne.owner,"'.")};case"missing_required_field.log":return null;default:ne.kind,N(!1)}}).filter(Boolean);return{ok:!1,errors:B}},M._traverseSelections=function(X,B,ne){for(var oe=0;oe<X.length;oe++){var ie=X[oe];switch(ie.kind){case"RequiredField":var de=this._readClientSideDirectiveField(ie,B,ne);if(!this._handleRequiredFieldValue(ie,de))return!1;break;case"CatchField":{var be,ve,pe,_e=this._fieldErrors;this._fieldErrors=null;var se=this._readClientSideDirectiveField(ie,B,ne),me=(be=(ve=ie.field)===null||ve===void 0?void 0:ve.backingField)!==null&&be!==void 0?be:ie.field,ge=(pe=me==null?void 0:me.alias)!==null&&pe!==void 0?pe:me==null?void 0:me.name;ge==null&&N(!1),ne[ge]=this._catchErrors(se,ie.to,_e);break}case"ScalarField":this._readScalar(ie,B,ne);break;case"LinkedField":ie.plural?this._readPluralLink(ie,B,ne):this._readLink(ie,B,ne);break;case"Condition":var we=!!this._getVariableValue(ie.condition);if(we===ie.passingValue){var Ne=this._traverseSelections(ie.selections,B,ne);if(!Ne)return!1}break;case"InlineFragment":{var Re=this._readInlineFragment(ie,B,ne,!1);if(Re===!1)return!1;break}case"RelayLiveResolver":case"RelayResolver":{this._useExecTimeResolvers?this._readScalar(ie,B,ne):this._readResolverField(ie,B,ne);break}case"FragmentSpread":this._createFragmentPointer(ie,B,ne);break;case"AliasedInlineFragmentSpread":{this._readAliasedInlineFragment(ie,B,ne);break}case"ModuleImport":this._readModuleImport(ie,B,ne);break;case"InlineDataFragmentSpread":this._createInlineDataOrResolverFragmentPointer(ie,B,ne);break;case"Defer":case"ClientExtension":{var et=this._isMissingData,tt=this._missingClientEdges.length;this._clientEdgeTraversalPath.push(null);var Oe=this._traverseSelections(ie.selections,B,ne);if(this._isMissingData=et||this._missingClientEdges.length>tt||this._missingLiveResolverFields.length>0,this._clientEdgeTraversalPath.pop(),!Oe)return!1;break}case"Stream":{var $e=this._traverseSelections(ie.selections,B,ne);if(!$e)return!1;break}case"ActorChange":this._readActorChange(ie,B,ne);break;case"ClientEdgeToClientObject":case"ClientEdgeToServerObject":if(this._useExecTimeResolvers&&(ie.backingField.kind==="RelayResolver"||ie.backingField.kind==="RelayLiveResolver")){var Ae=ie.linkedField;Ae.plural?this._readPluralLink(Ae,B,ne):this._readLink(Ae,B,ne)}else this._readClientEdge(ie,B,ne);break;default:N(!1)}}return!0},M._readClientSideDirectiveField=function(X,B,ne){switch(X.field.kind){case"ScalarField":return this._readScalar(X.field,B,ne);case"LinkedField":return X.field.plural?this._readPluralLink(X.field,B,ne):this._readLink(X.field,B,ne);case"RelayResolver":case"RelayLiveResolver":return this._useExecTimeResolvers?this._readScalar(X.field,B,ne):this._readResolverField(X.field,B,ne);case"ClientEdgeToClientObject":case"ClientEdgeToServerObject":if(this._useExecTimeResolvers&&(X.field.backingField.kind==="RelayResolver"||X.field.backingField.kind==="RelayLiveResolver")){var oe=X.field;return oe.linkedField.plural?this._readPluralLink(oe.linkedField,B,ne):this._readLink(oe.linkedField,B,ne)}else return this._readClientEdge(X.field,B,ne);case"AliasedInlineFragmentSpread":return this._readAliasedInlineFragment(X.field,B,ne);default:X.field.kind,N(!1)}},M._readResolverField=function(X,B,ne){var oe,ie=c.getDataID(B),de=this._fieldErrors;this._fieldErrors=null;var be=this._readResolverFieldImpl(X,ie),ve=(oe=X.alias)!==null&&oe!==void 0?oe:X.name;return this._prependPreviousErrors(de,ve),ne[ve]=be,be},M._readResolverFieldImpl=function(X,B){var ne=this,oe=X.fragment,ie,de=function(Re){return ie!=null?{data:ie.data,isMissingData:ie.isMissingData,fieldErrors:ie.fieldErrors}:(ie=U(ne._recordSource,Re,ne._resolverCache),{data:ie.data,isMissingData:ie.isMissingData,fieldErrors:ie.fieldErrors})},be=function(){if(oe!=null){var Re={__id:B,__fragmentOwner:ne._owner,__fragments:(0,n.default)({},oe.name,oe.args?C(oe.args,ne._variables):{})};ne._clientEdgeTraversalPath.length>0&&ne._clientEdgeTraversalPath[ne._clientEdgeTraversalPath.length-1]!==null&&(Re[h]=(0,i.default)(ne._clientEdgeTraversalPath));var et={getDataForResolverFragment:de};return j(et,function(){var Ae=J(X,ne._variables,Re,ne._resolverContext),Ue=Ae[0],Ze=Ae[1];return{resolverResult:Ue,snapshot:ie,error:Ze}})}else{var tt=J(X,ne._variables,null,ne._resolverContext),Oe=tt[0],$e=tt[1];return{resolverResult:Oe,snapshot:void 0,error:$e}}},ve=this._resolverCache.readFromCacheOrEvaluate(B,X,this._variables,be,de),pe=ve[0],_e=ve[1],se=ve[2],me=ve[3],ge=ve[4],we=ve[5];return this._propagateResolverMetadata(X.path,me,se,_e,ge,we),pe},M._propagateResolverMetadata=function(X,B,ne,oe,ie,de){var be=this;if(B!=null){if(B.missingClientEdges!=null)for(var ve=0;ve<B.missingClientEdges.length;ve++){var pe=B.missingClientEdges[ve];this._missingClientEdges.push(pe)}if(B.missingLiveResolverFields!=null){this._isMissingData=this._isMissingData||B.missingLiveResolverFields.length>0;for(var _e=0;_e<B.missingLiveResolverFields.length;_e++){var se=B.missingLiveResolverFields[_e];this._missingLiveResolverFields.push(se)}}if(B.fieldErrors!=null){this._fieldErrors==null&&(this._fieldErrors=[]);for(var me=0;me<B.fieldErrors.length;me++){var ge,we=B.fieldErrors[me];((ge=this._selector.node.metadata)===null||ge===void 0?void 0:ge.throwOnFieldError)===!0?this._fieldErrors.push(we):this._fieldErrors.push(G(we))}}this._isMissingData=this._isMissingData||B.isMissingData}if(ne){var Ne,Re,et={kind:"relay_resolver.error",fieldPath:X,owner:this._fragmentName,error:ne,shouldThrow:(Ne=(Re=this._selector.node.metadata)===null||Re===void 0?void 0:Re.throwOnFieldError)!==null&&Ne!==void 0?Ne:!1,handled:!1,uiContext:void 0};this._fieldErrors==null?this._fieldErrors=[et]:this._fieldErrors.push(et)}oe!=null&&this._seenRecords.add(oe),ie!=null&&(this._isMissingData=!0,this._missingLiveResolverFields.push(ie)),de!=null&&de.forEach(function(tt){be._updatedDataIDs.add(tt)})},M._readClientEdge=function(X,B,ne){var oe=this,ie,de=X.backingField;de.kind==="ClientExtension"&&N(!1);var be=(ie=de.alias)!==null&&ie!==void 0?ie:de.name,ve={};this._traverseSelections([de],B,ve);var pe=ve[be];if(pe==null||o(pe))return ne[be]=pe,pe;if(X.linkedField.plural){Array.isArray(pe)||N(!1);var _e;X.kind!=="ClientEdgeToClientObject"&&N(!1),X.backingField.normalizationInfo==null?_e=pe.map(function(Ze){var Ye,Me=(Ye=X.concreteType)!==null&&Ye!==void 0?Ye:Ze.__typename;typeof Me!="string"&&N(!1);var ze=te(Ze,de.path,oe._owner.identifier),st=oe._resolverCache.ensureClientRecord(ze,Me),Ot=X.modelResolvers;if(Ot!=null){var Nt=Ot[Me];Nt===void 0&&N(!1);var gt=oe._readResolverFieldImpl(Nt,st);return gt!=null?st:null}return st}):_e=pe.map(function(Ze){return te(Ze,de.path,oe._owner.identifier)}),this._clientEdgeTraversalPath.push(null);var se=this._readLinkedIds(X.linkedField,_e,B,ne);return this._clientEdgeTraversalPath.pop(),ne[be]=se,se}else{var me,ge=te(pe,de.path,this._owner.identifier),we,Ne=(me=X.concreteType)!==null&&me!==void 0?me:pe.__typename,Re;X.kind==="ClientEdgeToClientObject"?X.backingField.normalizationInfo==null?(typeof Ne!="string"&&N(!1),we=this._resolverCache.ensureClientRecord(ge,Ne),Re=null):(we=ge,Re=null):(we=ge,Re={readerClientEdge:X,clientEdgeDestinationID:ge});var et=X.modelResolvers;if(et!=null){typeof Ne!="string"&&N(!1);var tt=et[Ne];tt===void 0&&N(!1);var Oe=this._readResolverFieldImpl(tt,we);if(Oe==null)return ne[be]=null,null}this._clientEdgeTraversalPath.push(Re);var $e=ne[be];$e==null||typeof $e=="object"||N(!1);var Ae=this._fieldErrors;this._fieldErrors=null;var Ue=this._traverse(X.linkedField,we,$e);return this._prependPreviousErrors(Ae,be),this._clientEdgeTraversalPath.pop(),ne[be]=Ue,Ue}},M._readScalar=function(X,B,ne){var oe,ie=(oe=X.alias)!==null&&oe!==void 0?oe:X.name,de=R(X,this._variables),be=c.getValue(B,de);return be===null||u.ENABLE_NONCOMPLIANT_ERROR_HANDLING_ON_LISTS&&Array.isArray(be)&&be.length===0?this._maybeAddFieldErrors(B,de):be===void 0&&this._markDataAsMissing(ie),ne[ie]=be,be},M._readLink=function(X,B,ne){var oe,ie=(oe=X.alias)!==null&&oe!==void 0?oe:X.name,de=R(X,this._variables),be=c.getLinkedRecordID(B,de);if(be==null)return ne[ie]=be,be===null?this._maybeAddFieldErrors(B,de):be===void 0&&this._markDataAsMissing(ie),be;var ve=ne[ie];ve==null||typeof ve=="object"||N(!1);var pe=this._fieldErrors;this._fieldErrors=null;var _e=this._traverse(X,be,ve);return this._prependPreviousErrors(pe,ie),ne[ie]=_e,_e},M._prependPreviousErrors=function(X,B){if(this._fieldErrors!=null){for(var ne=0;ne<this._fieldErrors.length;ne++){var oe=this._fieldErrors[ne];oe.owner===this._fragmentName&&(oe.kind==="missing_expected_data.throw"||oe.kind==="missing_expected_data.log"||oe.kind==="missing_required_field.throw"||oe.kind==="missing_required_field.log")&&(oe.fieldPath="".concat(B,".").concat(oe.fieldPath))}if(X!=null){for(var ie=this._fieldErrors.length-1;ie>=0;ie--)X.push(this._fieldErrors[ie]);this._fieldErrors=X}}else this._fieldErrors=X},M._readActorChange=function(X,B,ne){var oe,ie=(oe=X.alias)!==null&&oe!==void 0?oe:X.name,de=R(X,this._variables),be=c.getActorLinkedRecordID(B,de);if(be==null)return ne[ie]=be,be===void 0?this._markDataAsMissing(ie):be===null&&this._maybeAddFieldErrors(B,de),ne[ie];var ve=be[0],pe=be[1],_e={};return this._createFragmentPointer(X.fragmentSpread,c.fromObject({__id:pe}),_e),ne[ie]={__fragmentRef:_e,__viewer:ve},ne[ie]},M._readPluralLink=function(X,B,ne){var oe=R(X,this._variables),ie=c.getLinkedRecordIDs(B,oe);return(ie===null||u.ENABLE_NONCOMPLIANT_ERROR_HANDLING_ON_LISTS&&Array.isArray(ie)&&ie.length===0)&&this._maybeAddFieldErrors(B,oe),this._readLinkedIds(X,ie,B,ne)},M._readLinkedIds=function(X,B,ne,oe){var ie=this,de,be=(de=X.alias)!==null&&de!==void 0?de:X.name;if(B==null)return oe[be]=B,B===void 0&&this._markDataAsMissing(be),B;var ve=oe[be];ve==null||Array.isArray(ve)||N(!1);var pe=this._fieldErrors;this._fieldErrors=null;var _e=ve||[];return B.forEach(function(se,me){if(se==null){se===void 0&&ie._markDataAsMissing(String(me)),_e[me]=se;return}var ge=_e[me];ge==null||typeof ge=="object"||N(!1);var we=ie._fieldErrors;ie._fieldErrors=null,_e[me]=ie._traverse(X,se,ge),ie._prependPreviousErrors(we,me)}),this._prependPreviousErrors(pe,be),oe[be]=_e,_e},M._readModuleImport=function(X,B,ne){var oe=T(X.documentName),ie=c.getValue(B,oe),de=ie!==void 0?ie:X.componentModuleProvider;if(de==null){de===void 0&&this._markDataAsMissing("<module-import>");return}this._createFragmentPointer({kind:"FragmentSpread",name:X.fragmentName,args:X.args},B,ne),ne[y]=X.fragmentPropName,ne[S]=de},M._readAliasedInlineFragment=function(X,B,ne){var oe=this._fieldErrors;this._fieldErrors=null;var ie=this._readInlineFragment(X.fragment,B,{},!0);this._prependPreviousErrors(oe,X.name),ie===!1&&(ie=null),ne[X.name]=ie},M._readInlineFragment=function(X,B,ne,oe){if(X.type==null){var ie=this._traverseSelections(X.selections,B,ne);return ie===!1?!1:ne}var de=X.abstractKey;if(de==null)if(this._recordMatchesTypeCondition(B,X.type)){var ie=this._traverseSelections(X.selections,B,ne);if(!ie)return!1}else return null;else{var be=this._implementsInterface(B,de);if(be===!1&&oe)return null;var ve=this._isMissingData,pe=this._isWithinUnmatchedTypeRefinement;this._isWithinUnmatchedTypeRefinement=pe||be===!1;var _e=this._traverseSelections(X.selections,B,ne);if(this._isWithinUnmatchedTypeRefinement=pe,be===!1)return this._isMissingData=ve,null;if(be==null)return;if(_e===!1)return!1}return ne},M._recordMatchesTypeCondition=function(X,B){var ne=c.getType(X);return ne!=null&&ne===B||c.getDataID(X)===E},M._createFragmentPointer=function(X,B,ne){var oe=ne[v];oe==null&&(oe=ne[v]={}),typeof oe=="object"&&oe!=null||N(!1),ne[_]==null&&(ne[_]=c.getDataID(B)),oe[X.name]=C(X.args,this._variables,this._isWithinUnmatchedTypeRefinement),ne[m]=this._owner,this._clientEdgeTraversalPath.length>0&&this._clientEdgeTraversalPath[this._clientEdgeTraversalPath.length-1]!==null&&(ne[h]=(0,i.default)(this._clientEdgeTraversalPath))},M._createInlineDataOrResolverFragmentPointer=function(X,B,ne){var oe=ne[v];oe==null&&(oe=ne[v]={}),typeof oe=="object"&&oe!=null||N(!1),ne[_]==null&&(ne[_]=c.getDataID(B));var ie={},de=this._fragmentName;this._fragmentName=X.name;var be=this._variables,ve=X.args?C(X.args,this._variables):{};this._variables=s.getFragmentVariables(X,this._owner.variables,ve),this._traverseSelections(X.selections,B,ie),this._variables=be,this._fragmentName=de,oe[X.name]=ie},M._implementsInterface=function(X,B){var ne=c.getType(X),oe=this._recordSource.get(q(ne)),ie=oe!=null?c.getValue(oe,B):null;return ie==null&&this._markDataAsMissing("<abstract-type-hint>"),ie},H})();function G(H){switch(H.kind){case"missing_expected_data.throw":case"missing_required_field.throw":case"relay_field_payload.error":case"relay_resolver.error":return(0,t.default)((0,t.default)({},H),{},{handled:!0});case"missing_expected_data.log":case"missing_required_field.log":return H;default:H.kind,N(!1)}}function J(H,M,K,X){var B=typeof H.resolverModule=="function"?H.resolverModule:H.resolverModule.default,ne=null,oe=null;try{var ie=[];H.fragment!=null&&ie.push(K);var de=H.args?C(H.args,M):void 0;ie.push(de),ie.push(X),ne=B.apply(null,ie)}catch(be){ne=null,be!==L&&(oe=be)}return[ne,oe]}function te(H,M,K){if(typeof H=="string")return H;if(typeof H=="object"&&H!=null&&typeof H.id=="string")return H.id;N(!1)}return WR={read:U},WR}var JR,aq;function c4e(){if(aq)return JR;aq=1;var e=Cn().default,t=e(Du()),n=VF(),r=XJ(),i=YJ(),a=cy(),u=a.getLocalVariables,l=df(),o=_a(),s=DC(),c=s.generateTypeID,d=on(),h=o.getReadTimeResolverStorageKey,m=o.getStorageKey,y=o.getModuleOperationKey;function v(S,E,C,T,R,$){var k=E.dataID,F=E.node,L=E.variables,j=new _(S,L,C,T,R,$);j.mark(F,k)}var _=(function(){function S(C,T,R,$,k,F){this._operationLoader=$??null,this._operationName=null,this._useExecTimeResolvers=F??!1,this._recordSource=C,this._references=R,this._variables=T,this._shouldProcessClientComponents=k}var E=S.prototype;return E.mark=function(T,R){(T.kind==="Operation"||T.kind==="SplitOperation")&&(this._operationName=T.name),this._traverse(T,R)},E._traverse=function(T,R){this._references.add(R);var $=this._recordSource.get(R);$!=null&&this._traverseSelections(T.selections,$)},E._getVariableValue=function(T){return this._variables.hasOwnProperty(T)||d(!1),this._variables[T]},E._traverseSelections=function(T,R){var $=this;T.forEach(function(k){switch(k.kind){case"ActorChange":$._traverseLink(k.linkedField,R);break;case"LinkedField":k.plural?$._traversePluralLink(k,R):$._traverseLink(k,R);break;case"Condition":var F=!!$._getVariableValue(k.condition);F===k.passingValue&&$._traverseSelections(k.selections,R);break;case"InlineFragment":if(k.abstractKey==null){var L=l.getType(R);(L!=null&&L===k.type||L===o.ROOT_TYPE)&&$._traverseSelections(k.selections,R)}else{var j=l.getType(R),V=c(j);$._references.add(V),$._traverseSelections(k.selections,R)}break;case"FragmentSpread":var q=$._variables;$._variables=u($._variables,k.fragment.argumentDefinitions,k.args),$._traverseSelections(k.fragment.selections,R),$._variables=q;break;case"LinkedHandle":var N=r(k,T,$._variables);N.plural?$._traversePluralLink(N,R):$._traverseLink(N,R);break;case"Defer":case"Stream":$._traverseSelections(k.selections,R);break;case"ScalarField":case"ScalarHandle":break;case"TypeDiscriminator":{var U=l.getType(R),W=c(U);$._references.add(W);break}case"ModuleImport":$._traverseModuleImport(k,R);break;case"ClientExtension":$._traverseSelections(k.selections,R);break;case"ClientComponent":if($._shouldProcessClientComponents===!1)break;$._traverseSelections(k.fragment.selections,R);break;case"RelayResolver":case"RelayLiveResolver":$._traverseResolverField(k,R);break;case"ClientEdgeToClientObject":$._traverseClientEdgeToClientObject(k,R);break;default:d(!1)}})},E._traverseClientEdgeToClientObject=function(T,R){if(this._useExecTimeResolvers){this._traverseLink(T.linkedField,R);return}var $=this._traverseResolverField(T.backingField,R);if($!=null){var k=this._recordSource.get($);if(k!=null)if(T.backingField.isOutputType){var F=i(k);if(F!=null){var L=(0,t.default)(F),j;try{for(L.s();!(j=L.n()).done;){var V=j.value;this._references.add(V)}}catch(H){L.e(H)}finally{L.f()}}}else{var q=T.linkedField,N=q.concreteType;if(N==null)return;if(q.plural){var U=l.getResolverLinkedRecordIDs(k,N);if(U!=null){var W=(0,t.default)(U),G;try{for(W.s();!(G=W.n()).done;){var J=G.value;J!=null&&this._traverse(q,J)}}catch(H){W.e(H)}finally{W.f()}}}else{var te=l.getResolverLinkedRecordID(k,N);te!=null&&this._traverse(q,te)}}}},E._traverseResolverField=function(T,R){if(!this._useExecTimeResolvers){var $=h(T,this._variables),k=l.getLinkedRecordID(R,$);k!=null&&this._references.add(k);var F=T.fragment;return F!=null&&this._traverseSelections([F],R),k}},E._traverseModuleImport=function(T,R){var $=this._operationLoader;$===null&&d(!1);var k=y(T.documentName),F=l.getValue(R,k);if(F!=null){var L=$.get(F);if(L!=null){var j=n(L),V=this._variables;this._variables=u(this._variables,j.argumentDefinitions,T.args),this._traverseSelections(j.selections,R),this._variables=V}}},E._traverseLink=function(T,R){var $=m(T,this._variables),k=l.getLinkedRecordID(R,$);k!=null&&this._traverse(T,k)},E._traversePluralLink=function(T,R){var $=this,k=m(T,this._variables),F=l.getLinkedRecordIDs(R,k);F!=null&&F.forEach(function(L){L!=null&&$._traverse(T,L)})},S})();return JR={mark:v},JR}var eA,uq;function f4e(){if(uq)return eA;uq=1;var e=Symbol.iterator;function t(n,r){for(var i=n[e](),a=i.next();!a.done;){var u=a.value;if(r.has(u))return!0;a=i.next()}return!1}return eA=t,eA}var tA,lq;function d4e(){if(lq)return tA;lq=1;var e=_a(),t=e.ROOT_ID,n=qF(),r=n.VIEWER_ID,i=Symbol.iterator;function a(u,l){for(var o=u[i](),s=o.next();!s.done;){var c=s.value;if(l.has(c)&&c!==t&&c!==r)return!0;s=o.next()}return!1}return tA=a,tA}var nA,oq;function h4e(){if(oq)return nA;oq=1,iS();var e=SC(),t=th(),n=f4e(),r=d4e(),i=UF(),a=(function(){function u(o,s,c){this._subscriptions=new Set,this.__log=o,this._resolverCache=s,this._resolverContext=c}var l=u.prototype;return l.subscribe=function(s,c){var d=this,h={backup:null,callback:c,snapshot:s,stale:!1},m=function(){d._subscriptions.delete(h)};return this._subscriptions.add(h),{dispose:m}},l.snapshotSubscriptions=function(s){var c=this;this._subscriptions.forEach(function(d){if(!d.stale){d.backup=d.snapshot;return}var h=d.snapshot,m=i.read(s,h.selector,c._resolverCache,c._resolverContext),y=e(h.data,m.data);m.data=y,d.backup=m})},l.restoreSubscriptions=function(){this._subscriptions.forEach(function(s){var c=s.backup;s.backup=null,c?(c.data!==s.snapshot.data&&(s.stale=!0),s.snapshot={data:s.snapshot.data,isMissingData:c.isMissingData,missingClientEdges:c.missingClientEdges,missingLiveResolverFields:c.missingLiveResolverFields,seenRecords:c.seenRecords,selector:c.selector,fieldErrors:c.fieldErrors}):s.stale=!0})},l.updateSubscriptions=function(s,c,d,h){var m=this,y=c.size!==0;this._subscriptions.forEach(function(v){var _=m._updateSubscription(s,v,c,y,h);_!=null&&d.push(_)})},l._updateSubscription=function(s,c,d,h,m){var y=c.backup,v=c.callback,_=c.snapshot,S=c.stale,E=h&&n(_.seenRecords,d);if(!(!S&&!E)){var C=E||!y?i.read(s,_.selector,this._resolverCache,this._resolverContext):y,T=e(_.data,C.data);if(C={data:T,isMissingData:C.isMissingData,missingClientEdges:C.missingClientEdges,missingLiveResolverFields:C.missingLiveResolverFields,seenRecords:C.seenRecords,selector:C.selector,fieldErrors:C.fieldErrors},c.snapshot=C,c.stale=!1,C.data!==_.data)return this.__log&&t.ENABLE_NOTIFY_SUBSCRIPTION&&this.__log({name:"store.notify.subscription",sourceOperation:m,snapshot:_,nextSnapshot:C}),v(C),_.selector.owner;if(t.ENABLE_LOOSE_SUBSCRIPTION_ATTRIBUTION&&(S||r(_.seenRecords,d)))return _.selector.owner}},l.size=function(){return this._subscriptions.size},u})();return nA=a,nA}var rA,sq;function GJ(){if(sq)return rA;sq=1;var e=Cn().default,t=e(Du()),n=e(hc()),r=zF(),i=r.INTERNAL_ACTOR_IDENTIFIER_DO_NOT_USE,a=r.assertInternalActorIdentifier;iS();var u=t4e(),l=i4e(),o=zJ(),s=l4e(),c=s.LiveResolverCache,d=s.RELAY_RESOLVER_LIVE_STATE_SUBSCRIPTION_KEY,h=s.getUpdatedDataIDs,m=df(),y=o4e(),v=UF(),_=c4e(),S=h4e(),E=_a(),C=_a(),T=C.ROOT_ID,R=C.ROOT_TYPE,$=on(),k=10,F=(function(){function q(U,W){var G=this,J,te,H,M,K,X,B,ne;(0,n.default)(this,"_gcStep",function(){G._gcRun&&(G._gcRun.next().done?G._gcRun=null:G._gcScheduler(G._gcStep))}),this._currentWriteEpoch=0,this._gcHoldCounter=0,this._gcReleaseBufferSize=(J=W==null?void 0:W.gcReleaseBufferSize)!==null&&J!==void 0?J:k,this._shouldRetainWithinTTL_EXPERIMENTAL=(te=W==null?void 0:W.shouldRetainWithinTTL_EXPERIMENTAL)!==null&&te!==void 0?te:!1,this._gcRun=null,this._gcScheduler=(H=W==null?void 0:W.gcScheduler)!==null&&H!==void 0?H:u,this._getDataID=(M=W==null?void 0:W.getDataID)!==null&&M!==void 0?M:o,this._globalInvalidationEpoch=null,this._invalidationSubscriptions=new Set,this._invalidatedRecordIDs=new Set,this.__log=(K=W==null?void 0:W.log)!==null&&K!==void 0?K:null,this._queryCacheExpirationTime=W==null?void 0:W.queryCacheExpirationTime,this._operationLoader=(X=W==null?void 0:W.operationLoader)!==null&&X!==void 0?X:null,this._optimisticSource=null,this._recordSource=U,this._releaseBuffer=[],this._roots=new Map,this._shouldScheduleGC=!1,this._resolverCache=new c(function(){return G._getMutableRecordSource()},this),this._resolverContext=W==null?void 0:W.resolverContext,this._storeSubscriptions=new S(W==null?void 0:W.log,this._resolverCache,this._resolverContext),this._updatedRecordIDs=new Set,this._shouldProcessClientComponents=(B=W==null?void 0:W.shouldProcessClientComponents)!==null&&B!==void 0?B:!1,this._treatMissingFieldsAsNull=(ne=W==null?void 0:W.treatMissingFieldsAsNull)!==null&&ne!==void 0?ne:!1,this._actorIdentifier=W==null?void 0:W.actorIdentifier,L(this._recordSource)}var N=q.prototype;return N.getSource=function(){var W;return(W=this._optimisticSource)!==null&&W!==void 0?W:this._recordSource},N.getOperationLoader=function(){return this._operationLoader},N._getMutableRecordSource=function(){var W;return(W=this._optimisticSource)!==null&&W!==void 0?W:this._recordSource},N.getLiveResolverPromise=function(W){return this._resolverCache.getLiveResolverPromise(W)},N.batchLiveStateUpdates=function(W){this.__log!=null&&this.__log({name:"liveresolver.batch.start"});try{this._resolverCache.batchLiveStateUpdates(W)}finally{this.__log!=null&&this.__log({name:"liveresolver.batch.end"})}},N.check=function(W,G){var J,te,H,M,K,X,B,ne=W.root,oe=this._getMutableRecordSource(),ie=this._globalInvalidationEpoch,de=(J=(te=W.request.node.operation.use_exec_time_resolvers)!==null&&te!==void 0?te:((H=W.request.node.operation.exec_time_resolvers_enabled_provider)===null||H===void 0?void 0:H.get())===!0)!==null&&J!==void 0?J:!1,be=this._roots.get(W.request.identifier),ve=be!=null?be.epoch:null;if(ie!=null&&(ve==null||ve<=ie))return{status:"stale"};var pe=(M=G==null?void 0:G.handlers)!==null&&M!==void 0?M:[],_e=(K=G==null?void 0:G.getSourceForActor)!==null&&K!==void 0?K:function(ge){return a(ge),oe},se=(X=G==null?void 0:G.getTargetForActor)!==null&&X!==void 0?X:function(ge){return a(ge),oe},me=l.check(_e,se,(B=G==null?void 0:G.defaultActorIdentifier)!==null&&B!==void 0?B:i,ne,pe,this._operationLoader,this._getDataID,this._shouldProcessClientComponents,this.__log,de);return V(me,ve,be==null?void 0:be.fetchTime,this._queryCacheExpirationTime)},N.retain=function(W){var G=this,J=W.request.identifier,te=!1,H=function(){if(!te){te=!0;var X=G._roots.get(J);if(X!=null&&(X.refCount--,X.refCount===0)){var B=G._queryCacheExpirationTime,ne=X.fetchTime!=null&&B!=null&&X.fetchTime<=Date.now()-B;if(ne)G._shouldRetainWithinTTL_EXPERIMENTAL||G._roots.delete(J),G.scheduleGC();else if(G._releaseBuffer.push(J),G._releaseBuffer.length>G._gcReleaseBufferSize){var oe=G._releaseBuffer.shift();G._shouldRetainWithinTTL_EXPERIMENTAL||G._roots.delete(oe),G.scheduleGC()}}}},M=this._roots.get(J);return M!=null?(M.refCount===0&&(this._releaseBuffer=this._releaseBuffer.filter(function(K){return K!==J})),M.refCount+=1):this._roots.set(J,{operation:W,refCount:1,epoch:null,fetchTime:null}),{dispose:H}},N.lookup=function(W){var G=this.__log;G!=null&&G({name:"store.lookup.start",selector:W});var J=this.getSource(),te=v.read(J,W,this._resolverCache,this._resolverContext);return G!=null&&G({name:"store.lookup.end",selector:W}),te},N.notify=function(W,G){var J=this,te=this.__log;te!=null&&te({name:"store.notify.start",sourceOperation:W}),this._currentWriteEpoch++,G===!0&&(this._globalInvalidationEpoch=this._currentWriteEpoch),this._resolverCache.invalidateDataIDs(this._updatedRecordIDs);var H=this.getSource(),M=[];if(this._storeSubscriptions.updateSubscriptions(H,this._updatedRecordIDs,M,W),this._invalidationSubscriptions.forEach(function(ne){J._updateInvalidationSubscription(ne,G===!0)}),W!=null){var K=W.request.identifier,X=this._roots.get(K);if(X!=null)X.epoch=this._currentWriteEpoch,X.fetchTime=Date.now();else if(W.request.node.params.operationKind==="query"&&this._gcReleaseBufferSize>0&&this._releaseBuffer.length<this._gcReleaseBufferSize){var B={operation:W,refCount:0,epoch:this._currentWriteEpoch,fetchTime:Date.now()};this._releaseBuffer.push(K),this._roots.set(K,B)}}return te!=null&&te({name:"store.notify.complete",sourceOperation:W,updatedRecordIDs:this._updatedRecordIDs,invalidatedRecordIDs:this._invalidatedRecordIDs,subscriptionsSize:this._storeSubscriptions.size(),updatedOwners:M}),this._updatedRecordIDs.clear(),this._invalidatedRecordIDs.clear(),M},N.publish=function(W,G){var J=this._getMutableRecordSource();j(J,W,this._currentWriteEpoch+1,G,this._updatedRecordIDs,this._invalidatedRecordIDs);var te=this.__log;te!=null&&te({name:"store.publish",source:W,optimistic:J===this._optimisticSource})},N.subscribe=function(W,G){return this._storeSubscriptions.subscribe(W,G)},N.holdGC=function(){var W=this;this._gcRun&&(this._gcRun=null,this._shouldScheduleGC=!0),this._gcHoldCounter++;var G=function(){W._gcHoldCounter>0&&(W._gcHoldCounter--,W._gcHoldCounter===0&&W._shouldScheduleGC&&(W.scheduleGC(),W._shouldScheduleGC=!1))};return{dispose:G}},N.toJSON=function(){return"RelayModernStore()"},N.getEpoch=function(){return this._currentWriteEpoch},N.__getUpdatedRecordIDs=function(){return this._updatedRecordIDs},N.lookupInvalidationState=function(W){var G=this,J=new Map;return W.forEach(function(te){var H,M=G.getSource().get(te);J.set(te,(H=m.getInvalidationEpoch(M))!==null&&H!==void 0?H:null)}),J.set("global",this._globalInvalidationEpoch),{dataIDs:W,invalidations:J}},N.checkInvalidationState=function(W){var G=this.lookupInvalidationState(W.dataIDs),J=G.invalidations,te=W.invalidations;if(J.get("global")!==te.get("global"))return!0;var H=(0,t.default)(W.dataIDs),M;try{for(H.s();!(M=H.n()).done;){var K=M.value;if(J.get(K)!==te.get(K))return!0}}catch(X){H.e(X)}finally{H.f()}return!1},N.subscribeToInvalidationState=function(W,G){var J=this,te={callback:G,invalidationState:W},H=function(){J._invalidationSubscriptions.delete(te)};return this._invalidationSubscriptions.add(te),{dispose:H}},N._updateInvalidationSubscription=function(W,G){var J=this,te=W.callback,H=W.invalidationState,M=H.dataIDs,K=G||M.some(function(X){return J._invalidatedRecordIDs.has(X)});K&&te()},N.snapshot=function(){this._optimisticSource!=null&&$(!1);var W=this.__log;W!=null&&W({name:"store.snapshot"}),this._storeSubscriptions.snapshotSubscriptions(this.getSource()),this._gcRun&&(this._gcRun=null,this._shouldScheduleGC=!0),this._optimisticSource=y.create(this.getSource())},N.restore=function(){var W=this._optimisticSource;W||$(!1);var G=this.__log;G!=null&&G({name:"store.restore"});var J=y.getOptimisticRecordIDs(W);this._resolverCache.unsubscribeFromLiveResolverRecords(J),this._optimisticSource=null,this._shouldScheduleGC&&this.scheduleGC(),this._storeSubscriptions.restoreSubscriptions(),this._resolverCache.invalidateResolverRecords(J)},N.scheduleGC=function(){if(this._gcHoldCounter>0){this._shouldScheduleGC=!0;return}this._gcRun||(this._gcRun=this._collect(),this._gcScheduler(this._gcStep))},N.__gc=function(){if(this._optimisticSource==null)for(var W=this._collect();!W.next().done;);},N._collect=function*(){if(!(this._shouldRetainWithinTTL_EXPERIMENTAL&&this._queryCacheExpirationTime==null)){var W=this.__log;e:for(;;){W!=null&&W({name:"store.gc.start"});var G=this._currentWriteEpoch,J=new Set,te=(0,t.default)(this._roots.entries()),H;try{for(te.s();!(H=te.n()).done;){var M,K,X,B=H.value,ne=B[0],oe=B[1],ie=oe.operation,de=oe.refCount,be=oe.fetchTime;if(this._shouldRetainWithinTTL_EXPERIMENTAL){var ve=this._queryCacheExpirationTime;ve==null&&$(!1);var pe=be==null||be<=Date.now()-ve,_e=pe&&de===0&&!this._releaseBuffer.includes(ne);if(_e)continue}var se=ie.root,me=(M=(K=ie.request.node.operation.use_exec_time_resolvers)!==null&&K!==void 0?K:((X=ie.request.node.operation.exec_time_resolvers_enabled_provider)===null||X===void 0?void 0:X.get())===!0)!==null&&M!==void 0?M:!1;if(_.mark(this._recordSource,se,J,this._operationLoader,this._shouldProcessClientComponents,me),yield,G!==this._currentWriteEpoch){W!=null&&W({name:"store.gc.interrupted"});continue e}}}catch(tt){te.e(tt)}finally{te.f()}for(var ge=this._recordSource.getRecordIDs(),we=0;we<ge.length;we++){var Ne=ge[we];if(!J.has(Ne)){var Re=this._recordSource.get(Ne);if(Re!=null){var et=m.getValue(Re,d);et!=null&&et()}this._recordSource.remove(Ne),this._shouldRetainWithinTTL_EXPERIMENTAL&&this._roots.delete(Ne)}}W!=null&&W({name:"store.gc.end",references:J});return}}},N.__getNormalizationOptions=function(W){return{path:W,getDataID:this._getDataID,log:this.__log,treatMissingFieldsAsNull:this._treatMissingFieldsAsNull,shouldProcessClientComponents:this._shouldProcessClientComponents,actorIdentifier:this._actorIdentifier}},N.__notifyUpdatedSubscribers=function(W){var G=h(W),J=this._updatedRecordIDs;this._updatedRecordIDs=G,this.notify(),this._updatedRecordIDs=J},q})();function L(q){if(!q.has(T)){var N=m.create(T,R);q.set(T,N)}}function j(q,N,U,W,G,J){W&&W.forEach(function(ne){var oe=q.get(ne),ie=N.get(ne);if(ie!==null){var de;oe!=null?de=m.clone(oe):de=ie!=null?m.clone(ie):null,de&&(m.setValue(de,E.INVALIDATED_AT_KEY,U),J.add(ne),q.set(ne,de))}});for(var te=N.getRecordIDs(),H=0;H<te.length;H++){var M=te[H],K=N.get(M),X=q.get(M);if(K&&X){var B=m.update(X,K);B!==X&&(G.add(M),q.set(M,B))}else K===null?(q.delete(M),X!==null&&G.add(M)):K&&(q.set(M,K),G.add(M))}}function V(q,N,U,W){var G=q.mostRecentlyInvalidatedAt,J=q.status;if(typeof G=="number"&&(N==null||G>N))return{status:"stale"};if(J==="missing")return{status:"missing"};if(U!=null&&W!=null){var te=U<=Date.now()-W;if(te)return{status:"stale"}}return{status:"available",fetchTime:U??null}}return rA=F,rA}var iA,cq;function p4e(){if(cq)return iA;cq=1;var e=_a(),t=e.ROOT_TYPE,n=e.getStorageKey,r=jJ(),i=r.readUpdatableFragment,a=ZJ(),u=a.readUpdatableQuery,l=on(),o=(function(){function s(d,h,m,y){this.__mutator=d,this.__recordSource=h,this._readSelector=m,this._missingFieldHandlers=y}var c=s.prototype;return c.create=function(h,m){return this.__recordSource.create(h,m)},c.delete=function(h){this.__recordSource.delete(h)},c.get=function(h){return this.__recordSource.get(h)},c.getRoot=function(){return this.__recordSource.getRoot()},c.getOperationRoot=function(){var h=this.__recordSource.get(this._readSelector.dataID);return h||(h=this.__recordSource.create(this._readSelector.dataID,t)),h},c._getRootField=function(h,m,y){var v=h.node.selections.find(function(_){return _.kind==="LinkedField"&&_.name===m||_.kind==="RequiredField"&&_.field.name===m});return v&&v.kind==="RequiredField"&&(v=v.field),v&&v.kind==="LinkedField"||l(!1),v.plural!==y&&l(!1),v},c.getRootField=function(h){var m=this._getRootField(this._readSelector,h,!1),y=n(m,this._readSelector.variables);return this.getOperationRoot().getLinkedRecord(y)},c.getPluralRootField=function(h){var m=this._getRootField(this._readSelector,h,!0),y=n(m,this._readSelector.variables);return this.getOperationRoot().getLinkedRecords(y)},c.invalidateStore=function(){this.__recordSource.invalidateStore()},c.readUpdatableQuery=function(h,m){return u(h,m,this,this._missingFieldHandlers)},c.readUpdatableFragment=function(h,m){return i(h,m,this,this._missingFieldHandlers)},s})();return iA=o,iA}var aA,fq;function m4e(){if(fq)return aA;fq=1;var e,t,n=VJ(),r=HJ(),i=p4e(),a=th(),u=UF(),l=_b(),o=on();Qi();var s=typeof Hd<"u"?Hd:typeof window<"u"?window:void 0,c=(e=s==null||(t=s.ErrorUtils)===null||t===void 0?void 0:t.applyWithGuard)!==null&&e!==void 0?e:function(m,y,v,_,S){return m.apply(y,v)},d=(function(){function m(v,_,S,E,C){this._hasStoreSnapshot=!1,this._handlerProvider=_||null,this._pendingBackupRebase=!1,this._pendingData=new Set,this._pendingOptimisticUpdates=new Set,this._store=v,this._appliedOptimisticUpdates=new Set,this._gcHold=null,this._getDataID=S,this._missingFieldHandlers=E,this._log=C}var y=m.prototype;return y.applyUpdate=function(_){!this._appliedOptimisticUpdates.has(_)&&!this._pendingOptimisticUpdates.has(_)||o(!1),this._pendingOptimisticUpdates.add(_)},y.revertUpdate=function(_){this._pendingOptimisticUpdates.has(_)?this._pendingOptimisticUpdates.delete(_):this._appliedOptimisticUpdates.has(_)&&(this._pendingBackupRebase=!0,this._appliedOptimisticUpdates.delete(_))},y.revertAll=function(){this._pendingBackupRebase=!0,this._pendingOptimisticUpdates.clear(),this._appliedOptimisticUpdates.clear()},y.commitPayload=function(_,S,E){this._pendingBackupRebase=!0,this._pendingData.add({kind:"payload",operation:_,payload:S,updater:E})},y.commitUpdate=function(_){this._pendingBackupRebase=!0,this._pendingData.add({kind:"updater",updater:_})},y.commitSource=function(_){this._pendingBackupRebase=!0,this._pendingData.add({kind:"source",source:_})},y.run=function(_){var S=this._appliedOptimisticUpdates===0&&!!this._gcHold,E=!this._pendingBackupRebase&&this._pendingOptimisticUpdates.size===0&&!S;if(a.DISALLOW_NESTED_UPDATES&&this._isRunning===!0&&o(!1),this._isRunning=!0,E)return this._isRunning=!1,[];this._pendingBackupRebase&&this._hasStoreSnapshot&&(this._store.restore(),this._hasStoreSnapshot=!1);var C=this._commitData();return(this._pendingOptimisticUpdates.size||this._pendingBackupRebase&&this._appliedOptimisticUpdates.size)&&(this._hasStoreSnapshot||(this._store.snapshot(),this._hasStoreSnapshot=!0),this._applyUpdates()),this._pendingBackupRebase=!1,this._appliedOptimisticUpdates.size>0?this._gcHold||(this._gcHold=this._store.holdGC()):this._gcHold&&(this._gcHold.dispose(),this._gcHold=null),this._isRunning=!1,this._store.notify(_,C)},y._publishSourceFromPayload=function(_){var S=this,E=_.payload,C=_.operation,T=_.updater,R=E.source,$=E.fieldPayloads,k=new n(this._store.getSource(),R),F=new r(k,this._getDataID,this._handlerProvider,this._missingFieldHandlers,this._log);if($&&$.length&&$.forEach(function(N){var U=S._handlerProvider&&S._handlerProvider(N.handle);U||o(!1),U.update(F,N)}),T){var L=C.fragment;L==null&&o(!1);var j=new i(k,F,L,this._missingFieldHandlers),V=h(R,L);T(j,V)}var q=F.getIDsMarkedForInvalidation();return this._store.publish(R,q),F.isStoreMarkedForInvalidation()},y._commitData=function(){var _=this;if(!this._pendingData.size)return!1;var S=!1;return this._pendingData.forEach(function(E){if(E.kind==="payload"){var C=_._publishSourceFromPayload(E);S=S||C}else if(E.kind==="source"){var T=E.source;_._store.publish(T)}else{var R=E.updater,$=l.create(),k=new n(_._store.getSource(),$),F=new r(k,_._getDataID,_._handlerProvider,_._missingFieldHandlers,_._log);c(R,null,[F],null,"RelayPublishQueue:commitData"),S=S||F.isStoreMarkedForInvalidation();var L=F.getIDsMarkedForInvalidation();_._store.publish($,L)}}),this._pendingData.clear(),S},y._applyUpdates=function(){var _=this,S=l.create(),E=new n(this._store.getSource(),S),C=new r(E,this._getDataID,this._handlerProvider,this._missingFieldHandlers,this._log),T=function($){if($.storeUpdater){var k=$.storeUpdater;c(k,null,[C],null,"RelayPublishQueue:applyUpdates")}else{var F=$.operation,L=$.payload,j=$.updater,V=L.source,q=L.fieldPayloads;if(V&&C.publishSource(V,q),j){var N;V&&(N=h(V,F.fragment));var U=new i(E,C,F.fragment,_._missingFieldHandlers);c(j,null,[U,N],null,"RelayPublishQueue:applyUpdates")}}};this._pendingBackupRebase&&this._appliedOptimisticUpdates.size&&this._appliedOptimisticUpdates.forEach(T),this._pendingOptimisticUpdates.size&&(this._pendingOptimisticUpdates.forEach(function(R){T(R),_._appliedOptimisticUpdates.add(R)}),this._pendingOptimisticUpdates.clear()),this._store.publish(S)},m})();function h(m,y){var v=u.read(m,y).data;return v}return aA=d,aA}var uA,dq;function g4e(){if(dq)return uA;dq=1;var e=Cn().default,t=e(zi()),n=PJ(),r=zF(),i=r.INTERNAL_ACTOR_IDENTIFIER_DO_NOT_USE,a=r.assertInternalActorIdentifier,u=fy(),l=G3e(),o=QJ(),s=K3e(),c=zJ(),d=W3e(),h=LJ(),m=e4e(),y=GJ(),v=m4e(),_=_b();on();var S=(function(){function T($){var k=this,F,L,j,V,q,N,U,W,G,J,te;this.configName=$.configName,this._treatMissingFieldsAsNull=$.treatMissingFieldsAsNull===!0;var H=$.operationLoader,M=(F=$.store)!==null&&F!==void 0?F:new y(new _,{log:$.log,operationLoader:$.operationLoader,getDataID:$.getDataID,shouldProcessClientComponents:$.shouldProcessClientComponents});this.__log=(L=$.log)!==null&&L!==void 0?L:C,this.relayFieldLogger=(j=$.relayFieldLogger)!==null&&j!==void 0?j:d,this._defaultRenderPolicy=(V=$.UNSTABLE_defaultRenderPolicy)!==null&&V!==void 0?V:"partial",this._operationLoader=H,this._operationExecutions=new Map,this._network=l(this,$.network),this._getDataID=(q=$.getDataID)!==null&&q!==void 0?q:c,this._missingFieldHandlers=(N=$.missingFieldHandlers)!==null&&N!==void 0?N:[],this._publishQueue=new v(M,(U=$.handlerProvider)!==null&&U!==void 0?U:n,this._getDataID,this._missingFieldHandlers,this.__log),this._scheduler=(W=$.scheduler)!==null&&W!==void 0?W:null,this._store=M,this.options=$.options,this._isServer=(G=$.isServer)!==null&&G!==void 0?G:!1,this._normalizeResponse=(J=$.normalizeResponse)!==null&&J!==void 0?J:h,this.__setNet=function(K){return k._network=l(k,K)},this._operationTracker=(te=$.operationTracker)!==null&&te!==void 0?te:new o,this._shouldProcessClientComponents=$.shouldProcessClientComponents,s(this)}var R=T.prototype;return R.getStore=function(){return this._store},R.getNetwork=function(){return this._network},R.getOperationTracker=function(){return this._operationTracker},R.getScheduler=function(){return this._scheduler},R.isRequestActive=function(k){var F=this._operationExecutions.get(k);return F==="active"},R.UNSTABLE_getDefaultRenderPolicy=function(){return this._defaultRenderPolicy},R.applyUpdate=function(k){var F=this,L=function(){F._scheduleUpdates(function(){F._publishQueue.revertUpdate(k),F._publishQueue.run()})};return this._scheduleUpdates(function(){F._publishQueue.applyUpdate(k),F._publishQueue.run()}),{dispose:L}},R.revertUpdate=function(k){var F=this;this._scheduleUpdates(function(){F._publishQueue.revertUpdate(k),F._publishQueue.run()})},R.replaceUpdate=function(k,F){var L=this;this._scheduleUpdates(function(){L._publishQueue.revertUpdate(k),L._publishQueue.applyUpdate(F),L._publishQueue.run()})},R.applyMutation=function(k){var F=this._execute({createSource:function(){return u.create(function(j){})},isClientPayload:!1,operation:k.operation,optimisticConfig:k,updater:null}).subscribe({});return{dispose:function(){return F.unsubscribe()}}},R.check=function(k){return this._missingFieldHandlers.length===0&&!E(k)?this._store.check(k):this._checkSelectorAndHandleMissingFields(k,this._missingFieldHandlers)},R.commitPayload=function(k,F){this._execute({createSource:function(){return u.from({data:F})},isClientPayload:!0,operation:k,optimisticConfig:null,updater:null}).subscribe({})},R.commitUpdate=function(k){var F=this;this._scheduleUpdates(function(){F._publishQueue.commitUpdate(k),F._publishQueue.run()})},R.lookup=function(k){return this._store.lookup(k)},R.subscribe=function(k,F){return this._store.subscribe(k,F)},R.retain=function(k){return this._store.retain(k)},R.isServer=function(){return this._isServer},R._checkSelectorAndHandleMissingFields=function(k,F){var L=this,j=_.create(),V=this._store.getSource(),q=this._store.check(k,{handlers:F,defaultActorIdentifier:i,getSourceForActor:function(U){return a(U),V},getTargetForActor:function(U){return a(U),j}});return j.size()>0&&this._scheduleUpdates(function(){L._publishQueue.commitSource(j),L._publishQueue.run()}),q},R._scheduleUpdates=function(k){var F=this._scheduler;F!=null?F.schedule(k):k()},R.execute=function(k){var F=this,L=k.operation;return this._execute({createSource:function(){return F.getNetwork().execute(L.request.node.params,L.request.variables,L.request.cacheConfig||{},null,void 0,void 0,void 0,function(){return F.check(L)})},isClientPayload:!1,operation:L,optimisticConfig:null,updater:null})},R.executeSubscription=function(k){var F=this,L=k.operation,j=k.updater;return this._execute({createSource:function(){return F.getNetwork().execute(L.request.node.params,L.request.variables,L.request.cacheConfig||{},null)},isClientPayload:!1,operation:L,optimisticConfig:null,updater:j})},R.executeMutation=function(k){var F=this,L=k.operation,j=k.optimisticResponse,V=k.optimisticUpdater,q=k.updater,N=k.uploadables,U;return(j||V)&&(U={operation:L,response:j,updater:V}),this._execute({createSource:function(){return F.getNetwork().execute(L.request.node.params,L.request.variables,(0,t.default)((0,t.default)({},L.request.cacheConfig),{},{force:!0}),N)},isClientPayload:!1,operation:L,optimisticConfig:U,updater:q})},R.executeWithSource=function(k){var F=k.operation,L=k.source;return this._execute({createSource:function(){return L},isClientPayload:!1,operation:F,optimisticConfig:null,updater:null})},R.toJSON=function(){var k;return"RelayModernEnvironment(".concat((k=this.configName)!==null&&k!==void 0?k:"",")")},R._execute=function(k){var F=this,L=k.createSource,j=k.isClientPayload,V=k.operation,q=k.optimisticConfig,N=k.updater,U=this._publishQueue,W=this._store;return u.create(function(G){var J=m.execute({actorIdentifier:i,getDataID:F._getDataID,isClientPayload:j,log:F.__log,operation:V,operationExecutions:F._operationExecutions,operationLoader:F._operationLoader,operationTracker:F._operationTracker,optimisticConfig:q,getPublishQueue:function(H){return a(H),U},scheduler:F._scheduler,shouldProcessClientComponents:F._shouldProcessClientComponents,sink:G,source:L(),getStore:function(H){return a(H),W},treatMissingFieldsAsNull:F._treatMissingFieldsAsNull,updater:N,normalizeResponse:F._normalizeResponse});return function(){return J.cancel()}})},T})();function E(T){return T.root.node.kind==="Operation"&&T.root.node.clientAbstractTypes!=null}S.prototype["@@RelayModernEnvironment"]=!0;function C(){}return uA=S,uA}var lA,hq;function v4e(){if(hq)return lA;hq=1;var e=xC(),t=fp(),n=t.getRequest,r=dy(),i=r.createOperationDescriptor,a=dp(),u=a.createReaderSelector;Qi();function l(o,s){var c=n(s.subscription);if(c.params.operationKind!=="subscription")throw new Error("requestSubscription: Must use Subscription operation");var d=s.configs,h=s.onCompleted,m=s.onError,y=s.onNext,v=s.variables,_=s.cacheConfig,S=i(c,v,_),E=d?e.convert(d,c,null,s.updater):s,C=E.updater,T=o.executeSubscription({operation:S,updater:C}).subscribe({next:function($){if(y!=null){var k=S.fragment,F;if(Array.isArray($)){var L,j;F=(L=$[0])===null||L===void 0||(j=L.extensions)===null||j===void 0?void 0:j.__relay_subscription_root_id}else{var V;F=(V=$.extensions)===null||V===void 0?void 0:V.__relay_subscription_root_id}typeof F=="string"&&(k=u(k.node,F,k.variables,k.owner));var q=o.lookup(k).data;y(q)}},error:m,complete:h});return{dispose:T.unsubscribe}}return lA=l,lA}var oA,pq;function y4e(){if(pq)return oA;pq=1;var e=Cn().default,t=e(zi()),n=_a(),r=n.getModuleComponentKey,i=n.getModuleOperationKey;function a(u,l,o,s){var c=(0,t.default)({},s);return c[r(u)]=o,c[i(u)]=l,c}return oA=a,oA}var sA,mq;function b4e(){if(mq)return sA;mq=1;var e=Object.prototype.hasOwnProperty;function t(n){for(var r in n)if(e.call(n,r))return!1;return!0}return sA=t,sA}var cA,gq;function O4e(){if(gq)return cA;gq=1;var e=dp(),t=e.getDataIDsFromFragment,n=e.getSelector,r=e.getVariablesFromFragment,i=b4e(),a=th(),u=Sb(),l=u.stableCopy,o=TJ(),s=o.intern;function c(d,h){var m=n(d,h),y=m==null?"null":m.kind==="SingularReaderSelector"?m.owner.identifier:"["+m.selectors.map(function(T){return T.owner.identifier}).join(",")+"]",v=r(d,h),_=t(d,h);if(a.ENABLE_GETFRAGMENTIDENTIFIER_OPTIMIZATION){var S=typeof _>"u"?"missing":_==null?"null":Array.isArray(_)?"["+_.join(",")+"]":_;return S=a.STRING_INTERN_LEVEL<=1?S:s(S,a.MAX_DATA_ID_LENGTH),y+"/"+d.name+"/"+(v==null||i(v)?"{}":JSON.stringify(l(v)))+"/"+S}else{var E,C=(E=JSON.stringify(_))!==null&&E!==void 0?E:"missing";return C=a.STRING_INTERN_LEVEL<=1?C:s(C,a.MAX_DATA_ID_LENGTH),y+"/"+d.name+"/"+JSON.stringify(l(v))+"/"+C}}return cA=c,cA}var fA,vq;function KJ(){if(vq)return fA;vq=1;var e=on();function t(n,r){var i,a;((i=n.metadata)===null||i===void 0?void 0:i.plural)===!0&&e(!1);var u=(a=n.metadata)===null||a===void 0?void 0:a.refetch;u==null&&e(!1);var l=u.operation.default?u.operation.default:u.operation,o=u.fragmentPathInResult;typeof l=="string"&&e(!1);var s=u.identifierInfo;return s!=null&&(s.identifierField==null||typeof s.identifierField=="string"||e(!1),s.identifierQueryVariableName==null||typeof s.identifierQueryVariableName=="string"||e(!1)),{fragmentRefPathInResponse:o,identifierInfo:s,refetchableRequest:l,refetchMetadata:u}}return fA=t,fA}var dA,yq;function x4e(){if(yq)return dA;yq=1;var e=KJ(),t=on();function n(r,i){var a,u,l=e(r,i),o=l.refetchableRequest,s=l.refetchMetadata,c=s.connection;c==null&&t(!1);var d=c.path,h=((a=(u=r.metadata)===null||u===void 0?void 0:u.connection)!==null&&a!==void 0?a:[])[0];h==null&&t(!1);var m=s.identifierInfo;return(m==null?void 0:m.identifierField)==null||typeof m.identifierField=="string"||t(!1),{connectionPathInFragmentData:d,identifierField:m==null?void 0:m.identifierField,paginationRequest:o,paginationMetadata:c,stream:h.stream===!0}}return dA=n,dA}var hA,bq;function S4e(){if(bq)return hA;bq=1;var e=Cn().default,t=e(hc()),n=e(zi()),r=on();Qi();function i(a,u,l,o,s,c){var d,h=c.backward,m=c.forward;if(a==="backward"){var y;h!=null&&h.count!=null&&h.cursor!=null||r(!1);var v=(0,n.default)((0,n.default)((0,n.default)({},o),s),{},(y={},(0,t.default)(y,h.cursor,l),(0,t.default)(y,h.count,u),y));return m&&m.cursor&&(v[m.cursor]=null),m&&m.count&&(v[m.count]=null),v}m!=null&&m.count!=null&&m.cursor!=null||r(!1);var _=(0,n.default)((0,n.default)((0,n.default)({},o),s),{},(d={},(0,t.default)(d,m.cursor,l),(0,t.default)(d,m.count,u),d));return h&&h.cursor&&(_[h.cursor]=null),h&&h.count&&(_[h.count]=null),_}return hA=i,hA}var pA,Oq;function _4e(){if(Oq)return pA;Oq=1;var e=Cn().default,t=e(Du()),n=on();function r(i,a){var u=i,l=(0,t.default)(a),o;try{for(l.s();!(o=l.n()).done;){var s=o.value;if(u==null)return null;typeof s=="number"?(Array.isArray(u)||n(!1),u=u[s]):(typeof u=="object"&&!Array.isArray(u)||n(!1),u=u[s])}}catch(c){l.e(c)}finally{l.f()}return u}return pA=r,pA}var mA,xq;function E4e(){if(xq)return mA;xq=1;var e={},t={stop:function(){}},n={profile:function(a,u){var l=e[a];if(l&&l.length>0){for(var o=[],s=l.length-1;s>=0;s--){var c=l[s](a,u);o.unshift(c)}return{stop:function(h){o.forEach(function(m){return m(h)})}}}return t},attachProfileHandler:function(a,u){e.hasOwnProperty(a)||(e[a]=[]),e[a].push(u)},detachProfileHandler:function(a,u){e.hasOwnProperty(a)&&r(e[a],u)}};function r(i,a){var u=i.indexOf(a);u!==-1&&i.splice(u,1)}return mA=n,mA}var gA,Sq;function D4e(){if(Sq)return gA;Sq=1;var e=k3e(),t=e.isErrorResult,n=e.isValueResult,r=OC(),i=BF(),a=kJ(),u=PJ(),l=P3e(),o=M3e(),s=N3e(),c=xC(),d=L3e(),h=fy(),m=B3e(),y=Q3e(),v=z3e(),_=bC(),S=fp(),E=q3e(),C=I0(),T=C.generateClientID,R=C.generateUniqueClientID,$=C.isClientID,k=U3e(),F=j3e(),L=Z3e(),j=QF(),V=_C(),q=V.isSuspenseSentinel,N=V.suspenseSentinel,U=LJ(),W=Y3e(),G=cy(),J=g4e(),te=dy(),H=df(),M=dp(),K=GJ(),X=QJ(),B=_b(),ne=_a(),oe=IF(),ie=qF(),de=v4e(),be=y4e(),ve=iS(),pe=O4e(),_e=x4e(),se=S4e(),me=FJ(),ge=KJ(),we=NF(),Ne=AJ(),Re=_4e(),et=rS(),tt=et.handlePotentialSnapshotErrors,Oe=wJ(),$e=NJ(),Ae=SC(),Ue=oy(),Ze=$J(),Ye=qJ(),Me=th(),ze=E4e(),st=RJ(),Ot=Sb(),Nt=Ot.hasCycle,gt=Ot.stableCopy,qt=MJ();return gA={Environment:J,Network:d,Observable:h,QueryResponseCache:m,RecordSource:B,Record:H,ReplaySubject:st,Store:K,areEqualSelectors:M.areEqualSelectors,createFragmentSpecResolver:k,createNormalizationSelector:M.createNormalizationSelector,createOperationDescriptor:te.createOperationDescriptor,createReaderSelector:M.createReaderSelector,createRequestDescriptor:te.createRequestDescriptor,getArgumentValues:ne.getArgumentValues,getDataIDsFromFragment:M.getDataIDsFromFragment,getDataIDsFromObject:M.getDataIDsFromObject,getNode:S.getNode,getFragment:S.getFragment,getInlineDataFragment:S.getInlineDataFragment,getModuleComponentKey:ne.getModuleComponentKey,getModuleOperationKey:ne.getModuleOperationKey,getPaginationFragment:S.getPaginationFragment,getPluralSelector:M.getPluralSelector,getRefetchableFragment:S.getRefetchableFragment,getRequest:S.getRequest,getRequestIdentifier:Ne,getSelector:M.getSelector,getSelectorsFromObject:M.getSelectorsFromObject,getSingularSelector:M.getSingularSelector,getStorageKey:ne.getStorageKey,getVariablesFromFragment:M.getVariablesFromFragment,getVariablesFromObject:M.getVariablesFromObject,getVariablesFromPluralFragment:M.getVariablesFromPluralFragment,getVariablesFromSingularFragment:M.getVariablesFromSingularFragment,handlePotentialSnapshotErrors:tt,graphql:S.graphql,isErrorResult:t,isValueResult:n,isFragment:S.isFragment,isInlineDataFragment:S.isInlineDataFragment,isSuspenseSentinel:q,suspenseSentinel:N,isRequest:S.isRequest,readInlineData:W,readFragment:oe.readFragment,MutationTypes:c.MutationTypes,RangeOperations:c.RangeOperations,DefaultHandlerProvider:u,ConnectionHandler:r,MutationHandlers:a,VIEWER_ID:ie.VIEWER_ID,VIEWER_TYPE:ie.VIEWER_TYPE,applyOptimisticMutation:l,commitLocalUpdate:o,commitMutation:s,fetchQuery:y,fetchQuery_DEPRECATED:v,isRelayModernEnvironment:j,requestSubscription:de,ConnectionInterface:i,PreloadableQueryRegistry:E,RelayProfiler:ze,createPayloadFor3DField:be,RelayConcreteNode:Ue,RelayError:Ye,RelayFeatureFlags:Me,DEFAULT_HANDLE_KEY:Ze.DEFAULT_HANDLE_KEY,FRAGMENTS_KEY:ne.FRAGMENTS_KEY,FRAGMENT_OWNER_KEY:ne.FRAGMENT_OWNER_KEY,ID_KEY:ne.ID_KEY,REF_KEY:ne.REF_KEY,REFS_KEY:ne.REFS_KEY,ROOT_ID:ne.ROOT_ID,ROOT_TYPE:ne.ROOT_TYPE,TYPENAME_KEY:ne.TYPENAME_KEY,deepFreeze:ve,generateClientID:T,generateUniqueClientID:R,getRelayHandleKey:we,isClientID:$,isPromise:Oe,isScalarAndEqual:$e,recycleNodesInto:Ae,stableCopy:gt,hasCycle:Nt,getFragmentIdentifier:pe,getRefetchMetadata:ge,getPaginationMetadata:_e,getPaginationVariables:se,getPendingOperationsForFragment:me,getValueAtPath:Re,__internal:{ResolverFragments:oe,OperationTracker:X,createRelayContext:F,createRelayLoggingContext:L,getOperationVariables:G.getOperationVariables,getLocalVariables:G.getLocalVariables,fetchQuery:_.fetchQuery,fetchQueryDeduped:_.fetchQueryDeduped,getPromiseForActiveRequest:_.getPromiseForActiveRequest,getObservableForActiveRequest:_.getObservableForActiveRequest,normalizeResponse:U,withProvidedVariables:qt}},gA}var vA,_q;function ei(){return _q||(_q=1,vA=D4e()),vA}var yA,Eq;function hy(){if(Eq)return yA;Eq=1;var e=nr(),t=ei(),n=t.__internal.createRelayContext;return yA=n(e),yA}var bA={exports:{}},Dq;function $C(){return Dq||(Dq=1,(function(e){function t(){return e.exports=t=Object.assign?Object.assign.bind():function(n){for(var r=1;r<arguments.length;r++){var i=arguments[r];for(var a in i)({}).hasOwnProperty.call(i,a)&&(n[a]=i[a])}return n},e.exports.__esModule=!0,e.exports.default=e.exports,t.apply(null,arguments)}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports})(bA)),bA.exports}var OA={exports:{}},$q;function CC(){return $q||($q=1,(function(e){function t(n){if(n===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return n}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports})(OA)),OA.exports}var xA={exports:{}},SA={exports:{}},Cq;function $4e(){return Cq||(Cq=1,(function(e){function t(n,r){return e.exports=t=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(i,a){return i.__proto__=a,i},e.exports.__esModule=!0,e.exports.default=e.exports,t(n,r)}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports})(SA)),SA.exports}var wq;function wC(){return wq||(wq=1,(function(e){var t=$4e();function n(r,i){r.prototype=Object.create(i.prototype),r.prototype.constructor=r,t(r,i)}e.exports=n,e.exports.__esModule=!0,e.exports.default=e.exports})(xA)),xA.exports}var _A,Rq;function C4e(){if(Rq)return _A;Rq=1;var e=on();function t(n,r){r&&typeof r=="object"||e(!1);for(var i in r)if(r.hasOwnProperty(i)){var a=r[i];a&&(typeof a=="object"||typeof a=="function")||e(!1)}}return _A=t,_A}var EA,Aq;function RC(){if(Aq)return EA;Aq=1;function e(n){return n.displayName||n.name||"Component"}function t(n){return"Relay("+e(n)+")"}return EA={getComponentName:e,getContainerName:t},EA}var DA,Tq;function jF(){if(Tq)return DA;Tq=1;var e=nr();return DA=e.createContext({rootIsQueryRenderer:!1}),DA}var $A,kq;function ZF(){if(kq)return $A;kq=1;var e=Cn().default,t=e($C()),n=C4e(),r=RC(),i=r.getComponentName,a=r.getContainerName,u=hy(),l=jF(),o=on(),s=nr(),c=ei(),d=c.getFragment,h=s.useContext;function m(y,v,_){var S=a(y);n(i(y),v);var E={};for(var C in v)E[C]=d(v[C]);var T=_(y,E);T.displayName=S;function R(k,F){var L,j=h(u);j==null&&o(!1);var V=h(l);return s.createElement(T,(0,t.default)({},k,{__relayContext:j,__rootIsQueryRenderer:(L=V==null?void 0:V.rootIsQueryRenderer)!==null&&L!==void 0?L:!1,componentRef:k.componentRef||F}))}R.displayName=S;var $=s.forwardRef(R);return $}return $A=m,$A}var CA,Pq;function w4e(){if(Pq)return CA;Pq=1;function e(t){return typeof t=="object"&&t!==null&&typeof t.check=="function"&&typeof t.lookup=="function"&&typeof t.retain=="function"&&typeof t.execute=="function"&&typeof t.subscribe=="function"}return CA=e,CA}var wA,Mq;function HF(){if(Mq)return wA;Mq=1;var e=w4e(),t=on();function n(i){return r(i)||t(!1),i}function r(i){return typeof i=="object"&&i!==null&&!Array.isArray(i)&&e(i.environment)}return wA={assertRelayContext:n,isRelayContext:r},wA}var RA,Fq;function R4e(){if(Fq)return RA;Fq=1;var e=Cn().default,t=e($C()),n=e(j3()),r=e(CC()),i=e(wC()),a=e(hc()),u=["componentRef","__relayContext","__rootIsQueryRenderer"],l=ZF(),o=RC(),s=o.getContainerName,c=HF(),d=c.assertRelayContext,h=Jf(),m=nr(),y=ei(),v=y.createFragmentSpecResolver,_=y.getDataIDsFromObject,S=y.isScalarAndEqual;function E(R,$){var k,F=s(R);return k=(function(L){(0,i.default)(j,L);function j(q){var N,U;U=L.call(this,q)||this,(0,a.default)((0,r.default)(U),"_handleFragmentDataUpdate",function(){var te=U.state.resolver;U.setState(function(H){return te===H.resolver?{data:H.resolver.resolve(),relayProp:C(H.relayProp.environment)}:null})});var W=d(q.__relayContext),G=(N=q.__rootIsQueryRenderer)!==null&&N!==void 0?N:!1,J=v(W,F,$,q,G);return U.state={data:J.resolve(),prevProps:q,prevPropsContext:W,relayProp:C(W.environment),resolver:J},U}j.getDerivedStateFromProps=function(N,U){var W,G=U.prevProps,J=d(N.__relayContext),te=(W=N.__rootIsQueryRenderer)!==null&&W!==void 0?W:!1,H=_($,G),M=_($,N),K=U.resolver;if(U.prevPropsContext.environment!==J.environment||!h(H,M))return K=v(J,F,$,N,te),{data:K.resolve(),prevPropsContext:J,prevProps:N,relayProp:C(J.environment),resolver:K};K.setProps(N);var X=K.resolve();return X!==U.data?{data:X,prevProps:N,prevPropsContext:J,relayProp:C(J.environment)}:null};var V=j.prototype;return V.componentDidMount=function(){this._subscribeToNewResolverAndRerenderIfStoreHasChanged()},V.componentDidUpdate=function(N,U){this.state.resolver!==U.resolver?(U.resolver.dispose(),this._subscribeToNewResolverAndRerenderIfStoreHasChanged()):this._rerenderIfStoreHasChanged()},V.componentWillUnmount=function(){this.state.resolver.dispose()},V.shouldComponentUpdate=function(N,U){if(U.data!==this.state.data)return!0;for(var W=Object.keys(N),G=0;G<W.length;G++){var J=W[G];if(J==="__relayContext"){if(U.prevPropsContext.environment!==this.state.prevPropsContext.environment)return!0}else if(!$.hasOwnProperty(J)&&!S(N[J],this.props[J]))return!0}return!1},V._rerenderIfStoreHasChanged=function(){var N=this.state,U=N.data,W=N.resolver,G=W.resolve();U!==G&&this.setState({data:G})},V._subscribeToNewResolverAndRerenderIfStoreHasChanged=function(){var N=this.state,U=N.data,W=N.resolver,G=W.resolve();W.setCallback(this.props,this._handleFragmentDataUpdate),U!==G&&this.setState({data:G})},V.render=function(){var N=this.props,U=N.componentRef;N.__relayContext,N.__rootIsQueryRenderer;var W=(0,n.default)(N,u);return m.createElement(R,(0,t.default)({},W,this.state.data,{ref:U,relay:this.state.relayProp}))},j})(m.Component),(0,a.default)(k,"displayName",F),k}function C(R){return{environment:R}}function T(R,$){return l(R,$,E)}return RA={createContainer:T},RA}var AA,Nq;function A4e(){if(Nq)return AA;Nq=1;var e=hy(),t=jF(),n=Jf(),r=nr(),i=ei(),a=i.createOperationDescriptor;i.deepFreeze;var u=i.getRequest,l=r.useLayoutEffect,o=r.useState,s=r.useRef,c=r.useMemo,d={rootIsQueryRenderer:!0};function h(y){var v=r.useRef(y);return n(v.current,y)||(v.current=y),v.current}function m(y){var v=y.environment,_=y.query,S=y.variables,E=y.render,C=h(S),T=c(function(){var V=u(_);return a(V,C)},[_,C]),R=c(function(){return{environment:v}},[v]),$=s(null),k=o(null),F=k[1],L=s(null),j=c(function(){v.check(T);var V=v.lookup(T.fragment);$.current=V.data;var q=v.retain(T),N=v.subscribe(V,function(G){$.current=G.data,F($.current)}),U=!1;function W(){U||(U=!0,L.current=null,q.dispose(),N.dispose())}return L.current&&L.current(),L.current=W,V},[v,T]);return l(function(){var V=L.current;return function(){V&&V()}},[j]),r.createElement(e.Provider,{value:R},r.createElement(t.Provider,{value:d},E({props:$.current})))}return AA=m,AA}var TA,Iq;function WJ(){if(Iq)return TA;Iq=1;var e=Cn().default,t=e(zi()),n=ei(),r=n.getSelector;function i(a,u){var l={};return Object.keys(a).forEach(function(o){var s,c,d,h=a[o],m=u[o],y=r(h,m),v=y!=null&&y.kind==="PluralReaderSelector"?(s=(c=y.selectors[0])===null||c===void 0?void 0:c.owner.variables)!==null&&s!==void 0?s:{}:(d=y==null?void 0:y.owner.variables)!==null&&d!==void 0?d:{};l=(0,t.default)((0,t.default)({},l),v)}),l}return TA=i,TA}var kA,Lq;function XF(){if(Lq)return kA;Lq=1;var e=Cn().default,t=e(hc()),n=on(),r=ei(),i=r.__internal.fetchQuery,a=r.createOperationDescriptor,u=r.isRelayModernEnvironment,l=(function(){function o(c){(0,t.default)(this,"_selectionReferences",[]),(0,t.default)(this,"_didFetchFinish",!1),c!=null&&(this._cacheSelectionReference=c.cacheSelectionReference,this._selectionReferences=c.selectionReferences)}var s=o.prototype;return s.getSelectionReferences=function(){return{cacheSelectionReference:this._cacheSelectionReference,selectionReferences:this._selectionReferences}},s.lookupInStore=function(d,h,m){return(m==="store-and-network"||m==="store-or-network")&&d.check(h).status==="available"?(this._retainCachedOperation(d,h),d.lookup(h.fragment)):null},s.getFetchResult=function(){if(this._didFetchFinish){if(this._error!=null)return{error:this._error};if(this._snapshot!=null)return{snapshot:this._snapshot}}else return null},s.execute=function(d){var h=this,m=d.environment,y=d.operation,v=d.preservePreviousReferences,_=v===void 0?!1:v,S=m.retain(y),E=function(){h._selectionReferences=h._selectionReferences.concat(S)},C=function(){_||h.disposeSelectionReferences(),h._selectionReferences=h._selectionReferences.concat(S)},T=function(){h._selectionReferences=h._selectionReferences.concat(S)};return u(m)?i(m,y).do({error:E,complete:C,unsubscribe:T}):m.execute({operation:y}).do({error:E,complete:C,unsubscribe:T})},s.setOnDataChange=function(d){this._fetchOptions||n(!1),typeof d=="function"&&(this._fetchOptions.onDataChangeCallbacks=this._fetchOptions.onDataChangeCallbacks||[],this._fetchOptions.onDataChangeCallbacks.push(d),this._didFetchFinish&&(this._error!=null?d({error:this._error}):this._snapshot!=null&&d({snapshot:this._snapshot})))},s.fetch=function(d,h){var m=this,y=d.environment,v=d.operation,_=d.onDataChange,S=!1,E;this.disposeRequest();var C=this._fetchOptions&&this._fetchOptions.onDataChangeCallbacks;this._fetchOptions={environment:y,onDataChangeCallbacks:C||[],operation:v},_&&this._fetchOptions.onDataChangeCallbacks.indexOf(_)===-1&&this._fetchOptions.onDataChangeCallbacks.push(_);var T=h?a(v.request.node,v.request.variables,h):v,R=this.execute({environment:y,operation:T}).finally(function(){m._pendingRequest=null}).subscribe({next:function(){m._didFetchFinish=!0,m._error=null,m._onQueryDataAvailable({notifyFirstResult:S})},error:function(k){m._didFetchFinish=!0,m._error=k,m._snapshot=null;var F=m._fetchOptions&&m._fetchOptions.onDataChangeCallbacks;S?F&&F.forEach(function(L){L({error:k})}):E=k}});if(this._pendingRequest={dispose:function(){R.unsubscribe()}},S=!0,E)throw E;return this._snapshot},s.retry=function(d){return this._fetchOptions||n(!1),this.fetch({environment:this._fetchOptions.environment,operation:this._fetchOptions.operation,onDataChange:null},d)},s.dispose=function(){this.disposeRequest(),this.disposeSelectionReferences()},s.disposeRequest=function(){this._error=null,this._snapshot=null,this._pendingRequest&&this._pendingRequest.dispose(),this._rootSubscription&&(this._rootSubscription.dispose(),this._rootSubscription=null)},s._retainCachedOperation=function(d,h){this._disposeCacheSelectionReference(),this._cacheSelectionReference=d.retain(h)},s._disposeCacheSelectionReference=function(){this._cacheSelectionReference&&this._cacheSelectionReference.dispose(),this._cacheSelectionReference=null},s.disposeSelectionReferences=function(){this._disposeCacheSelectionReference(),this._selectionReferences.forEach(function(d){return d.dispose()}),this._selectionReferences=[]},s._onQueryDataAvailable=function(d){var h=this,m=d.notifyFirstResult;this._fetchOptions||n(!1);var y=this._fetchOptions,v=y.environment,_=y.onDataChangeCallbacks,S=y.operation;if(!this._snapshot&&(this._snapshot=v.lookup(S.fragment),this._rootSubscription=v.subscribe(this._snapshot,function(C){if(h._fetchOptions!=null){var T=h._fetchOptions.onDataChangeCallbacks;Array.isArray(T)&&T.forEach(function(R){return R({snapshot:C})})}}),this._snapshot&&m&&Array.isArray(_))){var E=this._snapshot;_.forEach(function(C){return C({snapshot:E})})}},o})();return kA=l,kA}var PA,Bq;function T4e(){if(Bq)return PA;Bq=1;var e=Cn().default,t=e($C()),n=e(j3()),r=e(CC()),i=e(wC()),a=e(hc()),u=e(zi()),l=["componentRef"],o=["componentRef","__relayContext","__rootIsQueryRenderer"],s=["componentRef","__relayContext","__rootIsQueryRenderer"],c=ZF(),d=WJ(),h=RC(),m=h.getComponentName,y=h.getContainerName,v=hy(),_=XF(),S=HF(),E=S.assertRelayContext,C=Jf(),T=on(),R=nr(),$=ei(),k=$.ConnectionInterface,F=$.Observable,L=$.RelayFeatureFlags,j=$.createFragmentSpecResolver,V=$.createOperationDescriptor,q=$.getDataIDsFromObject,N=$.getRequest,U=$.getVariablesFromObject,W=$.isScalarAndEqual;Qi();var G="forward";function J(B){var ne=B.path;return ne||T(!1),function(oe){for(var ie=oe[B.fragmentName],de=0;de<ne.length;de++){if(!ie||typeof ie!="object")return null;ie=ie[ne[de]]}return ie}}function te(B){var ne=B.count;return ne||T(!1),function(oe,ie){return(0,u.default)((0,u.default)({},oe),{},(0,a.default)({},ne,ie))}}function H(B){var ne=null,oe=!1;for(var ie in B){var de=B[ie],be=de.metadata&&de.metadata.connection;de.metadata!==void 0&&(oe=!0),be&&(be.length!==1&&T(!1),ne&&T(!1),ne=(0,u.default)((0,u.default)({},be[0]),{},{fragmentName:ie}))}return!oe||ne!==null||T(!1),ne||{}}function M(B){return typeof B=="function"?{error:B,complete:B,unsubscribe:function(oe){typeof B=="function"&&B()}}:B||{}}function K(B,ne,oe){var ie;m(B);var de=y(B),be=H(ne),ve=oe.getConnectionFromProps||J(be),pe=oe.direction||be.direction;pe||T(!1);var _e=oe.getFragmentVariables||te(be);return ie=(function(se){(0,i.default)(me,se);function me(we){var Ne,Re;Re=se.call(this,we)||this,(0,a.default)((0,r.default)(Re),"_handleFragmentDataUpdate",function(){Re.setState({data:Re._resolver.resolve()})}),(0,a.default)((0,r.default)(Re),"_hasMore",function(){var Oe=Re._getConnectionData();return!!(Oe&&Oe.hasMore&&Oe.cursor)}),(0,a.default)((0,r.default)(Re),"_isLoading",function(){return!!Re._refetchSubscription}),(0,a.default)((0,r.default)(Re),"_refetchConnection",function(Oe,$e,Ae){if(!Re._canFetchPage("refetchConnection"))return{dispose:function(){}};Re._refetchVariables=Ae;var Ue={count:Oe,cursor:null,totalCount:Oe},Ze=Re._fetchPage(Ue,M($e),{force:!0});return{dispose:Ze.unsubscribe}}),(0,a.default)((0,r.default)(Re),"_loadMore",function(Oe,$e,Ae){if(!Re._canFetchPage("loadMore"))return{dispose:function(){}};var Ue=M($e),Ze=Re._getConnectionData();if(!Ze)return F.create(function(Nt){return Nt.complete()}).subscribe(Ue),null;var Ye=Ze.edgeCount+Oe;if(Ae&&Ae.force)return Re._refetchConnection(Ye,$e);var Me=k.get();Me.END_CURSOR,Me.START_CURSOR;var ze=Ze.cursor,st={count:Oe,cursor:ze,totalCount:Ye},Ot=Re._fetchPage(st,Ue,Ae);return{dispose:Ot.unsubscribe}});var et=E(we.__relayContext),tt=(Ne=we.__rootIsQueryRenderer)!==null&&Ne!==void 0?Ne:!1;return Re._isARequestInFlight=!1,Re._refetchSubscription=null,Re._refetchVariables=null,L.ENABLE_CONTAINERS_SUBSCRIBE_ON_COMMIT===!0?Re._resolver=j(et,de,ne,we,tt):Re._resolver=j(et,de,ne,we,tt,Re._handleFragmentDataUpdate),Re.state={data:Re._resolver.resolve(),prevContext:et,contextForChildren:et,relayProp:Re._buildRelayProp(et),resolverGeneration:0},Re._isUnmounted=!1,Re._hasFetched=!1,Re}var ge=me.prototype;return ge.componentDidMount=function(){this._isUnmounted=!1,L.ENABLE_CONTAINERS_SUBSCRIBE_ON_COMMIT===!0&&this._subscribeToNewResolverAndRerenderIfStoreHasChanged()},ge.componentDidUpdate=function(Ne,Re){L.ENABLE_CONTAINERS_SUBSCRIBE_ON_COMMIT===!0&&(Re.resolverGeneration!==this.state.resolverGeneration?this._subscribeToNewResolverAndRerenderIfStoreHasChanged():this._rerenderIfStoreHasChanged())},ge.UNSAFE_componentWillReceiveProps=function(Ne){var Re=this,et,tt=E(Ne.__relayContext),Oe=(et=Ne.__rootIsQueryRenderer)!==null&&et!==void 0?et:!1,$e=q(ne,this.props),Ae=q(ne,Ne),Ue=d(ne,this.props),Ze=d(ne,Ne);tt.environment!==this.state.prevContext.environment||!C(Ue,Ze)||!C($e,Ae)?(this._cleanup(),L.ENABLE_CONTAINERS_SUBSCRIBE_ON_COMMIT===!0?this._resolver=j(tt,de,ne,Ne,Oe):this._resolver=j(tt,de,ne,Ne,Oe,this._handleFragmentDataUpdate),this.setState(function(Me){return{prevContext:tt,contextForChildren:tt,relayProp:Re._buildRelayProp(tt),resolverGeneration:Me.resolverGeneration+1}})):this._hasFetched||this._resolver.setProps(Ne);var Ye=this._resolver.resolve();Ye!==this.state.data&&this.setState({data:Ye})},ge.componentWillUnmount=function(){this._isUnmounted=!0,this._cleanup()},ge.shouldComponentUpdate=function(Ne,Re){if(Re.data!==this.state.data||Re.relayProp!==this.state.relayProp||Re.resolverGeneration!==this.state.resolverGeneration)return!0;for(var et=Object.keys(Ne),tt=0;tt<et.length;tt++){var Oe=et[tt];if(Oe==="__relayContext"){if(Re.prevContext.environment!==this.state.prevContext.environment)return!0}else if(!ne.hasOwnProperty(Oe)&&!W(Ne[Oe],this.props[Oe]))return!0}return!1},ge._buildRelayProp=function(Ne){return{hasMore:this._hasMore,isLoading:this._isLoading,loadMore:this._loadMore,refetchConnection:this._refetchConnection,environment:Ne.environment}},ge._rerenderIfStoreHasChanged=function(){var Ne=this.state.data,Re=this._resolver.resolve();Ne!==Re&&this.setState({data:Re})},ge._subscribeToNewResolverAndRerenderIfStoreHasChanged=function(){var Ne=this.state.data,Re=this._resolver.resolve();this._resolver.setCallback(this.props,this._handleFragmentDataUpdate),Ne!==Re&&this.setState({data:Re})},ge._getConnectionData=function(){var Ne=this.props;Ne.componentRef;var Re=(0,n.default)(Ne,l),et=(0,u.default)((0,u.default)({},Re),this.state.data),tt=ve(et);if(tt==null)return null;var Oe=k.get(),$e=Oe.EDGES,Ae=Oe.PAGE_INFO,Ue=Oe.HAS_NEXT_PAGE,Ze=Oe.HAS_PREV_PAGE,Ye=Oe.END_CURSOR,Me=Oe.START_CURSOR;typeof tt!="object"&&T(!1);var ze=tt[$e],st=tt[Ae];if(ze==null||st==null)return null;Array.isArray(ze)||T(!1),typeof st!="object"&&T(!1);var Ot=pe===G?st[Ue]:st[Ze],Nt=pe===G?st[Ye]:st[Me];return typeof Ot!="boolean"||ze.length!==0&&typeof Nt>"u"?null:{cursor:Nt,edgeCount:ze.length,hasMore:Ot}},ge._getQueryFetcher=function(){return this._queryFetcher||(this._queryFetcher=new _),this._queryFetcher},ge._canFetchPage=function(Ne){return!this._isUnmounted},ge._fetchPage=function(Ne,Re,et){var tt=this,Oe=E(this.props.__relayContext),$e=Oe.environment,Ae=this.props;Ae.componentRef,Ae.__relayContext,Ae.__rootIsQueryRenderer;var Ue=(0,n.default)(Ae,o),Ze=(0,u.default)((0,u.default)({},Ue),this.state.data),Ye,Me=d(ne,Ue);Ye=U(ne,Ue),Ye=(0,u.default)((0,u.default)((0,u.default)({},Me),Ye),this._refetchVariables);var ze=oe.getVariables(Ze,{count:Ne.count,cursor:Ne.cursor},Ye);typeof ze=="object"&&ze!==null||T(!1),ze=(0,u.default)((0,u.default)({},ze),this._refetchVariables),Ye=(0,u.default)((0,u.default)({},ze),Ye);var st=et?{force:!!et.force}:void 0;st!=null&&(et==null?void 0:et.metadata)!=null&&(st.metadata=et==null?void 0:et.metadata);var Ot=N(oe.query),Nt=V(Ot,ze,st),gt=null;this._refetchSubscription&&this._refetchSubscription.unsubscribe(),this._hasFetched=!0;var qt=function(rn,Fe){var ht=tt._resolver.resolve();tt._resolver.setVariables(_e(Ye,Ne.totalCount),Nt.request.node);var Tt=tt._resolver.resolve();C(ht,Tt)?Fe():tt.setState({data:Tt,contextForChildren:{environment:tt.props.__relayContext.environment}},Fe)},zt=function(){tt._refetchSubscription===gt&&(tt._refetchSubscription=null,tt._isARequestInFlight=!1)};return this._isARequestInFlight=!0,gt=this._getQueryFetcher().execute({environment:$e,operation:Nt,preservePreviousReferences:!0}).mergeMap(function(an){return F.create(function(rn){qt(an,function(){rn.next(),rn.complete()})})}).do({error:zt,complete:zt,unsubscribe:zt}).subscribe(Re||{}),this._refetchSubscription=this._isARequestInFlight?gt:null,gt},ge._cleanup=function(){this._resolver.dispose(),this._refetchVariables=null,this._hasFetched=!1,this._refetchSubscription&&(this._refetchSubscription.unsubscribe(),this._refetchSubscription=null,this._isARequestInFlight=!1),this._queryFetcher&&this._queryFetcher.dispose()},ge.render=function(){var Ne=this.props,Re=Ne.componentRef;Ne.__relayContext,Ne.__rootIsQueryRenderer;var et=(0,n.default)(Ne,s);return R.createElement(v.Provider,{value:this.state.contextForChildren},R.createElement(B,(0,t.default)({},et,this.state.data,{ref:Re,relay:this.state.relayProp})))},me})(R.Component),(0,a.default)(ie,"displayName",de),ie}function X(B,ne,oe){return c(B,ne,function(ie,de){return K(ie,de,oe)})}return PA={createContainer:X},PA}var MA,Qq;function k4e(){if(Qq)return MA;Qq=1;var e=Cn().default,t=e(zi()),n=e(CC()),r=e(wC()),i=e(hc()),a=hy(),u=XF(),l=jF(),o=Jf(),s=nr(),c=ei(),d=c.createOperationDescriptor;c.deepFreeze;var h=c.getRequest,m={},y={rootIsQueryRenderer:!0},v=(function($){(0,r.default)(k,$);function k(L){var j;j=$.call(this,L)||this,(0,i.default)((0,n.default)(j),"_handleDataChange",function(G){var J=G.error==null?null:G.error,te=G.snapshot==null?null:G.snapshot;j.setState(function(H){var M=H.requestCacheKey;return M&&delete m[M],te===H.snapshot&&J===H.error?null:{renderProps:E(J,te,H.queryFetcher,H.retryCallbacks),snapshot:te,requestCacheKey:null}})});var V={handleDataChange:null,handleRetryAfterError:null},q,N;if(L.query){var U=L.query,W=h(U);N=C(W.params,L.variables),q=m[N]?m[N].queryFetcher:new u}else q=new u;return j._maybeHiddenOrFastRefresh=!1,j.state=(0,t.default)({prevPropsEnvironment:L.environment,prevPropsVariables:L.variables,prevQuery:L.query,queryFetcher:q,retryCallbacks:V},R(L,q,V,N)),j}k.getDerivedStateFromProps=function(j,V){return V.prevQuery!==j.query||V.prevPropsEnvironment!==j.environment||!o(V.prevPropsVariables,j.variables)?T(j,V):null};var F=k.prototype;return F.componentDidMount=function(){var j=this;if(this._maybeHiddenOrFastRefresh===!0){this._maybeHiddenOrFastRefresh=!1,this.setState(function(W){var G=T(j.props,W),J=G.requestCacheKey,te=G.queryFetcher;return J!=null&&m[J]!=null&&te.setOnDataChange(j._handleDataChange),G});return}var V=this.state,q=V.retryCallbacks,N=V.queryFetcher,U=V.requestCacheKey;U&&delete m[U],q.handleDataChange=this._handleDataChange,q.handleRetryAfterError=function(W){return j.setState(function(G){var J=G.requestCacheKey;return J&&delete m[J],{renderProps:_(),requestCacheKey:null}})},this.props.query&&N.setOnDataChange(this._handleDataChange)},F.componentDidUpdate=function(j,V){var q=this.state,N=q.queryFetcher,U=q.requestCacheKey;U&&(delete m[U],delete this.state.requestCacheKey),this.props.query&&N!==V.queryFetcher&&N.setOnDataChange(this._handleDataChange)},F.componentWillUnmount=function(){this.state.queryFetcher.dispose(),this._maybeHiddenOrFastRefresh=!0},F.shouldComponentUpdate=function(j,V){return j.render!==this.props.render||V.renderProps!==this.state.renderProps},F.render=function(){var j=this.state,V=j.renderProps,q=j.relayContext;return s.createElement(a.Provider,{value:q},s.createElement(l.Provider,{value:y},this.props.render(V)))},k})(s.Component);function _(){return{error:null,props:null,retry:null}}function S(){return{error:null,props:{},retry:null}}function E($,k,F,L){return{error:$||null,props:k?k.data:null,retry:function(V){var q=F.retry(V);q&&typeof L.handleDataChange=="function"?L.handleDataChange({snapshot:q}):$&&typeof L.handleRetryAfterError=="function"&&L.handleRetryAfterError($)}}}function C($,k){return JSON.stringify({id:$.cacheID?$.cacheID:$.id,variables:k})}function T($,k){var F=$.query,L=k.queryFetcher.getSelectionReferences();k.queryFetcher.disposeRequest();var j;if(F){var V=h(F),q=C(V.params,$.variables);j=m[q]?m[q].queryFetcher:new u(L)}else j=new u(L);return(0,t.default)({prevQuery:$.query,prevPropsEnvironment:$.environment,prevPropsVariables:$.variables,queryFetcher:j},R($,j,k.retryCallbacks))}function R($,k,F,L){var j=$.environment,V=$.query,q=$.variables,N=$.cacheConfig,U=j;if(V){var W=h(V),G=d(W,q,N),J={environment:U};if(typeof L=="string"&&m[L]){var te=m[L].snapshot;return te?{error:null,relayContext:J,renderProps:E(null,te,k,F),snapshot:te,requestCacheKey:L}:{error:null,relayContext:J,renderProps:_(),snapshot:null,requestCacheKey:L}}try{var H=k.lookupInStore(U,G,$.fetchPolicy),M=k.fetch({environment:U,onDataChange:null,operation:G}),K=M||H;return L=L||C(W.params,$.variables),m[L]={queryFetcher:k,snapshot:K},K?{error:null,relayContext:J,renderProps:E(null,K,k,F),snapshot:K,requestCacheKey:L}:{error:null,relayContext:J,renderProps:_(),snapshot:null,requestCacheKey:L}}catch(B){return{error:B,relayContext:J,renderProps:E(B,null,k,F),snapshot:null,requestCacheKey:L}}}else{k.dispose();var X={environment:U};return{error:null,relayContext:X,renderProps:S(),requestCacheKey:null}}}return MA=v,MA}var FA,zq;function P4e(){if(zq)return FA;zq=1;var e=Cn().default,t=e($C()),n=e(j3()),r=e(zi()),i=e(CC()),a=e(wC()),u=e(hc()),l=["componentRef","__relayContext","__rootIsQueryRenderer"],o=ZF(),s=WJ(),c=RC(),d=c.getContainerName,h=hy(),m=XF(),y=HF(),v=y.assertRelayContext,_=Jf(),S=nr(),E=ei(),C=E.Observable,T=E.createFragmentSpecResolver,R=E.createOperationDescriptor,$=E.getDataIDsFromObject,k=E.getRequest,F=E.getVariablesFromObject,L=E.isScalarAndEqual;Qi();function j(N,U,W){var G,J=d(N);return G=(function(te){(0,a.default)(H,te);function H(K){var X,B;B=te.call(this,K)||this,(0,u.default)((0,i.default)(B),"_handleFragmentDataUpdate",function(){var de=B.state.resolver;B.setState(function(be){return de===be.resolver?{data:be.resolver.resolve()}:null})}),(0,u.default)((0,i.default)(B),"_refetch",function(de,be,ve,pe){if(B._isUnmounted)return{dispose:function(){}};var _e=v(B.props.__relayContext),se=_e.environment,me=s(U,B.props),ge=typeof de=="function"?de(B._getFragmentVariables()):de;ge=(0,r.default)((0,r.default)({},me),ge);var we=be?(0,r.default)((0,r.default)({},ge),be):ge,Ne=pe?{force:!!pe.force}:void 0;Ne!=null&&(pe==null?void 0:pe.metadata)!=null&&(Ne.metadata=pe==null?void 0:pe.metadata);var Re=typeof ve=="function"?{next:ve,error:ve}:ve||{},et=k(W),tt=R(et,ge,Ne);B.state.localVariables=ge,B._refetchSubscription&&B._refetchSubscription.unsubscribe();var Oe,$e=B._getQueryFetcher().lookupInStore(se,tt,pe==null?void 0:pe.fetchPolicy);return $e!=null?(B.state.resolver.setVariables(we,tt.request.node),B.setState(function(Ae){return{data:Ae.resolver.resolve(),contextForChildren:{environment:B.props.__relayContext.environment}}},function(){Re.next&&Re.next(),Re.complete&&Re.complete()}),{dispose:function(){}}):(B._getQueryFetcher().execute({environment:se,operation:tt,preservePreviousReferences:!0}).mergeMap(function(Ae){return B.state.resolver.setVariables(we,tt.request.node),C.create(function(Ue){return B.setState(function(Ze){return{data:Ze.resolver.resolve(),contextForChildren:{environment:B.props.__relayContext.environment}}},function(){Ue.next(),Ue.complete()})})}).finally(function(){B._refetchSubscription===Oe&&(B._refetchSubscription=null)}).subscribe((0,r.default)((0,r.default)({},Re),{},{start:function(Ue){B._refetchSubscription=Oe=Ue,Re.start&&Re.start(Ue)}})),{dispose:function(){Oe&&Oe.unsubscribe()}})});var ne=v(K.__relayContext),oe=(X=K.__rootIsQueryRenderer)!==null&&X!==void 0?X:!1;B._refetchSubscription=null;var ie=T(ne,J,U,K,oe);return B.state={data:ie.resolve(),localVariables:null,prevProps:K,prevPropsContext:ne,contextForChildren:ne,relayProp:V(ne.environment,B._refetch),resolver:ie},B._isUnmounted=!1,B}var M=H.prototype;return M.componentDidMount=function(){this._isUnmounted=!1,this._subscribeToNewResolverAndRerenderIfStoreHasChanged()},M.componentDidUpdate=function(X,B){this.state.resolver!==B.resolver?(B.resolver.dispose(),this._queryFetcher&&this._queryFetcher.dispose(),this._refetchSubscription&&this._refetchSubscription.unsubscribe(),this._subscribeToNewResolverAndRerenderIfStoreHasChanged()):this._rerenderIfStoreHasChanged()},H.getDerivedStateFromProps=function(X,B){var ne,oe=B.prevProps,ie=v(X.__relayContext),de=(ne=X.__rootIsQueryRenderer)!==null&&ne!==void 0?ne:!1,be=$(U,oe),ve=$(U,X),pe=s(U,oe),_e=s(U,X),se=B.resolver;if(B.prevPropsContext.environment!==ie.environment||!_(pe,_e)||!_(be,ve))return se=T(ie,J,U,X,de),{data:se.resolve(),localVariables:null,prevProps:X,prevPropsContext:ie,contextForChildren:ie,relayProp:V(ie.environment,B.relayProp.refetch),resolver:se};B.localVariables||se.setProps(X);var me=se.resolve();return me!==B.data?{data:me,prevProps:X}:null},M.componentWillUnmount=function(){this._isUnmounted=!0,this.state.resolver.dispose(),this._queryFetcher&&this._queryFetcher.dispose(),this._refetchSubscription&&this._refetchSubscription.unsubscribe()},M.shouldComponentUpdate=function(X,B){if(B.data!==this.state.data||B.relayProp!==this.state.relayProp)return!0;for(var ne=Object.keys(X),oe=0;oe<ne.length;oe++){var ie=ne[oe];if(ie==="__relayContext"){if(this.state.prevPropsContext.environment!==B.prevPropsContext.environment)return!0}else if(!U.hasOwnProperty(ie)&&!L(X[ie],this.props[ie]))return!0}return!1},M._rerenderIfStoreHasChanged=function(){var X=this.state,B=X.data,ne=X.resolver,oe=ne.resolve();B!==oe&&this.setState({data:oe})},M._subscribeToNewResolverAndRerenderIfStoreHasChanged=function(){var X=this.state,B=X.data,ne=X.resolver,oe=ne.resolve();ne.setCallback(this.props,this._handleFragmentDataUpdate),B!==oe&&this.setState({data:oe})},M._getFragmentVariables=function(){return F(U,this.props)},M._getQueryFetcher=function(){return this._queryFetcher||(this._queryFetcher=new m),this._queryFetcher},M.render=function(){var X=this.props,B=X.componentRef;X.__relayContext,X.__rootIsQueryRenderer;var ne=(0,n.default)(X,l),oe=this.state,ie=oe.relayProp,de=oe.contextForChildren;return S.createElement(h.Provider,{value:de},S.createElement(N,(0,t.default)({},ne,this.state.data,{ref:B,relay:ie})))},H})(S.Component),(0,u.default)(G,"displayName",J),G}function V(N,U){return{environment:N,refetch:U}}function q(N,U,W){return o(N,U,function(G,J){return j(G,J,W)})}return FA={createContainer:q},FA}var NA,qq;function AC(){if(qq)return NA;qq=1;var e=nr(),t=e.createContext({wrapPrepareQueryResource:function(r){return r()}});return NA=t,NA}var IA,Vq;function io(){if(Vq)return IA;Vq=1;var e=hy(),t=on(),n=nr(),r=n.useContext;function i(){var a=r(e);return a==null&&t(!1),a.environment}return IA=i,IA}var LA,Uq;function M4e(){if(Uq)return LA;Uq=1;var e=AC(),t=io(),n=nr(),r=nr(),i=r.useContext,a=r.useEffect;Qi();function u(l){var o=l.entryPointReference,s=l.props,c=o.getComponent,d=o.queries,h=o.entryPoints,m=o.extraProps,y=o.rootModuleID,v=c(),_=i(e),S=t();return a(function(){S.__log({name:"entrypoint.root.consume",profilerContext:_,rootModuleID:y})},[S,_,y]),n.createElement(v,{entryPoints:h,extraProps:m,props:s,queries:d})}return LA=u,LA}var BA,jq;function TC(){if(jq)return BA;jq=1;var e=Cn().default,t=e(zi()),n=on(),r=ei(),i=r.__internal.fetchQueryDeduped,a=r.Observable,u=r.PreloadableQueryRegistry,l=r.ReplaySubject,o=r.createOperationDescriptor,s=r.getRequest,c=r.getRequestIdentifier,d=100001;function h(m,y,v,_,S){var E;d++;var C=(E=_==null?void 0:_.fetchPolicy)!==null&&E!==void 0?E:"store-or-network",T=(0,t.default)((0,t.default)({},_==null?void 0:_.networkCacheConfig),{},{force:!0}),R,$=!1,k=function(me,ge){return $=!0,m.executeWithSource({operation:me,source:ge})},F=new l,L=a.create(function(se){return F.subscribe(se)}),j,V=null,q=!1,N=function(me,ge){q=!0;var we=new l,Ne="raw-network-request-"+c(me,v),Re=i(m,Ne,function(){var Oe=m.getNetwork();return Oe.execute(me,v,T,void 0,void 0,void 0,void 0,ge)}),et=Re.subscribe({error:function($e){V=$e,we.error($e)},next:function($e){we.next($e)},complete:function(){we.complete()}}),tt=et.unsubscribe;return j=tt,a.create(function(Oe){var $e=we.subscribe(Oe);return function(){$e.unsubscribe(),j()}})},U,W=function(me,ge){q=!0;var we=i(m,me.request.identifier,ge).subscribe({error:function(Re){F.error(Re)},next:function(Re){F.next(Re)},complete:function(){F.complete()}});U=we.unsubscribe},G=function(me){var ge=o(me,v,T);if(R=m.retain(ge),C!=="store-only"){var we=C!=="store-or-network"||m.check(ge).status!=="available";we&&W(ge,function(){var Ne=N(me.params,function(){return m.check(ge)}),Re=k(ge,Ne);return Re})}},J,te,H;if(y.kind==="PreloadableConcreteRequest"){var M=y;J=M.params;var K=J;H=K.id,H===null&&n(!1);var X=u.get(H);if(X!=null)G(X);else{var B=C==="store-only"?null:N(J),ne=u.onLoad(H,function(se){te();var me=o(se,v,T);R=m.retain(me),B!=null&&W(me,function(){return k(me,B)})});te=ne.dispose}}else{var oe=y,ie=s(oe);J=ie.params,H=J.cacheID!=null?J.cacheID:J.id,G(ie)}var de=!1,be=!1,ve=!1,pe=function(){be||(R&&R.dispose(),be=!0)},_e=function(){ve||($?U&&U():j&&j(),te&&te(),ve=!0)};return{kind:"PreloadedQuery",environment:m,environmentProviderOptions:S,dispose:function(){de||(pe(),_e(),de=!0)},releaseQuery:pe,cancelNetworkRequest:_e,fetchKey:d,id:H,get isDisposed(){return de||be},get networkError(){return V},name:J.name,networkCacheConfig:T,fetchPolicy:C,source:q?L:void 0,variables:v}}return BA={loadQuery:h},BA}var QA,Zq;function JJ(){if(Zq)return QA;Zq=1;var e=TC(),t=e.loadQuery;function n(r,i,a){var u=null;i.root.getModuleIfRequired()==null&&(u=i.root.load());var l=i.getPreloadProps(a),o=l.queries,s=l.entryPoints,c=l.extraProps,d={},h={};if(o!=null){var m=Object.keys(o);m.forEach(function(_){var S=o[_];if(S!=null){var E=S.environmentProviderOptions,C=S.options,T=S.parameters,R=S.variables;if((C==null?void 0:C.includeIf)!==!1){var $=r.getEnvironment(E);d[_]=t($,T,R,{fetchPolicy:C==null?void 0:C.fetchPolicy,networkCacheConfig:C==null?void 0:C.networkCacheConfig,__nameForWarning:"loadEntryPoint"},E)}}})}if(s!=null){var y=Object.keys(s);y.forEach(function(_){var S=s[_];if(S!=null){var E=S.entryPoint,C=S.entryPointParams;h[_]=n(r,E,C)}})}var v=!1;return{dispose:function(){v||(d!=null&&Object.values(d).forEach(function(S){var E=S.dispose;E()}),h!=null&&Object.values(h).forEach(function(S){var E=S.dispose;E()}),v=!0)},entryPoints:h,extraProps:c??null,getComponent:function(){var S=i.root.getModuleIfRequired();if(S==null){var E;throw u=(E=u)!==null&&E!==void 0?E:i.root.load(),u}var C=S.default!=null?S.default:S;return C},get isDisposed(){return v},queries:d,rootModuleID:i.root.getModuleId()}}return QA=n,QA}var zA,Hq;function F4e(){if(Hq)return zA;Hq=1;var e=hy(),t=nr(),n=t.useMemo;function r(i){var a=i.children,u=i.environment,l=i.getEnvironmentForActor,o=n(function(){return{environment:u,getEnvironmentForActor:l}},[u,l]);return t.createElement(e.Provider,{value:o},a)}return zA=r,zA}var qA,Xq;function N4e(){if(Xq)return qA;Xq=1;var e=on(),t=(function(){function r(a){this._capacity=a,this._capacity>0||e(!1),this._map=new Map}var i=r.prototype;return i.set=function(u,l){if(this._map.delete(u),this._map.set(u,l),this._map.size>this._capacity){var o=this._map.keys().next();o.done||this._map.delete(o.value)}},i.get=function(u){var l=this._map.get(u);return l!=null&&(this._map.delete(u),this._map.set(u,l)),l},i.has=function(u){return this._map.has(u)},i.delete=function(u){this._map.delete(u)},i.size=function(){return this._map.size},i.capacity=function(){return this._capacity-this._map.size},i.clear=function(){this._map.clear()},r})();function n(r){return new t(r)}return qA={create:n},qA}var VA,Yq;function I4e(){if(Yq)return VA;Yq=1;var e=Cn().default,t=e(hc());Qi();var n=300*1e3,r=(function(){function i(u){var l=this;(0,t.default)(this,"_retainCount",0),(0,t.default)(this,"_retainDisposable",null),(0,t.default)(this,"_releaseTemporaryRetain",null),this._retain=function(o){return l._retainCount++,l._retainCount===1&&(l._retainDisposable=u(o)),{dispose:function(){l._retainCount=Math.max(0,l._retainCount-1),l._retainCount===0&&l._retainDisposable!=null&&(l._retainDisposable.dispose(),l._retainDisposable=null)}}}}var a=i.prototype;return a.temporaryRetain=function(l){var o=this,s;if(l.isServer())return{dispose:function(){}};var c=this._retain(l),d=null,h=function(){clearTimeout(d),d=null,o._releaseTemporaryRetain=null,c.dispose()};return d=setTimeout(h,n),(s=this._releaseTemporaryRetain)===null||s===void 0||s.call(this),this._releaseTemporaryRetain=h,{dispose:function(){var y;(y=o._releaseTemporaryRetain)===null||y===void 0||y.call(o)}}},a.permanentRetain=function(l){var o=this._retain(l);return this.releaseTemporaryRetain(),o},a.releaseTemporaryRetain=function(){var l;(l=this._releaseTemporaryRetain)===null||l===void 0||l.call(this),this._releaseTemporaryRetain=null},a.getRetainCount=function(){return this._retainCount},i})();return VA=r,VA}var UA,Gq;function aS(){if(Gq)return UA;Gq=1;var e=Cn().default,t=e(zi()),n=e(hc()),r=N4e(),i=I4e(),a=on(),u=ei(),l=u.isPromise;Qi();var o=1e3,s="store-or-network",c="store-and-network",d=typeof WeakMap=="function";function h(R){return R.request.node.params.metadata.live!==void 0}function m(R,$,k,F,L){var j=k??(h($)?c:s),V=F??R.UNSTABLE_getDefaultRenderPolicy(),q="".concat(j,"-").concat(V,"-").concat($.request.identifier);return L!=null?"".concat(q,"-").concat(L):q}function y(R,$){var k={__id:R.fragment.dataID,__fragments:(0,n.default)({},R.fragment.node.name,R.request.variables),__fragmentOwner:R.request};return{cacheIdentifier:$,fragmentNode:R.request.node.fragment,fragmentRef:k,operation:R}}var v=2e5;function _(R,$,k,F,L,j){var V=h($),q=F,N=L,U=new i(function(G){var J=G.retain($);return{dispose:function(){V&&N!=null&&N.unsubscribe(),J.dispose(),j(W)}}}),W={cacheIdentifier:R,id:v++,processedPayloadsCount:0,operationAvailability:k,getValue:function(){return q},setValue:function(J){q=J},setNetworkSubscription:function(J){V&&N!=null&&N.unsubscribe(),N=J},temporaryRetain:function(J){return U.temporaryRetain(J)},permanentRetain:function(J){return U.permanentRetain(J)},releaseTemporaryRetain:function(){U.releaseTemporaryRetain()}};return W}var S=(function(){function R(k){var F=this;(0,n.default)(this,"_clearCacheEntry",function(L){F._cache.delete(L.cacheIdentifier)}),this._environment=k,this._cache=r.create(o)}var $=R.prototype;return $.prepare=function(F,L,j,V,q,N,U){var W=m(this._environment,F,j,V,N);return this.prepareWithIdentifier(W,F,L,j,V,q,U)},$.prepareWithIdentifier=function(F,L,j,V,q,N,U){var W=this._environment,G=V??(h(L)?c:s),J=q??W.UNSTABLE_getDefaultRenderPolicy(),te=this._cache.get(F),H=null,M=te!=null;te==null&&(te=this._fetchAndSaveQuery(F,L,j,G,J,U,(0,t.default)((0,t.default)({},N),{},{unsubscribe:function(B){H!=null&&H.dispose();var ne=N==null?void 0:N.unsubscribe;ne&&ne(B)}}))),H=te.temporaryRetain(W);var K=te.getValue();if(l(K))throw W.__log({name:"suspense.query",fetchPolicy:G,isPromiseCached:M,operation:L,queryAvailability:te.operationAvailability,renderPolicy:J}),K;if(K instanceof Error)throw K;return K},$.retain=function(F,L){var j=this._environment,V=F.cacheIdentifier,q=F.operation,N=this._getOrCreateCacheEntry(V,q,null,F,null),U=N.permanentRetain(j);return j.__log({name:"queryresource.retain",profilerContext:L,resourceID:N.id}),{dispose:function(){U.dispose()}}},$.releaseTemporaryRetain=function(F){var L=this._cache.get(F.cacheIdentifier);L!=null&&L.releaseTemporaryRetain()},$.TESTS_ONLY__getCacheEntry=function(F,L,j,V){var q=this._environment,N=m(q,F,L,j,V);return this._cache.get(N)},$._getOrCreateCacheEntry=function(F,L,j,V,q){var N=this._cache.get(F);return N==null&&(N=_(F,L,j,V,q,this._clearCacheEntry),this._cache.set(F,N)),N},$._fetchAndSaveQuery=function(F,L,j,V,q,N,U){var W=this,G=this._environment,J=G.check(L),te=J.status,H=te==="available",M=H||q==="partial"&&te!=="stale",K,X,B=function(){};switch(V){case"store-only":{K=!1,X=!0;break}case"store-or-network":{K=!H,X=M;break}case"store-and-network":{K=!0,X=M;break}case"network-only":default:{K=!0,X=!1;break}}if(X){var ne=y(L,F),oe=_(F,L,J,ne,null,this._clearCacheEntry);this._cache.set(F,oe)}if(K){var ie=y(L,F),de;j.subscribe({start:function(me){de=me;var ge=W._cache.get(F);ge&&ge.setNetworkSubscription(de);var we=U==null?void 0:U.start;if(we){var Ne=(0,t.default)((0,t.default)({},me),{},{unsubscribe:function(){h(L)&&me.unsubscribe()}});we(Ne)}},next:function(){var me=W._getOrCreateCacheEntry(F,L,J,ie,de);me.processedPayloadsCount+=1,me.setValue(ie),B();var ge=U==null?void 0:U.next;if(ge!=null){var we=G.lookup(L.fragment);ge(we)}},error:function(me){var ge=W._getOrCreateCacheEntry(F,L,J,me,de);ge.processedPayloadsCount===0&&ge.setValue(me),B(),de=null,ge.setNetworkSubscription(null);var we=U==null?void 0:U.error;we&&we(me)},complete:function(){B(),de=null;var me=W._cache.get(F);me&&me.setNetworkSubscription(null);var ge=U==null?void 0:U.complete;ge&&ge()},unsubscribe:U==null?void 0:U.unsubscribe});var be=this._cache.get(F);if(!be){var ve=new Promise(function(se){B=se});ve.displayName="Relay("+L.fragment.node.name+")",be=_(F,L,J,ve,de,this._clearCacheEntry),this._cache.set(F,be)}}else{var pe=U==null?void 0:U.complete;pe&&pe()}var _e=this._cache.get(F);return _e==null&&a(!1),G.__log({name:"queryresource.fetch",resourceID:_e.id,operation:L,profilerContext:N,fetchPolicy:V,renderPolicy:q,queryAvailability:J,shouldFetch:K}),_e},R})();function E(R){return new S(R)}var C=d?new WeakMap:new Map;function T(R){var $=C.get(R);if($)return $;var k=E(R);return C.set(R,k),k}return UA={createQueryResource:E,getQueryResourceForEnvironment:T,getQueryCacheIdentifier:m},UA}var jA,Kq;function eee(){if(Kq)return jA;Kq=1;var e=nr(),t=e.useMemo;function n(r){return t(function(){return{current:r}},[])}return jA=n,jA}var ZA,Wq;function tee(){if(Wq)return ZA;Wq=1;var e=eee(),t=nr(),n=t.useCallback,r=t.useEffect;function i(){var a=e(null),u=e(!1),l=n(function(){a.current!=null&&(a.current.unsubscribe(),a.current=null),u.current=!1},[]),o=n(function(c){a.current=c,u.current=!0},[]),s=n(function(){a.current=null,u.current=!1},[]);return r(function(){return l},[l]),{isFetchingRef:u,startFetch:o,disposeFetch:l,completeFetch:s}}return ZA=i,ZA}var HA,Jq;function L4e(){if(Jq)return HA;Jq=1;var e=nr(),t=ei(),n=t.__internal.createRelayLoggingContext;return HA=n(e),HA}var XA,eV;function nee(){if(eV)return XA;eV=1;var e=L4e(),t=nr(),n=t.useContext;function r(){return n(e)}return XA=r,XA}var YA,tV;function B4e(){if(tV)return YA;tV=1;var e=Cn().default,t=e(zi()),n=e(Du()),r=e(sy()),i=aS(),a=i.getQueryResourceForEnvironment,u=io(),l=nee(),o=on(),s=nr();s.useDebugValue;var c=s.useEffect,d=s.useMemo,h=s.useRef,m=s.useState,y=ei(),v=y.__internal,_=v.fetchQuery,S=v.getPromiseForActiveRequest,E=y.RelayFeatureFlags,C=y.areEqualSelectors,T=y.createOperationDescriptor,R=y.getPendingOperationsForFragment,$=y.getSelector,k=y.getVariablesFromFragment,F=y.handlePotentialSnapshotErrors,L=y.recycleNodesInto;Qi();function j(H){return H.kind==="bailout"?!1:H.kind==="singular"?H.snapshot.isMissingData:H.snapshots.some(function(M){return M.isMissingData})}function V(H){if(H.kind==="bailout")return null;if(H.kind==="singular"){var M;return(M=H.snapshot.missingClientEdges)!==null&&M!==void 0?M:null}else{var K=null,X=(0,n.default)(H.snapshots),B;try{for(X.s();!(B=X.n()).done;){var ne=B.value;if(ne.missingClientEdges){var oe;K=(oe=K)!==null&&oe!==void 0?oe:[];var ie=(0,n.default)(ne.missingClientEdges),de;try{for(ie.s();!(de=ie.n()).done;){var be=de.value;K.push(be)}}catch(ve){ie.e(ve)}finally{ie.f()}}}}catch(ve){X.e(ve)}finally{X.f()}return K}}function q(H){if(H.kind==="bailout")return null;if(H.kind==="singular"){var M;return(M=H.snapshot.missingLiveResolverFields)!==null&&M!==void 0?M:null}else{var K=null,X=(0,n.default)(H.snapshots),B;try{for(X.s();!(B=X.n()).done;){var ne=B.value;if(ne.missingLiveResolverFields){var oe;K=(oe=K)!==null&&oe!==void 0?oe:[];var ie=(0,n.default)(ne.missingLiveResolverFields),de;try{for(ie.s();!(de=ie.n()).done;){var be=de.value;K.push(be)}}catch(ve){ie.e(ve)}finally{ie.f()}}}}catch(ve){X.e(ve)}finally{X.f()}return K}}function N(H,M,K){if(M.kind==="singular")F(H,M.snapshot.fieldErrors,K);else if(M.kind==="plural"){var X=(0,n.default)(M.snapshots),B;try{for(X.s();!(B=X.n()).done;){var ne=B.value;F(H,ne.fieldErrors,K)}}catch(oe){X.e(oe)}finally{X.f()}}}function U(H,M){if(M.kind==="bailout")return null;var K=H.getStore().getEpoch();if(K===M.epoch)return null;if(M.kind==="singular"){var X=H.lookup(M.snapshot.selector),B=L(M.snapshot.data,X.data),ne={data:B,isMissingData:X.isMissingData,missingClientEdges:X.missingClientEdges,missingLiveResolverFields:X.missingLiveResolverFields,seenRecords:X.seenRecords,selector:X.selector,fieldErrors:X.fieldErrors};return[B!==M.snapshot.data,{kind:"singular",snapshot:ne,epoch:K}]}else{for(var oe=!1,ie=[],de=0;de<M.snapshots.length;de++){var be=M.snapshots[de],ve=H.lookup(be.selector),pe=L(be.data,ve.data),_e={data:pe,isMissingData:ve.isMissingData,missingClientEdges:ve.missingClientEdges,missingLiveResolverFields:ve.missingLiveResolverFields,seenRecords:ve.seenRecords,selector:ve.selector,fieldErrors:ve.fieldErrors};pe!==be.data&&(oe=!0),ie.push(_e)}return ie.length!==M.snapshots.length&&o(!1),[oe,{kind:"plural",snapshots:ie,epoch:K}]}}function W(H,M,K,X,B){var ne=k(M,K),oe=(0,t.default)((0,t.default)({},ne),{},{id:X.clientEdgeDestinationID}),ie=T(X.request,oe,B==null?void 0:B.networkCacheConfig),de=a(H),be=de.prepare(ie,_(H,ie),B==null?void 0:B.fetchPolicy);return[be,S(H,ie.request)]}function G(H,M,K,X){if(M.kind==="bailout")return function(){};if(M.kind==="singular"){var B=H.subscribe(M.snapshot,function(oe){K(function(ie){if(ie.kind!=="singular"||ie.snapshot.selector!==oe.selector){var de=U(H,ie);if(de!=null){var be=de[0],ve=de[1];return H.__log({name:"useFragment.subscription.missedUpdates",hasDataChanges:be}),X.current=be,be?ve:ie}else return ie}return X.current=!0,{kind:"singular",snapshot:oe,epoch:H.getStore().getEpoch()}})});return function(){B.dispose()}}else{var ne=M.snapshots.map(function(oe,ie){return H.subscribe(oe,function(de){K(function(be){var ve;if(be.kind!=="plural"||((ve=be.snapshots[ie])===null||ve===void 0?void 0:ve.selector)!==de.selector){var pe=U(H,be);if(pe!=null){var _e=pe[0],se=pe[1];return H.__log({name:"useFragment.subscription.missedUpdates",hasDataChanges:_e}),X.current=X.current||_e,_e?se:be}else return be}var me=(0,r.default)(be.snapshots);return me[ie]=de,X.current=!0,{kind:"plural",snapshots:me,epoch:H.getStore().getEpoch()}})})});return function(){var oe=(0,n.default)(ne),ie;try{for(oe.s();!(ie=oe.n()).done;){var de=ie.value;de.dispose()}}catch(be){oe.e(be)}finally{oe.f()}}}}function J(H,M){return M==null?{kind:"bailout"}:M.kind==="PluralReaderSelector"?{kind:"plural",snapshots:M.selectors.map(function(K){return H.lookup(K)}),epoch:H.getStore().getEpoch()}:{kind:"singular",snapshot:H.lookup(M),epoch:H.getStore().getEpoch()}}function te(H,M,K,X){var B,ne,oe=d(function(){return $(H,M)},[H,M]),ie=(H==null||(B=H.metadata)===null||B===void 0?void 0:B.plural)===!0;ie?M==null||Array.isArray(M)||o(!1):Array.isArray(M)&&o(!1),M==null||ie&&Array.isArray(M)&&M.length===0||oe!=null||o(!1);var de=u(),be;E.ENABLE_UI_CONTEXT_ON_RELAY_LOGGER&&(be=l());var ve=m(function(){return J(de,oe)}),pe=ve[0],_e=ve[1],se=pe,me=m(se),ge=me[0],we=me[1],Ne=ge,Re=m(oe),et=Re[0],tt=Re[1],Oe=m(de),$e=Oe[0],Ae=Oe[1];if(!C(oe,et)||de!==$e){tt(oe),Ae(de);var Ue=J(de,oe);_e(Ue),we(Ue),se=Ue,Ne=Ue}var Ze=h(!1);if(c(function(){Ze.current=oe},[oe]),((ne=H.metadata)===null||ne===void 0?void 0:ne.hasClientEdges)===!0||E.CHECK_ALL_FRAGMENTS_FOR_MISSING_CLIENT_EDGES){var Ye=d(function(){var ht=V(se),Tt,Qt=[];if(ht!=null&&ht.length){Tt=[];var un=(0,n.default)(ht),Ln;try{for(un.s();!(Ln=un.n()).done;){var ln=Ln.value,Zn=W(de,H,M,ln,X),cr=Zn[0],ur=Zn[1];Tt.push(cr),ur!=null&&Qt.push(ur)}}catch(Cr){un.e(Cr)}finally{un.f()}}return[Tt,Qt]},[se,de,H,M,X]),Me=Ye[0],ze=Ye[1];if(ze.length)throw Promise.all(ze);c(function(){var ht=a(de);if(Me!=null&&Me.length){var Tt=[],Qt=(0,n.default)(Me),un;try{for(Qt.s();!(un=Qt.n()).done;){var Ln=un.value;Tt.push(ht.retain(Ln))}}catch(ln){Qt.e(ln)}finally{Qt.f()}return function(){for(var ln=0,Zn=Tt;ln<Zn.length;ln++){var cr=Zn[ln];cr.dispose()}}}},[de,Me])}if(j(se)){var st=q(se);if(st!=null&&st.length>0)throw Promise.all(st.map(function(ht){return de.getStore().getLiveResolverPromise(ht)}));if(E.ENABLE_RELAY_OPERATION_TRACKER_SUSPENSE||de!==$e||!Ze.current||!C(Ze.current,oe)){oe==null&&o(!1);var Ot=oe.kind==="PluralReaderSelector"?oe.selectors[0].owner:oe.owner,Nt=R(de,H,Ot);if(Nt)throw Nt.promise}}N(de,se,be);var gt=h(!1);if(c(function(){var ht=Ne,Tt=U(de,Ne);if(Tt!==null){var Qt=Tt[0],un=Tt[1];Qt&&_e(un),ht=un}return G(de,ht,_e,gt)},[de,Ne]),gt.current){var qt=U(de,se);if(qt!=null){var zt=qt[0],an=qt[1];zt&&(_e(an),se=an)}gt.current=!1}var rn;if(ie){var Fe=M==null;rn=d(function(){return se.kind==="bailout"?Fe?null:[]:(se.kind!=="plural"&&o(!1),se.snapshots.map(function(ht){return ht.data}))},[se,Fe])}else se.kind==="bailout"?rn=null:(se.kind!=="singular"&&o(!1),rn=se.snapshot.data);return E.LOG_MISSING_RECORDS_IN_PROD&&M!=null&&(rn===void 0||Array.isArray(rn)&&rn.length>0&&rn.every(function(ht){return ht===void 0})),rn}return YA=te,YA}var GA,nV;function Q4e(){if(nV)return GA;nV=1;var e=Cn().default,t=e(zi()),n=e(Du()),r=e(sy()),i=aS(),a=i.getQueryResourceForEnvironment,u=io(),l=nee(),o=on(),s=nr();s.useDebugValue;var c=s.useEffect,d=s.useMemo,h=s.useRef,m=s.useState,y=ei(),v=y.__internal,_=v.fetchQuery,S=v.getPromiseForActiveRequest,E=y.RelayFeatureFlags,C=y.areEqualSelectors,T=y.createOperationDescriptor,R=y.getPendingOperationsForFragment,$=y.getSelector,k=y.getVariablesFromFragment,F=y.handlePotentialSnapshotErrors,L=y.recycleNodesInto;Qi();function j(H){return H.kind==="bailout"?!1:H.kind==="singular"?H.snapshot.isMissingData:H.snapshots.some(function(M){return M.isMissingData})}function V(H){if(H.kind==="bailout")return null;if(H.kind==="singular"){var M;return(M=H.snapshot.missingClientEdges)!==null&&M!==void 0?M:null}else{var K=null,X=(0,n.default)(H.snapshots),B;try{for(X.s();!(B=X.n()).done;){var ne=B.value;if(ne.missingClientEdges){var oe;K=(oe=K)!==null&&oe!==void 0?oe:[];var ie=(0,n.default)(ne.missingClientEdges),de;try{for(ie.s();!(de=ie.n()).done;){var be=de.value;K.push(be)}}catch(ve){ie.e(ve)}finally{ie.f()}}}}catch(ve){X.e(ve)}finally{X.f()}return K}}function q(H){if(H.kind==="bailout")return null;if(H.kind==="singular"){var M;return(M=H.snapshot.missingLiveResolverFields)!==null&&M!==void 0?M:null}else{var K=null,X=(0,n.default)(H.snapshots),B;try{for(X.s();!(B=X.n()).done;){var ne=B.value;if(ne.missingLiveResolverFields){var oe;K=(oe=K)!==null&&oe!==void 0?oe:[];var ie=(0,n.default)(ne.missingLiveResolverFields),de;try{for(ie.s();!(de=ie.n()).done;){var be=de.value;K.push(be)}}catch(ve){ie.e(ve)}finally{ie.f()}}}}catch(ve){X.e(ve)}finally{X.f()}return K}}function N(H,M,K){if(M.kind==="singular")F(H,M.snapshot.fieldErrors,K);else if(M.kind==="plural"){var X=(0,n.default)(M.snapshots),B;try{for(X.s();!(B=X.n()).done;){var ne=B.value;F(H,ne.fieldErrors,K)}}catch(oe){X.e(oe)}finally{X.f()}}}function U(H,M){if(M.kind==="bailout")return null;var K=H.getStore().getEpoch();if(K===M.epoch)return null;if(M.kind==="singular"){var X=H.lookup(M.snapshot.selector),B=L(M.snapshot.data,X.data),ne={data:B,isMissingData:X.isMissingData,missingClientEdges:X.missingClientEdges,missingLiveResolverFields:X.missingLiveResolverFields,seenRecords:X.seenRecords,selector:X.selector,fieldErrors:X.fieldErrors};return[B!==M.snapshot.data,{kind:"singular",snapshot:ne,epoch:K,selector:M.selector,environment:M.environment}]}else{for(var oe=!1,ie=[],de=0;de<M.snapshots.length;de++){var be=M.snapshots[de],ve=H.lookup(be.selector),pe=L(be.data,ve.data),_e={data:pe,isMissingData:ve.isMissingData,missingClientEdges:ve.missingClientEdges,missingLiveResolverFields:ve.missingLiveResolverFields,seenRecords:ve.seenRecords,selector:ve.selector,fieldErrors:ve.fieldErrors};pe!==be.data&&(oe=!0),ie.push(_e)}return ie.length!==M.snapshots.length&&o(!1),[oe,{kind:"plural",snapshots:ie,epoch:K,selector:M.selector,environment:M.environment}]}}function W(H,M,K,X,B){var ne=k(M,K),oe=(0,t.default)((0,t.default)({},ne),{},{id:X.clientEdgeDestinationID}),ie=T(X.request,oe,B==null?void 0:B.networkCacheConfig),de=a(H),be=de.prepare(ie,_(H,ie),B==null?void 0:B.fetchPolicy),ve=S(H,ie.request);return ve!=null&&ve.displayName==null&&(ve.displayName=X.request.params.name),[be,ve]}function G(H,M,K){if(M.kind==="bailout")return function(){};if(M.kind==="singular"){var X=H.subscribe(M.snapshot,function(ne){K(function(oe){var ie=null;if(oe.kind!=="singular"||oe.snapshot.selector!==ne.selector||oe.environment!==H){var de=U(oe.environment,oe);if(de!=null){var be=de[0],ve=de[1];H.__log({name:"useFragment.subscription.missedUpdates",hasDataChanges:be}),ie=be?ve:oe}else ie=oe}else ie={kind:"singular",snapshot:ne,epoch:H.getStore().getEpoch(),selector:M.selector,environment:M.environment};return ie})});return function(){X.dispose()}}else{var B=M.snapshots.map(function(ne,oe){return H.subscribe(ne,function(ie){K(function(de){var be,ve=null;if(de.kind!=="plural"||((be=de.snapshots[oe])===null||be===void 0?void 0:be.selector)!==ie.selector||de.environment!==H){var pe=U(de.environment,de);if(pe!=null){var _e=pe[0],se=pe[1];H.__log({name:"useFragment.subscription.missedUpdates",hasDataChanges:_e}),ve=_e?se:de}else ve=de}else{var me=(0,r.default)(de.snapshots);me[oe]=ie,ve={kind:"plural",snapshots:me,epoch:H.getStore().getEpoch(),selector:M.selector,environment:M.environment}}return ve})})});return function(){var ne=(0,n.default)(B),oe;try{for(ne.s();!(oe=ne.n()).done;){var ie=oe.value;ie.dispose()}}catch(de){ne.e(de)}finally{ne.f()}}}}function J(H,M){return M==null?{kind:"bailout",environment:H}:M.kind==="PluralReaderSelector"?{kind:"plural",snapshots:M.selectors.map(function(K){return H.lookup(K)}),epoch:H.getStore().getEpoch(),selector:M,environment:H}:{kind:"singular",snapshot:H.lookup(M),epoch:H.getStore().getEpoch(),selector:M,environment:H}}function te(H,M,K,X){var B,ne,oe=d(function(){return $(H,M)},[H,M]),ie=(H==null||(B=H.metadata)===null||B===void 0?void 0:B.plural)===!0;ie?M==null||Array.isArray(M)||o(!1):Array.isArray(M)&&o(!1),M==null||ie&&Array.isArray(M)&&M.length===0||oe!=null||o(!1);var de=u(),be;E.ENABLE_UI_CONTEXT_ON_RELAY_LOGGER&&(be=l());var ve=m(function(){return J(de,oe)}),pe=ve[0],_e=ve[1],se=pe,me=se.environment;if(!C(oe,se.selector)||de!==se.environment){var ge=J(de,oe);_e(ge),se=ge}var we=h(!1);if(c(function(){we.current=oe},[oe]),((ne=H.metadata)===null||ne===void 0?void 0:ne.hasClientEdges)===!0||E.CHECK_ALL_FRAGMENTS_FOR_MISSING_CLIENT_EDGES){var Ne=d(function(){var ze=V(se),st,Ot=[];if(ze!=null&&ze.length){st=[];var Nt=(0,n.default)(ze),gt;try{for(Nt.s();!(gt=Nt.n()).done;){var qt=gt.value,zt=W(de,H,M,qt,X),an=zt[0],rn=zt[1];st.push(an),rn!=null&&Ot.push(rn)}}catch(Fe){Nt.e(Fe)}finally{Nt.f()}}return[st,Ot]},[se,de,H,M,X]),Re=Ne[0],et=Ne[1];if(et.length){var tt=Promise.all(et);throw tt.displayName="RelayClientEdge(".concat(et.map(function(ze){return ze.displayName}).join(","),")"),tt}c(function(){var ze=a(de);if(Re!=null&&Re.length){var st=[],Ot=(0,n.default)(Re),Nt;try{for(Ot.s();!(Nt=Ot.n()).done;){var gt=Nt.value;st.push(ze.retain(gt))}}catch(qt){Ot.e(qt)}finally{Ot.f()}return function(){for(var qt=0,zt=st;qt<zt.length;qt++){var an=zt[qt];an.dispose()}}}},[de,Re])}if(j(se)){var Oe=q(se);if(Oe!=null&&Oe.length>0){var $e=Promise.all(Oe.map(function(ze){return de.getStore().getLiveResolverPromise(ze)}));throw $e.displayName="RelayLiveResolver("+H.name+")",$e}if(E.ENABLE_RELAY_OPERATION_TRACKER_SUSPENSE||de!==me||!we.current||!C(we.current,oe)){oe==null&&o(!1);var Ae=oe.kind==="PluralReaderSelector"?oe.selectors[0].owner:oe.owner,Ue=R(de,H,Ae);if(Ue)throw Ue.promise}}N(de,se,be);var Ze=h(null);c(function(){var ze=Ze.current;if(ze!=null){if(se.environment===ze.environment&&se.selector===ze.selector)return;ze.dispose()}if(se.kind!=="bailout"){var st=se,Ot=U(se.environment,se);if(Ot!==null){var Nt=Ot[0],gt=Ot[1];if(Nt){_e(gt);return}st=gt}var qt=G(se.environment,st,_e);Ze.current={dispose:qt,selector:se.selector,environment:se.environment}}},[se]),c(function(){if(Ze.current==null&&se.kind!=="bailout"){var ze=G(se.environment,se,_e);Ze.current={dispose:ze,selector:se.selector,environment:se.environment}}return function(){var st;(st=Ze.current)===null||st===void 0||st.dispose(),Ze.current=null}},[]);var Ye;if(ie){var Me=M==null;Ye=d(function(){return se.kind==="bailout"?Me?null:[]:(se.kind!=="plural"&&o(!1),se.snapshots.map(function(ze){return ze.data}))},[se,Me])}else se.kind==="bailout"?Ye=null:(se.kind!=="singular"&&o(!1),Ye=se.snapshot.data);return E.LOG_MISSING_RECORDS_IN_PROD&&M!=null&&(Ye===void 0||Array.isArray(Ye)&&Ye.length>0&&Ye.every(function(ze){return ze===void 0})),Ye}return GA=te,GA}var KA,rV;function YF(){if(rV)return KA;rV=1;var e=Cn().default,t=e(B4e()),n=e(Q4e()),r=ei();function i(a,u,l,o){return r.RelayFeatureFlags.ENABLE_ACTIVITY_COMPATIBILITY?(0,n.default)(a,u,l,o):(0,t.default)(a,u,l,o)}return KA=i,KA}var WA,iV;function ree(){if(iV)return WA;iV=1;var e=AC(),t=aS(),n=t.getQueryCacheIdentifier,r=t.getQueryResourceForEnvironment,i=tee(),a=YF(),u=io(),l=nr(),o=l.useContext,s=l.useEffect,c=l.useState,d=l.useRef;function h(m){var y=m.query,v=m.componentDisplayName,_=m.fetchObservable,S=m.fetchPolicy,E=m.fetchKey,C=m.renderPolicy,T=u(),R=o(e),$=r(T),k=c(0),F=k[0],L=k[1],j=i(),V=j.startFetch,q=j.completeFetch,N="".concat(F,"-").concat(E??""),U=n(T,y,S,C,N),W=R.wrapPrepareQueryResource(function(){return $.prepareWithIdentifier(U,y,_,S,C,{start:V,complete:q,error:q},R)}),G=d(!1);s(function(){return function(){G.current=!0}},[]),s(function(){if(G.current===!0){G.current=!1,L(function(K){return K+1});return}var M=$.retain(W,R);return function(){M.dispose()}},[T,U]),s(function(){$.releaseTemporaryRetain(W)});var J=W.fragmentNode,te=W.fragmentRef,H=a(J,te,v);return H}return WA=h,WA}var JA,aV;function z4e(){if(aV)return JA;aV=1;var e=Jf(),t=nr(),n=t.useState;function r(i){var a=n(i),u=a[0],l=a[1];return e(i,u)?u:(l(i),i)}return JA=r,JA}var eT,uV;function iee(){if(uV)return eT;uV=1;var e=z4e(),t=nr(),n=ei(),r=n.createOperationDescriptor,i=n.getRequest,a=t.useMemo;function u(l,o,s){var c=e(o),d=e(s||{});return a(function(){return r(i(l),c,d)},[l,c,d])}return eT=u,eT}var tT,lV;function aee(){if(lV)return tT;lV=1;var e=ree(),t=iee(),n=io(),r=ei(),i=r.__internal.fetchQuery;function a(u,l,o){var s=n(),c=t(u,l,o&&o.networkCacheConfig?o.networkCacheConfig:{force:!0}),d=e({componentDisplayName:"useLazyLoadQuery()",fetchKey:o==null?void 0:o.fetchKey,fetchObservable:i(s,c),fetchPolicy:o==null?void 0:o.fetchPolicy,query:c,renderPolicy:o==null?void 0:o.UNSTABLE_renderPolicy});return d}return tT=a,tT}var nT,oV;function q4e(){if(oV)return nT;oV=1;var e=Cn().default,t=e(zi()),n=aee();function r(i,a,u){var l=i;return n(l,a,(0,t.default)((0,t.default)({},u),{},{fetchPolicy:"store-only"}))}return nT=r,nT}var rT,sV;function Eb(){if(sV)return rT;sV=1;var e=nr(),t=e.useEffect,n=e.useRef;function r(){var i=n(!0);return t(function(){return i.current=!0,function(){i.current=!1}},[]),i}return rT=r,rT}var iT,cV;function V4e(){if(cV)return iT;cV=1;var e=Cn().default,t=e(Du()),n=JJ(),r=Eb(),i=nr(),a=i.useCallback,u=i.useEffect,l=i.useRef,o=i.useState,s={kind:"NullEntryPointReference"};function c(d,h,m){var y,v,_,S,E=(y=m==null||(v=m.TEST_ONLY__initialEntryPointData)===null||v===void 0?void 0:v.entryPointReference)!==null&&y!==void 0?y:s,C=(_=m==null||(S=m.TEST_ONLY__initialEntryPointData)===null||S===void 0?void 0:S.entryPointParams)!==null&&_!==void 0?_:null,T=r(),R=l(new Set([E])),$=o(E),k=$[0],F=$[1],L=o(C),j=L[0],V=L[1],q=a(function(){if(T.current){var W={kind:"NullEntryPointReference"};R.current.add(W),F(W)}},[F,T]),N=a(function(W){if(T.current){var G=n(d,h,W);R.current.add(G),F(G),V(W)}},[d,h,F,T]),U=l(!1);return u(function(){return function(){U.current=!0}},[]),u(function(){if(U.current===!0){U.current=!1,k.kind!=="NullEntryPointReference"&&j!=null&&N(j);return}var W=R.current;if(T.current){var G=(0,t.default)(W),J;try{for(G.s();!(J=G.n()).done;){var te=J.value;if(te===k)break;W.delete(te),te.kind!=="NullEntryPointReference"&&te.dispose()}}catch(H){G.e(H)}finally{G.f()}}},[k,j,N,T]),u(function(){return function(){var G=(0,t.default)(R.current),J;try{for(G.s();!(J=G.n()).done;){var te=J.value;te.kind!=="NullEntryPointReference"&&te.dispose()}}catch(H){G.e(H)}finally{G.f()}}},[]),[k.kind==="NullEntryPointReference"?null:k,N,q]}return iT=c,iT}var aT,fV;function kC(){if(fV)return aT;fV=1,eee(),Qi();function e(t,n){}return aT=e,aT}var uT,dV;function uee(){if(dV)return uT;dV=1;var e=YF(),t=kC(),n=nr();n.useDebugValue;var r=ei(),i=r.getFragment;function a(u,l){var o=i(u);t(o,"first argument of useFragment()");var s=e(o,l,"useFragment()");return s}return uT=a,uT}var lT,hV;function U4e(){if(hV)return lT;hV=1;var e=Cn().default,t=e(zi()),n=Eb(),r=io(),i=nr(),a=ei(),u=a.commitMutation,l=i.useState,o=i.useEffect,s=i.useRef,c=i.useCallback;function d(h){var m=arguments.length>1&&arguments[1]!==void 0?arguments[1]:u,y=r(),v=n(),_=s(y),S=s(h),E=s(new Set),C=l(!1),T=C[0],R=C[1],$=c(function(F){_.current===y&&S.current===h&&(E.current.delete(F),v.current&&R(E.current.size>0))},[y,v,h]);o(function(){(_.current!==y||S.current!==h)&&(E.current=new Set,v.current&&R(!1),_.current=y,S.current=h)},[y,v,h]);var k=c(function(F){v.current&&R(!0);var L=m(y,(0,t.default)((0,t.default)({},F),{},{mutation:h,onCompleted:function(V,q){var N;$(L),(N=F.onCompleted)===null||N===void 0||N.call(F,V,q)},onError:function(V){var q;$(L),(q=F.onError)===null||q===void 0||q.call(F,V)},onUnsubscribe:function(){var V;$(L),(V=F.onUnsubscribe)===null||V===void 0||V.call(F)},onNext:function(){var V;(V=F.onNext)===null||V===void 0||V.call(F)}}));return E.current.add(L),L},[$,m,y,v,h]);return[k,T]}return lT=d,lT}var oT,pV;function lee(){if(pV)return oT;pV=1;var e=on(),t=ei(),n=t.ConnectionInterface,r=t.getValueAtPath;function i(a,u,l,o){var s,c,d=n.get(),h=d.EDGES,m=d.PAGE_INFO,y=d.HAS_NEXT_PAGE,v=d.HAS_PREV_PAGE,_=d.END_CURSOR,S=d.START_CURSOR,E=r(l,o);if(E==null)return{cursor:null,hasMore:!1};typeof E!="object"&&e(!1);var C=E[h],T=E[m];if(C==null||T==null)return{cursor:null,hasMore:!1};Array.isArray(C)||e(!1),typeof T!="object"&&e(!1);var R=a==="forward"?(s=T[_])!==null&&s!==void 0?s:null:(c=T[S])!==null&&c!==void 0?c:null;R===null||typeof R=="string"||e(!1);var $;return a==="forward"?$=R!=null&&T[y]===!0:$=R!=null&&T[v]===!0,{cursor:R,hasMore:$}}return oT=i,oT}var sT,mV;function oee(){if(mV)return sT;mV=1;var e=io(),t=on(),n=nr(),r=ei(),i=r.__internal.getObservableForActiveRequest,a=r.getSelector,u=n.useEffect,l=n.useState,o=n.useMemo;function s(c,d){var h=e(),m=o(function(){var S=a(c,d);return S==null?null:(S.kind!=="SingularReaderSelector"&&t(!1),i(h,S.owner))},[h,c,d]),y=l(m!=null),v=y[0],_=y[1];return u(function(){var S;if(_(m!=null),m!=null){var E=function(){_(!1)};S=m.subscribe({complete:E,error:E})}return function(){S&&S.unsubscribe()}},[m]),v}return sT=s,sT}var cT,gV;function j4e(){if(gV)return cT;gV=1;var e=Cn().default,t=e(zi()),n=lee(),r=Eb(),i=oee(),a=io(),u=on(),l=nr(),o=l.useCallback,s=l.useRef,c=l.useState,d=ei(),h=d.__internal.fetchQuery,m=d.createOperationDescriptor,y=d.getPaginationVariables,v=d.getRefetchMetadata,_=d.getSelector;Qi();function S(E){var C=E.direction,T=E.fragmentNode,R=E.fragmentRef,$=E.fragmentIdentifier,k=E.fragmentData,F=E.connectionPathInFragmentData,L=E.paginationRequest,j=E.paginationMetadata,V=E.componentDisplayName,q=E.observer,N=E.onReset,U=a(),W=v(T,V),G=W.identifierInfo,J=(G==null?void 0:G.identifierField)!=null&&k!=null&&typeof k=="object"?k[G.identifierField]:null,te=s({kind:"none"}),H=c(U),M=H[0],K=H[1],X=c($),B=X[0],ne=X[1],oe=i(T,R),ie=o(function(){te.current.kind==="fetching"&&te.current.subscription.unsubscribe(),te.current={kind:"none"}},[]),de=U!==M||$!==B;de&&(ie(),N(),K(U),ne($));var be=n(C,T,k,F),ve=be.cursor,pe=be.hasMore,_e=k==null||oe,se=r(),me=o(function(ge,we){var Ne=we==null?void 0:we.onComplete;if(se.current!==!0)return{dispose:function(){}};var Re=_(T,R);if(te.current.kind==="fetching"||_e)return Ne&&Ne(null),{dispose:function(){}};Re!=null&&Re.kind!=="PluralReaderSelector"||u(!1);var et=Re.owner.variables,tt=Re.variables,Oe=we==null?void 0:we.UNSTABLE_extraVariables,$e=(0,t.default)((0,t.default)({},et),tt),Ae=y(C,ge,ve,$e,(0,t.default)({},Oe),j);G!=null&&(Ae[G.identifierQueryVariableName]=J);var Ue=m(L,Ae,{force:!0});return h(U,Ue).subscribe((0,t.default)((0,t.default)({},q),{},{start:function(Ye){te.current={kind:"fetching",subscription:Ye},q.start&&q.start(Ye)},complete:function(){te.current={kind:"none"},q.complete&&q.complete(),Ne&&Ne(null)},error:function(Ye){te.current={kind:"none"},q.complete&&q.complete(),Ne&&Ne(Ye)}})),{dispose:function(){}}},[U,J,C,ve,_e,T.name,R,V]);return[me,pe,ie]}return cT=S,cT}var fT,vV;function see(){if(vV)return fT;vV=1;var e=Cn().default,t=e(zi()),n=lee(),r=tee(),i=Eb(),a=oee(),u=j4e(),l=io(),o=on(),s=nr(),c=s.useCallback,d=s.useEffect,h=s.useState,m=ei(),y=m.__internal.fetchQuery,v=m.RelayFeatureFlags,_=m.createOperationDescriptor,S=m.getPaginationVariables,E=m.getRefetchMetadata,C=m.getSelector;Qi();function T($){return v.ENABLE_ACTIVITY_COMPATIBILITY?u($):R($)}function R($){var k=$.direction,F=$.fragmentNode,L=$.fragmentRef,j=$.fragmentIdentifier,V=$.fragmentData,q=$.connectionPathInFragmentData,N=$.paginationRequest,U=$.paginationMetadata,W=$.componentDisplayName,G=$.observer,J=$.onReset,te=l(),H=r(),M=H.isFetchingRef,K=H.startFetch,X=H.disposeFetch,B=H.completeFetch,ne=E(F,W),oe=ne.identifierInfo,ie=(oe==null?void 0:oe.identifierField)!=null&&V!=null&&typeof V=="object"?V[oe.identifierField]:null,de=i(),be=h(te),ve=be[0],pe=be[1],_e=h(j),se=_e[0],me=_e[1],ge=a(F,L),we=te!==ve||j!==se;we&&(X(),J(),pe(te),me(j));var Ne=n(k,F,V,q),Re=Ne.cursor,et=Ne.hasMore;d(function(){return function(){X()}},[X]);var tt=V==null||ge,Oe=c(function($e,Ae){var Ue=Ae==null?void 0:Ae.onComplete;if(de.current!==!0)return{dispose:function(){}};var Ze=C(F,L);if(M.current===!0||tt)return Ue&&Ue(null),{dispose:function(){}};Ze!=null&&Ze.kind!=="PluralReaderSelector"||o(!1);var Ye=Ze.owner.variables,Me=Ze.variables,ze=Ae==null?void 0:Ae.UNSTABLE_extraVariables,st=(0,t.default)((0,t.default)({},Ye),Me),Ot=S(k,$e,Re,st,(0,t.default)({},ze),U);oe!=null&&(Ot[oe.identifierQueryVariableName]=ie);var Nt=_(N,Ot,{force:!0});return y(te,Nt).subscribe((0,t.default)((0,t.default)({},G),{},{start:function(qt){K(qt),G.start&&G.start(qt)},complete:function(){B(),G.complete&&G.complete(),Ue&&Ue(null)},error:function(qt){B(),G.error&&G.error(qt),Ue&&Ue(qt)}})),{dispose:X}},[te,ie,k,Re,K,X,B,M,tt,F.name,L,W]);return[Oe,et,X]}return fT=T,fT}var dT,yV;function Z4e(){if(yV)return dT;yV=1;var e=Cn().default,t=e(zi()),n=e(Du()),r=aS(),i=r.getQueryResourceForEnvironment,a=on(),u=ei(),l=u.__internal.fetchQuery,o=u.RelayFeatureFlags,s=u.createOperationDescriptor,c=u.getPendingOperationsForFragment,d=u.getSelector,h=u.getVariablesFromFragment,m=u.handlePotentialSnapshotErrors;Qi();function y(T){return T.kind==="bailout"?!1:T.kind==="singular"?T.snapshot.isMissingData:T.snapshots.some(function(R){return R.isMissingData})}function v(T){if(T.kind==="bailout")return null;if(T.kind==="singular"){var R;return(R=T.snapshot.missingClientEdges)!==null&&R!==void 0?R:null}else{var $=null,k=(0,n.default)(T.snapshots),F;try{for(k.s();!(F=k.n()).done;){var L=F.value;if(L.missingClientEdges){var j;$=(j=$)!==null&&j!==void 0?j:[];var V=(0,n.default)(L.missingClientEdges),q;try{for(V.s();!(q=V.n()).done;){var N=q.value;$.push(N)}}catch(U){V.e(U)}finally{V.f()}}}}catch(U){k.e(U)}finally{k.f()}return $}}function _(T,R){if(R.kind==="singular")m(T,R.snapshot.fieldErrors);else if(R.kind==="plural"){var $=(0,n.default)(R.snapshots),k;try{for($.s();!(k=$.n()).done;){var F=k.value;m(T,F.fieldErrors)}}catch(L){$.e(L)}finally{$.f()}}}function S(T,R,$,k,F){var L=h(R,$),j=(0,t.default)((0,t.default)({},L),{},{id:k.clientEdgeDestinationID}),V=s(k.request,j,F==null?void 0:F.networkCacheConfig),q=i(T);return q.prepare(V,l(T,V),F==null?void 0:F.fetchPolicy)}function E(T,R){return R==null?{kind:"bailout"}:R.kind==="PluralReaderSelector"?R.selectors.length===0?{kind:"bailout"}:{kind:"plural",snapshots:R.selectors.map(function($){return T.lookup($)}),epoch:T.getStore().getEpoch()}:{kind:"singular",snapshot:T.lookup(R),epoch:T.getStore().getEpoch()}}function C(T,R,$,k,F,L){var j,V,q=d(R,$),N=(R==null||(j=R.metadata)===null||j===void 0?void 0:j.plural)===!0;N?$==null||Array.isArray($)||a(!1):Array.isArray($)&&a(!1),$==null||N&&Array.isArray($)&&$.length===0||q!=null||a(!1);var U=E(T,q),W=null;if(((V=R.metadata)===null||V===void 0?void 0:V.hasClientEdges)===!0||o.CHECK_ALL_FRAGMENTS_FOR_MISSING_CLIENT_EDGES){var G=v(U);if(G!=null&&G.length){W=[];var J=(0,n.default)(G),te;try{for(J.s();!(te=J.n()).done;){var H=te.value;W.push(S(T,R,$,H,F))}}catch(B){J.e(B)}finally{J.f()}}}if(y(U)){q==null&&a(!1);var M=q.kind==="PluralReaderSelector"?q.selectors[0].owner:q.owner,K=c(T,R,M);if(K)throw K.promise;_(T,U)}var X;return U.kind==="bailout"?X=N?[]:null:U.kind==="singular"?X=U.snapshot.data:X=U.snapshots.map(function(B){return B.data}),o.LOG_MISSING_RECORDS_IN_PROD&&$!=null&&(X===void 0||Array.isArray(X)&&X.length>0&&X.every(function(B){return B===void 0})),{data:X,clientEdgeQueries:W}}return dT=C,dT}var hT,bV;function H4e(){if(bV)return hT;bV=1;var e=Cn().default,t=e(Du()),n=TC(),r=n.loadQuery,i=Eb(),a=io(),u=nr(),l=u.useCallback,o=u.useEffect,s=u.useInsertionEffect,c=u.useRef,d=u.useState,h=ei(),m=h.getRequest,y={kind:"NullQueryReference"};function v(E){if(E.kind==="PreloadableConcreteRequest")return E.params.metadata.live!==void 0;var C=m(E);return C.params.metadata.live!==void 0}var _=1e3*60*5;function S(E,C){var T=C??y,R=a(),$=i(),k=c(null);k.current==null&&(k.current=new Set([T]));var F=d(function(){return T}),L=F[0],j=F[1],V=d(function(){return T}),q=V[0],N=V[1];if(T!==q){var U;(U=k.current)===null||U===void 0||U.add(T),N(T),j(T)}var W=l(function(){if($.current){var H;(H=k.current)===null||H===void 0||H.add(y),j(y)}},[$]),G=l(function(H,M){var K,X;if($.current){var B=M!=null&&M.hasOwnProperty("__environment")?{fetchPolicy:M.fetchPolicy,networkCacheConfig:M.networkCacheConfig,__nameForWarning:M.__nameForWarning}:M,ne=r((K=M==null?void 0:M.__environment)!==null&&K!==void 0?K:R,E,H,B);(X=k.current)===null||X===void 0||X.add(ne),j(ne)}},[R,E,j,$]),J=l(function(M,K){var X,B=(X=k.current)!==null&&X!==void 0?X:new Set,ne=(0,t.default)(B),oe;try{for(ne.s();!(oe=ne.n()).done;){var ie=oe.value;ie!==K&&ie.kind!=="NullQueryReference"&&(v(M)?ie.dispose&&ie.dispose():ie.releaseQuery&&ie.releaseQuery())}}catch(de){ne.e(de)}finally{ne.f()}},[]),te=c(null);return o(function(){return J(E,L),te.current!=null&&(clearTimeout(te.current),te.current=null),function(){te.current=setTimeout(function(){J(E,null)},_)}},[E,L]),s(function(){return function(){te.current&&clearTimeout(te.current),te.current=null,J(E,null)}},[E]),[L.kind==="NullQueryReference"?null:L,G,W]}return hT=S,hT}var pT,OV;function cee(){if(OV)return pT;OV=1;var e=Cn().default,t=e(Du()),n=TC(),r=n.loadQuery,i=Eb(),a=H4e(),u=io(),l=nr(),o=l.useCallback,s=l.useEffect,c=l.useRef,d=l.useState,h=ei(),m=h.RelayFeatureFlags,y=h.getRequest,v={kind:"NullQueryReference"};function _(C){if(C.kind==="PreloadableConcreteRequest")return C.params.metadata.live!==void 0;var T=y(C);return T.params.metadata.live!==void 0}function S(C,T){return m.ENABLE_ACTIVITY_COMPATIBILITY?a(C,T):E(C,T)}function E(C,T){var R=T??v,$=u(),k=i(),F=c(new Set([R])),L=d(function(){return R}),j=L[0],V=L[1],q=d(function(){return R}),N=q[0],U=q[1];R!==N&&(F.current.add(R),U(R),V(R));var W=o(function(){k.current&&(F.current.add(v),V(v))},[k]),G=o(function(te,H){var M=H!=null&&H.hasOwnProperty("__environment")?{fetchPolicy:H.fetchPolicy,networkCacheConfig:H.networkCacheConfig,__nameForWarning:H.__nameForWarning}:H;if(k.current){var K,X=r((K=H==null?void 0:H.__environment)!==null&&K!==void 0?K:$,C,te,M);F.current.add(X),V(X)}},[$,C,V,k]),J=c(!1);return s(function(){return function(){J.current=!0}},[]),s(function(){if(J.current===!0){J.current=!1,j.kind!=="NullQueryReference"&&G(j.variables,{fetchPolicy:j.fetchPolicy,networkCacheConfig:j.networkCacheConfig});return}var te=F.current;if(k.current){var H=(0,t.default)(te),M;try{for(H.s();!(M=H.n()).done;){var K=M.value;if(K===j)break;te.delete(K),K.kind!=="NullQueryReference"&&(_(C)?K.dispose&&K.dispose():K.releaseQuery&&K.releaseQuery())}}catch(X){H.e(X)}finally{H.f()}}},[j,k,G,C]),s(function(){return function(){var H=(0,t.default)(F.current),M;try{for(H.s();!(M=H.n()).done;){var K=M.value;K.kind!=="NullQueryReference"&&(_(C)?K.dispose&&K.dispose():K.releaseQuery&&K.releaseQuery())}}catch(X){H.e(X)}finally{H.f()}}},[C]),[j.kind==="NullQueryReference"?null:j,G,W]}return pT=S,pT}var mT,xV;function GF(){if(xV)return mT;xV=1;var e=Cn().default,t=e(zi()),n=AC(),r=aS(),i=r.getQueryResourceForEnvironment,a=Z4e(),u=YF(),l=Eb(),o=cee(),s=io(),c=on(),d=nr(),h=d.useCallback,m=d.useContext,y=d.useReducer,v=ei(),_=v.__internal.fetchQuery,S=v.createOperationDescriptor,E=v.getFragmentIdentifier,C=v.getRefetchMetadata,T=v.getSelector,R=v.getValueAtPath;Qi();function $(L,j){switch(j.type){case"refetch":{var V;return(0,t.default)((0,t.default)({},L),{},{fetchPolicy:j.fetchPolicy,mirroredEnvironment:(V=j.refetchEnvironment)!==null&&V!==void 0?V:L.mirroredEnvironment,onComplete:j.onComplete,refetchEnvironment:j.refetchEnvironment,refetchQuery:j.refetchQuery,renderPolicy:j.renderPolicy})}case"reset":return{fetchPolicy:void 0,mirroredEnvironment:j.environment,mirroredFragmentIdentifier:j.fragmentIdentifier,onComplete:void 0,refetchQuery:null,renderPolicy:void 0};default:throw j.type,new Error("useRefetchableFragmentNode: Unexpected action type")}}function k(L,j,V){var q=s(),N=C(L,V),U=N.refetchableRequest,W=N.fragmentRefPathInResponse,G=N.identifierInfo,J=E(L,j),te=y($,{fetchPolicy:void 0,mirroredEnvironment:q,mirroredFragmentIdentifier:J,onComplete:void 0,refetchEnvironment:null,refetchQuery:null,renderPolicy:void 0}),H=te[0],M=te[1],K=H.fetchPolicy,X=H.mirroredEnvironment,B=H.mirroredFragmentIdentifier,ne=H.onComplete,oe=H.refetchEnvironment,ie=H.refetchQuery,de=H.renderPolicy,be=oe??q,ve=i(be),pe=m(n),_e=be!==X||J!==B,se=o(U),me=se[0],ge=se[1],we=se[2],Ne=j;if(_e)M({type:"reset",environment:be,fragmentIdentifier:J}),we();else if(ie!=null&&me!=null){var Re=function(Ye){ne&&ne(Ye??null)},et=me.source!=null?me.source:_(be,ie),tt=pe.wrapPrepareQueryResource(function(){return ve.prepare(ie,et,K,de,{error:Re,complete:function(){Re()}},me.fetchKey,pe)}),Oe=a(be,tt.fragmentNode,tt.fragmentRef,V).data;Oe==null&&c(!1);var $e=R(Oe,W);Ne=$e}var Ae=u(L,Ne,V),Ue=F(V,M,we,Ae,J,L,W,G,ge,j,U);return{fragmentData:Ae,fragmentRef:Ne,refetch:Ue}}function F(L,j,V,q,N,U,W,G,J,te,H){var M=l(),K=(G==null?void 0:G.identifierField)!=null&&q!=null&&typeof q=="object"?q[G.identifierField]:null;return h(function(X,B){if(M.current!==!0)return{dispose:function(){}};var ne=B==null?void 0:B.__environment,oe=B==null?void 0:B.fetchPolicy,ie=B==null?void 0:B.UNSTABLE_renderPolicy,de=B==null?void 0:B.onComplete,be=T(U,te),ve,pe;if(be==null)ve={},pe={};else if(be.kind==="PluralReaderSelector"){var _e,se,me,ge;ve=(_e=(se=be.selectors[0])===null||se===void 0?void 0:se.owner.variables)!==null&&_e!==void 0?_e:{},pe=(me=(ge=be.selectors[0])===null||ge===void 0?void 0:ge.variables)!==null&&me!==void 0?me:{}}else ve=be.owner.variables,pe=be.variables;var we=(0,t.default)((0,t.default)((0,t.default)({},ve),pe),X);G!=null&&!X.hasOwnProperty(G.identifierQueryVariableName)&&(we[G.identifierQueryVariableName]=K);var Ne=S(H,we,{force:!0});return J(Ne.request.variables,{fetchPolicy:oe,__environment:ne,__nameForWarning:"refetch"}),j({type:"refetch",fetchPolicy:oe,onComplete:de,refetchEnvironment:ne,refetchQuery:Ne,renderPolicy:ie}),{dispose:V}},[N,j,V,K,J])}return mT=k,mT}var gT,SV;function X4e(){if(SV)return gT;SV=1;var e=Cn().default,t=e(zi()),n=see(),r=GF(),i=io(),a=kC(),u=nr(),l=u.useCallback;u.useDebugValue;var o=u.useState,s=ei(),c=s.RelayFeatureFlags,d=s.getFragment,h=s.getFragmentIdentifier,m=s.getPaginationMetadata;function y(_,S){var E=d(_);a(E,"first argument of usePaginationFragment()");var C="usePaginationFragment()",T=m(E,C),R=T.connectionPathInFragmentData,$=T.paginationRequest,k=T.paginationMetadata,F=r(E,S,C),L=F.fragmentData,j=F.fragmentRef,V=F.refetch,q=h(E,j),N=v({componentDisplayName:C,connectionPathInFragmentData:R,direction:"backward",fragmentData:L,fragmentIdentifier:q,fragmentNode:E,fragmentRef:j,paginationMetadata:k,paginationRequest:$}),U=N[0],W=N[1],G=N[2],J=N[3],te=v({componentDisplayName:C,connectionPathInFragmentData:R,direction:"forward",fragmentData:L,fragmentIdentifier:q,fragmentNode:E,fragmentRef:j,paginationMetadata:k,paginationRequest:$}),H=te[0],M=te[1],K=te[2],X=te[3],B=l(function(ne,oe){return X(),J(),V(ne,(0,t.default)((0,t.default)({},oe),{},{__environment:void 0}))},[X,J,V]);return{data:L,loadNext:H,loadPrevious:U,hasNext:M,hasPrevious:W,isLoadingNext:K,isLoadingPrevious:G,refetch:B}}function v(_){var S=i(),E=o(!1),C=E[0],T=E[1],R=function(N){var U,W=(U=S.getScheduler())===null||U===void 0?void 0:U.schedule;W?W(function(){T(N)}):T(N)},$={start:function(){return R(!0)},complete:function(){return R(!1)},error:function(){return R(!1)},unsubscribe:c.ENABLE_USE_PAGINATION_IS_LOADING_FIX?function(){return R(!1)}:void 0},k=function(){return R(!1)},F=n((0,t.default)((0,t.default)({},_),{},{observer:$,onReset:k})),L=F[0],j=F[1],V=F[2];return[L,j,C,V]}return gT=y,gT}var vT,_V;function Y4e(){if(_V)return vT;_V=1;var e=Cn().default,t=e(zi()),n=uee(),r=see(),i=GF(),a=io(),u=kC(),l=on(),o=nr(),s=o.useCallback;o.useDebugValue;var c=o.useEffect,d=o.useLayoutEffect,h=o.useMemo,m=o.useRef,y=o.useState,v=ei(),_=v.getFragment,S=v.getFragmentIdentifier,E=v.getPaginationMetadata,C=ei(),T=C.ConnectionInterface,R=C.RelayFeatureFlags,$=C.getSelector,k=C.getValueAtPath;function F(L,j,V,q,N){var U,W,G=arguments.length>5&&arguments[5]!==void 0?arguments[5]:1,J=arguments.length>6&&arguments[6]!==void 0?arguments[6]:!1,te=_(L);u(te,"first argument of usePrefetchableForwardPaginationFragment()");var H="usePrefetchableForwardPaginationFragment()",M=E(te,H),K=M.connectionPathInFragmentData,X=M.paginationRequest,B=M.paginationMetadata,ne=i(te,j,H),oe=ne.fragmentData,ie=ne.fragmentRef,de=ne.refetch,be=S(te,ie),ve=h(function(){var Qt=k(oe,K);if(Qt==null)return null;var un=T.get(),Ln=un.EDGES;return Qt[Ln]},[K,oe]),pe=ve==null?-1:ve.length,_e=y(q??pe),se=_e[0],me=_e[1],ge=se;se===-1&&pe!==-1&&(ge=q??pe,me(ge));var we=a(),Ne=y(!1),Re=Ne[0],et=Ne[1],tt=y(!1),Oe=tt[0],$e=tt[1],Ae=m(0),Ue=s(function(Qt){var un,Ln=(un=we.getScheduler())===null||un===void 0?void 0:un.schedule;Ln?Ln(function(){et(Qt)}):et(Qt)},[we]),Ze=m(!1),Ye=h(function(){function Qt(){Ze.current=!1,Ue(!1)}return{start:function(){Ze.current=!0,et(!0)},complete:Qt,error:Qt,unsubscribe:R.ENABLE_USE_PAGINATION_IS_LOADING_FIX?Qt:void 0}},[Ue]),Me=s(function(){if(!Oe){var Qt,un=(Qt=we.getScheduler())===null||Qt===void 0?void 0:Qt.schedule;un?un(function(){me(-1)}):me(-1)}Ze.current=!1,Ue(!1)},[we,Oe,Ue]),ze=r({componentDisplayName:H,connectionPathInFragmentData:K,direction:"forward",fragmentData:oe,fragmentIdentifier:be,fragmentNode:te,fragmentRef:ie,paginationMetadata:B,paginationRequest:X,observer:Ye,onReset:Me}),st=ze[0],Ot=ze[1],Nt=ze[2];d(function(){Ae.current=pe-ge},[ge,pe]);var gt=N==null?void 0:N.UNSTABLE_extraVariables,qt=N==null?void 0:N.onComplete,zt=s(function(Qt,un){(!Ze.current||Ae.current>=0)&&(Ae.current-=Qt,me(function(Ln){return Ln+Qt}),!Ze.current&&Ae.current<0&&st(Math.max(G,Math.min(Qt,V-Ae.current)),un??{onComplete:qt,UNSTABLE_extraVariables:typeof gt=="function"?gt({hasNext:Ot,data:oe,getServerEdges:function(){var ln=$(an,ve);return ln==null?[]:(ln.kind!=="PluralReaderSelector"&&l(!1),ln.selectors.map(function(Zn){return we.lookup(Zn).data}))}}):gt}))},[V,st,G,ve,oe,gt,qt]),an=(U=L.metadata)===null||U===void 0||(W=U.refetch)===null||W===void 0?void 0:W.edgesFragment;an==null&&l(!1),c(function(){if(!Ze.current&&!Re&&!Oe&&!J&&Ot&&(pe-ge<V||ge>pe)){var Qt=qt;st(Math.max(V-Math.max(pe-ge,0),ge-pe,G),{onComplete:Qt,UNSTABLE_extraVariables:typeof gt=="function"?gt({hasNext:Ot,data:oe,getServerEdges:function(){var Ln=$(an,ve);return Ln==null?[]:(Ln.kind!=="PluralReaderSelector"&&l(!1),Ln.selectors.map(function(ln){return we.lookup(ln).data}))}}):gt})}},[Ot,V,Oe,st,ge,gt,qt,pe,ve,Re,G,we,an]);var rn=Math.min(ge,pe),Fe=h(function(){var Qt;return(Qt=ve==null?void 0:ve.slice(0,rn))!==null&&Qt!==void 0?Qt:[]},[ve,rn]),ht=n(an,Fe),Tt=s(function(Qt,un){return Nt(),$e(!0),de(Qt,(0,t.default)((0,t.default)({},un),{},{onComplete:function(ln){var Zn,cr,ur=(Zn=we.getScheduler())===null||Zn===void 0?void 0:Zn.schedule;ur?ur(function(){$e(!1),me(-1)}):($e(!1),me(-1)),un==null||(cr=un.onComplete)===null||cr===void 0||cr.call(un,ln)},__environment:void 0}))},[Nt,we,de]);return{edges:ht,data:oe,loadNext:zt,hasNext:Ot||pe>ge,isLoadingNext:Re&&ge>pe,refetch:Tt}}return vT=F,vT}var yT,EV;function G4e(){if(EV)return yT;EV=1;var e=ree(),t=iee(),n=io(),r=on(),i=nr();i.useDebugValue;var a=ei(),u=a.__internal,l=u.fetchQueryDeduped,o=u.fetchQuery;Qi();function s(c,d,h){var m=n(),y=d.fetchKey,v=d.fetchPolicy,_=d.source,S=d.variables,E=d.networkCacheConfig,C=t(c,S,E),T;if(d.kind==="PreloadedQuery_DEPRECATED")C.request.node.params.name!==d.name&&r(!1),T={componentDisplayName:"usePreloadedQuery()",fetchKey:y,fetchObservable:l(m,C.request.identifier,function(){return m===d.environment&&_!=null?m.executeWithSource({operation:C,source:_}):m.execute({operation:C})}),fetchPolicy:v,query:C,renderPolicy:h==null?void 0:h.UNSTABLE_renderPolicy};else{var R=o(m,C),$;_!=null&&m===d.environment?$=_.ifEmpty(R):(d.environment,$=R),T={componentDisplayName:"usePreloadedQuery()",fetchObservable:$,fetchKey:y,fetchPolicy:v,query:C,renderPolicy:h==null?void 0:h.UNSTABLE_renderPolicy}}var k=e(T);return k}return yT=s,yT}var bT,DV;function K4e(){if(DV)return bT;DV=1;var e=GF(),t=kC(),n=nr();n.useDebugValue;var r=ei(),i=r.getFragment;function a(u,l){var o=i(u);t(o,"first argument of useRefetchableFragment()");var s=e(o,l,"useRefetchableFragment()"),c=s.fragmentData,d=s.refetch;return[c,d]}return bT=a,bT}var OT,$V;function W4e(){if($V)return OT;$V=1;var e=io(),t=nr(),n=t.useEffect,r=t.useRef;function i(a,u){var l=e(),o=r(null),s=Array.from(a).sort().join("");return n(function(){var c=l.getStore(),d=c.lookupInvalidationState(a),h=c.subscribeToInvalidationState(d,u);return o.current=h,function(){return h.dispose()}},[s,u,l]),{dispose:function(){o.current!=null&&o.current.dispose()}}}return OT=i,OT}var xT,CV;function J4e(){if(CV)return xT;CV=1;var e=io(),t=nr(),n=t.useEffect,r=ei(),i=r.requestSubscription;function a(u,l){var o=l??i,s=e();n(function(){var c=o(s,u),d=c.dispose;return d},[s,u,o])}return xT=a,xT}var ST,wV;function e2e(){if(wV)return ST;wV=1;var e=hy(),t=R4e(),n=A4e(),r=T4e(),i=k4e(),a=P4e(),u=M4e(),l=JJ(),o=TC(),s=o.loadQuery,c=AC(),d=F4e(),h=q4e(),m=V4e(),y=uee(),v=aee(),_=U4e(),S=X4e(),E=Y4e(),C=G4e(),T=cee(),R=K4e(),$=io(),k=W4e(),F=J4e(),L=ei();return ST={ConnectionHandler:L.ConnectionHandler,QueryRenderer:i,LocalQueryRenderer:n,MutationTypes:L.MutationTypes,RangeOperations:L.RangeOperations,ReactRelayContext:e,applyOptimisticMutation:L.applyOptimisticMutation,commitLocalUpdate:L.commitLocalUpdate,commitMutation:L.commitMutation,createFragmentContainer:t.createContainer,createPaginationContainer:r.createContainer,createRefetchContainer:a.createContainer,fetchQuery_DEPRECATED:L.fetchQuery_DEPRECATED,graphql:L.graphql,readInlineData:L.readInlineData,requestSubscription:L.requestSubscription,EntryPointContainer:u,RelayEnvironmentProvider:d,ProfilerContext:c,fetchQuery:L.fetchQuery,loadQuery:s,loadEntryPoint:l,useClientQuery:h,useFragment:y,useLazyLoadQuery:v,useEntryPointLoader:m,useQueryLoader:T,useMutation:_,usePaginationFragment:S,usePreloadedQuery:C,useRefetchableFragment:R,usePrefetchableForwardPaginationFragment:E,useRelayEnvironment:$,useSubscribeToInvalidationState:k,useSubscription:F},ST}var _T,RV;function t2e(){return RV||(RV=1,_T=e2e()),_T}var Pnt=t2e();function Mnt(e,t,n=Object.is){const r=e.getState(),[[i,a],u]=P.useReducer((l,o)=>{if(o)return o;const s=e.getState();if(Object.is(l[2],s)&&l[1]===e)return l;const c=t(s);return n(l[0],c)&&l[1]===e?l:[c,e,s]},void 0,()=>[t(r),e,r]);if(P.useEffect(()=>{const l=e.subscribe(()=>u());return u(),l},[e]),a!==e){const l=t(r);return u([l,e,r]),l}return i}const n2e={},AV=e=>{let t;const n=new Set,r=(c,d)=>{const h=typeof c=="function"?c(t):c;if(!Object.is(h,t)){const m=t;t=d??(typeof h!="object"||h===null)?h:Object.assign({},t,h),n.forEach(y=>y(t,m))}},i=()=>t,o={setState:r,getState:i,getInitialState:()=>s,subscribe:c=>(n.add(c),()=>n.delete(c)),destroy:()=>{(n2e?"production":void 0)!=="production"&&console.warn("[DEPRECATED] The `destroy` method will be unsupported in a future version. Instead use unsubscribe function returned by subscribe. Everything will be garbage-collected if store is garbage-collected."),n.clear()}},s=t=e(r,i,o);return o},r2e=e=>e?AV(e):AV;var ET={exports:{}},DT={},$T={exports:{}},CT={};/**
 * @license React
 * use-sync-external-store-shim.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var TV;function i2e(){if(TV)return CT;TV=1;var e=nr();function t(d,h){return d===h&&(d!==0||1/d===1/h)||d!==d&&h!==h}var n=typeof Object.is=="function"?Object.is:t,r=e.useState,i=e.useEffect,a=e.useLayoutEffect,u=e.useDebugValue;function l(d,h){var m=h(),y=r({inst:{value:m,getSnapshot:h}}),v=y[0].inst,_=y[1];return a(function(){v.value=m,v.getSnapshot=h,o(v)&&_({inst:v})},[d,m,h]),i(function(){return o(v)&&_({inst:v}),d(function(){o(v)&&_({inst:v})})},[d]),u(m),m}function o(d){var h=d.getSnapshot;d=d.value;try{var m=h();return!n(d,m)}catch{return!0}}function s(d,h){return h()}var c=typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"?s:l;return CT.useSyncExternalStore=e.useSyncExternalStore!==void 0?e.useSyncExternalStore:c,CT}var kV;function fee(){return kV||(kV=1,$T.exports=i2e()),$T.exports}/**
 * @license React
 * use-sync-external-store-shim/with-selector.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var PV;function a2e(){if(PV)return DT;PV=1;var e=nr(),t=fee();function n(s,c){return s===c&&(s!==0||1/s===1/c)||s!==s&&c!==c}var r=typeof Object.is=="function"?Object.is:n,i=t.useSyncExternalStore,a=e.useRef,u=e.useEffect,l=e.useMemo,o=e.useDebugValue;return DT.useSyncExternalStoreWithSelector=function(s,c,d,h,m){var y=a(null);if(y.current===null){var v={hasValue:!1,value:null};y.current=v}else v=y.current;y=l(function(){function S($){if(!E){if(E=!0,C=$,$=h($),m!==void 0&&v.hasValue){var k=v.value;if(m(k,$))return T=k}return T=$}if(k=T,r(C,$))return k;var F=h($);return m!==void 0&&m(k,F)?(C=$,k):(C=$,T=F)}var E=!1,C,T,R=d===void 0?null:d;return[function(){return S(c())},R===null?void 0:function(){return S(R())}]},[c,d,h,m]);var _=i(s,y[0],y[1]);return u(function(){v.hasValue=!0,v.value=_},[_]),o(_),_},DT}var MV;function u2e(){return MV||(MV=1,ET.exports=a2e()),ET.exports}var l2e=u2e();const dee=sa(l2e),hee={},{useDebugValue:o2e}=ye,{useSyncExternalStoreWithSelector:s2e}=dee;let FV=!1;const c2e=e=>e;function f2e(e,t=c2e,n){(hee?"production":void 0)!=="production"&&n&&!FV&&(console.warn("[DEPRECATED] Use `createWithEqualityFn` instead of `create` or use `useStoreWithEqualityFn` instead of `useStore`. They can be imported from 'zustand/traditional'. https://github.com/pmndrs/zustand/discussions/1937"),FV=!0);const r=s2e(e.subscribe,e.getState,e.getServerState||e.getInitialState,t,n);return o2e(r),r}const NV=e=>{(hee?"production":void 0)!=="production"&&typeof e!="function"&&console.warn("[DEPRECATED] Passing a vanilla store will be unsupported in a future version. Instead use `import { useStore } from 'zustand'`.");const t=typeof e=="function"?r2e(e):e,n=(r,i)=>f2e(t,r,i);return Object.assign(n,t),n},Fnt=e=>e?NV(e):NV,zE={BASE_URL:"/",DEV:!1,MODE:"production",PROD:!0,SSR:!1},J7=new Map,w_=e=>{const t=J7.get(e);return t?Object.fromEntries(Object.entries(t.stores).map(([n,r])=>[n,r.getState()])):{}},d2e=(e,t,n)=>{if(e===void 0)return{type:"untracked",connection:t.connect(n)};const r=J7.get(n.name);if(r)return{type:"tracked",store:e,...r};const i={connection:t.connect(n),stores:{}};return J7.set(n.name,i),{type:"tracked",store:e,...i}},h2e=(e,t={})=>(n,r,i)=>{const{enabled:a,anonymousActionType:u,store:l,...o}=t;let s;try{s=(a??(zE?"production":void 0)!=="production")&&window.__REDUX_DEVTOOLS_EXTENSION__}catch{}if(!s)return(zE?"production":void 0)!=="production"&&a&&console.warn("[zustand devtools middleware] Please install/enable Redux devtools extension"),e(n,r,i);const{connection:c,...d}=d2e(l,s,o);let h=!0;i.setState=(v,_,S)=>{const E=n(v,_);if(!h)return E;const C=S===void 0?{type:u||"anonymous"}:typeof S=="string"?{type:S}:S;return l===void 0?(c==null||c.send(C,r()),E):(c==null||c.send({...C,type:`${l}/${C.type}`},{...w_(o.name),[l]:i.getState()}),E)};const m=(...v)=>{const _=h;h=!1,n(...v),h=_},y=e(i.setState,r,i);if(d.type==="untracked"?c==null||c.init(y):(d.stores[d.store]=i,c==null||c.init(Object.fromEntries(Object.entries(d.stores).map(([v,_])=>[v,v===d.store?y:_.getState()])))),i.dispatchFromDevtools&&typeof i.dispatch=="function"){let v=!1;const _=i.dispatch;i.dispatch=(...S)=>{(zE?"production":void 0)!=="production"&&S[0].type==="__setState"&&!v&&(console.warn('[zustand devtools middleware] "__setState" action type is reserved to set state from the devtools. Avoid using it.'),v=!0),_(...S)}}return c.subscribe(v=>{var _;switch(v.type){case"ACTION":if(typeof v.payload!="string"){console.error("[zustand devtools middleware] Unsupported action format");return}return wT(v.payload,S=>{if(S.type==="__setState"){if(l===void 0){m(S.state);return}Object.keys(S.state).length!==1&&console.error(`
                    [zustand devtools middleware] Unsupported __setState action format. 
                    When using 'store' option in devtools(), the 'state' should have only one key, which is a value of 'store' that was passed in devtools(),
                    and value of this only key should be a state object. Example: { "type": "__setState", "state": { "abc123Store": { "foo": "bar" } } }
                    `);const E=S.state[l];if(E==null)return;JSON.stringify(i.getState())!==JSON.stringify(E)&&m(E);return}i.dispatchFromDevtools&&typeof i.dispatch=="function"&&i.dispatch(S)});case"DISPATCH":switch(v.payload.type){case"RESET":return m(y),l===void 0?c==null?void 0:c.init(i.getState()):c==null?void 0:c.init(w_(o.name));case"COMMIT":if(l===void 0){c==null||c.init(i.getState());return}return c==null?void 0:c.init(w_(o.name));case"ROLLBACK":return wT(v.state,S=>{if(l===void 0){m(S),c==null||c.init(i.getState());return}m(S[l]),c==null||c.init(w_(o.name))});case"JUMP_TO_STATE":case"JUMP_TO_ACTION":return wT(v.state,S=>{if(l===void 0){m(S);return}JSON.stringify(i.getState())!==JSON.stringify(S[l])&&m(S[l])});case"IMPORT_STATE":{const{nextLiftedState:S}=v.payload,E=(_=S.computedStates.slice(-1)[0])==null?void 0:_.state;if(!E)return;m(l===void 0?E:E[l]),c==null||c.send(null,S);return}case"PAUSE_RECORDING":return h=!h}return}}),y},Nnt=h2e,wT=(e,t)=>{let n;try{n=JSON.parse(e)}catch(r){console.error("[zustand devtools middleware] Could not parse the received json",r)}n!==void 0&&t(n)};function p2e(e,t){let n;try{n=e()}catch{return}return{getItem:i=>{var a;const u=o=>o===null?null:JSON.parse(o,void 0),l=(a=n.getItem(i))!=null?a:null;return l instanceof Promise?l.then(u):u(l)},setItem:(i,a)=>n.setItem(i,JSON.stringify(a,void 0)),removeItem:i=>n.removeItem(i)}}const lx=e=>t=>{try{const n=e(t);return n instanceof Promise?n:{then(r){return lx(r)(n)},catch(r){return this}}}catch(n){return{then(r){return this},catch(r){return lx(r)(n)}}}},m2e=(e,t)=>(n,r,i)=>{let a={getStorage:()=>localStorage,serialize:JSON.stringify,deserialize:JSON.parse,partialize:_=>_,version:0,merge:(_,S)=>({...S,..._}),...t},u=!1;const l=new Set,o=new Set;let s;try{s=a.getStorage()}catch{}if(!s)return e((..._)=>{console.warn(`[zustand persist middleware] Unable to update item '${a.name}', the given storage is currently unavailable.`),n(..._)},r,i);const c=lx(a.serialize),d=()=>{const _=a.partialize({...r()});let S;const E=c({state:_,version:a.version}).then(C=>s.setItem(a.name,C)).catch(C=>{S=C});if(S)throw S;return E},h=i.setState;i.setState=(_,S)=>{h(_,S),d()};const m=e((..._)=>{n(..._),d()},r,i);let y;const v=()=>{var _;if(!s)return;u=!1,l.forEach(E=>E(r()));const S=((_=a.onRehydrateStorage)==null?void 0:_.call(a,r()))||void 0;return lx(s.getItem.bind(s))(a.name).then(E=>{if(E)return a.deserialize(E)}).then(E=>{if(E)if(typeof E.version=="number"&&E.version!==a.version){if(a.migrate)return a.migrate(E.state,E.version);console.error("State loaded from storage couldn't be migrated since no migrate function was provided")}else return E.state}).then(E=>{var C;return y=a.merge(E,(C=r())!=null?C:m),n(y,!0),d()}).then(()=>{S==null||S(y,void 0),u=!0,o.forEach(E=>E(y))}).catch(E=>{S==null||S(void 0,E)})};return i.persist={setOptions:_=>{a={...a,..._},_.getStorage&&(s=_.getStorage())},clearStorage:()=>{s==null||s.removeItem(a.name)},getOptions:()=>a,rehydrate:()=>v(),hasHydrated:()=>u,onHydrate:_=>(l.add(_),()=>{l.delete(_)}),onFinishHydration:_=>(o.add(_),()=>{o.delete(_)})},v(),y||m},g2e=(e,t)=>(n,r,i)=>{let a={storage:p2e(()=>localStorage),partialize:v=>v,version:0,merge:(v,_)=>({..._,...v}),...t},u=!1;const l=new Set,o=new Set;let s=a.storage;if(!s)return e((...v)=>{console.warn(`[zustand persist middleware] Unable to update item '${a.name}', the given storage is currently unavailable.`),n(...v)},r,i);const c=()=>{const v=a.partialize({...r()});return s.setItem(a.name,{state:v,version:a.version})},d=i.setState;i.setState=(v,_)=>{d(v,_),c()};const h=e((...v)=>{n(...v),c()},r,i);i.getInitialState=()=>h;let m;const y=()=>{var v,_;if(!s)return;u=!1,l.forEach(E=>{var C;return E((C=r())!=null?C:h)});const S=((_=a.onRehydrateStorage)==null?void 0:_.call(a,(v=r())!=null?v:h))||void 0;return lx(s.getItem.bind(s))(a.name).then(E=>{if(E)if(typeof E.version=="number"&&E.version!==a.version){if(a.migrate)return[!0,a.migrate(E.state,E.version)];console.error("State loaded from storage couldn't be migrated since no migrate function was provided")}else return[!1,E.state];return[!1,void 0]}).then(E=>{var C;const[T,R]=E;if(m=a.merge(R,(C=r())!=null?C:h),n(m,!0),T)return c()}).then(()=>{S==null||S(m,void 0),m=r(),u=!0,o.forEach(E=>E(m))}).catch(E=>{S==null||S(void 0,E)})};return i.persist={setOptions:v=>{a={...a,...v},v.storage&&(s=v.storage)},clearStorage:()=>{s==null||s.removeItem(a.name)},getOptions:()=>a,rehydrate:()=>y(),hasHydrated:()=>u,onHydrate:v=>(l.add(v),()=>{l.delete(v)}),onFinishHydration:v=>(o.add(v),()=>{o.delete(v)})},a.skipHydration||y(),m||h},v2e=(e,t)=>"getStorage"in t||"serialize"in t||"deserialize"in t?((zE?"production":void 0)!=="production"&&console.warn("[DEPRECATED] `getStorage`, `serialize` and `deserialize` options are deprecated. Use `storage` option instead."),m2e(e,t)):g2e(e,t),Int=v2e;var di;(function(e){e.assertEqual=i=>{};function t(i){}e.assertIs=t;function n(i){throw new Error}e.assertNever=n,e.arrayToEnum=i=>{const a={};for(const u of i)a[u]=u;return a},e.getValidEnumValues=i=>{const a=e.objectKeys(i).filter(l=>typeof i[i[l]]!="number"),u={};for(const l of a)u[l]=i[l];return e.objectValues(u)},e.objectValues=i=>e.objectKeys(i).map(function(a){return i[a]}),e.objectKeys=typeof Object.keys=="function"?i=>Object.keys(i):i=>{const a=[];for(const u in i)Object.prototype.hasOwnProperty.call(i,u)&&a.push(u);return a},e.find=(i,a)=>{for(const u of i)if(a(u))return u},e.isInteger=typeof Number.isInteger=="function"?i=>Number.isInteger(i):i=>typeof i=="number"&&Number.isFinite(i)&&Math.floor(i)===i;function r(i,a=" | "){return i.map(u=>typeof u=="string"?`'${u}'`:u).join(a)}e.joinValues=r,e.jsonStringifyReplacer=(i,a)=>typeof a=="bigint"?a.toString():a})(di||(di={}));var IV;(function(e){e.mergeShapes=(t,n)=>({...t,...n})})(IV||(IV={}));const dn=di.arrayToEnum(["string","nan","number","integer","float","boolean","date","bigint","symbol","function","undefined","null","array","object","unknown","promise","void","never","map","set"]),yv=e=>{switch(typeof e){case"undefined":return dn.undefined;case"string":return dn.string;case"number":return Number.isNaN(e)?dn.nan:dn.number;case"boolean":return dn.boolean;case"function":return dn.function;case"bigint":return dn.bigint;case"symbol":return dn.symbol;case"object":return Array.isArray(e)?dn.array:e===null?dn.null:e.then&&typeof e.then=="function"&&e.catch&&typeof e.catch=="function"?dn.promise:typeof Map<"u"&&e instanceof Map?dn.map:typeof Set<"u"&&e instanceof Set?dn.set:typeof Date<"u"&&e instanceof Date?dn.date:dn.object;default:return dn.unknown}},Ft=di.arrayToEnum(["invalid_type","invalid_literal","custom","invalid_union","invalid_union_discriminator","invalid_enum_value","unrecognized_keys","invalid_arguments","invalid_return_type","invalid_date","invalid_string","too_small","too_big","invalid_intersection_types","not_multiple_of","not_finite"]);class lg extends Error{get errors(){return this.issues}constructor(t){super(),this.issues=[],this.addIssue=r=>{this.issues=[...this.issues,r]},this.addIssues=(r=[])=>{this.issues=[...this.issues,...r]};const n=new.target.prototype;Object.setPrototypeOf?Object.setPrototypeOf(this,n):this.__proto__=n,this.name="ZodError",this.issues=t}format(t){const n=t||function(a){return a.message},r={_errors:[]},i=a=>{for(const u of a.issues)if(u.code==="invalid_union")u.unionErrors.map(i);else if(u.code==="invalid_return_type")i(u.returnTypeError);else if(u.code==="invalid_arguments")i(u.argumentsError);else if(u.path.length===0)r._errors.push(n(u));else{let l=r,o=0;for(;o<u.path.length;){const s=u.path[o];o===u.path.length-1?(l[s]=l[s]||{_errors:[]},l[s]._errors.push(n(u))):l[s]=l[s]||{_errors:[]},l=l[s],o++}}};return i(this),r}static assert(t){if(!(t instanceof lg))throw new Error(`Not a ZodError: ${t}`)}toString(){return this.message}get message(){return JSON.stringify(this.issues,di.jsonStringifyReplacer,2)}get isEmpty(){return this.issues.length===0}flatten(t=n=>n.message){const n={},r=[];for(const i of this.issues)if(i.path.length>0){const a=i.path[0];n[a]=n[a]||[],n[a].push(t(i))}else r.push(t(i));return{formErrors:r,fieldErrors:n}}get formErrors(){return this.flatten()}}lg.create=e=>new lg(e);const e9=(e,t)=>{let n;switch(e.code){case Ft.invalid_type:e.received===dn.undefined?n="Required":n=`Expected ${e.expected}, received ${e.received}`;break;case Ft.invalid_literal:n=`Invalid literal value, expected ${JSON.stringify(e.expected,di.jsonStringifyReplacer)}`;break;case Ft.unrecognized_keys:n=`Unrecognized key(s) in object: ${di.joinValues(e.keys,", ")}`;break;case Ft.invalid_union:n="Invalid input";break;case Ft.invalid_union_discriminator:n=`Invalid discriminator value. Expected ${di.joinValues(e.options)}`;break;case Ft.invalid_enum_value:n=`Invalid enum value. Expected ${di.joinValues(e.options)}, received '${e.received}'`;break;case Ft.invalid_arguments:n="Invalid function arguments";break;case Ft.invalid_return_type:n="Invalid function return type";break;case Ft.invalid_date:n="Invalid date";break;case Ft.invalid_string:typeof e.validation=="object"?"includes"in e.validation?(n=`Invalid input: must include "${e.validation.includes}"`,typeof e.validation.position=="number"&&(n=`${n} at one or more positions greater than or equal to ${e.validation.position}`)):"startsWith"in e.validation?n=`Invalid input: must start with "${e.validation.startsWith}"`:"endsWith"in e.validation?n=`Invalid input: must end with "${e.validation.endsWith}"`:di.assertNever(e.validation):e.validation!=="regex"?n=`Invalid ${e.validation}`:n="Invalid";break;case Ft.too_small:e.type==="array"?n=`Array must contain ${e.exact?"exactly":e.inclusive?"at least":"more than"} ${e.minimum} element(s)`:e.type==="string"?n=`String must contain ${e.exact?"exactly":e.inclusive?"at least":"over"} ${e.minimum} character(s)`:e.type==="number"?n=`Number must be ${e.exact?"exactly equal to ":e.inclusive?"greater than or equal to ":"greater than "}${e.minimum}`:e.type==="bigint"?n=`Number must be ${e.exact?"exactly equal to ":e.inclusive?"greater than or equal to ":"greater than "}${e.minimum}`:e.type==="date"?n=`Date must be ${e.exact?"exactly equal to ":e.inclusive?"greater than or equal to ":"greater than "}${new Date(Number(e.minimum))}`:n="Invalid input";break;case Ft.too_big:e.type==="array"?n=`Array must contain ${e.exact?"exactly":e.inclusive?"at most":"less than"} ${e.maximum} element(s)`:e.type==="string"?n=`String must contain ${e.exact?"exactly":e.inclusive?"at most":"under"} ${e.maximum} character(s)`:e.type==="number"?n=`Number must be ${e.exact?"exactly":e.inclusive?"less than or equal to":"less than"} ${e.maximum}`:e.type==="bigint"?n=`BigInt must be ${e.exact?"exactly":e.inclusive?"less than or equal to":"less than"} ${e.maximum}`:e.type==="date"?n=`Date must be ${e.exact?"exactly":e.inclusive?"smaller than or equal to":"smaller than"} ${new Date(Number(e.maximum))}`:n="Invalid input";break;case Ft.custom:n="Invalid input";break;case Ft.invalid_intersection_types:n="Intersection results could not be merged";break;case Ft.not_multiple_of:n=`Number must be a multiple of ${e.multipleOf}`;break;case Ft.not_finite:n="Number must be finite";break;default:n=t.defaultError,di.assertNever(e)}return{message:n}};let y2e=e9;function b2e(){return y2e}const O2e=e=>{const{data:t,path:n,errorMaps:r,issueData:i}=e,a=[...n,...i.path||[]],u={...i,path:a};if(i.message!==void 0)return{...i,path:a,message:i.message};let l="";const o=r.filter(s=>!!s).slice().reverse();for(const s of o)l=s(u,{data:t,defaultError:l}).message;return{...i,path:a,message:l}};function en(e,t){const n=b2e(),r=O2e({issueData:t,data:e.data,path:e.path,errorMaps:[e.common.contextualErrorMap,e.schemaErrorMap,n,n===e9?void 0:e9].filter(i=>!!i)});e.common.issues.push(r)}class fc{constructor(){this.value="valid"}dirty(){this.value==="valid"&&(this.value="dirty")}abort(){this.value!=="aborted"&&(this.value="aborted")}static mergeArray(t,n){const r=[];for(const i of n){if(i.status==="aborted")return Gn;i.status==="dirty"&&t.dirty(),r.push(i.value)}return{status:t.value,value:r}}static async mergeObjectAsync(t,n){const r=[];for(const i of n){const a=await i.key,u=await i.value;r.push({key:a,value:u})}return fc.mergeObjectSync(t,r)}static mergeObjectSync(t,n){const r={};for(const i of n){const{key:a,value:u}=i;if(a.status==="aborted"||u.status==="aborted")return Gn;a.status==="dirty"&&t.dirty(),u.status==="dirty"&&t.dirty(),a.value!=="__proto__"&&(typeof u.value<"u"||i.alwaysSet)&&(r[a.value]=u.value)}return{status:t.value,value:r}}}const Gn=Object.freeze({status:"aborted"}),w2=e=>({status:"dirty",value:e}),nh=e=>({status:"valid",value:e}),LV=e=>e.status==="aborted",BV=e=>e.status==="dirty",_3=e=>e.status==="valid",SD=e=>typeof Promise<"u"&&e instanceof Promise;var xn;(function(e){e.errToObj=t=>typeof t=="string"?{message:t}:t||{},e.toString=t=>typeof t=="string"?t:t==null?void 0:t.message})(xn||(xn={}));class k0{constructor(t,n,r,i){this._cachedPath=[],this.parent=t,this.data=n,this._path=r,this._key=i}get path(){return this._cachedPath.length||(Array.isArray(this._key)?this._cachedPath.push(...this._path,...this._key):this._cachedPath.push(...this._path,this._key)),this._cachedPath}}const QV=(e,t)=>{if(_3(t))return{success:!0,data:t.value};if(!e.common.issues.length)throw new Error("Validation failed but no issues detected.");return{success:!1,get error(){if(this._error)return this._error;const n=new lg(e.common.issues);return this._error=n,this._error}}};function mr(e){if(!e)return{};const{errorMap:t,invalid_type_error:n,required_error:r,description:i}=e;if(t&&(n||r))throw new Error(`Can't use "invalid_type_error" or "required_error" in conjunction with custom error map.`);return t?{errorMap:t,description:i}:{errorMap:(u,l)=>{const{message:o}=e;return u.code==="invalid_enum_value"?{message:o??l.defaultError}:typeof l.data>"u"?{message:o??r??l.defaultError}:u.code!=="invalid_type"?{message:l.defaultError}:{message:o??n??l.defaultError}},description:i}}class Zr{get description(){return this._def.description}_getType(t){return yv(t.data)}_getOrReturnCtx(t,n){return n||{common:t.parent.common,data:t.data,parsedType:yv(t.data),schemaErrorMap:this._def.errorMap,path:t.path,parent:t.parent}}_processInputParams(t){return{status:new fc,ctx:{common:t.parent.common,data:t.data,parsedType:yv(t.data),schemaErrorMap:this._def.errorMap,path:t.path,parent:t.parent}}}_parseSync(t){const n=this._parse(t);if(SD(n))throw new Error("Synchronous parse encountered promise.");return n}_parseAsync(t){const n=this._parse(t);return Promise.resolve(n)}parse(t,n){const r=this.safeParse(t,n);if(r.success)return r.data;throw r.error}safeParse(t,n){const r={common:{issues:[],async:(n==null?void 0:n.async)??!1,contextualErrorMap:n==null?void 0:n.errorMap},path:(n==null?void 0:n.path)||[],schemaErrorMap:this._def.errorMap,parent:null,data:t,parsedType:yv(t)},i=this._parseSync({data:t,path:r.path,parent:r});return QV(r,i)}"~validate"(t){var r,i;const n={common:{issues:[],async:!!this["~standard"].async},path:[],schemaErrorMap:this._def.errorMap,parent:null,data:t,parsedType:yv(t)};if(!this["~standard"].async)try{const a=this._parseSync({data:t,path:[],parent:n});return _3(a)?{value:a.value}:{issues:n.common.issues}}catch(a){(i=(r=a==null?void 0:a.message)==null?void 0:r.toLowerCase())!=null&&i.includes("encountered")&&(this["~standard"].async=!0),n.common={issues:[],async:!0}}return this._parseAsync({data:t,path:[],parent:n}).then(a=>_3(a)?{value:a.value}:{issues:n.common.issues})}async parseAsync(t,n){const r=await this.safeParseAsync(t,n);if(r.success)return r.data;throw r.error}async safeParseAsync(t,n){const r={common:{issues:[],contextualErrorMap:n==null?void 0:n.errorMap,async:!0},path:(n==null?void 0:n.path)||[],schemaErrorMap:this._def.errorMap,parent:null,data:t,parsedType:yv(t)},i=this._parse({data:t,path:r.path,parent:r}),a=await(SD(i)?i:Promise.resolve(i));return QV(r,a)}refine(t,n){const r=i=>typeof n=="string"||typeof n>"u"?{message:n}:typeof n=="function"?n(i):n;return this._refinement((i,a)=>{const u=t(i),l=()=>a.addIssue({code:Ft.custom,...r(i)});return typeof Promise<"u"&&u instanceof Promise?u.then(o=>o?!0:(l(),!1)):u?!0:(l(),!1)})}refinement(t,n){return this._refinement((r,i)=>t(r)?!0:(i.addIssue(typeof n=="function"?n(r,i):n),!1))}_refinement(t){return new tb({schema:this,typeName:It.ZodEffects,effect:{type:"refinement",refinement:t}})}superRefine(t){return this._refinement(t)}constructor(t){this.spa=this.safeParseAsync,this._def=t,this.parse=this.parse.bind(this),this.safeParse=this.safeParse.bind(this),this.parseAsync=this.parseAsync.bind(this),this.safeParseAsync=this.safeParseAsync.bind(this),this.spa=this.spa.bind(this),this.refine=this.refine.bind(this),this.refinement=this.refinement.bind(this),this.superRefine=this.superRefine.bind(this),this.optional=this.optional.bind(this),this.nullable=this.nullable.bind(this),this.nullish=this.nullish.bind(this),this.array=this.array.bind(this),this.promise=this.promise.bind(this),this.or=this.or.bind(this),this.and=this.and.bind(this),this.transform=this.transform.bind(this),this.brand=this.brand.bind(this),this.default=this.default.bind(this),this.catch=this.catch.bind(this),this.describe=this.describe.bind(this),this.pipe=this.pipe.bind(this),this.readonly=this.readonly.bind(this),this.isNullable=this.isNullable.bind(this),this.isOptional=this.isOptional.bind(this),this["~standard"]={version:1,vendor:"zod",validate:n=>this["~validate"](n)}}optional(){return ng.create(this,this._def)}nullable(){return nb.create(this,this._def)}nullish(){return this.nullable().optional()}array(){return $0.create(this)}promise(){return AD.create(this,this._def)}or(t){return DD.create([this,t],this._def)}and(t){return $D.create(this,t,this._def)}transform(t){return new tb({...mr(this._def),schema:this,typeName:It.ZodEffects,effect:{type:"transform",transform:t}})}default(t){const n=typeof t=="function"?t:()=>t;return new TD({...mr(this._def),innerType:this,defaultValue:n,typeName:It.ZodDefault})}brand(){return new vee({typeName:It.ZodBranded,type:this,...mr(this._def)})}catch(t){const n=typeof t=="function"?t:()=>t;return new kD({...mr(this._def),innerType:this,catchValue:n,typeName:It.ZodCatch})}describe(t){const n=this.constructor;return new n({...this._def,description:t})}pipe(t){return WF.create(this,t)}readonly(){return PD.create(this)}isOptional(){return this.safeParse(void 0).success}isNullable(){return this.safeParse(null).success}}const x2e=/^c[^\s-]{8,}$/i,S2e=/^[0-9a-z]+$/,_2e=/^[0-9A-HJKMNP-TV-Z]{26}$/i,E2e=/^[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{12}$/i,D2e=/^[a-z0-9_-]{21}$/i,$2e=/^[A-Za-z0-9-_]+\.[A-Za-z0-9-_]+\.[A-Za-z0-9-_]*$/,C2e=/^[-+]?P(?!$)(?:(?:[-+]?\d+Y)|(?:[-+]?\d+[.,]\d+Y$))?(?:(?:[-+]?\d+M)|(?:[-+]?\d+[.,]\d+M$))?(?:(?:[-+]?\d+W)|(?:[-+]?\d+[.,]\d+W$))?(?:(?:[-+]?\d+D)|(?:[-+]?\d+[.,]\d+D$))?(?:T(?=[\d+-])(?:(?:[-+]?\d+H)|(?:[-+]?\d+[.,]\d+H$))?(?:(?:[-+]?\d+M)|(?:[-+]?\d+[.,]\d+M$))?(?:[-+]?\d+(?:[.,]\d+)?S)?)??$/,w2e=/^(?!\.)(?!.*\.\.)([A-Z0-9_'+\-\.]*)[A-Z0-9_+-]@([A-Z0-9][A-Z0-9\-]*\.)+[A-Z]{2,}$/i,R2e="^(\\p{Extended_Pictographic}|\\p{Emoji_Component})+$";let RT;const A2e=/^(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])$/,T2e=/^(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\/(3[0-2]|[12]?[0-9])$/,k2e=/^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))$/,P2e=/^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))\/(12[0-8]|1[01][0-9]|[1-9]?[0-9])$/,M2e=/^([0-9a-zA-Z+/]{4})*(([0-9a-zA-Z+/]{2}==)|([0-9a-zA-Z+/]{3}=))?$/,F2e=/^([0-9a-zA-Z-_]{4})*(([0-9a-zA-Z-_]{2}(==)?)|([0-9a-zA-Z-_]{3}(=)?))?$/,pee="((\\d\\d[2468][048]|\\d\\d[13579][26]|\\d\\d0[48]|[02468][048]00|[13579][26]00)-02-29|\\d{4}-((0[13578]|1[02])-(0[1-9]|[12]\\d|3[01])|(0[469]|11)-(0[1-9]|[12]\\d|30)|(02)-(0[1-9]|1\\d|2[0-8])))",N2e=new RegExp(`^${pee}$`);function mee(e){let t="[0-5]\\d";e.precision?t=`${t}\\.\\d{${e.precision}}`:e.precision==null&&(t=`${t}(\\.\\d+)?`);const n=e.precision?"+":"?";return`([01]\\d|2[0-3]):[0-5]\\d(:${t})${n}`}function I2e(e){return new RegExp(`^${mee(e)}$`)}function L2e(e){let t=`${pee}T${mee(e)}`;const n=[];return n.push(e.local?"Z?":"Z"),e.offset&&n.push("([+-]\\d{2}:?\\d{2})"),t=`${t}(${n.join("|")})`,new RegExp(`^${t}$`)}function B2e(e,t){return!!((t==="v4"||!t)&&A2e.test(e)||(t==="v6"||!t)&&k2e.test(e))}function Q2e(e,t){if(!$2e.test(e))return!1;try{const[n]=e.split(".");if(!n)return!1;const r=n.replace(/-/g,"+").replace(/_/g,"/").padEnd(n.length+(4-n.length%4)%4,"="),i=JSON.parse(atob(r));return!(typeof i!="object"||i===null||"typ"in i&&(i==null?void 0:i.typ)!=="JWT"||!i.alg||t&&i.alg!==t)}catch{return!1}}function z2e(e,t){return!!((t==="v4"||!t)&&T2e.test(e)||(t==="v6"||!t)&&P2e.test(e))}class Gm extends Zr{_parse(t){if(this._def.coerce&&(t.data=String(t.data)),this._getType(t)!==dn.string){const a=this._getOrReturnCtx(t);return en(a,{code:Ft.invalid_type,expected:dn.string,received:a.parsedType}),Gn}const r=new fc;let i;for(const a of this._def.checks)if(a.kind==="min")t.data.length<a.value&&(i=this._getOrReturnCtx(t,i),en(i,{code:Ft.too_small,minimum:a.value,type:"string",inclusive:!0,exact:!1,message:a.message}),r.dirty());else if(a.kind==="max")t.data.length>a.value&&(i=this._getOrReturnCtx(t,i),en(i,{code:Ft.too_big,maximum:a.value,type:"string",inclusive:!0,exact:!1,message:a.message}),r.dirty());else if(a.kind==="length"){const u=t.data.length>a.value,l=t.data.length<a.value;(u||l)&&(i=this._getOrReturnCtx(t,i),u?en(i,{code:Ft.too_big,maximum:a.value,type:"string",inclusive:!0,exact:!0,message:a.message}):l&&en(i,{code:Ft.too_small,minimum:a.value,type:"string",inclusive:!0,exact:!0,message:a.message}),r.dirty())}else if(a.kind==="email")w2e.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"email",code:Ft.invalid_string,message:a.message}),r.dirty());else if(a.kind==="emoji")RT||(RT=new RegExp(R2e,"u")),RT.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"emoji",code:Ft.invalid_string,message:a.message}),r.dirty());else if(a.kind==="uuid")E2e.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"uuid",code:Ft.invalid_string,message:a.message}),r.dirty());else if(a.kind==="nanoid")D2e.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"nanoid",code:Ft.invalid_string,message:a.message}),r.dirty());else if(a.kind==="cuid")x2e.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"cuid",code:Ft.invalid_string,message:a.message}),r.dirty());else if(a.kind==="cuid2")S2e.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"cuid2",code:Ft.invalid_string,message:a.message}),r.dirty());else if(a.kind==="ulid")_2e.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"ulid",code:Ft.invalid_string,message:a.message}),r.dirty());else if(a.kind==="url")try{new URL(t.data)}catch{i=this._getOrReturnCtx(t,i),en(i,{validation:"url",code:Ft.invalid_string,message:a.message}),r.dirty()}else a.kind==="regex"?(a.regex.lastIndex=0,a.regex.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"regex",code:Ft.invalid_string,message:a.message}),r.dirty())):a.kind==="trim"?t.data=t.data.trim():a.kind==="includes"?t.data.includes(a.value,a.position)||(i=this._getOrReturnCtx(t,i),en(i,{code:Ft.invalid_string,validation:{includes:a.value,position:a.position},message:a.message}),r.dirty()):a.kind==="toLowerCase"?t.data=t.data.toLowerCase():a.kind==="toUpperCase"?t.data=t.data.toUpperCase():a.kind==="startsWith"?t.data.startsWith(a.value)||(i=this._getOrReturnCtx(t,i),en(i,{code:Ft.invalid_string,validation:{startsWith:a.value},message:a.message}),r.dirty()):a.kind==="endsWith"?t.data.endsWith(a.value)||(i=this._getOrReturnCtx(t,i),en(i,{code:Ft.invalid_string,validation:{endsWith:a.value},message:a.message}),r.dirty()):a.kind==="datetime"?L2e(a).test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{code:Ft.invalid_string,validation:"datetime",message:a.message}),r.dirty()):a.kind==="date"?N2e.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{code:Ft.invalid_string,validation:"date",message:a.message}),r.dirty()):a.kind==="time"?I2e(a).test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{code:Ft.invalid_string,validation:"time",message:a.message}),r.dirty()):a.kind==="duration"?C2e.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"duration",code:Ft.invalid_string,message:a.message}),r.dirty()):a.kind==="ip"?B2e(t.data,a.version)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"ip",code:Ft.invalid_string,message:a.message}),r.dirty()):a.kind==="jwt"?Q2e(t.data,a.alg)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"jwt",code:Ft.invalid_string,message:a.message}),r.dirty()):a.kind==="cidr"?z2e(t.data,a.version)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"cidr",code:Ft.invalid_string,message:a.message}),r.dirty()):a.kind==="base64"?M2e.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"base64",code:Ft.invalid_string,message:a.message}),r.dirty()):a.kind==="base64url"?F2e.test(t.data)||(i=this._getOrReturnCtx(t,i),en(i,{validation:"base64url",code:Ft.invalid_string,message:a.message}),r.dirty()):di.assertNever(a);return{status:r.value,value:t.data}}_regex(t,n,r){return this.refinement(i=>t.test(i),{validation:n,code:Ft.invalid_string,...xn.errToObj(r)})}_addCheck(t){return new Gm({...this._def,checks:[...this._def.checks,t]})}email(t){return this._addCheck({kind:"email",...xn.errToObj(t)})}url(t){return this._addCheck({kind:"url",...xn.errToObj(t)})}emoji(t){return this._addCheck({kind:"emoji",...xn.errToObj(t)})}uuid(t){return this._addCheck({kind:"uuid",...xn.errToObj(t)})}nanoid(t){return this._addCheck({kind:"nanoid",...xn.errToObj(t)})}cuid(t){return this._addCheck({kind:"cuid",...xn.errToObj(t)})}cuid2(t){return this._addCheck({kind:"cuid2",...xn.errToObj(t)})}ulid(t){return this._addCheck({kind:"ulid",...xn.errToObj(t)})}base64(t){return this._addCheck({kind:"base64",...xn.errToObj(t)})}base64url(t){return this._addCheck({kind:"base64url",...xn.errToObj(t)})}jwt(t){return this._addCheck({kind:"jwt",...xn.errToObj(t)})}ip(t){return this._addCheck({kind:"ip",...xn.errToObj(t)})}cidr(t){return this._addCheck({kind:"cidr",...xn.errToObj(t)})}datetime(t){return typeof t=="string"?this._addCheck({kind:"datetime",precision:null,offset:!1,local:!1,message:t}):this._addCheck({kind:"datetime",precision:typeof(t==null?void 0:t.precision)>"u"?null:t==null?void 0:t.precision,offset:(t==null?void 0:t.offset)??!1,local:(t==null?void 0:t.local)??!1,...xn.errToObj(t==null?void 0:t.message)})}date(t){return this._addCheck({kind:"date",message:t})}time(t){return typeof t=="string"?this._addCheck({kind:"time",precision:null,message:t}):this._addCheck({kind:"time",precision:typeof(t==null?void 0:t.precision)>"u"?null:t==null?void 0:t.precision,...xn.errToObj(t==null?void 0:t.message)})}duration(t){return this._addCheck({kind:"duration",...xn.errToObj(t)})}regex(t,n){return this._addCheck({kind:"regex",regex:t,...xn.errToObj(n)})}includes(t,n){return this._addCheck({kind:"includes",value:t,position:n==null?void 0:n.position,...xn.errToObj(n==null?void 0:n.message)})}startsWith(t,n){return this._addCheck({kind:"startsWith",value:t,...xn.errToObj(n)})}endsWith(t,n){return this._addCheck({kind:"endsWith",value:t,...xn.errToObj(n)})}min(t,n){return this._addCheck({kind:"min",value:t,...xn.errToObj(n)})}max(t,n){return this._addCheck({kind:"max",value:t,...xn.errToObj(n)})}length(t,n){return this._addCheck({kind:"length",value:t,...xn.errToObj(n)})}nonempty(t){return this.min(1,xn.errToObj(t))}trim(){return new Gm({...this._def,checks:[...this._def.checks,{kind:"trim"}]})}toLowerCase(){return new Gm({...this._def,checks:[...this._def.checks,{kind:"toLowerCase"}]})}toUpperCase(){return new Gm({...this._def,checks:[...this._def.checks,{kind:"toUpperCase"}]})}get isDatetime(){return!!this._def.checks.find(t=>t.kind==="datetime")}get isDate(){return!!this._def.checks.find(t=>t.kind==="date")}get isTime(){return!!this._def.checks.find(t=>t.kind==="time")}get isDuration(){return!!this._def.checks.find(t=>t.kind==="duration")}get isEmail(){return!!this._def.checks.find(t=>t.kind==="email")}get isURL(){return!!this._def.checks.find(t=>t.kind==="url")}get isEmoji(){return!!this._def.checks.find(t=>t.kind==="emoji")}get isUUID(){return!!this._def.checks.find(t=>t.kind==="uuid")}get isNANOID(){return!!this._def.checks.find(t=>t.kind==="nanoid")}get isCUID(){return!!this._def.checks.find(t=>t.kind==="cuid")}get isCUID2(){return!!this._def.checks.find(t=>t.kind==="cuid2")}get isULID(){return!!this._def.checks.find(t=>t.kind==="ulid")}get isIP(){return!!this._def.checks.find(t=>t.kind==="ip")}get isCIDR(){return!!this._def.checks.find(t=>t.kind==="cidr")}get isBase64(){return!!this._def.checks.find(t=>t.kind==="base64")}get isBase64url(){return!!this._def.checks.find(t=>t.kind==="base64url")}get minLength(){let t=null;for(const n of this._def.checks)n.kind==="min"&&(t===null||n.value>t)&&(t=n.value);return t}get maxLength(){let t=null;for(const n of this._def.checks)n.kind==="max"&&(t===null||n.value<t)&&(t=n.value);return t}}Gm.create=e=>new Gm({checks:[],typeName:It.ZodString,coerce:(e==null?void 0:e.coerce)??!1,...mr(e)});function q2e(e,t){const n=(e.toString().split(".")[1]||"").length,r=(t.toString().split(".")[1]||"").length,i=n>r?n:r,a=Number.parseInt(e.toFixed(i).replace(".","")),u=Number.parseInt(t.toFixed(i).replace(".",""));return a%u/10**i}class E3 extends Zr{constructor(){super(...arguments),this.min=this.gte,this.max=this.lte,this.step=this.multipleOf}_parse(t){if(this._def.coerce&&(t.data=Number(t.data)),this._getType(t)!==dn.number){const a=this._getOrReturnCtx(t);return en(a,{code:Ft.invalid_type,expected:dn.number,received:a.parsedType}),Gn}let r;const i=new fc;for(const a of this._def.checks)a.kind==="int"?di.isInteger(t.data)||(r=this._getOrReturnCtx(t,r),en(r,{code:Ft.invalid_type,expected:"integer",received:"float",message:a.message}),i.dirty()):a.kind==="min"?(a.inclusive?t.data<a.value:t.data<=a.value)&&(r=this._getOrReturnCtx(t,r),en(r,{code:Ft.too_small,minimum:a.value,type:"number",inclusive:a.inclusive,exact:!1,message:a.message}),i.dirty()):a.kind==="max"?(a.inclusive?t.data>a.value:t.data>=a.value)&&(r=this._getOrReturnCtx(t,r),en(r,{code:Ft.too_big,maximum:a.value,type:"number",inclusive:a.inclusive,exact:!1,message:a.message}),i.dirty()):a.kind==="multipleOf"?q2e(t.data,a.value)!==0&&(r=this._getOrReturnCtx(t,r),en(r,{code:Ft.not_multiple_of,multipleOf:a.value,message:a.message}),i.dirty()):a.kind==="finite"?Number.isFinite(t.data)||(r=this._getOrReturnCtx(t,r),en(r,{code:Ft.not_finite,message:a.message}),i.dirty()):di.assertNever(a);return{status:i.value,value:t.data}}gte(t,n){return this.setLimit("min",t,!0,xn.toString(n))}gt(t,n){return this.setLimit("min",t,!1,xn.toString(n))}lte(t,n){return this.setLimit("max",t,!0,xn.toString(n))}lt(t,n){return this.setLimit("max",t,!1,xn.toString(n))}setLimit(t,n,r,i){return new E3({...this._def,checks:[...this._def.checks,{kind:t,value:n,inclusive:r,message:xn.toString(i)}]})}_addCheck(t){return new E3({...this._def,checks:[...this._def.checks,t]})}int(t){return this._addCheck({kind:"int",message:xn.toString(t)})}positive(t){return this._addCheck({kind:"min",value:0,inclusive:!1,message:xn.toString(t)})}negative(t){return this._addCheck({kind:"max",value:0,inclusive:!1,message:xn.toString(t)})}nonpositive(t){return this._addCheck({kind:"max",value:0,inclusive:!0,message:xn.toString(t)})}nonnegative(t){return this._addCheck({kind:"min",value:0,inclusive:!0,message:xn.toString(t)})}multipleOf(t,n){return this._addCheck({kind:"multipleOf",value:t,message:xn.toString(n)})}finite(t){return this._addCheck({kind:"finite",message:xn.toString(t)})}safe(t){return this._addCheck({kind:"min",inclusive:!0,value:Number.MIN_SAFE_INTEGER,message:xn.toString(t)})._addCheck({kind:"max",inclusive:!0,value:Number.MAX_SAFE_INTEGER,message:xn.toString(t)})}get minValue(){let t=null;for(const n of this._def.checks)n.kind==="min"&&(t===null||n.value>t)&&(t=n.value);return t}get maxValue(){let t=null;for(const n of this._def.checks)n.kind==="max"&&(t===null||n.value<t)&&(t=n.value);return t}get isInt(){return!!this._def.checks.find(t=>t.kind==="int"||t.kind==="multipleOf"&&di.isInteger(t.value))}get isFinite(){let t=null,n=null;for(const r of this._def.checks){if(r.kind==="finite"||r.kind==="int"||r.kind==="multipleOf")return!0;r.kind==="min"?(n===null||r.value>n)&&(n=r.value):r.kind==="max"&&(t===null||r.value<t)&&(t=r.value)}return Number.isFinite(n)&&Number.isFinite(t)}}E3.create=e=>new E3({checks:[],typeName:It.ZodNumber,coerce:(e==null?void 0:e.coerce)||!1,...mr(e)});class ox extends Zr{constructor(){super(...arguments),this.min=this.gte,this.max=this.lte}_parse(t){if(this._def.coerce)try{t.data=BigInt(t.data)}catch{return this._getInvalidInput(t)}if(this._getType(t)!==dn.bigint)return this._getInvalidInput(t);let r;const i=new fc;for(const a of this._def.checks)a.kind==="min"?(a.inclusive?t.data<a.value:t.data<=a.value)&&(r=this._getOrReturnCtx(t,r),en(r,{code:Ft.too_small,type:"bigint",minimum:a.value,inclusive:a.inclusive,message:a.message}),i.dirty()):a.kind==="max"?(a.inclusive?t.data>a.value:t.data>=a.value)&&(r=this._getOrReturnCtx(t,r),en(r,{code:Ft.too_big,type:"bigint",maximum:a.value,inclusive:a.inclusive,message:a.message}),i.dirty()):a.kind==="multipleOf"?t.data%a.value!==BigInt(0)&&(r=this._getOrReturnCtx(t,r),en(r,{code:Ft.not_multiple_of,multipleOf:a.value,message:a.message}),i.dirty()):di.assertNever(a);return{status:i.value,value:t.data}}_getInvalidInput(t){const n=this._getOrReturnCtx(t);return en(n,{code:Ft.invalid_type,expected:dn.bigint,received:n.parsedType}),Gn}gte(t,n){return this.setLimit("min",t,!0,xn.toString(n))}gt(t,n){return this.setLimit("min",t,!1,xn.toString(n))}lte(t,n){return this.setLimit("max",t,!0,xn.toString(n))}lt(t,n){return this.setLimit("max",t,!1,xn.toString(n))}setLimit(t,n,r,i){return new ox({...this._def,checks:[...this._def.checks,{kind:t,value:n,inclusive:r,message:xn.toString(i)}]})}_addCheck(t){return new ox({...this._def,checks:[...this._def.checks,t]})}positive(t){return this._addCheck({kind:"min",value:BigInt(0),inclusive:!1,message:xn.toString(t)})}negative(t){return this._addCheck({kind:"max",value:BigInt(0),inclusive:!1,message:xn.toString(t)})}nonpositive(t){return this._addCheck({kind:"max",value:BigInt(0),inclusive:!0,message:xn.toString(t)})}nonnegative(t){return this._addCheck({kind:"min",value:BigInt(0),inclusive:!0,message:xn.toString(t)})}multipleOf(t,n){return this._addCheck({kind:"multipleOf",value:t,message:xn.toString(n)})}get minValue(){let t=null;for(const n of this._def.checks)n.kind==="min"&&(t===null||n.value>t)&&(t=n.value);return t}get maxValue(){let t=null;for(const n of this._def.checks)n.kind==="max"&&(t===null||n.value<t)&&(t=n.value);return t}}ox.create=e=>new ox({checks:[],typeName:It.ZodBigInt,coerce:(e==null?void 0:e.coerce)??!1,...mr(e)});class t9 extends Zr{_parse(t){if(this._def.coerce&&(t.data=!!t.data),this._getType(t)!==dn.boolean){const r=this._getOrReturnCtx(t);return en(r,{code:Ft.invalid_type,expected:dn.boolean,received:r.parsedType}),Gn}return nh(t.data)}}t9.create=e=>new t9({typeName:It.ZodBoolean,coerce:(e==null?void 0:e.coerce)||!1,...mr(e)});class _D extends Zr{_parse(t){if(this._def.coerce&&(t.data=new Date(t.data)),this._getType(t)!==dn.date){const a=this._getOrReturnCtx(t);return en(a,{code:Ft.invalid_type,expected:dn.date,received:a.parsedType}),Gn}if(Number.isNaN(t.data.getTime())){const a=this._getOrReturnCtx(t);return en(a,{code:Ft.invalid_date}),Gn}const r=new fc;let i;for(const a of this._def.checks)a.kind==="min"?t.data.getTime()<a.value&&(i=this._getOrReturnCtx(t,i),en(i,{code:Ft.too_small,message:a.message,inclusive:!0,exact:!1,minimum:a.value,type:"date"}),r.dirty()):a.kind==="max"?t.data.getTime()>a.value&&(i=this._getOrReturnCtx(t,i),en(i,{code:Ft.too_big,message:a.message,inclusive:!0,exact:!1,maximum:a.value,type:"date"}),r.dirty()):di.assertNever(a);return{status:r.value,value:new Date(t.data.getTime())}}_addCheck(t){return new _D({...this._def,checks:[...this._def.checks,t]})}min(t,n){return this._addCheck({kind:"min",value:t.getTime(),message:xn.toString(n)})}max(t,n){return this._addCheck({kind:"max",value:t.getTime(),message:xn.toString(n)})}get minDate(){let t=null;for(const n of this._def.checks)n.kind==="min"&&(t===null||n.value>t)&&(t=n.value);return t!=null?new Date(t):null}get maxDate(){let t=null;for(const n of this._def.checks)n.kind==="max"&&(t===null||n.value<t)&&(t=n.value);return t!=null?new Date(t):null}}_D.create=e=>new _D({checks:[],coerce:(e==null?void 0:e.coerce)||!1,typeName:It.ZodDate,...mr(e)});class zV extends Zr{_parse(t){if(this._getType(t)!==dn.symbol){const r=this._getOrReturnCtx(t);return en(r,{code:Ft.invalid_type,expected:dn.symbol,received:r.parsedType}),Gn}return nh(t.data)}}zV.create=e=>new zV({typeName:It.ZodSymbol,...mr(e)});class n9 extends Zr{_parse(t){if(this._getType(t)!==dn.undefined){const r=this._getOrReturnCtx(t);return en(r,{code:Ft.invalid_type,expected:dn.undefined,received:r.parsedType}),Gn}return nh(t.data)}}n9.create=e=>new n9({typeName:It.ZodUndefined,...mr(e)});class ED extends Zr{_parse(t){if(this._getType(t)!==dn.null){const r=this._getOrReturnCtx(t);return en(r,{code:Ft.invalid_type,expected:dn.null,received:r.parsedType}),Gn}return nh(t.data)}}ED.create=e=>new ED({typeName:It.ZodNull,...mr(e)});class qV extends Zr{constructor(){super(...arguments),this._any=!0}_parse(t){return nh(t.data)}}qV.create=e=>new qV({typeName:It.ZodAny,...mr(e)});class r9 extends Zr{constructor(){super(...arguments),this._unknown=!0}_parse(t){return nh(t.data)}}r9.create=e=>new r9({typeName:It.ZodUnknown,...mr(e)});class Xv extends Zr{_parse(t){const n=this._getOrReturnCtx(t);return en(n,{code:Ft.invalid_type,expected:dn.never,received:n.parsedType}),Gn}}Xv.create=e=>new Xv({typeName:It.ZodNever,...mr(e)});class VV extends Zr{_parse(t){if(this._getType(t)!==dn.undefined){const r=this._getOrReturnCtx(t);return en(r,{code:Ft.invalid_type,expected:dn.void,received:r.parsedType}),Gn}return nh(t.data)}}VV.create=e=>new VV({typeName:It.ZodVoid,...mr(e)});class $0 extends Zr{_parse(t){const{ctx:n,status:r}=this._processInputParams(t),i=this._def;if(n.parsedType!==dn.array)return en(n,{code:Ft.invalid_type,expected:dn.array,received:n.parsedType}),Gn;if(i.exactLength!==null){const u=n.data.length>i.exactLength.value,l=n.data.length<i.exactLength.value;(u||l)&&(en(n,{code:u?Ft.too_big:Ft.too_small,minimum:l?i.exactLength.value:void 0,maximum:u?i.exactLength.value:void 0,type:"array",inclusive:!0,exact:!0,message:i.exactLength.message}),r.dirty())}if(i.minLength!==null&&n.data.length<i.minLength.value&&(en(n,{code:Ft.too_small,minimum:i.minLength.value,type:"array",inclusive:!0,exact:!1,message:i.minLength.message}),r.dirty()),i.maxLength!==null&&n.data.length>i.maxLength.value&&(en(n,{code:Ft.too_big,maximum:i.maxLength.value,type:"array",inclusive:!0,exact:!1,message:i.maxLength.message}),r.dirty()),n.common.async)return Promise.all([...n.data].map((u,l)=>i.type._parseAsync(new k0(n,u,n.path,l)))).then(u=>fc.mergeArray(r,u));const a=[...n.data].map((u,l)=>i.type._parseSync(new k0(n,u,n.path,l)));return fc.mergeArray(r,a)}get element(){return this._def.type}min(t,n){return new $0({...this._def,minLength:{value:t,message:xn.toString(n)}})}max(t,n){return new $0({...this._def,maxLength:{value:t,message:xn.toString(n)}})}length(t,n){return new $0({...this._def,exactLength:{value:t,message:xn.toString(n)}})}nonempty(t){return this.min(1,t)}}$0.create=(e,t)=>new $0({type:e,minLength:null,maxLength:null,exactLength:null,typeName:It.ZodArray,...mr(t)});function FO(e){if(e instanceof hl){const t={};for(const n in e.shape){const r=e.shape[n];t[n]=ng.create(FO(r))}return new hl({...e._def,shape:()=>t})}else return e instanceof $0?new $0({...e._def,type:FO(e.element)}):e instanceof ng?ng.create(FO(e.unwrap())):e instanceof nb?nb.create(FO(e.unwrap())):e instanceof J1?J1.create(e.items.map(t=>FO(t))):e}class hl extends Zr{constructor(){super(...arguments),this._cached=null,this.nonstrict=this.passthrough,this.augment=this.extend}_getCached(){if(this._cached!==null)return this._cached;const t=this._def.shape(),n=di.objectKeys(t);return this._cached={shape:t,keys:n},this._cached}_parse(t){if(this._getType(t)!==dn.object){const s=this._getOrReturnCtx(t);return en(s,{code:Ft.invalid_type,expected:dn.object,received:s.parsedType}),Gn}const{status:r,ctx:i}=this._processInputParams(t),{shape:a,keys:u}=this._getCached(),l=[];if(!(this._def.catchall instanceof Xv&&this._def.unknownKeys==="strip"))for(const s in i.data)u.includes(s)||l.push(s);const o=[];for(const s of u){const c=a[s],d=i.data[s];o.push({key:{status:"valid",value:s},value:c._parse(new k0(i,d,i.path,s)),alwaysSet:s in i.data})}if(this._def.catchall instanceof Xv){const s=this._def.unknownKeys;if(s==="passthrough")for(const c of l)o.push({key:{status:"valid",value:c},value:{status:"valid",value:i.data[c]}});else if(s==="strict")l.length>0&&(en(i,{code:Ft.unrecognized_keys,keys:l}),r.dirty());else if(s!=="strip")throw new Error("Internal ZodObject error: invalid unknownKeys value.")}else{const s=this._def.catchall;for(const c of l){const d=i.data[c];o.push({key:{status:"valid",value:c},value:s._parse(new k0(i,d,i.path,c)),alwaysSet:c in i.data})}}return i.common.async?Promise.resolve().then(async()=>{const s=[];for(const c of o){const d=await c.key,h=await c.value;s.push({key:d,value:h,alwaysSet:c.alwaysSet})}return s}).then(s=>fc.mergeObjectSync(r,s)):fc.mergeObjectSync(r,o)}get shape(){return this._def.shape()}strict(t){return xn.errToObj,new hl({...this._def,unknownKeys:"strict",...t!==void 0?{errorMap:(n,r)=>{var a,u;const i=((u=(a=this._def).errorMap)==null?void 0:u.call(a,n,r).message)??r.defaultError;return n.code==="unrecognized_keys"?{message:xn.errToObj(t).message??i}:{message:i}}}:{}})}strip(){return new hl({...this._def,unknownKeys:"strip"})}passthrough(){return new hl({...this._def,unknownKeys:"passthrough"})}extend(t){return new hl({...this._def,shape:()=>({...this._def.shape(),...t})})}merge(t){return new hl({unknownKeys:t._def.unknownKeys,catchall:t._def.catchall,shape:()=>({...this._def.shape(),...t._def.shape()}),typeName:It.ZodObject})}setKey(t,n){return this.augment({[t]:n})}catchall(t){return new hl({...this._def,catchall:t})}pick(t){const n={};for(const r of di.objectKeys(t))t[r]&&this.shape[r]&&(n[r]=this.shape[r]);return new hl({...this._def,shape:()=>n})}omit(t){const n={};for(const r of di.objectKeys(this.shape))t[r]||(n[r]=this.shape[r]);return new hl({...this._def,shape:()=>n})}deepPartial(){return FO(this)}partial(t){const n={};for(const r of di.objectKeys(this.shape)){const i=this.shape[r];t&&!t[r]?n[r]=i:n[r]=i.optional()}return new hl({...this._def,shape:()=>n})}required(t){const n={};for(const r of di.objectKeys(this.shape))if(t&&!t[r])n[r]=this.shape[r];else{let a=this.shape[r];for(;a instanceof ng;)a=a._def.innerType;n[r]=a}return new hl({...this._def,shape:()=>n})}keyof(){return gee(di.objectKeys(this.shape))}}hl.create=(e,t)=>new hl({shape:()=>e,unknownKeys:"strip",catchall:Xv.create(),typeName:It.ZodObject,...mr(t)});hl.strictCreate=(e,t)=>new hl({shape:()=>e,unknownKeys:"strict",catchall:Xv.create(),typeName:It.ZodObject,...mr(t)});hl.lazycreate=(e,t)=>new hl({shape:e,unknownKeys:"strip",catchall:Xv.create(),typeName:It.ZodObject,...mr(t)});class DD extends Zr{_parse(t){const{ctx:n}=this._processInputParams(t),r=this._def.options;function i(a){for(const l of a)if(l.result.status==="valid")return l.result;for(const l of a)if(l.result.status==="dirty")return n.common.issues.push(...l.ctx.common.issues),l.result;const u=a.map(l=>new lg(l.ctx.common.issues));return en(n,{code:Ft.invalid_union,unionErrors:u}),Gn}if(n.common.async)return Promise.all(r.map(async a=>{const u={...n,common:{...n.common,issues:[]},parent:null};return{result:await a._parseAsync({data:n.data,path:n.path,parent:u}),ctx:u}})).then(i);{let a;const u=[];for(const o of r){const s={...n,common:{...n.common,issues:[]},parent:null},c=o._parseSync({data:n.data,path:n.path,parent:s});if(c.status==="valid")return c;c.status==="dirty"&&!a&&(a={result:c,ctx:s}),s.common.issues.length&&u.push(s.common.issues)}if(a)return n.common.issues.push(...a.ctx.common.issues),a.result;const l=u.map(o=>new lg(o));return en(n,{code:Ft.invalid_union,unionErrors:l}),Gn}}get options(){return this._def.options}}DD.create=(e,t)=>new DD({options:e,typeName:It.ZodUnion,...mr(t)});const Pm=e=>e instanceof wD?Pm(e.schema):e instanceof tb?Pm(e.innerType()):e instanceof RD?[e.value]:e instanceof eb?e.options:e instanceof a9?di.objectValues(e.enum):e instanceof TD?Pm(e._def.innerType):e instanceof n9?[void 0]:e instanceof ED?[null]:e instanceof ng?[void 0,...Pm(e.unwrap())]:e instanceof nb?[null,...Pm(e.unwrap())]:e instanceof vee||e instanceof PD?Pm(e.unwrap()):e instanceof kD?Pm(e._def.innerType):[];class KF extends Zr{_parse(t){const{ctx:n}=this._processInputParams(t);if(n.parsedType!==dn.object)return en(n,{code:Ft.invalid_type,expected:dn.object,received:n.parsedType}),Gn;const r=this.discriminator,i=n.data[r],a=this.optionsMap.get(i);return a?n.common.async?a._parseAsync({data:n.data,path:n.path,parent:n}):a._parseSync({data:n.data,path:n.path,parent:n}):(en(n,{code:Ft.invalid_union_discriminator,options:Array.from(this.optionsMap.keys()),path:[r]}),Gn)}get discriminator(){return this._def.discriminator}get options(){return this._def.options}get optionsMap(){return this._def.optionsMap}static create(t,n,r){const i=new Map;for(const a of n){const u=Pm(a.shape[t]);if(!u.length)throw new Error(`A discriminator value for key \`${t}\` could not be extracted from all schema options`);for(const l of u){if(i.has(l))throw new Error(`Discriminator property ${String(t)} has duplicate value ${String(l)}`);i.set(l,a)}}return new KF({typeName:It.ZodDiscriminatedUnion,discriminator:t,options:n,optionsMap:i,...mr(r)})}}function i9(e,t){const n=yv(e),r=yv(t);if(e===t)return{valid:!0,data:e};if(n===dn.object&&r===dn.object){const i=di.objectKeys(t),a=di.objectKeys(e).filter(l=>i.indexOf(l)!==-1),u={...e,...t};for(const l of a){const o=i9(e[l],t[l]);if(!o.valid)return{valid:!1};u[l]=o.data}return{valid:!0,data:u}}else if(n===dn.array&&r===dn.array){if(e.length!==t.length)return{valid:!1};const i=[];for(let a=0;a<e.length;a++){const u=e[a],l=t[a],o=i9(u,l);if(!o.valid)return{valid:!1};i.push(o.data)}return{valid:!0,data:i}}else return n===dn.date&&r===dn.date&&+e==+t?{valid:!0,data:e}:{valid:!1}}class $D extends Zr{_parse(t){const{status:n,ctx:r}=this._processInputParams(t),i=(a,u)=>{if(LV(a)||LV(u))return Gn;const l=i9(a.value,u.value);return l.valid?((BV(a)||BV(u))&&n.dirty(),{status:n.value,value:l.data}):(en(r,{code:Ft.invalid_intersection_types}),Gn)};return r.common.async?Promise.all([this._def.left._parseAsync({data:r.data,path:r.path,parent:r}),this._def.right._parseAsync({data:r.data,path:r.path,parent:r})]).then(([a,u])=>i(a,u)):i(this._def.left._parseSync({data:r.data,path:r.path,parent:r}),this._def.right._parseSync({data:r.data,path:r.path,parent:r}))}}$D.create=(e,t,n)=>new $D({left:e,right:t,typeName:It.ZodIntersection,...mr(n)});class J1 extends Zr{_parse(t){const{status:n,ctx:r}=this._processInputParams(t);if(r.parsedType!==dn.array)return en(r,{code:Ft.invalid_type,expected:dn.array,received:r.parsedType}),Gn;if(r.data.length<this._def.items.length)return en(r,{code:Ft.too_small,minimum:this._def.items.length,inclusive:!0,exact:!1,type:"array"}),Gn;!this._def.rest&&r.data.length>this._def.items.length&&(en(r,{code:Ft.too_big,maximum:this._def.items.length,inclusive:!0,exact:!1,type:"array"}),n.dirty());const a=[...r.data].map((u,l)=>{const o=this._def.items[l]||this._def.rest;return o?o._parse(new k0(r,u,r.path,l)):null}).filter(u=>!!u);return r.common.async?Promise.all(a).then(u=>fc.mergeArray(n,u)):fc.mergeArray(n,a)}get items(){return this._def.items}rest(t){return new J1({...this._def,rest:t})}}J1.create=(e,t)=>{if(!Array.isArray(e))throw new Error("You must pass an array of schemas to z.tuple([ ... ])");return new J1({items:e,typeName:It.ZodTuple,rest:null,...mr(t)})};class CD extends Zr{get keySchema(){return this._def.keyType}get valueSchema(){return this._def.valueType}_parse(t){const{status:n,ctx:r}=this._processInputParams(t);if(r.parsedType!==dn.object)return en(r,{code:Ft.invalid_type,expected:dn.object,received:r.parsedType}),Gn;const i=[],a=this._def.keyType,u=this._def.valueType;for(const l in r.data)i.push({key:a._parse(new k0(r,l,r.path,l)),value:u._parse(new k0(r,r.data[l],r.path,l)),alwaysSet:l in r.data});return r.common.async?fc.mergeObjectAsync(n,i):fc.mergeObjectSync(n,i)}get element(){return this._def.valueType}static create(t,n,r){return n instanceof Zr?new CD({keyType:t,valueType:n,typeName:It.ZodRecord,...mr(r)}):new CD({keyType:Gm.create(),valueType:t,typeName:It.ZodRecord,...mr(n)})}}class UV extends Zr{get keySchema(){return this._def.keyType}get valueSchema(){return this._def.valueType}_parse(t){const{status:n,ctx:r}=this._processInputParams(t);if(r.parsedType!==dn.map)return en(r,{code:Ft.invalid_type,expected:dn.map,received:r.parsedType}),Gn;const i=this._def.keyType,a=this._def.valueType,u=[...r.data.entries()].map(([l,o],s)=>({key:i._parse(new k0(r,l,r.path,[s,"key"])),value:a._parse(new k0(r,o,r.path,[s,"value"]))}));if(r.common.async){const l=new Map;return Promise.resolve().then(async()=>{for(const o of u){const s=await o.key,c=await o.value;if(s.status==="aborted"||c.status==="aborted")return Gn;(s.status==="dirty"||c.status==="dirty")&&n.dirty(),l.set(s.value,c.value)}return{status:n.value,value:l}})}else{const l=new Map;for(const o of u){const s=o.key,c=o.value;if(s.status==="aborted"||c.status==="aborted")return Gn;(s.status==="dirty"||c.status==="dirty")&&n.dirty(),l.set(s.value,c.value)}return{status:n.value,value:l}}}}UV.create=(e,t,n)=>new UV({valueType:t,keyType:e,typeName:It.ZodMap,...mr(n)});class sx extends Zr{_parse(t){const{status:n,ctx:r}=this._processInputParams(t);if(r.parsedType!==dn.set)return en(r,{code:Ft.invalid_type,expected:dn.set,received:r.parsedType}),Gn;const i=this._def;i.minSize!==null&&r.data.size<i.minSize.value&&(en(r,{code:Ft.too_small,minimum:i.minSize.value,type:"set",inclusive:!0,exact:!1,message:i.minSize.message}),n.dirty()),i.maxSize!==null&&r.data.size>i.maxSize.value&&(en(r,{code:Ft.too_big,maximum:i.maxSize.value,type:"set",inclusive:!0,exact:!1,message:i.maxSize.message}),n.dirty());const a=this._def.valueType;function u(o){const s=new Set;for(const c of o){if(c.status==="aborted")return Gn;c.status==="dirty"&&n.dirty(),s.add(c.value)}return{status:n.value,value:s}}const l=[...r.data.values()].map((o,s)=>a._parse(new k0(r,o,r.path,s)));return r.common.async?Promise.all(l).then(o=>u(o)):u(l)}min(t,n){return new sx({...this._def,minSize:{value:t,message:xn.toString(n)}})}max(t,n){return new sx({...this._def,maxSize:{value:t,message:xn.toString(n)}})}size(t,n){return this.min(t,n).max(t,n)}nonempty(t){return this.min(1,t)}}sx.create=(e,t)=>new sx({valueType:e,minSize:null,maxSize:null,typeName:It.ZodSet,...mr(t)});class wD extends Zr{get schema(){return this._def.getter()}_parse(t){const{ctx:n}=this._processInputParams(t);return this._def.getter()._parse({data:n.data,path:n.path,parent:n})}}wD.create=(e,t)=>new wD({getter:e,typeName:It.ZodLazy,...mr(t)});class RD extends Zr{_parse(t){if(t.data!==this._def.value){const n=this._getOrReturnCtx(t);return en(n,{received:n.data,code:Ft.invalid_literal,expected:this._def.value}),Gn}return{status:"valid",value:t.data}}get value(){return this._def.value}}RD.create=(e,t)=>new RD({value:e,typeName:It.ZodLiteral,...mr(t)});function gee(e,t){return new eb({values:e,typeName:It.ZodEnum,...mr(t)})}class eb extends Zr{_parse(t){if(typeof t.data!="string"){const n=this._getOrReturnCtx(t),r=this._def.values;return en(n,{expected:di.joinValues(r),received:n.parsedType,code:Ft.invalid_type}),Gn}if(this._cache||(this._cache=new Set(this._def.values)),!this._cache.has(t.data)){const n=this._getOrReturnCtx(t),r=this._def.values;return en(n,{received:n.data,code:Ft.invalid_enum_value,options:r}),Gn}return nh(t.data)}get options(){return this._def.values}get enum(){const t={};for(const n of this._def.values)t[n]=n;return t}get Values(){const t={};for(const n of this._def.values)t[n]=n;return t}get Enum(){const t={};for(const n of this._def.values)t[n]=n;return t}extract(t,n=this._def){return eb.create(t,{...this._def,...n})}exclude(t,n=this._def){return eb.create(this.options.filter(r=>!t.includes(r)),{...this._def,...n})}}eb.create=gee;class a9 extends Zr{_parse(t){const n=di.getValidEnumValues(this._def.values),r=this._getOrReturnCtx(t);if(r.parsedType!==dn.string&&r.parsedType!==dn.number){const i=di.objectValues(n);return en(r,{expected:di.joinValues(i),received:r.parsedType,code:Ft.invalid_type}),Gn}if(this._cache||(this._cache=new Set(di.getValidEnumValues(this._def.values))),!this._cache.has(t.data)){const i=di.objectValues(n);return en(r,{received:r.data,code:Ft.invalid_enum_value,options:i}),Gn}return nh(t.data)}get enum(){return this._def.values}}a9.create=(e,t)=>new a9({values:e,typeName:It.ZodNativeEnum,...mr(t)});class AD extends Zr{unwrap(){return this._def.type}_parse(t){const{ctx:n}=this._processInputParams(t);if(n.parsedType!==dn.promise&&n.common.async===!1)return en(n,{code:Ft.invalid_type,expected:dn.promise,received:n.parsedType}),Gn;const r=n.parsedType===dn.promise?n.data:Promise.resolve(n.data);return nh(r.then(i=>this._def.type.parseAsync(i,{path:n.path,errorMap:n.common.contextualErrorMap})))}}AD.create=(e,t)=>new AD({type:e,typeName:It.ZodPromise,...mr(t)});class tb extends Zr{innerType(){return this._def.schema}sourceType(){return this._def.schema._def.typeName===It.ZodEffects?this._def.schema.sourceType():this._def.schema}_parse(t){const{status:n,ctx:r}=this._processInputParams(t),i=this._def.effect||null,a={addIssue:u=>{en(r,u),u.fatal?n.abort():n.dirty()},get path(){return r.path}};if(a.addIssue=a.addIssue.bind(a),i.type==="preprocess"){const u=i.transform(r.data,a);if(r.common.async)return Promise.resolve(u).then(async l=>{if(n.value==="aborted")return Gn;const o=await this._def.schema._parseAsync({data:l,path:r.path,parent:r});return o.status==="aborted"?Gn:o.status==="dirty"||n.value==="dirty"?w2(o.value):o});{if(n.value==="aborted")return Gn;const l=this._def.schema._parseSync({data:u,path:r.path,parent:r});return l.status==="aborted"?Gn:l.status==="dirty"||n.value==="dirty"?w2(l.value):l}}if(i.type==="refinement"){const u=l=>{const o=i.refinement(l,a);if(r.common.async)return Promise.resolve(o);if(o instanceof Promise)throw new Error("Async refinement encountered during synchronous parse operation. Use .parseAsync instead.");return l};if(r.common.async===!1){const l=this._def.schema._parseSync({data:r.data,path:r.path,parent:r});return l.status==="aborted"?Gn:(l.status==="dirty"&&n.dirty(),u(l.value),{status:n.value,value:l.value})}else return this._def.schema._parseAsync({data:r.data,path:r.path,parent:r}).then(l=>l.status==="aborted"?Gn:(l.status==="dirty"&&n.dirty(),u(l.value).then(()=>({status:n.value,value:l.value}))))}if(i.type==="transform")if(r.common.async===!1){const u=this._def.schema._parseSync({data:r.data,path:r.path,parent:r});if(!_3(u))return Gn;const l=i.transform(u.value,a);if(l instanceof Promise)throw new Error("Asynchronous transform encountered during synchronous parse operation. Use .parseAsync instead.");return{status:n.value,value:l}}else return this._def.schema._parseAsync({data:r.data,path:r.path,parent:r}).then(u=>_3(u)?Promise.resolve(i.transform(u.value,a)).then(l=>({status:n.value,value:l})):Gn);di.assertNever(i)}}tb.create=(e,t,n)=>new tb({schema:e,typeName:It.ZodEffects,effect:t,...mr(n)});tb.createWithPreprocess=(e,t,n)=>new tb({schema:t,effect:{type:"preprocess",transform:e},typeName:It.ZodEffects,...mr(n)});class ng extends Zr{_parse(t){return this._getType(t)===dn.undefined?nh(void 0):this._def.innerType._parse(t)}unwrap(){return this._def.innerType}}ng.create=(e,t)=>new ng({innerType:e,typeName:It.ZodOptional,...mr(t)});class nb extends Zr{_parse(t){return this._getType(t)===dn.null?nh(null):this._def.innerType._parse(t)}unwrap(){return this._def.innerType}}nb.create=(e,t)=>new nb({innerType:e,typeName:It.ZodNullable,...mr(t)});class TD extends Zr{_parse(t){const{ctx:n}=this._processInputParams(t);let r=n.data;return n.parsedType===dn.undefined&&(r=this._def.defaultValue()),this._def.innerType._parse({data:r,path:n.path,parent:n})}removeDefault(){return this._def.innerType}}TD.create=(e,t)=>new TD({innerType:e,typeName:It.ZodDefault,defaultValue:typeof t.default=="function"?t.default:()=>t.default,...mr(t)});class kD extends Zr{_parse(t){const{ctx:n}=this._processInputParams(t),r={...n,common:{...n.common,issues:[]}},i=this._def.innerType._parse({data:r.data,path:r.path,parent:{...r}});return SD(i)?i.then(a=>({status:"valid",value:a.status==="valid"?a.value:this._def.catchValue({get error(){return new lg(r.common.issues)},input:r.data})})):{status:"valid",value:i.status==="valid"?i.value:this._def.catchValue({get error(){return new lg(r.common.issues)},input:r.data})}}removeCatch(){return this._def.innerType}}kD.create=(e,t)=>new kD({innerType:e,typeName:It.ZodCatch,catchValue:typeof t.catch=="function"?t.catch:()=>t.catch,...mr(t)});class jV extends Zr{_parse(t){if(this._getType(t)!==dn.nan){const r=this._getOrReturnCtx(t);return en(r,{code:Ft.invalid_type,expected:dn.nan,received:r.parsedType}),Gn}return{status:"valid",value:t.data}}}jV.create=e=>new jV({typeName:It.ZodNaN,...mr(e)});class vee extends Zr{_parse(t){const{ctx:n}=this._processInputParams(t),r=n.data;return this._def.type._parse({data:r,path:n.path,parent:n})}unwrap(){return this._def.type}}class WF extends Zr{_parse(t){const{status:n,ctx:r}=this._processInputParams(t);if(r.common.async)return(async()=>{const a=await this._def.in._parseAsync({data:r.data,path:r.path,parent:r});return a.status==="aborted"?Gn:a.status==="dirty"?(n.dirty(),w2(a.value)):this._def.out._parseAsync({data:a.value,path:r.path,parent:r})})();{const i=this._def.in._parseSync({data:r.data,path:r.path,parent:r});return i.status==="aborted"?Gn:i.status==="dirty"?(n.dirty(),{status:"dirty",value:i.value}):this._def.out._parseSync({data:i.value,path:r.path,parent:r})}}static create(t,n){return new WF({in:t,out:n,typeName:It.ZodPipeline})}}class PD extends Zr{_parse(t){const n=this._def.innerType._parse(t),r=i=>(_3(i)&&(i.value=Object.freeze(i.value)),i);return SD(n)?n.then(i=>r(i)):r(n)}unwrap(){return this._def.innerType}}PD.create=(e,t)=>new PD({innerType:e,typeName:It.ZodReadonly,...mr(t)});var It;(function(e){e.ZodString="ZodString",e.ZodNumber="ZodNumber",e.ZodNaN="ZodNaN",e.ZodBigInt="ZodBigInt",e.ZodBoolean="ZodBoolean",e.ZodDate="ZodDate",e.ZodSymbol="ZodSymbol",e.ZodUndefined="ZodUndefined",e.ZodNull="ZodNull",e.ZodAny="ZodAny",e.ZodUnknown="ZodUnknown",e.ZodNever="ZodNever",e.ZodVoid="ZodVoid",e.ZodArray="ZodArray",e.ZodObject="ZodObject",e.ZodUnion="ZodUnion",e.ZodDiscriminatedUnion="ZodDiscriminatedUnion",e.ZodIntersection="ZodIntersection",e.ZodTuple="ZodTuple",e.ZodRecord="ZodRecord",e.ZodMap="ZodMap",e.ZodSet="ZodSet",e.ZodFunction="ZodFunction",e.ZodLazy="ZodLazy",e.ZodLiteral="ZodLiteral",e.ZodEnum="ZodEnum",e.ZodEffects="ZodEffects",e.ZodNativeEnum="ZodNativeEnum",e.ZodOptional="ZodOptional",e.ZodNullable="ZodNullable",e.ZodDefault="ZodDefault",e.ZodCatch="ZodCatch",e.ZodPromise="ZodPromise",e.ZodBranded="ZodBranded",e.ZodPipeline="ZodPipeline",e.ZodReadonly="ZodReadonly"})(It||(It={}));const Lnt=Gm.create,Bnt=E3.create,Qnt=t9.create,znt=ED.create,qnt=r9.create;Xv.create;const Vnt=$0.create,Unt=hl.create,jnt=DD.create,Znt=KF.create;$D.create;J1.create;const Hnt=CD.create,Xnt=wD.create,Ynt=RD.create,Gnt=eb.create;AD.create;ng.create;nb.create;const Knt=Gn,yee=1024;let V2e=0,AT=class{constructor(t,n){this.from=t,this.to=n}},Sa=class{constructor(t={}){this.id=V2e++,this.perNode=!!t.perNode,this.deserialize=t.deserialize||(()=>{throw new Error("This node type doesn't define a deserialize function")})}add(t){if(this.perNode)throw new RangeError("Can't add per-node props to node types");return typeof t!="function"&&(t=og.match(t)),n=>{let r=t(n);return r===void 0?null:[this,r]}}};Sa.closedBy=new Sa({deserialize:e=>e.split(" ")});Sa.openedBy=new Sa({deserialize:e=>e.split(" ")});Sa.group=new Sa({deserialize:e=>e.split(" ")});Sa.isolate=new Sa({deserialize:e=>{if(e&&e!="rtl"&&e!="ltr"&&e!="auto")throw new RangeError("Invalid value for isolate: "+e);return e||"auto"}});Sa.contextHash=new Sa({perNode:!0});Sa.lookAhead=new Sa({perNode:!0});Sa.mounted=new Sa({perNode:!0});let MD=class{constructor(t,n,r){this.tree=t,this.overlay=n,this.parser=r}static get(t){return t&&t.props&&t.props[Sa.mounted.id]}};const U2e=Object.create(null);let og=class bee{constructor(t,n,r,i=0){this.name=t,this.props=n,this.id=r,this.flags=i}static define(t){let n=t.props&&t.props.length?Object.create(null):U2e,r=(t.top?1:0)|(t.skipped?2:0)|(t.error?4:0)|(t.name==null?8:0),i=new bee(t.name||"",n,t.id,r);if(t.props){for(let a of t.props)if(Array.isArray(a)||(a=a(i)),a){if(a[0].perNode)throw new RangeError("Can't store a per-node prop on a node type");n[a[0].id]=a[1]}}return i}prop(t){return this.props[t.id]}get isTop(){return(this.flags&1)>0}get isSkipped(){return(this.flags&2)>0}get isError(){return(this.flags&4)>0}get isAnonymous(){return(this.flags&8)>0}is(t){if(typeof t=="string"){if(this.name==t)return!0;let n=this.prop(Sa.group);return n?n.indexOf(t)>-1:!1}return this.id==t}static match(t){let n=Object.create(null);for(let r in t)for(let i of r.split(" "))n[i]=t[r];return r=>{for(let i=r.prop(Sa.group),a=-1;a<(i?i.length:0);a++){let u=n[a<0?r.name:i[a]];if(u)return u}}}};og.none=new og("",Object.create(null),0,8);class JF{constructor(t){this.types=t;for(let n=0;n<t.length;n++)if(t[n].id!=n)throw new RangeError("Node type ids should correspond to array positions when creating a node set")}extend(...t){let n=[];for(let r of this.types){let i=null;for(let a of t){let u=a(r);u&&(i||(i=Object.assign({},r.props)),i[u[0].id]=u[1])}n.push(i?new og(r.name,i,r.id,r.flags):r)}return new JF(n)}}const R_=new WeakMap,ZV=new WeakMap;var Po;(function(e){e[e.ExcludeBuffers=1]="ExcludeBuffers",e[e.IncludeAnonymous=2]="IncludeAnonymous",e[e.IgnoreMounts=4]="IgnoreMounts",e[e.IgnoreOverlays=8]="IgnoreOverlays"})(Po||(Po={}));let ep=class u9{constructor(t,n,r,i,a){if(this.type=t,this.children=n,this.positions=r,this.length=i,this.props=null,a&&a.length){this.props=Object.create(null);for(let[u,l]of a)this.props[typeof u=="number"?u:u.id]=l}}toString(){let t=MD.get(this);if(t&&!t.overlay)return t.tree.toString();let n="";for(let r of this.children){let i=r.toString();i&&(n&&(n+=","),n+=i)}return this.type.name?(/\W/.test(this.type.name)&&!this.type.isError?JSON.stringify(this.type.name):this.type.name)+(n.length?"("+n+")":""):n}cursor(t=0){return new o9(this.topNode,t)}cursorAt(t,n=0,r=0){let i=R_.get(this)||this.topNode,a=new o9(i);return a.moveTo(t,n),R_.set(this,a._tree),a}get topNode(){return new P0(this,0,0,null)}resolve(t,n=0){let r=cx(R_.get(this)||this.topNode,t,n,!1);return R_.set(this,r),r}resolveInner(t,n=0){let r=cx(ZV.get(this)||this.topNode,t,n,!0);return ZV.set(this,r),r}resolveStack(t,n=0){return X2e(this,t,n)}iterate(t){let{enter:n,leave:r,from:i=0,to:a=this.length}=t,u=t.mode||0,l=(u&Po.IncludeAnonymous)>0;for(let o=this.cursor(u|Po.IncludeAnonymous);;){let s=!1;if(o.from<=a&&o.to>=i&&(!l&&o.type.isAnonymous||n(o)!==!1)){if(o.firstChild())continue;s=!0}for(;s&&r&&(l||!o.type.isAnonymous)&&r(o),!o.nextSibling();){if(!o.parent())return;s=!0}}}prop(t){return t.perNode?this.props?this.props[t.id]:void 0:this.type.prop(t)}get propValues(){let t=[];if(this.props)for(let n in this.props)t.push([+n,this.props[n]]);return t}balance(t={}){return this.children.length<=8?this:tN(og.none,this.children,this.positions,0,this.children.length,0,this.length,(n,r,i)=>new u9(this.type,n,r,i,this.propValues),t.makeTree||((n,r,i)=>new u9(og.none,n,r,i)))}static build(t){return Y2e(t)}};ep.empty=new ep(og.none,[],[],0);let j2e=class Oee{constructor(t,n){this.buffer=t,this.index=n}get id(){return this.buffer[this.index-4]}get start(){return this.buffer[this.index-3]}get end(){return this.buffer[this.index-2]}get size(){return this.buffer[this.index-1]}get pos(){return this.index}next(){this.index-=4}fork(){return new Oee(this.buffer,this.index)}},D3=class xee{constructor(t,n,r){this.buffer=t,this.length=n,this.set=r}get type(){return og.none}toString(){let t=[];for(let n=0;n<this.buffer.length;)t.push(this.childString(n)),n=this.buffer[n+3];return t.join(",")}childString(t){let n=this.buffer[t],r=this.buffer[t+3],i=this.set.types[n],a=i.name;if(/\W/.test(a)&&!i.isError&&(a=JSON.stringify(a)),t+=4,r==t)return a;let u=[];for(;t<r;)u.push(this.childString(t)),t=this.buffer[t+3];return a+"("+u.join(",")+")"}findChild(t,n,r,i,a){let{buffer:u}=this,l=-1;for(let o=t;o!=n&&!(See(a,i,u[o+1],u[o+2])&&(l=o,r>0));o=u[o+3]);return l}slice(t,n,r){let i=this.buffer,a=new Uint16Array(n-t),u=0;for(let l=t,o=0;l<n;){a[o++]=i[l++],a[o++]=i[l++]-r;let s=a[o++]=i[l++]-r;a[o++]=i[l++]-t,u=Math.max(u,s)}return new xee(a,u,this.set)}};function See(e,t,n,r){switch(e){case-2:return n<t;case-1:return r>=t&&n<t;case 0:return n<t&&r>t;case 1:return n<=t&&r>t;case 2:return r>t;case 4:return!0}}function cx(e,t,n,r){for(var i;e.from==e.to||(n<1?e.from>=t:e.from>t)||(n>-1?e.to<=t:e.to<t);){let u=!r&&e instanceof P0&&e.index<0?null:e.parent;if(!u)return e;e=u}let a=r?0:Po.IgnoreOverlays;if(r)for(let u=e,l=u.parent;l;u=l,l=u.parent)u instanceof P0&&u.index<0&&((i=l.enter(t,n,a))===null||i===void 0?void 0:i.from)!=u.from&&(e=l);for(;;){let u=e.enter(t,n,a);if(!u)return e;e=u}}let _ee=class{cursor(t=0){return new o9(this,t)}getChild(t,n=null,r=null){let i=HV(this,t,n,r);return i.length?i[0]:null}getChildren(t,n=null,r=null){return HV(this,t,n,r)}resolve(t,n=0){return cx(this,t,n,!1)}resolveInner(t,n=0){return cx(this,t,n,!0)}matchContext(t){return l9(this.parent,t)}enterUnfinishedNodesBefore(t){let n=this.childBefore(t),r=this;for(;n;){let i=n.lastChild;if(!i||i.to!=n.to)break;i.type.isError&&i.from==i.to?(r=n,n=i.prevSibling):n=i}return r}get node(){return this}get next(){return this.parent}},P0=class qE extends _ee{constructor(t,n,r,i){super(),this._tree=t,this.from=n,this.index=r,this._parent=i}get type(){return this._tree.type}get name(){return this._tree.type.name}get to(){return this.from+this._tree.length}nextChild(t,n,r,i,a=0){for(let u=this;;){for(let{children:l,positions:o}=u._tree,s=n>0?l.length:-1;t!=s;t+=n){let c=l[t],d=o[t]+u.from;if(See(i,r,d,d+c.length)){if(c instanceof D3){if(a&Po.ExcludeBuffers)continue;let h=c.findChild(0,c.buffer.length,n,r-d,i);if(h>-1)return new fx(new Z2e(u,c,t,d),null,h)}else if(a&Po.IncludeAnonymous||!c.type.isAnonymous||eN(c)){let h;if(!(a&Po.IgnoreMounts)&&(h=MD.get(c))&&!h.overlay)return new qE(h.tree,d,t,u);let m=new qE(c,d,t,u);return a&Po.IncludeAnonymous||!m.type.isAnonymous?m:m.nextChild(n<0?c.children.length-1:0,n,r,i)}}}if(a&Po.IncludeAnonymous||!u.type.isAnonymous||(u.index>=0?t=u.index+n:t=n<0?-1:u._parent._tree.children.length,u=u._parent,!u))return null}}get firstChild(){return this.nextChild(0,1,0,4)}get lastChild(){return this.nextChild(this._tree.children.length-1,-1,0,4)}childAfter(t){return this.nextChild(0,1,t,2)}childBefore(t){return this.nextChild(this._tree.children.length-1,-1,t,-2)}enter(t,n,r=0){let i;if(!(r&Po.IgnoreOverlays)&&(i=MD.get(this._tree))&&i.overlay){let a=t-this.from;for(let{from:u,to:l}of i.overlay)if((n>0?u<=a:u<a)&&(n<0?l>=a:l>a))return new qE(i.tree,i.overlay[0].from+this.from,-1,this)}return this.nextChild(0,1,t,n,r)}nextSignificantParent(){let t=this;for(;t.type.isAnonymous&&t._parent;)t=t._parent;return t}get parent(){return this._parent?this._parent.nextSignificantParent():null}get nextSibling(){return this._parent&&this.index>=0?this._parent.nextChild(this.index+1,1,0,4):null}get prevSibling(){return this._parent&&this.index>=0?this._parent.nextChild(this.index-1,-1,0,4):null}get tree(){return this._tree}toTree(){return this._tree}toString(){return this._tree.toString()}};function HV(e,t,n,r){let i=e.cursor(),a=[];if(!i.firstChild())return a;if(n!=null){for(let u=!1;!u;)if(u=i.type.is(n),!i.nextSibling())return a}for(;;){if(r!=null&&i.type.is(r))return a;if(i.type.is(t)&&a.push(i.node),!i.nextSibling())return r==null?a:[]}}function l9(e,t,n=t.length-1){for(let r=e;n>=0;r=r.parent){if(!r)return!1;if(!r.type.isAnonymous){if(t[n]&&t[n]!=r.name)return!1;n--}}return!0}let Z2e=class{constructor(t,n,r,i){this.parent=t,this.buffer=n,this.index=r,this.start=i}},fx=class R2 extends _ee{get name(){return this.type.name}get from(){return this.context.start+this.context.buffer.buffer[this.index+1]}get to(){return this.context.start+this.context.buffer.buffer[this.index+2]}constructor(t,n,r){super(),this.context=t,this._parent=n,this.index=r,this.type=t.buffer.set.types[t.buffer.buffer[r]]}child(t,n,r){let{buffer:i}=this.context,a=i.findChild(this.index+4,i.buffer[this.index+3],t,n-this.context.start,r);return a<0?null:new R2(this.context,this,a)}get firstChild(){return this.child(1,0,4)}get lastChild(){return this.child(-1,0,4)}childAfter(t){return this.child(1,t,2)}childBefore(t){return this.child(-1,t,-2)}enter(t,n,r=0){if(r&Po.ExcludeBuffers)return null;let{buffer:i}=this.context,a=i.findChild(this.index+4,i.buffer[this.index+3],n>0?1:-1,t-this.context.start,n);return a<0?null:new R2(this.context,this,a)}get parent(){return this._parent||this.context.parent.nextSignificantParent()}externalSibling(t){return this._parent?null:this.context.parent.nextChild(this.context.index+t,t,0,4)}get nextSibling(){let{buffer:t}=this.context,n=t.buffer[this.index+3];return n<(this._parent?t.buffer[this._parent.index+3]:t.buffer.length)?new R2(this.context,this._parent,n):this.externalSibling(1)}get prevSibling(){let{buffer:t}=this.context,n=this._parent?this._parent.index+4:0;return this.index==n?this.externalSibling(-1):new R2(this.context,this._parent,t.findChild(n,this.index,-1,0,4))}get tree(){return null}toTree(){let t=[],n=[],{buffer:r}=this.context,i=this.index+4,a=r.buffer[this.index+3];if(a>i){let u=r.buffer[this.index+1];t.push(r.slice(i,a,u)),n.push(0)}return new ep(this.type,t,n,this.to-this.from)}toString(){return this.context.buffer.childString(this.index)}};function Eee(e){if(!e.length)return null;let t=0,n=e[0];for(let a=1;a<e.length;a++){let u=e[a];(u.from>n.from||u.to<n.to)&&(n=u,t=a)}let r=n instanceof P0&&n.index<0?null:n.parent,i=e.slice();return r?i[t]=r:i.splice(t,1),new H2e(i,n)}let H2e=class{constructor(t,n){this.heads=t,this.node=n}get next(){return Eee(this.heads)}};function X2e(e,t,n){let r=e.resolveInner(t,n),i=null;for(let a=r instanceof P0?r:r.context.parent;a;a=a.parent)if(a.index<0){let u=a.parent;(i||(i=[r])).push(u.resolve(t,n)),a=u}else{let u=MD.get(a.tree);if(u&&u.overlay&&u.overlay[0].from<=t&&u.overlay[u.overlay.length-1].to>=t){let l=new P0(u.tree,u.overlay[0].from+a.from,-1,a);(i||(i=[r])).push(cx(l,t,n,!1))}}return i?Eee(i):r}let o9=class{get name(){return this.type.name}constructor(t,n=0){if(this.mode=n,this.buffer=null,this.stack=[],this.index=0,this.bufferNode=null,t instanceof P0)this.yieldNode(t);else{this._tree=t.context.parent,this.buffer=t.context;for(let r=t._parent;r;r=r._parent)this.stack.unshift(r.index);this.bufferNode=t,this.yieldBuf(t.index)}}yieldNode(t){return t?(this._tree=t,this.type=t.type,this.from=t.from,this.to=t.to,!0):!1}yieldBuf(t,n){this.index=t;let{start:r,buffer:i}=this.buffer;return this.type=n||i.set.types[i.buffer[t]],this.from=r+i.buffer[t+1],this.to=r+i.buffer[t+2],!0}yield(t){return t?t instanceof P0?(this.buffer=null,this.yieldNode(t)):(this.buffer=t.context,this.yieldBuf(t.index,t.type)):!1}toString(){return this.buffer?this.buffer.buffer.childString(this.index):this._tree.toString()}enterChild(t,n,r){if(!this.buffer)return this.yield(this._tree.nextChild(t<0?this._tree._tree.children.length-1:0,t,n,r,this.mode));let{buffer:i}=this.buffer,a=i.findChild(this.index+4,i.buffer[this.index+3],t,n-this.buffer.start,r);return a<0?!1:(this.stack.push(this.index),this.yieldBuf(a))}firstChild(){return this.enterChild(1,0,4)}lastChild(){return this.enterChild(-1,0,4)}childAfter(t){return this.enterChild(1,t,2)}childBefore(t){return this.enterChild(-1,t,-2)}enter(t,n,r=this.mode){return this.buffer?r&Po.ExcludeBuffers?!1:this.enterChild(1,t,n):this.yield(this._tree.enter(t,n,r))}parent(){if(!this.buffer)return this.yieldNode(this.mode&Po.IncludeAnonymous?this._tree._parent:this._tree.parent);if(this.stack.length)return this.yieldBuf(this.stack.pop());let t=this.mode&Po.IncludeAnonymous?this.buffer.parent:this.buffer.parent.nextSignificantParent();return this.buffer=null,this.yieldNode(t)}sibling(t){if(!this.buffer)return this._tree._parent?this.yield(this._tree.index<0?null:this._tree._parent.nextChild(this._tree.index+t,t,0,4,this.mode)):!1;let{buffer:n}=this.buffer,r=this.stack.length-1;if(t<0){let i=r<0?0:this.stack[r]+4;if(this.index!=i)return this.yieldBuf(n.findChild(i,this.index,-1,0,4))}else{let i=n.buffer[this.index+3];if(i<(r<0?n.buffer.length:n.buffer[this.stack[r]+3]))return this.yieldBuf(i)}return r<0?this.yield(this.buffer.parent.nextChild(this.buffer.index+t,t,0,4,this.mode)):!1}nextSibling(){return this.sibling(1)}prevSibling(){return this.sibling(-1)}atLastNode(t){let n,r,{buffer:i}=this;if(i){if(t>0){if(this.index<i.buffer.buffer.length)return!1}else for(let a=0;a<this.index;a++)if(i.buffer.buffer[a+3]<this.index)return!1;({index:n,parent:r}=i)}else({index:n,_parent:r}=this._tree);for(;r;{index:n,_parent:r}=r)if(n>-1)for(let a=n+t,u=t<0?-1:r._tree.children.length;a!=u;a+=t){let l=r._tree.children[a];if(this.mode&Po.IncludeAnonymous||l instanceof D3||!l.type.isAnonymous||eN(l))return!1}return!0}move(t,n){if(n&&this.enterChild(t,0,4))return!0;for(;;){if(this.sibling(t))return!0;if(this.atLastNode(t)||!this.parent())return!1}}next(t=!0){return this.move(1,t)}prev(t=!0){return this.move(-1,t)}moveTo(t,n=0){for(;(this.from==this.to||(n<1?this.from>=t:this.from>t)||(n>-1?this.to<=t:this.to<t))&&this.parent(););for(;this.enterChild(1,t,n););return this}get node(){if(!this.buffer)return this._tree;let t=this.bufferNode,n=null,r=0;if(t&&t.context==this.buffer)e:for(let i=this.index,a=this.stack.length;a>=0;){for(let u=t;u;u=u._parent)if(u.index==i){if(i==this.index)return u;n=u,r=a+1;break e}i=this.stack[--a]}for(let i=r;i<this.stack.length;i++)n=new fx(this.buffer,n,this.stack[i]);return this.bufferNode=new fx(this.buffer,n,this.index)}get tree(){return this.buffer?null:this._tree._tree}iterate(t,n){for(let r=0;;){let i=!1;if(this.type.isAnonymous||t(this)!==!1){if(this.firstChild()){r++;continue}this.type.isAnonymous||(i=!0)}for(;;){if(i&&n&&n(this),i=this.type.isAnonymous,!r)return;if(this.nextSibling())break;this.parent(),r--,i=!0}}}matchContext(t){if(!this.buffer)return l9(this.node.parent,t);let{buffer:n}=this.buffer,{types:r}=n.set;for(let i=t.length-1,a=this.stack.length-1;i>=0;a--){if(a<0)return l9(this._tree,t,i);let u=r[n.buffer[this.stack[a]]];if(!u.isAnonymous){if(t[i]&&t[i]!=u.name)return!1;i--}}return!0}};function eN(e){return e.children.some(t=>t instanceof D3||!t.type.isAnonymous||eN(t))}function Y2e(e){var t;let{buffer:n,nodeSet:r,maxBufferLength:i=yee,reused:a=[],minRepeatType:u=r.types.length}=e,l=Array.isArray(n)?new j2e(n,n.length):n,o=r.types,s=0,c=0;function d(R,$,k,F,L,j){let{id:V,start:q,end:N,size:U}=l,W=c,G=s;for(;U<0;)if(l.next(),U==-1){let K=a[V];k.push(K),F.push(q-R);return}else if(U==-3){s=V;return}else if(U==-4){c=V;return}else throw new RangeError(`Unrecognized record size: ${U}`);let J=o[V],te,H,M=q-R;if(N-q<=i&&(H=_(l.pos-$,L))){let K=new Uint16Array(H.size-H.skip),X=l.pos-H.size,B=K.length;for(;l.pos>X;)B=S(H.start,K,B);te=new D3(K,N-H.start,r),M=H.start-R}else{let K=l.pos-U;l.next();let X=[],B=[],ne=V>=u?V:-1,oe=0,ie=N;for(;l.pos>K;)ne>=0&&l.id==ne&&l.size>=0?(l.end<=ie-i&&(y(X,B,q,oe,l.end,ie,ne,W,G),oe=X.length,ie=l.end),l.next()):j>2500?h(q,K,X,B):d(q,K,X,B,ne,j+1);if(ne>=0&&oe>0&&oe<X.length&&y(X,B,q,oe,q,ie,ne,W,G),X.reverse(),B.reverse(),ne>-1&&oe>0){let de=m(J,G);te=tN(J,X,B,0,X.length,0,N-q,de,de)}else te=v(J,X,B,N-q,W-N,G)}k.push(te),F.push(M)}function h(R,$,k,F){let L=[],j=0,V=-1;for(;l.pos>$;){let{id:q,start:N,end:U,size:W}=l;if(W>4)l.next();else{if(V>-1&&N<V)break;V<0&&(V=U-i),L.push(q,N,U),j++,l.next()}}if(j){let q=new Uint16Array(j*4),N=L[L.length-2];for(let U=L.length-3,W=0;U>=0;U-=3)q[W++]=L[U],q[W++]=L[U+1]-N,q[W++]=L[U+2]-N,q[W++]=W;k.push(new D3(q,L[2]-N,r)),F.push(N-R)}}function m(R,$){return(k,F,L)=>{let j=0,V=k.length-1,q,N;if(V>=0&&(q=k[V])instanceof ep){if(!V&&q.type==R&&q.length==L)return q;(N=q.prop(Sa.lookAhead))&&(j=F[V]+q.length+N)}return v(R,k,F,L,j,$)}}function y(R,$,k,F,L,j,V,q,N){let U=[],W=[];for(;R.length>F;)U.push(R.pop()),W.push($.pop()+k-L);R.push(v(r.types[V],U,W,j-L,q-j,N)),$.push(L-k)}function v(R,$,k,F,L,j,V){if(j){let q=[Sa.contextHash,j];V=V?[q].concat(V):[q]}if(L>25){let q=[Sa.lookAhead,L];V=V?[q].concat(V):[q]}return new ep(R,$,k,F,V)}function _(R,$){let k=l.fork(),F=0,L=0,j=0,V=k.end-i,q={size:0,start:0,skip:0};e:for(let N=k.pos-R;k.pos>N;){let U=k.size;if(k.id==$&&U>=0){q.size=F,q.start=L,q.skip=j,j+=4,F+=4,k.next();continue}let W=k.pos-U;if(U<0||W<N||k.start<V)break;let G=k.id>=u?4:0,J=k.start;for(k.next();k.pos>W;){if(k.size<0)if(k.size==-3)G+=4;else break e;else k.id>=u&&(G+=4);k.next()}L=J,F+=U,j+=G}return($<0||F==R)&&(q.size=F,q.start=L,q.skip=j),q.size>4?q:void 0}function S(R,$,k){let{id:F,start:L,end:j,size:V}=l;if(l.next(),V>=0&&F<u){let q=k;if(V>4){let N=l.pos-(V-4);for(;l.pos>N;)k=S(R,$,k)}$[--k]=q,$[--k]=j-R,$[--k]=L-R,$[--k]=F}else V==-3?s=F:V==-4&&(c=F);return k}let E=[],C=[];for(;l.pos>0;)d(e.start||0,e.bufferStart||0,E,C,-1,0);let T=(t=e.length)!==null&&t!==void 0?t:E.length?C[0]+E[0].length:0;return new ep(o[e.topID],E.reverse(),C.reverse(),T)}const XV=new WeakMap;function VE(e,t){if(!e.isAnonymous||t instanceof D3||t.type!=e)return 1;let n=XV.get(t);if(n==null){n=1;for(let r of t.children){if(r.type!=e||!(r instanceof ep)){n=1;break}n+=VE(e,r)}XV.set(t,n)}return n}function tN(e,t,n,r,i,a,u,l,o){let s=0;for(let y=r;y<i;y++)s+=VE(e,t[y]);let c=Math.ceil(s*1.5/8),d=[],h=[];function m(y,v,_,S,E){for(let C=_;C<S;){let T=C,R=v[C],$=VE(e,y[C]);for(C++;C<S;C++){let k=VE(e,y[C]);if($+k>=c)break;$+=k}if(C==T+1){if($>c){let k=y[T];m(k.children,k.positions,0,k.children.length,v[T]+E);continue}d.push(y[T])}else{let k=v[C-1]+y[C-1].length-R;d.push(tN(e,y,v,T,C,R,k,null,o))}h.push(R+E-a)}}return m(t,n,r,i,0),(l||o)(d,h,u)}class art{constructor(){this.map=new WeakMap}setBuffer(t,n,r){let i=this.map.get(t);i||this.map.set(t,i=new Map),i.set(n,r)}getBuffer(t,n){let r=this.map.get(t);return r&&r.get(n)}set(t,n){t instanceof fx?this.setBuffer(t.context.buffer,t.index,n):t instanceof P0&&this.map.set(t.tree,n)}get(t){return t instanceof fx?this.getBuffer(t.context.buffer,t.index):t instanceof P0?this.map.get(t.tree):void 0}cursorSet(t,n){t.buffer?this.setBuffer(t.buffer.buffer,t.index,n):this.map.set(t.tree,n)}cursorGet(t){return t.buffer?this.getBuffer(t.buffer.buffer,t.index):this.map.get(t.tree)}}let urt=class s9{constructor(t,n,r,i,a=!1,u=!1){this.from=t,this.to=n,this.tree=r,this.offset=i,this.open=(a?1:0)|(u?2:0)}get openStart(){return(this.open&1)>0}get openEnd(){return(this.open&2)>0}static addTree(t,n=[],r=!1){let i=[new s9(0,t.length,t,0,!1,r)];for(let a of n)a.to>t.length&&i.push(a);return i}static applyChanges(t,n,r=128){if(!n.length)return t;let i=[],a=1,u=t.length?t[0]:null;for(let l=0,o=0,s=0;;l++){let c=l<n.length?n[l]:null,d=c?c.fromA:1e9;if(d-o>=r)for(;u&&u.from<d;){let h=u;if(o>=h.from||d<=h.to||s){let m=Math.max(h.from,o)-s,y=Math.min(h.to,d)-s;h=m>=y?null:new s9(m,y,h.tree,h.offset+s,l>0,!!c)}if(h&&i.push(h),u.to>d)break;u=a<t.length?t[a++]:null}if(!c)break;o=c.toA,s=c.toA-c.toB}return i}},G2e=class{startParse(t,n,r){return typeof t=="string"&&(t=new K2e(t)),r=r?r.length?r.map(i=>new AT(i.from,i.to)):[new AT(0,0)]:[new AT(0,t.length)],this.createParse(t,n||[],r)}parse(t,n,r){let i=this.startParse(t,n,r);for(;;){let a=i.advance();if(a)return a}}},K2e=class{constructor(t){this.string=t}get length(){return this.string.length}chunk(t){return this.string.slice(t)}get lineChunks(){return!1}read(t,n){return this.string.slice(t,n)}};new Sa({perNode:!0});var A_={},YV;function srt(){if(YV)return A_;YV=1;let e=[],t=[];(()=>{let h="lc,34,7n,7,7b,19,,,,2,,2,,,20,b,1c,l,g,,2t,7,2,6,2,2,,4,z,,u,r,2j,b,1m,9,9,,o,4,,9,,3,,5,17,3,3b,f,,w,1j,,,,4,8,4,,3,7,a,2,t,,1m,,,,2,4,8,,9,,a,2,q,,2,2,1l,,4,2,4,2,2,3,3,,u,2,3,,b,2,1l,,4,5,,2,4,,k,2,m,6,,,1m,,,2,,4,8,,7,3,a,2,u,,1n,,,,c,,9,,14,,3,,1l,3,5,3,,4,7,2,b,2,t,,1m,,2,,2,,3,,5,2,7,2,b,2,s,2,1l,2,,,2,4,8,,9,,a,2,t,,20,,4,,2,3,,,8,,29,,2,7,c,8,2q,,2,9,b,6,22,2,r,,,,,,1j,e,,5,,2,5,b,,10,9,,2u,4,,6,,2,2,2,p,2,4,3,g,4,d,,2,2,6,,f,,jj,3,qa,3,t,3,t,2,u,2,1s,2,,7,8,,2,b,9,,19,3,3b,2,y,,3a,3,4,2,9,,6,3,63,2,2,,1m,,,7,,,,,2,8,6,a,2,,1c,h,1r,4,1c,7,,,5,,14,9,c,2,w,4,2,2,,3,1k,,,2,3,,,3,1m,8,2,2,48,3,,d,,7,4,,6,,3,2,5i,1m,,5,ek,,5f,x,2da,3,3x,,2o,w,fe,6,2x,2,n9w,4,,a,w,2,28,2,7k,,3,,4,,p,2,5,,47,2,q,i,d,,12,8,p,b,1a,3,1c,,2,4,2,2,13,,1v,6,2,2,2,2,c,,8,,1b,,1f,,,3,2,2,5,2,,,16,2,8,,6m,,2,,4,,fn4,,kh,g,g,g,a6,2,gt,,6a,,45,5,1ae,3,,2,5,4,14,3,4,,4l,2,fx,4,ar,2,49,b,4w,,1i,f,1k,3,1d,4,2,2,1x,3,10,5,,8,1q,,c,2,1g,9,a,4,2,,2n,3,2,,,2,6,,4g,,3,8,l,2,1l,2,,,,,m,,e,7,3,5,5f,8,2,3,,,n,,29,,2,6,,,2,,,2,,2,6j,,2,4,6,2,,2,r,2,2d,8,2,,,2,2y,,,,2,6,,,2t,3,2,4,,5,77,9,,2,6t,,a,2,,,4,,40,4,2,2,4,,w,a,14,6,2,4,8,,9,6,2,3,1a,d,,2,ba,7,,6,,,2a,m,2,7,,2,,2,3e,6,3,,,2,,7,,,20,2,3,,,,9n,2,f0b,5,1n,7,t4,,1r,4,29,,f5k,2,43q,,,3,4,5,8,8,2,7,u,4,44,3,1iz,1j,4,1e,8,,e,,m,5,,f,11s,7,,h,2,7,,2,,5,79,7,c5,4,15s,7,31,7,240,5,gx7k,2o,3k,6o".split(",").map(m=>m?parseInt(m,36):1);for(let m=0,y=0;m<h.length;m++)(m%2?t:e).push(y=y+h[m])})();function n(h){if(h<768)return!1;for(let m=0,y=e.length;;){let v=m+y>>1;if(h<e[v])y=v;else if(h>=t[v])m=v+1;else return!0;if(m==y)return!1}}function r(h){return h>=127462&&h<=127487}const i=8205;function a(h,m,y=!0,v=!0){return(y?u:l)(h,m,v)}function u(h,m,y){if(m==h.length)return m;m&&s(h.charCodeAt(m))&&c(h.charCodeAt(m-1))&&m--;let v=o(h,m);for(m+=d(v);m<h.length;){let _=o(h,m);if(v==i||_==i||y&&n(_))m+=d(_),v=_;else if(r(_)){let S=0,E=m-2;for(;E>=0&&r(o(h,E));)S++,E-=2;if(S%2==0)break;m+=2}else break}return m}function l(h,m,y){for(;m>0;){let v=u(h,m-2,y);if(v<m)return v;m--}return 0}function o(h,m){let y=h.charCodeAt(m);if(!c(y)||m+1==h.length)return y;let v=h.charCodeAt(m+1);return s(v)?(y-55296<<10)+(v-56320)+65536:y}function s(h){return h>=56320&&h<57344}function c(h){return h>=55296&&h<56320}function d(h){return h<65536?1:2}return A_.findClusterBreak=a,A_.isExtendingChar=n,A_}const c9="ͼ",GV=typeof Symbol>"u"?"__"+c9:Symbol.for(c9),f9=typeof Symbol>"u"?"__styleSet"+Math.floor(Math.random()*1e8):Symbol("styleSet"),KV=typeof globalThis<"u"?globalThis:typeof window<"u"?window:{};let crt=class{constructor(t,n){this.rules=[];let{finish:r}=n||{};function i(u){return/^@/.test(u)?[u]:u.split(/,\s*/)}function a(u,l,o,s){let c=[],d=/^@(\w+)\b/.exec(u[0]),h=d&&d[1]=="keyframes";if(d&&l==null)return o.push(u[0]+";");for(let m in l){let y=l[m];if(/&/.test(m))a(m.split(/,\s*/).map(v=>u.map(_=>v.replace(/&/,_))).reduce((v,_)=>v.concat(_)),y,o);else if(y&&typeof y=="object"){if(!d)throw new RangeError("The value of a property ("+m+") should be a primitive value.");a(i(m),y,c,h)}else y!=null&&c.push(m.replace(/_.*/,"").replace(/[A-Z]/g,v=>"-"+v.toLowerCase())+": "+y+";")}(c.length||h)&&o.push((r&&!d&&!s?u.map(r):u).join(", ")+" {"+c.join(" ")+"}")}for(let u in t)a(i(u),t[u],this.rules)}getRules(){return this.rules.join(`
`)}static newName(){let t=KV[GV]||1;return KV[GV]=t+1,c9+t.toString(36)}static mount(t,n,r){let i=t[f9],a=r&&r.nonce;i?a&&i.setNonce(a):i=new W2e(t,a),i.mount(Array.isArray(n)?n:[n],t)}},WV=new Map,W2e=class{constructor(t,n){let r=t.ownerDocument||t,i=r.defaultView;if(!t.head&&t.adoptedStyleSheets&&i.CSSStyleSheet){let a=WV.get(r);if(a)return t[f9]=a;this.sheet=new i.CSSStyleSheet,WV.set(r,this)}else this.styleTag=r.createElement("style"),n&&this.styleTag.setAttribute("nonce",n);this.modules=[],t[f9]=this}mount(t,n){let r=this.sheet,i=0,a=0;for(let u=0;u<t.length;u++){let l=t[u],o=this.modules.indexOf(l);if(o<a&&o>-1&&(this.modules.splice(o,1),a--,o=-1),o==-1){if(this.modules.splice(a++,0,l),r)for(let s=0;s<l.rules.length;s++)r.insertRule(l.rules[s],i++)}else{for(;a<o;)i+=this.modules[a++].rules.length;i+=l.rules.length,a++}}if(r)n.adoptedStyleSheets.indexOf(this.sheet)<0&&(n.adoptedStyleSheets=[this.sheet,...n.adoptedStyleSheets]);else{let u="";for(let o=0;o<this.modules.length;o++)u+=this.modules[o].getRules()+`
`;this.styleTag.textContent=u;let l=n.head||n;this.styleTag.parentNode!=l&&l.insertBefore(this.styleTag,l.firstChild)}}setNonce(t){this.styleTag&&this.styleTag.getAttribute("nonce")!=t&&this.styleTag.setAttribute("nonce",t)}};var rb={8:"Backspace",9:"Tab",10:"Enter",12:"NumLock",13:"Enter",16:"Shift",17:"Control",18:"Alt",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",44:"PrintScreen",45:"Insert",46:"Delete",59:";",61:"=",91:"Meta",92:"Meta",106:"*",107:"+",108:",",109:"-",110:".",111:"/",144:"NumLock",145:"ScrollLock",160:"Shift",161:"Shift",162:"Control",163:"Control",164:"Alt",165:"Alt",173:"-",186:";",187:"=",188:",",189:"-",190:".",191:"/",192:"`",219:"[",220:"\\",221:"]",222:"'"},FD={48:")",49:"!",50:"@",51:"#",52:"$",53:"%",54:"^",55:"&",56:"*",57:"(",59:":",61:"+",173:"_",186:":",187:"+",188:"<",189:"_",190:">",191:"?",192:"~",219:"{",220:"|",221:"}",222:'"'},J2e=typeof navigator<"u"&&/Mac/.test(navigator.platform),exe=typeof navigator<"u"&&/MSIE \d|Trident\/(?:[7-9]|\d{2,})\..*rv:(\d+)/.exec(navigator.userAgent);for(var Mo=0;Mo<10;Mo++)rb[48+Mo]=rb[96+Mo]=String(Mo);for(var Mo=1;Mo<=24;Mo++)rb[Mo+111]="F"+Mo;for(var Mo=65;Mo<=90;Mo++)rb[Mo]=String.fromCharCode(Mo+32),FD[Mo]=String.fromCharCode(Mo);for(var TT in rb)FD.hasOwnProperty(TT)||(FD[TT]=rb[TT]);function hrt(e){var t=J2e&&e.metaKey&&e.shiftKey&&!e.ctrlKey&&!e.altKey||exe&&e.shiftKey&&e.key&&e.key.length==1||e.key=="Unidentified",n=!t&&e.key||(e.shiftKey?FD:rb)[e.keyCode]||e.key||"Unidentified";return n=="Esc"&&(n="Escape"),n=="Del"&&(n="Delete"),n=="Left"&&(n="ArrowLeft"),n=="Up"&&(n="ArrowUp"),n=="Right"&&(n="ArrowRight"),n=="Down"&&(n="ArrowDown"),n}function prt(){var e=arguments[0];typeof e=="string"&&(e=document.createElement(e));var t=1,n=arguments[1];if(n&&typeof n=="object"&&n.nodeType==null&&!Array.isArray(n)){for(var r in n)if(Object.prototype.hasOwnProperty.call(n,r)){var i=n[r];typeof i=="string"?e.setAttribute(r,i):i!=null&&(e[r]=i)}t++}for(;t<arguments.length;t++)Dee(e,arguments[t]);return e}function Dee(e,t){if(typeof t=="string")e.appendChild(document.createTextNode(t));else if(t!=null)if(t.nodeType!=null)e.appendChild(t);else if(Array.isArray(t))for(var n=0;n<t.length;n++)Dee(e,t[n]);else throw new RangeError("Unsupported child node: "+t)}let txe=0,zm=class d9{constructor(t,n,r,i){this.name=t,this.set=n,this.base=r,this.modified=i,this.id=txe++}toString(){let{name:t}=this;for(let n of this.modified)n.name&&(t=`${n.name}(${t})`);return t}static define(t,n){let r=typeof t=="string"?t:"?";if(t instanceof d9&&(n=t),n!=null&&n.base)throw new Error("Can not derive from a modified tag");let i=new d9(r,[],null,[]);if(i.set.push(i),n)for(let a of n.set)i.set.push(a);return i}static defineModifier(t){let n=new JV(t);return r=>r.modified.indexOf(n)>-1?r:JV.get(r.base||r,r.modified.concat(n).sort((i,a)=>i.id-a.id))}},nxe=0,JV=class $ee{constructor(t){this.name=t,this.instances=[],this.id=nxe++}static get(t,n){if(!n.length)return t;let r=n[0].instances.find(l=>l.base==t&&rxe(n,l.modified));if(r)return r;let i=[],a=new zm(t.name,i,t,n);for(let l of n)l.instances.push(a);let u=ixe(n);for(let l of t.set)if(!l.modified.length)for(let o of u)i.push($ee.get(l,o));return a}};function rxe(e,t){return e.length==t.length&&e.every((n,r)=>n==t[r])}function ixe(e){let t=[[]];for(let n=0;n<e.length;n++)for(let r=0,i=t.length;r<i;r++)t.push(t[r].concat(e[n]));return t.sort((n,r)=>r.length-n.length)}function nN(e){let t=Object.create(null);for(let n in e){let r=e[n];Array.isArray(r)||(r=[r]);for(let i of n.split(" "))if(i){let a=[],u=2,l=i;for(let d=0;;){if(l=="..."&&d>0&&d+3==i.length){u=1;break}let h=/^"(?:[^"\\]|\\.)*?"|[^\/!]+/.exec(l);if(!h)throw new RangeError("Invalid path: "+i);if(a.push(h[0]=="*"?"":h[0][0]=='"'?JSON.parse(h[0]):h[0]),d+=h[0].length,d==i.length)break;let m=i[d++];if(d==i.length&&m=="!"){u=0;break}if(m!="/")throw new RangeError("Invalid path: "+i);l=i.slice(d)}let o=a.length-1,s=a[o];if(!s)throw new RangeError("Invalid path: "+i);let c=new ND(r,u,o>0?a.slice(0,o):null);t[s]=c.sort(t[s])}}return Cee.add(t)}const Cee=new Sa;let ND=class{constructor(t,n,r,i){this.tags=t,this.mode=n,this.context=r,this.next=i}get opaque(){return this.mode==0}get inherit(){return this.mode==1}sort(t){return!t||t.depth<this.depth?(this.next=t,this):(t.next=this.sort(t.next),t)}get depth(){return this.context?this.context.length:0}};ND.empty=new ND([],2,null);function axe(e,t){let n=Object.create(null);for(let a of e)if(!Array.isArray(a.tag))n[a.tag.id]=a.class;else for(let u of a.tag)n[u.id]=a.class;let{scope:r,all:i=null}=t||{};return{style:a=>{let u=i;for(let l of a)for(let o of l.set){let s=n[o.id];if(s){u=u?u+" "+s:s;break}}return u},scope:r}}function uxe(e,t){let n=null;for(let r of e){let i=r.style(t);i&&(n=n?n+" "+i:i)}return n}function grt(e,t,n,r=0,i=e.length){let a=new lxe(r,Array.isArray(t)?t:[t],n);a.highlightRange(e.cursor(),r,i,"",a.highlighters),a.flush(i)}let lxe=class{constructor(t,n,r){this.at=t,this.highlighters=n,this.span=r,this.class=""}startSpan(t,n){n!=this.class&&(this.flush(t),t>this.at&&(this.at=t),this.class=n)}flush(t){t>this.at&&this.class&&this.span(this.at,t,this.class)}highlightRange(t,n,r,i,a){let{type:u,from:l,to:o}=t;if(l>=r||o<=n)return;u.isTop&&(a=this.highlighters.filter(m=>!m.scope||m.scope(u)));let s=i,c=oxe(t)||ND.empty,d=uxe(a,c.tags);if(d&&(s&&(s+=" "),s+=d,c.mode==1&&(i+=(i?" ":"")+d)),this.startSpan(Math.max(n,l),s),c.opaque)return;let h=t.tree&&t.tree.prop(Sa.mounted);if(h&&h.overlay){let m=t.node.enter(h.overlay[0].from+l,1),y=this.highlighters.filter(_=>!_.scope||_.scope(h.tree.type)),v=t.firstChild();for(let _=0,S=l;;_++){let E=_<h.overlay.length?h.overlay[_]:null,C=E?E.from+l:o,T=Math.max(n,S),R=Math.min(r,C);if(T<R&&v)for(;t.from<R&&(this.highlightRange(t,T,R,i,a),this.startSpan(Math.min(R,t.to),s),!(t.to>=C||!t.nextSibling())););if(!E||C>r)break;S=E.to+l,S>n&&(this.highlightRange(m.cursor(),Math.max(n,E.from+l),Math.min(r,S),"",y),this.startSpan(Math.min(r,S),s))}v&&t.parent()}else if(t.firstChild()){h&&(i="");do if(!(t.to<=n)){if(t.from>=r)break;this.highlightRange(t,n,r,i,a),this.startSpan(Math.min(r,t.to),s)}while(t.nextSibling());t.parent()}}};function oxe(e){let t=e.type.prop(Cee);for(;t&&t.context&&!e.matchContext(t.context);)t=t.next;return t||null}const Xt=zm.define,T_=Xt(),bv=Xt(),eU=Xt(bv),tU=Xt(bv),Ov=Xt(),k_=Xt(Ov),kT=Xt(Ov),f0=Xt(),p1=Xt(f0),i0=Xt(),a0=Xt(),h9=Xt(),X4=Xt(h9),P_=Xt(),ot={comment:T_,lineComment:Xt(T_),blockComment:Xt(T_),docComment:Xt(T_),name:bv,variableName:Xt(bv),typeName:eU,tagName:Xt(eU),propertyName:tU,attributeName:Xt(tU),className:Xt(bv),labelName:Xt(bv),namespace:Xt(bv),macroName:Xt(bv),literal:Ov,string:k_,docString:Xt(k_),character:Xt(k_),attributeValue:Xt(k_),number:kT,integer:Xt(kT),float:Xt(kT),bool:Xt(Ov),regexp:Xt(Ov),escape:Xt(Ov),color:Xt(Ov),url:Xt(Ov),keyword:i0,self:Xt(i0),null:Xt(i0),atom:Xt(i0),unit:Xt(i0),modifier:Xt(i0),operatorKeyword:Xt(i0),controlKeyword:Xt(i0),definitionKeyword:Xt(i0),moduleKeyword:Xt(i0),operator:a0,derefOperator:Xt(a0),arithmeticOperator:Xt(a0),logicOperator:Xt(a0),bitwiseOperator:Xt(a0),compareOperator:Xt(a0),updateOperator:Xt(a0),definitionOperator:Xt(a0),typeOperator:Xt(a0),controlOperator:Xt(a0),punctuation:h9,separator:Xt(h9),bracket:X4,angleBracket:Xt(X4),squareBracket:Xt(X4),paren:Xt(X4),brace:Xt(X4),content:f0,heading:p1,heading1:Xt(p1),heading2:Xt(p1),heading3:Xt(p1),heading4:Xt(p1),heading5:Xt(p1),heading6:Xt(p1),contentSeparator:Xt(f0),list:Xt(f0),quote:Xt(f0),emphasis:Xt(f0),strong:Xt(f0),link:Xt(f0),monospace:Xt(f0),strikethrough:Xt(f0),inserted:Xt(),deleted:Xt(),changed:Xt(),invalid:Xt(),meta:P_,documentMeta:Xt(P_),annotation:Xt(P_),processingInstruction:Xt(P_),definition:zm.defineModifier("definition"),constant:zm.defineModifier("constant"),function:zm.defineModifier("function"),standard:zm.defineModifier("standard"),local:zm.defineModifier("local"),special:zm.defineModifier("special")};for(let e in ot){let t=ot[e];t instanceof zm&&(t.name=e)}axe([{tag:ot.link,class:"tok-link"},{tag:ot.heading,class:"tok-heading"},{tag:ot.emphasis,class:"tok-emphasis"},{tag:ot.strong,class:"tok-strong"},{tag:ot.keyword,class:"tok-keyword"},{tag:ot.atom,class:"tok-atom"},{tag:ot.bool,class:"tok-bool"},{tag:ot.url,class:"tok-url"},{tag:ot.labelName,class:"tok-labelName"},{tag:ot.inserted,class:"tok-inserted"},{tag:ot.deleted,class:"tok-deleted"},{tag:ot.literal,class:"tok-literal"},{tag:ot.string,class:"tok-string"},{tag:ot.number,class:"tok-number"},{tag:[ot.regexp,ot.escape,ot.special(ot.string)],class:"tok-string2"},{tag:ot.variableName,class:"tok-variableName"},{tag:ot.local(ot.variableName),class:"tok-variableName tok-local"},{tag:ot.definition(ot.variableName),class:"tok-variableName tok-definition"},{tag:ot.special(ot.variableName),class:"tok-variableName2"},{tag:ot.definition(ot.propertyName),class:"tok-propertyName tok-definition"},{tag:ot.typeName,class:"tok-typeName"},{tag:ot.namespace,class:"tok-namespace"},{tag:ot.className,class:"tok-className"},{tag:ot.macroName,class:"tok-macroName"},{tag:ot.propertyName,class:"tok-propertyName"},{tag:ot.operator,class:"tok-operator"},{tag:ot.comment,class:"tok-comment"},{tag:ot.meta,class:"tok-meta"},{tag:ot.invalid,class:"tok-invalid"},{tag:ot.punctuation,class:"tok-punctuation"}]);var nU={};class ID{constructor(t,n,r,i,a,u,l,o,s,c=0,d){this.p=t,this.stack=n,this.state=r,this.reducePos=i,this.pos=a,this.score=u,this.buffer=l,this.bufferBase=o,this.curContext=s,this.lookAhead=c,this.parent=d}toString(){return`[${this.stack.filter((t,n)=>n%3==0).concat(this.state)}]@${this.pos}${this.score?"!"+this.score:""}`}static start(t,n,r=0){let i=t.parser.context;return new ID(t,[],n,r,r,0,[],0,i?new rU(i,i.start):null,0,null)}get context(){return this.curContext?this.curContext.context:null}pushState(t,n){this.stack.push(this.state,n,this.bufferBase+this.buffer.length),this.state=t}reduce(t){var n;let r=t>>19,i=t&65535,{parser:a}=this.p,u=this.reducePos<this.pos-25;u&&this.setLookAhead(this.pos);let l=a.dynamicPrecedence(i);if(l&&(this.score+=l),r==0){this.pushState(a.getGoto(this.state,i,!0),this.reducePos),i<a.minRepeatTerm&&this.storeNode(i,this.reducePos,this.reducePos,u?8:4,!0),this.reduceContext(i,this.reducePos);return}let o=this.stack.length-(r-1)*3-(t&262144?6:0),s=o?this.stack[o-2]:this.p.ranges[0].from,c=this.reducePos-s;c>=2e3&&!(!((n=this.p.parser.nodeSet.types[i])===null||n===void 0)&&n.isAnonymous)&&(s==this.p.lastBigReductionStart?(this.p.bigReductionCount++,this.p.lastBigReductionSize=c):this.p.lastBigReductionSize<c&&(this.p.bigReductionCount=1,this.p.lastBigReductionStart=s,this.p.lastBigReductionSize=c));let d=o?this.stack[o-1]:0,h=this.bufferBase+this.buffer.length-d;if(i<a.minRepeatTerm||t&131072){let m=a.stateFlag(this.state,1)?this.pos:this.reducePos;this.storeNode(i,s,m,h+4,!0)}if(t&262144)this.state=this.stack[o];else{let m=this.stack[o-3];this.state=a.getGoto(m,i,!0)}for(;this.stack.length>o;)this.stack.pop();this.reduceContext(i,s)}storeNode(t,n,r,i=4,a=!1){if(t==0&&(!this.stack.length||this.stack[this.stack.length-1]<this.buffer.length+this.bufferBase)){let u=this,l=this.buffer.length;if(l==0&&u.parent&&(l=u.bufferBase-u.parent.bufferBase,u=u.parent),l>0&&u.buffer[l-4]==0&&u.buffer[l-1]>-1){if(n==r)return;if(u.buffer[l-2]>=n){u.buffer[l-2]=r;return}}}if(!a||this.pos==r)this.buffer.push(t,n,r,i);else{let u=this.buffer.length;if(u>0&&this.buffer[u-4]!=0){let l=!1;for(let o=u;o>0&&this.buffer[o-2]>r;o-=4)if(this.buffer[o-1]>=0){l=!0;break}if(l)for(;u>0&&this.buffer[u-2]>r;)this.buffer[u]=this.buffer[u-4],this.buffer[u+1]=this.buffer[u-3],this.buffer[u+2]=this.buffer[u-2],this.buffer[u+3]=this.buffer[u-1],u-=4,i>4&&(i-=4)}this.buffer[u]=t,this.buffer[u+1]=n,this.buffer[u+2]=r,this.buffer[u+3]=i}}shift(t,n,r,i){if(t&131072)this.pushState(t&65535,this.pos);else if((t&262144)==0){let a=t,{parser:u}=this.p;(i>this.pos||n<=u.maxNode)&&(this.pos=i,u.stateFlag(a,1)||(this.reducePos=i)),this.pushState(a,r),this.shiftContext(n,r),n<=u.maxNode&&this.buffer.push(n,r,i,4)}else this.pos=i,this.shiftContext(n,r),n<=this.p.parser.maxNode&&this.buffer.push(n,r,i,4)}apply(t,n,r,i){t&65536?this.reduce(t):this.shift(t,n,r,i)}useNode(t,n){let r=this.p.reused.length-1;(r<0||this.p.reused[r]!=t)&&(this.p.reused.push(t),r++);let i=this.pos;this.reducePos=this.pos=i+t.length,this.pushState(n,i),this.buffer.push(r,i,this.reducePos,-1),this.curContext&&this.updateContext(this.curContext.tracker.reuse(this.curContext.context,t,this,this.p.stream.reset(this.pos-t.length)))}split(){let t=this,n=t.buffer.length;for(;n>0&&t.buffer[n-2]>t.reducePos;)n-=4;let r=t.buffer.slice(n),i=t.bufferBase+n;for(;t&&i==t.bufferBase;)t=t.parent;return new ID(this.p,this.stack.slice(),this.state,this.reducePos,this.pos,this.score,r,i,this.curContext,this.lookAhead,t)}recoverByDelete(t,n){let r=t<=this.p.parser.maxNode;r&&this.storeNode(t,this.pos,n,4),this.storeNode(0,this.pos,n,r?8:4),this.pos=this.reducePos=n,this.score-=190}canShift(t){for(let n=new sxe(this);;){let r=this.p.parser.stateSlot(n.state,4)||this.p.parser.hasAction(n.state,t);if(r==0)return!1;if((r&65536)==0)return!0;n.reduce(r)}}recoverByInsert(t){if(this.stack.length>=300)return[];let n=this.p.parser.nextStates(this.state);if(n.length>8||this.stack.length>=120){let i=[];for(let a=0,u;a<n.length;a+=2)(u=n[a+1])!=this.state&&this.p.parser.hasAction(u,t)&&i.push(n[a],u);if(this.stack.length<120)for(let a=0;i.length<8&&a<n.length;a+=2){let u=n[a+1];i.some((l,o)=>o&1&&l==u)||i.push(n[a],u)}n=i}let r=[];for(let i=0;i<n.length&&r.length<4;i+=2){let a=n[i+1];if(a==this.state)continue;let u=this.split();u.pushState(a,this.pos),u.storeNode(0,u.pos,u.pos,4,!0),u.shiftContext(n[i],this.pos),u.reducePos=this.pos,u.score-=200,r.push(u)}return r}forceReduce(){let{parser:t}=this.p,n=t.stateSlot(this.state,5);if((n&65536)==0)return!1;if(!t.validAction(this.state,n)){let r=n>>19,i=n&65535,a=this.stack.length-r*3;if(a<0||t.getGoto(this.stack[a],i,!1)<0){let u=this.findForcedReduction();if(u==null)return!1;n=u}this.storeNode(0,this.pos,this.pos,4,!0),this.score-=100}return this.reducePos=this.pos,this.reduce(n),!0}findForcedReduction(){let{parser:t}=this.p,n=[],r=(i,a)=>{if(!n.includes(i))return n.push(i),t.allActions(i,u=>{if(!(u&393216))if(u&65536){let l=(u>>19)-a;if(l>1){let o=u&65535,s=this.stack.length-l*3;if(s>=0&&t.getGoto(this.stack[s],o,!1)>=0)return l<<19|65536|o}}else{let l=r(u,a+1);if(l!=null)return l}})};return r(this.state,0)}forceAll(){for(;!this.p.parser.stateFlag(this.state,2);)if(!this.forceReduce()){this.storeNode(0,this.pos,this.pos,4,!0);break}return this}get deadEnd(){if(this.stack.length!=3)return!1;let{parser:t}=this.p;return t.data[t.stateSlot(this.state,1)]==65535&&!t.stateSlot(this.state,4)}restart(){this.storeNode(0,this.pos,this.pos,4,!0),this.state=this.stack[0],this.stack.length=0}sameState(t){if(this.state!=t.state||this.stack.length!=t.stack.length)return!1;for(let n=0;n<this.stack.length;n+=3)if(this.stack[n]!=t.stack[n])return!1;return!0}get parser(){return this.p.parser}dialectEnabled(t){return this.p.parser.dialect.flags[t]}shiftContext(t,n){this.curContext&&this.updateContext(this.curContext.tracker.shift(this.curContext.context,t,this,this.p.stream.reset(n)))}reduceContext(t,n){this.curContext&&this.updateContext(this.curContext.tracker.reduce(this.curContext.context,t,this,this.p.stream.reset(n)))}emitContext(){let t=this.buffer.length-1;(t<0||this.buffer[t]!=-3)&&this.buffer.push(this.curContext.hash,this.pos,this.pos,-3)}emitLookAhead(){let t=this.buffer.length-1;(t<0||this.buffer[t]!=-4)&&this.buffer.push(this.lookAhead,this.pos,this.pos,-4)}updateContext(t){if(t!=this.curContext.context){let n=new rU(this.curContext.tracker,t);n.hash!=this.curContext.hash&&this.emitContext(),this.curContext=n}}setLookAhead(t){t>this.lookAhead&&(this.emitLookAhead(),this.lookAhead=t)}close(){this.curContext&&this.curContext.tracker.strict&&this.emitContext(),this.lookAhead>0&&this.emitLookAhead()}}class rU{constructor(t,n){this.tracker=t,this.context=n,this.hash=t.strict?t.hash(n):0}}class sxe{constructor(t){this.start=t,this.state=t.state,this.stack=t.stack,this.base=this.stack.length}reduce(t){let n=t&65535,r=t>>19;r==0?(this.stack==this.start.stack&&(this.stack=this.stack.slice()),this.stack.push(this.state,0,0),this.base+=3):this.base-=(r-1)*3;let i=this.start.p.parser.getGoto(this.stack[this.base-3],n,!0);this.state=i}}class LD{constructor(t,n,r){this.stack=t,this.pos=n,this.index=r,this.buffer=t.buffer,this.index==0&&this.maybeNext()}static create(t,n=t.bufferBase+t.buffer.length){return new LD(t,n,n-t.bufferBase)}maybeNext(){let t=this.stack.parent;t!=null&&(this.index=this.stack.bufferBase-t.bufferBase,this.stack=t,this.buffer=t.buffer)}get id(){return this.buffer[this.index-4]}get start(){return this.buffer[this.index-3]}get end(){return this.buffer[this.index-2]}get size(){return this.buffer[this.index-1]}next(){this.index-=4,this.pos-=4,this.index==0&&this.maybeNext()}fork(){return new LD(this.stack,this.pos,this.index)}}function A2(e,t=Uint16Array){if(typeof e!="string")return e;let n=null;for(let r=0,i=0;r<e.length;){let a=0;for(;;){let u=e.charCodeAt(r++),l=!1;if(u==126){a=65535;break}u>=92&&u--,u>=34&&u--;let o=u-32;if(o>=46&&(o-=46,l=!0),a+=o,l)break;a*=46}n?n[i++]=a:n=new t(a)}return n}class UE{constructor(){this.start=-1,this.value=-1,this.end=-1,this.extended=-1,this.lookAhead=0,this.mask=0,this.context=0}}const iU=new UE;class cxe{constructor(t,n){this.input=t,this.ranges=n,this.chunk="",this.chunkOff=0,this.chunk2="",this.chunk2Pos=0,this.next=-1,this.token=iU,this.rangeIndex=0,this.pos=this.chunkPos=n[0].from,this.range=n[0],this.end=n[n.length-1].to,this.readNext()}resolveOffset(t,n){let r=this.range,i=this.rangeIndex,a=this.pos+t;for(;a<r.from;){if(!i)return null;let u=this.ranges[--i];a-=r.from-u.to,r=u}for(;n<0?a>r.to:a>=r.to;){if(i==this.ranges.length-1)return null;let u=this.ranges[++i];a+=u.from-r.to,r=u}return a}clipPos(t){if(t>=this.range.from&&t<this.range.to)return t;for(let n of this.ranges)if(n.to>t)return Math.max(t,n.from);return this.end}peek(t){let n=this.chunkOff+t,r,i;if(n>=0&&n<this.chunk.length)r=this.pos+t,i=this.chunk.charCodeAt(n);else{let a=this.resolveOffset(t,1);if(a==null)return-1;if(r=a,r>=this.chunk2Pos&&r<this.chunk2Pos+this.chunk2.length)i=this.chunk2.charCodeAt(r-this.chunk2Pos);else{let u=this.rangeIndex,l=this.range;for(;l.to<=r;)l=this.ranges[++u];this.chunk2=this.input.chunk(this.chunk2Pos=r),r+this.chunk2.length>l.to&&(this.chunk2=this.chunk2.slice(0,l.to-r)),i=this.chunk2.charCodeAt(0)}}return r>=this.token.lookAhead&&(this.token.lookAhead=r+1),i}acceptToken(t,n=0){let r=n?this.resolveOffset(n,-1):this.pos;if(r==null||r<this.token.start)throw new RangeError("Token end out of bounds");this.token.value=t,this.token.end=r}acceptTokenTo(t,n){this.token.value=t,this.token.end=n}getChunk(){if(this.pos>=this.chunk2Pos&&this.pos<this.chunk2Pos+this.chunk2.length){let{chunk:t,chunkPos:n}=this;this.chunk=this.chunk2,this.chunkPos=this.chunk2Pos,this.chunk2=t,this.chunk2Pos=n,this.chunkOff=this.pos-this.chunkPos}else{this.chunk2=this.chunk,this.chunk2Pos=this.chunkPos;let t=this.input.chunk(this.pos),n=this.pos+t.length;this.chunk=n>this.range.to?t.slice(0,this.range.to-this.pos):t,this.chunkPos=this.pos,this.chunkOff=0}}readNext(){return this.chunkOff>=this.chunk.length&&(this.getChunk(),this.chunkOff==this.chunk.length)?this.next=-1:this.next=this.chunk.charCodeAt(this.chunkOff)}advance(t=1){for(this.chunkOff+=t;this.pos+t>=this.range.to;){if(this.rangeIndex==this.ranges.length-1)return this.setDone();t-=this.range.to-this.pos,this.range=this.ranges[++this.rangeIndex],this.pos=this.range.from}return this.pos+=t,this.pos>=this.token.lookAhead&&(this.token.lookAhead=this.pos+1),this.readNext()}setDone(){return this.pos=this.chunkPos=this.end,this.range=this.ranges[this.rangeIndex=this.ranges.length-1],this.chunk="",this.next=-1}reset(t,n){if(n?(this.token=n,n.start=t,n.lookAhead=t+1,n.value=n.extended=-1):this.token=iU,this.pos!=t){if(this.pos=t,t==this.end)return this.setDone(),this;for(;t<this.range.from;)this.range=this.ranges[--this.rangeIndex];for(;t>=this.range.to;)this.range=this.ranges[++this.rangeIndex];t>=this.chunkPos&&t<this.chunkPos+this.chunk.length?this.chunkOff=t-this.chunkPos:(this.chunk="",this.chunkOff=0),this.readNext()}return this}read(t,n){if(t>=this.chunkPos&&n<=this.chunkPos+this.chunk.length)return this.chunk.slice(t-this.chunkPos,n-this.chunkPos);if(t>=this.chunk2Pos&&n<=this.chunk2Pos+this.chunk2.length)return this.chunk2.slice(t-this.chunk2Pos,n-this.chunk2Pos);if(t>=this.range.from&&n<=this.range.to)return this.input.read(t,n);let r="";for(let i of this.ranges){if(i.from>=n)break;i.to>t&&(r+=this.input.read(Math.max(i.from,t),Math.min(i.to,n)))}return r}}class e3{constructor(t,n){this.data=t,this.id=n}token(t,n){let{parser:r}=n.p;wee(this.data,t,n,this.id,r.data,r.tokenPrecTable)}}e3.prototype.contextual=e3.prototype.fallback=e3.prototype.extend=!1;class p9{constructor(t,n,r){this.precTable=n,this.elseToken=r,this.data=typeof t=="string"?A2(t):t}token(t,n){let r=t.pos,i=0;for(;;){let a=t.next<0,u=t.resolveOffset(1,1);if(wee(this.data,t,n,0,this.data,this.precTable),t.token.value>-1)break;if(this.elseToken==null)return;if(a||i++,u==null)break;t.reset(u,t.token)}i&&(t.reset(r,t.token),t.acceptToken(this.elseToken,i))}}p9.prototype.contextual=e3.prototype.fallback=e3.prototype.extend=!1;class gg{constructor(t,n={}){this.token=t,this.contextual=!!n.contextual,this.fallback=!!n.fallback,this.extend=!!n.extend}}function wee(e,t,n,r,i,a){let u=0,l=1<<r,{dialect:o}=n.p.parser;e:for(;(l&e[u])!=0;){let s=e[u+1];for(let m=u+3;m<s;m+=2)if((e[m+1]&l)>0){let y=e[m];if(o.allows(y)&&(t.token.value==-1||t.token.value==y||fxe(y,t.token.value,i,a))){t.acceptToken(y);break}}let c=t.next,d=0,h=e[u+2];if(t.next<0&&h>d&&e[s+h*3-3]==65535){u=e[s+h*3-1];continue e}for(;d<h;){let m=d+h>>1,y=s+m+(m<<1),v=e[y],_=e[y+1]||65536;if(c<v)h=m;else if(c>=_)d=m+1;else{u=e[y+2],t.advance();continue e}}break}}function aU(e,t,n){for(let r=t,i;(i=e[r])!=65535;r++)if(i==n)return r-t;return-1}function fxe(e,t,n,r){let i=aU(n,r,t);return i<0||aU(n,r,e)<i}const Ff=typeof process<"u"&&nU&&/\bparse\b/.test(nU.LOG);let PT=null;function uU(e,t,n){let r=e.cursor(Po.IncludeAnonymous);for(r.moveTo(t);;)if(!(n<0?r.childBefore(t):r.childAfter(t)))for(;;){if((n<0?r.to<t:r.from>t)&&!r.type.isError)return n<0?Math.max(0,Math.min(r.to-1,t-25)):Math.min(e.length,Math.max(r.from+1,t+25));if(n<0?r.prevSibling():r.nextSibling())break;if(!r.parent())return n<0?0:e.length}}class dxe{constructor(t,n){this.fragments=t,this.nodeSet=n,this.i=0,this.fragment=null,this.safeFrom=-1,this.safeTo=-1,this.trees=[],this.start=[],this.index=[],this.nextFragment()}nextFragment(){let t=this.fragment=this.i==this.fragments.length?null:this.fragments[this.i++];if(t){for(this.safeFrom=t.openStart?uU(t.tree,t.from+t.offset,1)-t.offset:t.from,this.safeTo=t.openEnd?uU(t.tree,t.to+t.offset,-1)-t.offset:t.to;this.trees.length;)this.trees.pop(),this.start.pop(),this.index.pop();this.trees.push(t.tree),this.start.push(-t.offset),this.index.push(0),this.nextStart=this.safeFrom}else this.nextStart=1e9}nodeAt(t){if(t<this.nextStart)return null;for(;this.fragment&&this.safeTo<=t;)this.nextFragment();if(!this.fragment)return null;for(;;){let n=this.trees.length-1;if(n<0)return this.nextFragment(),null;let r=this.trees[n],i=this.index[n];if(i==r.children.length){this.trees.pop(),this.start.pop(),this.index.pop();continue}let a=r.children[i],u=this.start[n]+r.positions[i];if(u>t)return this.nextStart=u,null;if(a instanceof ep){if(u==t){if(u<this.safeFrom)return null;let l=u+a.length;if(l<=this.safeTo){let o=a.prop(Sa.lookAhead);if(!o||l+o<this.fragment.to)return a}}this.index[n]++,u+a.length>=Math.max(this.safeFrom,t)&&(this.trees.push(a),this.start.push(u),this.index.push(0))}else this.index[n]++,this.nextStart=u+a.length}}}class hxe{constructor(t,n){this.stream=n,this.tokens=[],this.mainToken=null,this.actions=[],this.tokens=t.tokenizers.map(r=>new UE)}getActions(t){let n=0,r=null,{parser:i}=t.p,{tokenizers:a}=i,u=i.stateSlot(t.state,3),l=t.curContext?t.curContext.hash:0,o=0;for(let s=0;s<a.length;s++){if((1<<s&u)==0)continue;let c=a[s],d=this.tokens[s];if(!(r&&!c.fallback)&&((c.contextual||d.start!=t.pos||d.mask!=u||d.context!=l)&&(this.updateCachedToken(d,c,t),d.mask=u,d.context=l),d.lookAhead>d.end+25&&(o=Math.max(d.lookAhead,o)),d.value!=0)){let h=n;if(d.extended>-1&&(n=this.addActions(t,d.extended,d.end,n)),n=this.addActions(t,d.value,d.end,n),!c.extend&&(r=d,n>h))break}}for(;this.actions.length>n;)this.actions.pop();return o&&t.setLookAhead(o),!r&&t.pos==this.stream.end&&(r=new UE,r.value=t.p.parser.eofTerm,r.start=r.end=t.pos,n=this.addActions(t,r.value,r.end,n)),this.mainToken=r,this.actions}getMainToken(t){if(this.mainToken)return this.mainToken;let n=new UE,{pos:r,p:i}=t;return n.start=r,n.end=Math.min(r+1,i.stream.end),n.value=r==i.stream.end?i.parser.eofTerm:0,n}updateCachedToken(t,n,r){let i=this.stream.clipPos(r.pos);if(n.token(this.stream.reset(i,t),r),t.value>-1){let{parser:a}=r.p;for(let u=0;u<a.specialized.length;u++)if(a.specialized[u]==t.value){let l=a.specializers[u](this.stream.read(t.start,t.end),r);if(l>=0&&r.p.parser.dialect.allows(l>>1)){(l&1)==0?t.value=l>>1:t.extended=l>>1;break}}}else t.value=0,t.end=this.stream.clipPos(i+1)}putAction(t,n,r,i){for(let a=0;a<i;a+=3)if(this.actions[a]==t)return i;return this.actions[i++]=t,this.actions[i++]=n,this.actions[i++]=r,i}addActions(t,n,r,i){let{state:a}=t,{parser:u}=t.p,{data:l}=u;for(let o=0;o<2;o++)for(let s=u.stateSlot(a,o?2:1);;s+=3){if(l[s]==65535)if(l[s+1]==1)s=qm(l,s+2);else{i==0&&l[s+1]==2&&(i=this.putAction(qm(l,s+2),n,r,i));break}l[s]==n&&(i=this.putAction(qm(l,s+1),n,r,i))}return i}}class pxe{constructor(t,n,r,i){this.parser=t,this.input=n,this.ranges=i,this.recovering=0,this.nextStackID=9812,this.minStackPos=0,this.reused=[],this.stoppedAt=null,this.lastBigReductionStart=-1,this.lastBigReductionSize=0,this.bigReductionCount=0,this.stream=new cxe(n,i),this.tokens=new hxe(t,this.stream),this.topTerm=t.top[1];let{from:a}=i[0];this.stacks=[ID.start(this,t.top[0],a)],this.fragments=r.length&&this.stream.end-a>t.bufferLength*4?new dxe(r,t.nodeSet):null}get parsedPos(){return this.minStackPos}advance(){let t=this.stacks,n=this.minStackPos,r=this.stacks=[],i,a;if(this.bigReductionCount>300&&t.length==1){let[u]=t;for(;u.forceReduce()&&u.stack.length&&u.stack[u.stack.length-2]>=this.lastBigReductionStart;);this.bigReductionCount=this.lastBigReductionSize=0}for(let u=0;u<t.length;u++){let l=t[u];for(;;){if(this.tokens.mainToken=null,l.pos>n)r.push(l);else{if(this.advanceStack(l,r,t))continue;{i||(i=[],a=[]),i.push(l);let o=this.tokens.getMainToken(l);a.push(o.value,o.end)}}break}}if(!r.length){let u=i&&gxe(i);if(u)return Ff&&console.log("Finish with "+this.stackID(u)),this.stackToTree(u);if(this.parser.strict)throw Ff&&i&&console.log("Stuck with token "+(this.tokens.mainToken?this.parser.getName(this.tokens.mainToken.value):"none")),new SyntaxError("No parse at "+n);this.recovering||(this.recovering=5)}if(this.recovering&&i){let u=this.stoppedAt!=null&&i[0].pos>this.stoppedAt?i[0]:this.runRecovery(i,a,r);if(u)return Ff&&console.log("Force-finish "+this.stackID(u)),this.stackToTree(u.forceAll())}if(this.recovering){let u=this.recovering==1?1:this.recovering*3;if(r.length>u)for(r.sort((l,o)=>o.score-l.score);r.length>u;)r.pop();r.some(l=>l.reducePos>n)&&this.recovering--}else if(r.length>1){e:for(let u=0;u<r.length-1;u++){let l=r[u];for(let o=u+1;o<r.length;o++){let s=r[o];if(l.sameState(s)||l.buffer.length>500&&s.buffer.length>500)if((l.score-s.score||l.buffer.length-s.buffer.length)>0)r.splice(o--,1);else{r.splice(u--,1);continue e}}}r.length>12&&r.splice(12,r.length-12)}this.minStackPos=r[0].pos;for(let u=1;u<r.length;u++)r[u].pos<this.minStackPos&&(this.minStackPos=r[u].pos);return null}stopAt(t){if(this.stoppedAt!=null&&this.stoppedAt<t)throw new RangeError("Can't move stoppedAt forward");this.stoppedAt=t}advanceStack(t,n,r){let i=t.pos,{parser:a}=this,u=Ff?this.stackID(t)+" -> ":"";if(this.stoppedAt!=null&&i>this.stoppedAt)return t.forceReduce()?t:null;if(this.fragments){let s=t.curContext&&t.curContext.tracker.strict,c=s?t.curContext.hash:0;for(let d=this.fragments.nodeAt(i);d;){let h=this.parser.nodeSet.types[d.type.id]==d.type?a.getGoto(t.state,d.type.id):-1;if(h>-1&&d.length&&(!s||(d.prop(Sa.contextHash)||0)==c))return t.useNode(d,h),Ff&&console.log(u+this.stackID(t)+` (via reuse of ${a.getName(d.type.id)})`),!0;if(!(d instanceof ep)||d.children.length==0||d.positions[0]>0)break;let m=d.children[0];if(m instanceof ep&&d.positions[0]==0)d=m;else break}}let l=a.stateSlot(t.state,4);if(l>0)return t.reduce(l),Ff&&console.log(u+this.stackID(t)+` (via always-reduce ${a.getName(l&65535)})`),!0;if(t.stack.length>=8400)for(;t.stack.length>6e3&&t.forceReduce(););let o=this.tokens.getActions(t);for(let s=0;s<o.length;){let c=o[s++],d=o[s++],h=o[s++],m=s==o.length||!r,y=m?t:t.split(),v=this.tokens.mainToken;if(y.apply(c,d,v?v.start:y.pos,h),Ff&&console.log(u+this.stackID(y)+` (via ${(c&65536)==0?"shift":`reduce of ${a.getName(c&65535)}`} for ${a.getName(d)} @ ${i}${y==t?"":", split"})`),m)return!0;y.pos>i?n.push(y):r.push(y)}return!1}advanceFully(t,n){let r=t.pos;for(;;){if(!this.advanceStack(t,null,null))return!1;if(t.pos>r)return lU(t,n),!0}}runRecovery(t,n,r){let i=null,a=!1;for(let u=0;u<t.length;u++){let l=t[u],o=n[u<<1],s=n[(u<<1)+1],c=Ff?this.stackID(l)+" -> ":"";if(l.deadEnd&&(a||(a=!0,l.restart(),Ff&&console.log(c+this.stackID(l)+" (restarted)"),this.advanceFully(l,r))))continue;let d=l.split(),h=c;for(let m=0;d.forceReduce()&&m<10&&(Ff&&console.log(h+this.stackID(d)+" (via force-reduce)"),!this.advanceFully(d,r));m++)Ff&&(h=this.stackID(d)+" -> ");for(let m of l.recoverByInsert(o))Ff&&console.log(c+this.stackID(m)+" (via recover-insert)"),this.advanceFully(m,r);this.stream.end>l.pos?(s==l.pos&&(s++,o=0),l.recoverByDelete(o,s),Ff&&console.log(c+this.stackID(l)+` (via recover-delete ${this.parser.getName(o)})`),lU(l,r)):(!i||i.score<l.score)&&(i=l)}return i}stackToTree(t){return t.close(),ep.build({buffer:LD.create(t),nodeSet:this.parser.nodeSet,topID:this.topTerm,maxBufferLength:this.parser.bufferLength,reused:this.reused,start:this.ranges[0].from,length:t.pos-this.ranges[0].from,minRepeatType:this.parser.minRepeatTerm})}stackID(t){let n=(PT||(PT=new WeakMap)).get(t);return n||PT.set(t,n=String.fromCodePoint(this.nextStackID++)),n+t}}function lU(e,t){for(let n=0;n<t.length;n++){let r=t[n];if(r.pos==e.pos&&r.sameState(e)){t[n].score<e.score&&(t[n]=e);return}}t.push(e)}class mxe{constructor(t,n,r){this.source=t,this.flags=n,this.disabled=r}allows(t){return!this.disabled||this.disabled[t]==0}}const MT=e=>e;class Ree{constructor(t){this.start=t.start,this.shift=t.shift||MT,this.reduce=t.reduce||MT,this.reuse=t.reuse||MT,this.hash=t.hash||(()=>0),this.strict=t.strict!==!1}}class $3 extends G2e{constructor(t){if(super(),this.wrappers=[],t.version!=14)throw new RangeError(`Parser version (${t.version}) doesn't match runtime version (14)`);let n=t.nodeNames.split(" ");this.minRepeatTerm=n.length;for(let l=0;l<t.repeatNodeCount;l++)n.push("");let r=Object.keys(t.topRules).map(l=>t.topRules[l][1]),i=[];for(let l=0;l<n.length;l++)i.push([]);function a(l,o,s){i[l].push([o,o.deserialize(String(s))])}if(t.nodeProps)for(let l of t.nodeProps){let o=l[0];typeof o=="string"&&(o=Sa[o]);for(let s=1;s<l.length;){let c=l[s++];if(c>=0)a(c,o,l[s++]);else{let d=l[s+-c];for(let h=-c;h>0;h--)a(l[s++],o,d);s++}}}this.nodeSet=new JF(n.map((l,o)=>og.define({name:o>=this.minRepeatTerm?void 0:l,id:o,props:i[o],top:r.indexOf(o)>-1,error:o==0,skipped:t.skippedNodes&&t.skippedNodes.indexOf(o)>-1}))),t.propSources&&(this.nodeSet=this.nodeSet.extend(...t.propSources)),this.strict=!1,this.bufferLength=yee;let u=A2(t.tokenData);this.context=t.context,this.specializerSpecs=t.specialized||[],this.specialized=new Uint16Array(this.specializerSpecs.length);for(let l=0;l<this.specializerSpecs.length;l++)this.specialized[l]=this.specializerSpecs[l].term;this.specializers=this.specializerSpecs.map(oU),this.states=A2(t.states,Uint32Array),this.data=A2(t.stateData),this.goto=A2(t.goto),this.maxTerm=t.maxTerm,this.tokenizers=t.tokenizers.map(l=>typeof l=="number"?new e3(u,l):l),this.topRules=t.topRules,this.dialects=t.dialects||{},this.dynamicPrecedences=t.dynamicPrecedences||null,this.tokenPrecTable=t.tokenPrec,this.termNames=t.termNames||null,this.maxNode=this.nodeSet.types.length-1,this.dialect=this.parseDialect(),this.top=this.topRules[Object.keys(this.topRules)[0]]}createParse(t,n,r){let i=new pxe(this,t,n,r);for(let a of this.wrappers)i=a(i,t,n,r);return i}getGoto(t,n,r=!1){let i=this.goto;if(n>=i[0])return-1;for(let a=i[n+1];;){let u=i[a++],l=u&1,o=i[a++];if(l&&r)return o;for(let s=a+(u>>1);a<s;a++)if(i[a]==t)return o;if(l)return-1}}hasAction(t,n){let r=this.data;for(let i=0;i<2;i++)for(let a=this.stateSlot(t,i?2:1),u;;a+=3){if((u=r[a])==65535)if(r[a+1]==1)u=r[a=qm(r,a+2)];else{if(r[a+1]==2)return qm(r,a+2);break}if(u==n||u==0)return qm(r,a+1)}return 0}stateSlot(t,n){return this.states[t*6+n]}stateFlag(t,n){return(this.stateSlot(t,0)&n)>0}validAction(t,n){return!!this.allActions(t,r=>r==n?!0:null)}allActions(t,n){let r=this.stateSlot(t,4),i=r?n(r):void 0;for(let a=this.stateSlot(t,1);i==null;a+=3){if(this.data[a]==65535)if(this.data[a+1]==1)a=qm(this.data,a+2);else break;i=n(qm(this.data,a+1))}return i}nextStates(t){let n=[];for(let r=this.stateSlot(t,1);;r+=3){if(this.data[r]==65535)if(this.data[r+1]==1)r=qm(this.data,r+2);else break;if((this.data[r+2]&1)==0){let i=this.data[r+1];n.some((a,u)=>u&1&&a==i)||n.push(this.data[r],i)}}return n}configure(t){let n=Object.assign(Object.create($3.prototype),this);if(t.props&&(n.nodeSet=this.nodeSet.extend(...t.props)),t.top){let r=this.topRules[t.top];if(!r)throw new RangeError(`Invalid top rule name ${t.top}`);n.top=r}return t.tokenizers&&(n.tokenizers=this.tokenizers.map(r=>{let i=t.tokenizers.find(a=>a.from==r);return i?i.to:r})),t.specializers&&(n.specializers=this.specializers.slice(),n.specializerSpecs=this.specializerSpecs.map((r,i)=>{let a=t.specializers.find(l=>l.from==r.external);if(!a)return r;let u=Object.assign(Object.assign({},r),{external:a.to});return n.specializers[i]=oU(u),u})),t.contextTracker&&(n.context=t.contextTracker),t.dialect&&(n.dialect=this.parseDialect(t.dialect)),t.strict!=null&&(n.strict=t.strict),t.wrap&&(n.wrappers=n.wrappers.concat(t.wrap)),t.bufferLength!=null&&(n.bufferLength=t.bufferLength),n}hasWrappers(){return this.wrappers.length>0}getName(t){return this.termNames?this.termNames[t]:String(t<=this.maxNode&&this.nodeSet.types[t].name||t)}get eofTerm(){return this.maxNode+1}get topNode(){return this.nodeSet.types[this.top[1]]}dynamicPrecedence(t){let n=this.dynamicPrecedences;return n==null?0:n[t]||0}parseDialect(t){let n=Object.keys(this.dialects),r=n.map(()=>!1);if(t)for(let a of t.split(" ")){let u=n.indexOf(a);u>=0&&(r[u]=!0)}let i=null;for(let a=0;a<n.length;a++)if(!r[a])for(let u=this.dialects[n[a]],l;(l=this.data[u++])!=65535;)(i||(i=new Uint8Array(this.maxTerm+1)))[l]=1;return new mxe(t,r,i)}static deserialize(t){return new $3(t)}}function qm(e,t){return e[t]|e[t+1]<<16}function gxe(e){let t=null;for(let n of e){let r=n.p.stoppedAt;(n.pos==n.p.stream.end||r!=null&&n.pos>r)&&n.p.parser.stateFlag(n.state,2)&&(!t||t.score<n.score)&&(t=n)}return t}function oU(e){if(e.external){let t=e.extend?1:0;return(n,r)=>e.external(n,r)<<1|t}return e.get}const vxe=Symbol("Let zodToJsonSchema decide on which parser to use"),sU={name:void 0,$refStrategy:"root",basePath:["#"],effectStrategy:"input",pipeStrategy:"all",dateStrategy:"format:date-time",mapStrategy:"entries",removeAdditionalStrategy:"passthrough",allowedAdditionalProperties:!0,rejectedAdditionalProperties:!1,definitionPath:"definitions",target:"jsonSchema7",strictUnions:!1,definitions:{},errorMessages:!1,markdownDescription:!1,patternStrategy:"escape",applyRegexFlags:!1,emailStrategy:"format:email",base64Strategy:"contentEncoding:base64",nameStrategy:"ref",openAiAnyTypeName:"OpenAiAnyType"},yxe=e=>typeof e=="string"?{...sU,name:e}:{...sU,...e},bxe=e=>{const t=yxe(e),n=t.name!==void 0?[...t.basePath,t.definitionPath,t.name]:t.basePath;return{...t,flags:{hasReferencedOpenAiAnyType:!1},currentPath:n,propertyPath:void 0,seen:new Map(Object.entries(t.definitions).map(([r,i])=>[i._def,{def:i._def,path:[...t.basePath,t.definitionPath,r],jsonSchema:void 0}]))}};function Aee(e,t,n,r){r!=null&&r.errorMessages&&n&&(e.errorMessage={...e.errorMessage,[t]:n})}function Zi(e,t,n,r,i){e[t]=n,Aee(e,t,r,i)}const Tee=(e,t)=>{let n=0;for(;n<e.length&&n<t.length&&e[n]===t[n];n++);return[(e.length-n).toString(),...t.slice(n)].join("/")};function sf(e){if(e.target!=="openAi")return{};const t=[...e.basePath,e.definitionPath,e.openAiAnyTypeName];return e.flags.hasReferencedOpenAiAnyType=!0,{$ref:e.$refStrategy==="relative"?Tee(t,e.currentPath):t.join("/")}}function Oxe(e,t){var r,i,a;const n={type:"array"};return(r=e.type)!=null&&r._def&&((a=(i=e.type)==null?void 0:i._def)==null?void 0:a.typeName)!==It.ZodAny&&(n.items=Ti(e.type._def,{...t,currentPath:[...t.currentPath,"items"]})),e.minLength&&Zi(n,"minItems",e.minLength.value,e.minLength.message,t),e.maxLength&&Zi(n,"maxItems",e.maxLength.value,e.maxLength.message,t),e.exactLength&&(Zi(n,"minItems",e.exactLength.value,e.exactLength.message,t),Zi(n,"maxItems",e.exactLength.value,e.exactLength.message,t)),n}function xxe(e,t){const n={type:"integer",format:"int64"};if(!e.checks)return n;for(const r of e.checks)switch(r.kind){case"min":t.target==="jsonSchema7"?r.inclusive?Zi(n,"minimum",r.value,r.message,t):Zi(n,"exclusiveMinimum",r.value,r.message,t):(r.inclusive||(n.exclusiveMinimum=!0),Zi(n,"minimum",r.value,r.message,t));break;case"max":t.target==="jsonSchema7"?r.inclusive?Zi(n,"maximum",r.value,r.message,t):Zi(n,"exclusiveMaximum",r.value,r.message,t):(r.inclusive||(n.exclusiveMaximum=!0),Zi(n,"maximum",r.value,r.message,t));break;case"multipleOf":Zi(n,"multipleOf",r.value,r.message,t);break}return n}function Sxe(){return{type:"boolean"}}function kee(e,t){return Ti(e.type._def,t)}const _xe=(e,t)=>Ti(e.innerType._def,t);function Pee(e,t,n){const r=n??t.dateStrategy;if(Array.isArray(r))return{anyOf:r.map((i,a)=>Pee(e,t,i))};switch(r){case"string":case"format:date-time":return{type:"string",format:"date-time"};case"format:date":return{type:"string",format:"date"};case"integer":return Exe(e,t)}}const Exe=(e,t)=>{const n={type:"integer",format:"unix-time"};if(t.target==="openApi3")return n;for(const r of e.checks)switch(r.kind){case"min":Zi(n,"minimum",r.value,r.message,t);break;case"max":Zi(n,"maximum",r.value,r.message,t);break}return n};function Dxe(e,t){return{...Ti(e.innerType._def,t),default:e.defaultValue()}}function $xe(e,t){return t.effectStrategy==="input"?Ti(e.schema._def,t):sf(t)}function Cxe(e){return{type:"string",enum:Array.from(e.values)}}const wxe=e=>"type"in e&&e.type==="string"?!1:"allOf"in e;function Rxe(e,t){const n=[Ti(e.left._def,{...t,currentPath:[...t.currentPath,"allOf","0"]}),Ti(e.right._def,{...t,currentPath:[...t.currentPath,"allOf","1"]})].filter(a=>!!a);let r=t.target==="jsonSchema2019-09"?{unevaluatedProperties:!1}:void 0;const i=[];return n.forEach(a=>{if(wxe(a))i.push(...a.allOf),a.unevaluatedProperties===void 0&&(r=void 0);else{let u=a;if("additionalProperties"in a&&a.additionalProperties===!1){const{additionalProperties:l,...o}=a;u=o}else r=void 0;i.push(u)}}),i.length?{allOf:i,...r}:void 0}function Axe(e,t){const n=typeof e.value;return n!=="bigint"&&n!=="number"&&n!=="boolean"&&n!=="string"?{type:Array.isArray(e.value)?"array":"object"}:t.target==="openApi3"?{type:n==="bigint"?"integer":n,enum:[e.value]}:{type:n==="bigint"?"integer":n,const:e.value}}let FT;const Uh={cuid:/^[cC][^\s-]{8,}$/,cuid2:/^[0-9a-z]+$/,ulid:/^[0-9A-HJKMNP-TV-Z]{26}$/,email:/^(?!\.)(?!.*\.\.)([a-zA-Z0-9_'+\-\.]*)[a-zA-Z0-9_+-]@([a-zA-Z0-9][a-zA-Z0-9\-]*\.)+[a-zA-Z]{2,}$/,emoji:()=>(FT===void 0&&(FT=RegExp("^(\\p{Extended_Pictographic}|\\p{Emoji_Component})+$","u")),FT),uuid:/^[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{12}$/,ipv4:/^(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])$/,ipv4Cidr:/^(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\/(3[0-2]|[12]?[0-9])$/,ipv6:/^(([a-f0-9]{1,4}:){7}|::([a-f0-9]{1,4}:){0,6}|([a-f0-9]{1,4}:){1}:([a-f0-9]{1,4}:){0,5}|([a-f0-9]{1,4}:){2}:([a-f0-9]{1,4}:){0,4}|([a-f0-9]{1,4}:){3}:([a-f0-9]{1,4}:){0,3}|([a-f0-9]{1,4}:){4}:([a-f0-9]{1,4}:){0,2}|([a-f0-9]{1,4}:){5}:([a-f0-9]{1,4}:){0,1})([a-f0-9]{1,4}|(((25[0-5])|(2[0-4][0-9])|(1[0-9]{2})|([0-9]{1,2}))\.){3}((25[0-5])|(2[0-4][0-9])|(1[0-9]{2})|([0-9]{1,2})))$/,ipv6Cidr:/^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))\/(12[0-8]|1[01][0-9]|[1-9]?[0-9])$/,base64:/^([0-9a-zA-Z+/]{4})*(([0-9a-zA-Z+/]{2}==)|([0-9a-zA-Z+/]{3}=))?$/,base64url:/^([0-9a-zA-Z-_]{4})*(([0-9a-zA-Z-_]{2}(==)?)|([0-9a-zA-Z-_]{3}(=)?))?$/,nanoid:/^[a-zA-Z0-9_-]{21}$/,jwt:/^[A-Za-z0-9-_]+\.[A-Za-z0-9-_]+\.[A-Za-z0-9-_]*$/};function Mee(e,t){const n={type:"string"};if(e.checks)for(const r of e.checks)switch(r.kind){case"min":Zi(n,"minLength",typeof n.minLength=="number"?Math.max(n.minLength,r.value):r.value,r.message,t);break;case"max":Zi(n,"maxLength",typeof n.maxLength=="number"?Math.min(n.maxLength,r.value):r.value,r.message,t);break;case"email":switch(t.emailStrategy){case"format:email":jh(n,"email",r.message,t);break;case"format:idn-email":jh(n,"idn-email",r.message,t);break;case"pattern:zod":ec(n,Uh.email,r.message,t);break}break;case"url":jh(n,"uri",r.message,t);break;case"uuid":jh(n,"uuid",r.message,t);break;case"regex":ec(n,r.regex,r.message,t);break;case"cuid":ec(n,Uh.cuid,r.message,t);break;case"cuid2":ec(n,Uh.cuid2,r.message,t);break;case"startsWith":ec(n,RegExp(`^${NT(r.value,t)}`),r.message,t);break;case"endsWith":ec(n,RegExp(`${NT(r.value,t)}$`),r.message,t);break;case"datetime":jh(n,"date-time",r.message,t);break;case"date":jh(n,"date",r.message,t);break;case"time":jh(n,"time",r.message,t);break;case"duration":jh(n,"duration",r.message,t);break;case"length":Zi(n,"minLength",typeof n.minLength=="number"?Math.max(n.minLength,r.value):r.value,r.message,t),Zi(n,"maxLength",typeof n.maxLength=="number"?Math.min(n.maxLength,r.value):r.value,r.message,t);break;case"includes":{ec(n,RegExp(NT(r.value,t)),r.message,t);break}case"ip":{r.version!=="v6"&&jh(n,"ipv4",r.message,t),r.version!=="v4"&&jh(n,"ipv6",r.message,t);break}case"base64url":ec(n,Uh.base64url,r.message,t);break;case"jwt":ec(n,Uh.jwt,r.message,t);break;case"cidr":{r.version!=="v6"&&ec(n,Uh.ipv4Cidr,r.message,t),r.version!=="v4"&&ec(n,Uh.ipv6Cidr,r.message,t);break}case"emoji":ec(n,Uh.emoji(),r.message,t);break;case"ulid":{ec(n,Uh.ulid,r.message,t);break}case"base64":{switch(t.base64Strategy){case"format:binary":{jh(n,"binary",r.message,t);break}case"contentEncoding:base64":{Zi(n,"contentEncoding","base64",r.message,t);break}case"pattern:zod":{ec(n,Uh.base64,r.message,t);break}}break}case"nanoid":ec(n,Uh.nanoid,r.message,t)}return n}function NT(e,t){return t.patternStrategy==="escape"?kxe(e):e}const Txe=new Set("ABCDEFGHIJKLMNOPQRSTUVXYZabcdefghijklmnopqrstuvxyz0123456789");function kxe(e){let t="";for(let n=0;n<e.length;n++)Txe.has(e[n])||(t+="\\"),t+=e[n];return t}function jh(e,t,n,r){var i;e.format||(i=e.anyOf)!=null&&i.some(a=>a.format)?(e.anyOf||(e.anyOf=[]),e.format&&(e.anyOf.push({format:e.format,...e.errorMessage&&r.errorMessages&&{errorMessage:{format:e.errorMessage.format}}}),delete e.format,e.errorMessage&&(delete e.errorMessage.format,Object.keys(e.errorMessage).length===0&&delete e.errorMessage)),e.anyOf.push({format:t,...n&&r.errorMessages&&{errorMessage:{format:n}}})):Zi(e,"format",t,n,r)}function ec(e,t,n,r){var i;e.pattern||(i=e.allOf)!=null&&i.some(a=>a.pattern)?(e.allOf||(e.allOf=[]),e.pattern&&(e.allOf.push({pattern:e.pattern,...e.errorMessage&&r.errorMessages&&{errorMessage:{pattern:e.errorMessage.pattern}}}),delete e.pattern,e.errorMessage&&(delete e.errorMessage.pattern,Object.keys(e.errorMessage).length===0&&delete e.errorMessage)),e.allOf.push({pattern:cU(t,r),...n&&r.errorMessages&&{errorMessage:{pattern:n}}})):Zi(e,"pattern",cU(t,r),n,r)}function cU(e,t){var o;if(!t.applyRegexFlags||!e.flags)return e.source;const n={i:e.flags.includes("i"),m:e.flags.includes("m"),s:e.flags.includes("s")},r=n.i?e.source.toLowerCase():e.source;let i="",a=!1,u=!1,l=!1;for(let s=0;s<r.length;s++){if(a){i+=r[s],a=!1;continue}if(n.i){if(u){if(r[s].match(/[a-z]/)){l?(i+=r[s],i+=`${r[s-2]}-${r[s]}`.toUpperCase(),l=!1):r[s+1]==="-"&&((o=r[s+2])!=null&&o.match(/[a-z]/))?(i+=r[s],l=!0):i+=`${r[s]}${r[s].toUpperCase()}`;continue}}else if(r[s].match(/[a-z]/)){i+=`[${r[s]}${r[s].toUpperCase()}]`;continue}}if(n.m){if(r[s]==="^"){i+=`(^|(?<=[\r
]))`;continue}else if(r[s]==="$"){i+=`($|(?=[\r
]))`;continue}}if(n.s&&r[s]==="."){i+=u?`${r[s]}\r
`:`[${r[s]}\r
]`;continue}i+=r[s],r[s]==="\\"?a=!0:u&&r[s]==="]"?u=!1:!u&&r[s]==="["&&(u=!0)}try{new RegExp(i)}catch{return console.warn(`Could not convert regex pattern at ${t.currentPath.join("/")} to a flag-independent form! Falling back to the flag-ignorant source`),e.source}return i}function Fee(e,t){var r,i,a,u,l,o;if(t.target==="openAi"&&console.warn("Warning: OpenAI may not support records in schemas! Try an array of key-value pairs instead."),t.target==="openApi3"&&((r=e.keyType)==null?void 0:r._def.typeName)===It.ZodEnum)return{type:"object",required:e.keyType._def.values,properties:e.keyType._def.values.reduce((s,c)=>({...s,[c]:Ti(e.valueType._def,{...t,currentPath:[...t.currentPath,"properties",c]})??sf(t)}),{}),additionalProperties:t.rejectedAdditionalProperties};const n={type:"object",additionalProperties:Ti(e.valueType._def,{...t,currentPath:[...t.currentPath,"additionalProperties"]})??t.allowedAdditionalProperties};if(t.target==="openApi3")return n;if(((i=e.keyType)==null?void 0:i._def.typeName)===It.ZodString&&((a=e.keyType._def.checks)!=null&&a.length)){const{type:s,...c}=Mee(e.keyType._def,t);return{...n,propertyNames:c}}else{if(((u=e.keyType)==null?void 0:u._def.typeName)===It.ZodEnum)return{...n,propertyNames:{enum:e.keyType._def.values}};if(((l=e.keyType)==null?void 0:l._def.typeName)===It.ZodBranded&&e.keyType._def.type._def.typeName===It.ZodString&&((o=e.keyType._def.type._def.checks)!=null&&o.length)){const{type:s,...c}=kee(e.keyType._def,t);return{...n,propertyNames:c}}}return n}function Pxe(e,t){if(t.mapStrategy==="record")return Fee(e,t);const n=Ti(e.keyType._def,{...t,currentPath:[...t.currentPath,"items","items","0"]})||sf(t),r=Ti(e.valueType._def,{...t,currentPath:[...t.currentPath,"items","items","1"]})||sf(t);return{type:"array",maxItems:125,items:{type:"array",items:[n,r],minItems:2,maxItems:2}}}function Mxe(e){const t=e.values,r=Object.keys(e.values).filter(a=>typeof t[t[a]]!="number").map(a=>t[a]),i=Array.from(new Set(r.map(a=>typeof a)));return{type:i.length===1?i[0]==="string"?"string":"number":["string","number"],enum:r}}function Fxe(e){return e.target==="openAi"?void 0:{not:sf({...e,currentPath:[...e.currentPath,"not"]})}}function Nxe(e){return e.target==="openApi3"?{enum:["null"],nullable:!0}:{type:"null"}}const BD={ZodString:"string",ZodNumber:"number",ZodBigInt:"integer",ZodBoolean:"boolean",ZodNull:"null"};function Ixe(e,t){if(t.target==="openApi3")return fU(e,t);const n=e.options instanceof Map?Array.from(e.options.values()):e.options;if(n.every(r=>r._def.typeName in BD&&(!r._def.checks||!r._def.checks.length))){const r=n.reduce((i,a)=>{const u=BD[a._def.typeName];return u&&!i.includes(u)?[...i,u]:i},[]);return{type:r.length>1?r:r[0]}}else if(n.every(r=>r._def.typeName==="ZodLiteral"&&!r.description)){const r=n.reduce((i,a)=>{const u=typeof a._def.value;switch(u){case"string":case"number":case"boolean":return[...i,u];case"bigint":return[...i,"integer"];case"object":if(a._def.value===null)return[...i,"null"];case"symbol":case"undefined":case"function":default:return i}},[]);if(r.length===n.length){const i=r.filter((a,u,l)=>l.indexOf(a)===u);return{type:i.length>1?i:i[0],enum:n.reduce((a,u)=>a.includes(u._def.value)?a:[...a,u._def.value],[])}}}else if(n.every(r=>r._def.typeName==="ZodEnum"))return{type:"string",enum:n.reduce((r,i)=>[...r,...i._def.values.filter(a=>!r.includes(a))],[])};return fU(e,t)}const fU=(e,t)=>{const n=(e.options instanceof Map?Array.from(e.options.values()):e.options).map((r,i)=>Ti(r._def,{...t,currentPath:[...t.currentPath,"anyOf",`${i}`]})).filter(r=>!!r&&(!t.strictUnions||typeof r=="object"&&Object.keys(r).length>0));return n.length?{anyOf:n}:void 0};function Lxe(e,t){if(["ZodString","ZodNumber","ZodBigInt","ZodBoolean","ZodNull"].includes(e.innerType._def.typeName)&&(!e.innerType._def.checks||!e.innerType._def.checks.length))return t.target==="openApi3"?{type:BD[e.innerType._def.typeName],nullable:!0}:{type:[BD[e.innerType._def.typeName],"null"]};if(t.target==="openApi3"){const r=Ti(e.innerType._def,{...t,currentPath:[...t.currentPath]});return r&&"$ref"in r?{allOf:[r],nullable:!0}:r&&{...r,nullable:!0}}const n=Ti(e.innerType._def,{...t,currentPath:[...t.currentPath,"anyOf","0"]});return n&&{anyOf:[n,{type:"null"}]}}function Bxe(e,t){const n={type:"number"};if(!e.checks)return n;for(const r of e.checks)switch(r.kind){case"int":n.type="integer",Aee(n,"type",r.message,t);break;case"min":t.target==="jsonSchema7"?r.inclusive?Zi(n,"minimum",r.value,r.message,t):Zi(n,"exclusiveMinimum",r.value,r.message,t):(r.inclusive||(n.exclusiveMinimum=!0),Zi(n,"minimum",r.value,r.message,t));break;case"max":t.target==="jsonSchema7"?r.inclusive?Zi(n,"maximum",r.value,r.message,t):Zi(n,"exclusiveMaximum",r.value,r.message,t):(r.inclusive||(n.exclusiveMaximum=!0),Zi(n,"maximum",r.value,r.message,t));break;case"multipleOf":Zi(n,"multipleOf",r.value,r.message,t);break}return n}function Qxe(e,t){const n=t.target==="openAi",r={type:"object",properties:{}},i=[],a=e.shape();for(const l in a){let o=a[l];if(o===void 0||o._def===void 0)continue;let s=qxe(o);s&&n&&(o._def.typeName==="ZodOptional"&&(o=o._def.innerType),o.isNullable()||(o=o.nullable()),s=!1);const c=Ti(o._def,{...t,currentPath:[...t.currentPath,"properties",l],propertyPath:[...t.currentPath,"properties",l]});c!==void 0&&(r.properties[l]=c,s||i.push(l))}i.length&&(r.required=i);const u=zxe(e,t);return u!==void 0&&(r.additionalProperties=u),r}function zxe(e,t){if(e.catchall._def.typeName!=="ZodNever")return Ti(e.catchall._def,{...t,currentPath:[...t.currentPath,"additionalProperties"]});switch(e.unknownKeys){case"passthrough":return t.allowedAdditionalProperties;case"strict":return t.rejectedAdditionalProperties;case"strip":return t.removeAdditionalStrategy==="strict"?t.allowedAdditionalProperties:t.rejectedAdditionalProperties}}function qxe(e){try{return e.isOptional()}catch{return!0}}const Vxe=(e,t)=>{var r;if(t.currentPath.toString()===((r=t.propertyPath)==null?void 0:r.toString()))return Ti(e.innerType._def,t);const n=Ti(e.innerType._def,{...t,currentPath:[...t.currentPath,"anyOf","1"]});return n?{anyOf:[{not:sf(t)},n]}:sf(t)},Uxe=(e,t)=>{if(t.pipeStrategy==="input")return Ti(e.in._def,t);if(t.pipeStrategy==="output")return Ti(e.out._def,t);const n=Ti(e.in._def,{...t,currentPath:[...t.currentPath,"allOf","0"]}),r=Ti(e.out._def,{...t,currentPath:[...t.currentPath,"allOf",n?"1":"0"]});return{allOf:[n,r].filter(i=>i!==void 0)}};function jxe(e,t){return Ti(e.type._def,t)}function Zxe(e,t){const r={type:"array",uniqueItems:!0,items:Ti(e.valueType._def,{...t,currentPath:[...t.currentPath,"items"]})};return e.minSize&&Zi(r,"minItems",e.minSize.value,e.minSize.message,t),e.maxSize&&Zi(r,"maxItems",e.maxSize.value,e.maxSize.message,t),r}function Hxe(e,t){return e.rest?{type:"array",minItems:e.items.length,items:e.items.map((n,r)=>Ti(n._def,{...t,currentPath:[...t.currentPath,"items",`${r}`]})).reduce((n,r)=>r===void 0?n:[...n,r],[]),additionalItems:Ti(e.rest._def,{...t,currentPath:[...t.currentPath,"additionalItems"]})}:{type:"array",minItems:e.items.length,maxItems:e.items.length,items:e.items.map((n,r)=>Ti(n._def,{...t,currentPath:[...t.currentPath,"items",`${r}`]})).reduce((n,r)=>r===void 0?n:[...n,r],[])}}function Xxe(e){return{not:sf(e)}}function Yxe(e){return sf(e)}const Gxe=(e,t)=>Ti(e.innerType._def,t),Kxe=(e,t,n)=>{switch(t){case It.ZodString:return Mee(e,n);case It.ZodNumber:return Bxe(e,n);case It.ZodObject:return Qxe(e,n);case It.ZodBigInt:return xxe(e,n);case It.ZodBoolean:return Sxe();case It.ZodDate:return Pee(e,n);case It.ZodUndefined:return Xxe(n);case It.ZodNull:return Nxe(n);case It.ZodArray:return Oxe(e,n);case It.ZodUnion:case It.ZodDiscriminatedUnion:return Ixe(e,n);case It.ZodIntersection:return Rxe(e,n);case It.ZodTuple:return Hxe(e,n);case It.ZodRecord:return Fee(e,n);case It.ZodLiteral:return Axe(e,n);case It.ZodEnum:return Cxe(e);case It.ZodNativeEnum:return Mxe(e);case It.ZodNullable:return Lxe(e,n);case It.ZodOptional:return Vxe(e,n);case It.ZodMap:return Pxe(e,n);case It.ZodSet:return Zxe(e,n);case It.ZodLazy:return()=>e.getter()._def;case It.ZodPromise:return jxe(e,n);case It.ZodNaN:case It.ZodNever:return Fxe(n);case It.ZodEffects:return $xe(e,n);case It.ZodAny:return sf(n);case It.ZodUnknown:return Yxe(n);case It.ZodDefault:return Dxe(e,n);case It.ZodBranded:return kee(e,n);case It.ZodReadonly:return Gxe(e,n);case It.ZodCatch:return _xe(e,n);case It.ZodPipeline:return Uxe(e,n);case It.ZodFunction:case It.ZodVoid:case It.ZodSymbol:return;default:return(r=>{})()}};function Ti(e,t,n=!1){var l;const r=t.seen.get(e);if(t.override){const o=(l=t.override)==null?void 0:l.call(t,e,t,r,n);if(o!==vxe)return o}if(r&&!n){const o=Wxe(r,t);if(o!==void 0)return o}const i={def:e,path:t.currentPath,jsonSchema:void 0};t.seen.set(e,i);const a=Kxe(e,e.typeName,t),u=typeof a=="function"?Ti(a(),t):a;if(u&&Jxe(e,t,u),t.postProcess){const o=t.postProcess(u,e,t);return i.jsonSchema=u,o}return i.jsonSchema=u,u}const Wxe=(e,t)=>{switch(t.$refStrategy){case"root":return{$ref:e.path.join("/")};case"relative":return{$ref:Tee(t.currentPath,e.path)};case"none":case"seen":return e.path.length<t.currentPath.length&&e.path.every((n,r)=>t.currentPath[r]===n)?(console.warn(`Recursive reference detected at ${t.currentPath.join("/")}! Defaulting to any`),sf(t)):t.$refStrategy==="seen"?sf(t):void 0}},Jxe=(e,t,n)=>(e.description&&(n.description=e.description,t.markdownDescription&&(n.markdownDescription=e.description)),n),yrt=(e,t)=>{const n=bxe(t);let r=typeof t=="object"&&t.definitions?Object.entries(t.definitions).reduce((o,[s,c])=>({...o,[s]:Ti(c._def,{...n,currentPath:[...n.basePath,n.definitionPath,s]},!0)??sf(n)}),{}):void 0;const i=typeof t=="string"?t:(t==null?void 0:t.nameStrategy)==="title"||t==null?void 0:t.name,a=Ti(e._def,i===void 0?n:{...n,currentPath:[...n.basePath,n.definitionPath,i]},!1)??sf(n),u=typeof t=="object"&&t.name!==void 0&&t.nameStrategy==="title"?t.name:void 0;u!==void 0&&(a.title=u),n.flags.hasReferencedOpenAiAnyType&&(r||(r={}),r[n.openAiAnyTypeName]||(r[n.openAiAnyTypeName]={type:["string","number","integer","boolean","array","null"],items:{$ref:n.$refStrategy==="relative"?"1":[...n.basePath,n.definitionPath,n.openAiAnyTypeName].join("/")}}));const l=i===void 0?r?{...a,[n.definitionPath]:r}:a:{$ref:[...n.$refStrategy==="relative"?[]:n.basePath,n.definitionPath,i].join("/"),[n.definitionPath]:{...r,[i]:a}};return n.target==="jsonSchema7"?l.$schema="http://json-schema.org/draft-07/schema#":(n.target==="jsonSchema2019-09"||n.target==="openAi")&&(l.$schema="https://json-schema.org/draft/2019-09/schema#"),n.target==="openAi"&&("anyOf"in l||"oneOf"in l||"allOf"in l||"type"in l&&Array.isArray(l.type))&&console.warn("Warning: OpenAI may not support schemas with unions as roots! Try wrapping it in an object property."),l},brt={output:"output",llm:"llm",retrieval:"retrieval",reranker:"reranker",message:"message",document:"document",embedding:"embedding",tool:"tool",tool_call:"tool_call",user:"user"},Ort={provider:"provider",model_name:"model_name",input_messages:"input_messages",output_messages:"output_messages",invocation_parameters:"invocation_parameters",prompts:"prompts",prompt_template:"prompt_template",tools:"tools"},xrt={documents:"documents"},Srt={input_documents:"input_documents",output_documents:"output_documents",query:"query"},_rt={embeddings:"embeddings",text:"text",model_name:"model_name"},Ert={name:"name",description:"description",parameters:"parameters",json_schema:"json_schema"},Drt={role:"role",content:"content",contents:"contents",name:"name",function_call_name:"function_call_name",function_call_arguments_json:"function_call_arguments_json",tool_calls:"tool_calls",tool_call_id:"tool_call_id"},$rt={id:"id",content:"content",score:"score",metadata:"metadata"},Crt={id:"id"};var dU;(function(e){e.LLM="LLM",e.CHAIN="CHAIN",e.TOOL="TOOL",e.RETRIEVER="RETRIEVER",e.RERANKER="RERANKER",e.EMBEDDING="EMBEDDING",e.AGENT="AGENT",e.GUARDRAIL="GUARDRAIL",e.EVALUATOR="EVALUATOR"})(dU||(dU={}));var hU;(function(e){e.TEXT="text/plain",e.JSON="application/json",e.AUDIO_WAV="audio/wav"})(hU||(hU={}));var pU;(function(e){e.OPENAI="openai",e.ANTHROPIC="anthropic",e.MISTRALAI="mistralai",e.COHERE="cohere",e.VERTEXAI="vertexai"})(pU||(pU={}));var mU;(function(e){e.OPENAI="openai",e.ANTHROPIC="anthropic",e.MISTRALAI="mistralai",e.COHERE="cohere",e.GOOGLE="google",e.AWS="aws",e.AZURE="azure"})(mU||(mU={}));function m9(){return m9=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},m9.apply(null,arguments)}var Nee=["shift","alt","meta","mod","ctrl"],eSe={esc:"escape",return:"enter",".":"period",",":"comma","-":"slash"," ":"space","`":"backquote","#":"backslash","+":"bracketright",ShiftLeft:"shift",ShiftRight:"shift",AltLeft:"alt",AltRight:"alt",MetaLeft:"meta",MetaRight:"meta",OSLeft:"meta",OSRight:"meta",ControlLeft:"ctrl",ControlRight:"ctrl"};function Mv(e){return(e&&eSe[e]||e||"").trim().toLowerCase().replace(/key|digit|numpad|arrow/,"")}function tSe(e){return Nee.includes(e)}function IT(e,t){return t===void 0&&(t=","),e.split(t)}function LT(e,t,n){t===void 0&&(t="+");var r=e.toLocaleLowerCase().split(t).map(function(u){return Mv(u)}),i={alt:r.includes("alt"),ctrl:r.includes("ctrl")||r.includes("control"),shift:r.includes("shift"),meta:r.includes("meta"),mod:r.includes("mod")},a=r.filter(function(u){return!Nee.includes(u)});return m9({},i,{keys:a,description:n,hotkey:e})}(function(){typeof document<"u"&&(document.addEventListener("keydown",function(e){e.key!==void 0&&Iee([Mv(e.key),Mv(e.code)])}),document.addEventListener("keyup",function(e){e.key!==void 0&&Lee([Mv(e.key),Mv(e.code)])})),typeof window<"u"&&window.addEventListener("blur",function(){Fv.clear()})})();var Fv=new Set;function rN(e){return Array.isArray(e)}function nSe(e,t){t===void 0&&(t=",");var n=rN(e)?e:e.split(t);return n.every(function(r){return Fv.has(r.trim().toLowerCase())})}function Iee(e){var t=Array.isArray(e)?e:[e];Fv.has("meta")&&Fv.forEach(function(n){return!tSe(n)&&Fv.delete(n.toLowerCase())}),t.forEach(function(n){return Fv.add(n.toLowerCase())})}function Lee(e){var t=Array.isArray(e)?e:[e];e==="meta"?Fv.clear():t.forEach(function(n){return Fv.delete(n.toLowerCase())})}function rSe(e,t,n){(typeof n=="function"&&n(e,t)||n===!0)&&e.preventDefault()}function iSe(e,t,n){return typeof n=="function"?n(e,t):n===!0||n===void 0}function aSe(e){return Bee(e,["input","textarea","select"])}function Bee(e,t){t===void 0&&(t=!1);var n=e.target,r=e.composed,i=null;return uSe(n)&&r?i=e.composedPath()[0]&&e.composedPath()[0].tagName:i=n&&n.tagName,rN(t)?!!(i&&t&&t.some(function(a){var u;return a.toLowerCase()===((u=i)==null?void 0:u.toLowerCase())})):!!(i&&t&&t)}function uSe(e){return!!e.tagName&&!e.tagName.startsWith("-")&&e.tagName.includes("-")}function lSe(e,t){return e.length===0&&t?(console.warn('A hotkey has the "scopes" option set, however no active scopes were found. If you want to use the global scopes feature, you need to wrap your app in a <HotkeysProvider>'),!0):t?e.some(function(n){return t.includes(n)})||e.includes("*"):!0}var oSe=function(t,n,r){r===void 0&&(r=!1);var i=n.alt,a=n.meta,u=n.mod,l=n.shift,o=n.ctrl,s=n.keys,c=t.key,d=t.code,h=t.ctrlKey,m=t.metaKey,y=t.shiftKey,v=t.altKey,_=Mv(d),S=c.toLowerCase();if(!(s!=null&&s.includes(_))&&!(s!=null&&s.includes(S))&&!["ctrl","control","unknown","meta","alt","shift","os"].includes(_))return!1;if(!r){if(i===!v&&S!=="alt"||l===!y&&S!=="shift")return!1;if(u){if(!m&&!h)return!1}else if(a===!m&&S!=="meta"&&S!=="os"||o===!h&&S!=="ctrl"&&S!=="control")return!1}return s&&s.length===1&&(s.includes(S)||s.includes(_))?!0:s?nSe(s):!s},sSe=P.createContext(void 0),cSe=function(){return P.useContext(sSe)};function Qee(e,t){return e&&t&&typeof e=="object"&&typeof t=="object"?Object.keys(e).length===Object.keys(t).length&&Object.keys(e).reduce(function(n,r){return n&&Qee(e[r],t[r])},!0):e===t}var fSe=P.createContext({hotkeys:[],enabledScopes:[],toggleScope:function(){},enableScope:function(){},disableScope:function(){}}),dSe=function(){return P.useContext(fSe)};function hSe(e){var t=P.useRef(void 0);return Qee(t.current,e)||(t.current=e),t.current}var gU=function(t){t.stopPropagation(),t.preventDefault(),t.stopImmediatePropagation()},pSe=typeof window<"u"?P.useLayoutEffect:P.useEffect;function wrt(e,t,n,r){var i=P.useState(null),a=i[0],u=i[1],l=P.useRef(!1),o=n instanceof Array?r instanceof Array?void 0:r:n,s=rN(e)?e.join(o==null?void 0:o.splitKey):e,c=n instanceof Array?n:r instanceof Array?r:void 0,d=P.useCallback(t,c??[]),h=P.useRef(d);c?h.current=d:h.current=t;var m=hSe(o),y=dSe(),v=y.enabledScopes,_=cSe();return pSe(function(){if(!((m==null?void 0:m.enabled)===!1||!lSe(v,m==null?void 0:m.scopes))){var S=function($,k){var F;if(k===void 0&&(k=!1),!(aSe($)&&!Bee($,m==null?void 0:m.enableOnFormTags))){if(a!==null){var L=a.getRootNode();if((L instanceof Document||L instanceof ShadowRoot)&&L.activeElement!==a&&!a.contains(L.activeElement)){gU($);return}}(F=$.target)!=null&&F.isContentEditable&&!(m!=null&&m.enableOnContentEditable)||IT(s,m==null?void 0:m.splitKey).forEach(function(j){var V,q=LT(j,m==null?void 0:m.combinationKey);if(oSe($,q,m==null?void 0:m.ignoreModifiers)||(V=q.keys)!=null&&V.includes("*")){if(m!=null&&m.ignoreEventWhen!=null&&m.ignoreEventWhen($)||k&&l.current)return;if(rSe($,q,m==null?void 0:m.preventDefault),!iSe($,q,m==null?void 0:m.enabled)){gU($);return}h.current($,q),k||(l.current=!0)}})}},E=function($){$.key!==void 0&&(Iee(Mv($.code)),((m==null?void 0:m.keydown)===void 0&&(m==null?void 0:m.keyup)!==!0||m!=null&&m.keydown)&&S($))},C=function($){$.key!==void 0&&(Lee(Mv($.code)),l.current=!1,m!=null&&m.keyup&&S($,!0))},T=a||(o==null?void 0:o.document)||document;return T.addEventListener("keyup",C,o==null?void 0:o.eventListenerOptions),T.addEventListener("keydown",E,o==null?void 0:o.eventListenerOptions),_&&IT(s,m==null?void 0:m.splitKey).forEach(function(R){return _.addHotkey(LT(R,m==null?void 0:m.combinationKey,m==null?void 0:m.description))}),function(){T.removeEventListener("keyup",C,o==null?void 0:o.eventListenerOptions),T.removeEventListener("keydown",E,o==null?void 0:o.eventListenerOptions),_&&IT(s,m==null?void 0:m.splitKey).forEach(function(R){return _.removeHotkey(LT(R,m==null?void 0:m.combinationKey,m==null?void 0:m.description))})}}},[a,s,m,v]),u}const mSe=P.createContext(null);P.createContext(null);const gSe=P.createContext(null);P.createContext(null);P.createContext(null);const zee=P.createContext({}),dx=P.createContext(null),PC=P.createContext(null),qr=typeof document<"u"?ye.useLayoutEffect:()=>{};var BT;const vSe=(BT=ye.useInsertionEffect)!==null&&BT!==void 0?BT:qr;function oi(e){const t=P.useRef(null);return vSe(()=>{t.current=e},[e]),P.useCallback((...n)=>{const r=t.current;return r==null?void 0:r(...n)},[])}function ySe(e){let[t,n]=P.useState(e),r=P.useRef(null),i=oi(()=>{if(!r.current)return;let u=r.current.next();if(u.done){r.current=null;return}t===u.value?i():n(u.value)});qr(()=>{r.current&&i()});let a=oi(u=>{r.current=u(t),i()});return[t,a]}const qee={prefix:String(Math.round(Math.random()*1e10)),current:0},Vee=ye.createContext(qee),bSe=ye.createContext(!1);let QT=new WeakMap;function OSe(e=!1){let t=P.useContext(Vee),n=P.useRef(null);if(n.current===null&&!e){var r,i;let a=(i=ye.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED)===null||i===void 0||(r=i.ReactCurrentOwner)===null||r===void 0?void 0:r.current;if(a){let u=QT.get(a);u==null?QT.set(a,{id:t.current,state:a.memoizedState}):a.memoizedState!==u.state&&(t.current=u.id,QT.delete(a))}n.current=++t.current}return n.current}function xSe(e){let t=P.useContext(Vee),n=OSe(!!e),r=`react-aria${t.prefix}`;return e||`${r}-${n}`}function SSe(e){let t=ye.useId(),[n]=P.useState(hp()),r=n?"react-aria":`react-aria${qee.prefix}`;return e||`${r}-${t}`}const _Se=typeof ye.useId=="function"?SSe:xSe;function ESe(){return!1}function DSe(){return!0}function $Se(e){return()=>{}}function hp(){return typeof ye.useSyncExternalStore=="function"?ye.useSyncExternalStore($Se,ESe,DSe):P.useContext(bSe)}let CSe=!!(typeof window<"u"&&window.document&&window.document.createElement),t3=new Map,T2;typeof FinalizationRegistry<"u"&&(T2=new FinalizationRegistry(e=>{t3.delete(e)}));function pi(e){let[t,n]=P.useState(e),r=P.useRef(null),i=_Se(t),a=P.useRef(null);if(T2&&T2.register(a,i),CSe){const u=t3.get(i);u&&!u.includes(r)?u.push(r):t3.set(i,[r])}return qr(()=>{let u=i;return()=>{T2&&T2.unregister(a),t3.delete(u)}},[i]),P.useEffect(()=>{let u=r.current;return u&&n(u),()=>{u&&(r.current=null)}}),i}function wSe(e,t){if(e===t)return e;let n=t3.get(e);if(n)return n.forEach(i=>i.current=t),t;let r=t3.get(t);return r?(r.forEach(i=>i.current=e),e):t}function C0(e=[]){let t=pi(),[n,r]=ySe(t),i=P.useCallback(()=>{r(function*(){yield t,yield document.getElementById(t)?t:void 0})},[t,r]);return qr(i,[t,i,...e]),n}function rh(...e){return(...t)=>{for(let n of e)typeof n=="function"&&n(...t)}}const ci=e=>{var t;return(t=e==null?void 0:e.ownerDocument)!==null&&t!==void 0?t:document},af=e=>e&&"window"in e&&e.window===e?e:ci(e).defaultView||window;function RSe(e){return e!==null&&typeof e=="object"&&"nodeType"in e&&typeof e.nodeType=="number"}function ASe(e){return RSe(e)&&e.nodeType===Node.DOCUMENT_FRAGMENT_NODE&&"host"in e}let TSe=!1;function MC(){return TSe}function Gc(e,t){if(!MC())return t&&e?e.contains(t):!1;if(!e||!t)return!1;let n=t;for(;n!==null;){if(n===e)return!0;n.tagName==="SLOT"&&n.assignedSlot?n=n.assignedSlot.parentNode:ASe(n)?n=n.host:n=n.parentNode}return!1}const Vu=(e=document)=>{var t;if(!MC())return e.activeElement;let n=e.activeElement;for(;n&&"shadowRoot"in n&&(!((t=n.shadowRoot)===null||t===void 0)&&t.activeElement);)n=n.shadowRoot.activeElement;return n};function qu(e){return MC()&&e.target.shadowRoot&&e.composedPath?e.composedPath()[0]:e.target}class kSe{get currentNode(){return this._currentNode}set currentNode(t){if(!Gc(this.root,t))throw new Error("Cannot set currentNode to a node that is not contained by the root node.");const n=[];let r=t,i=t;for(this._currentNode=t;r&&r!==this.root;)if(r.nodeType===Node.DOCUMENT_FRAGMENT_NODE){const u=r,l=this._doc.createTreeWalker(u,this.whatToShow,{acceptNode:this._acceptNode});n.push(l),l.currentNode=i,this._currentSetFor.add(l),r=i=u.host}else r=r.parentNode;const a=this._doc.createTreeWalker(this.root,this.whatToShow,{acceptNode:this._acceptNode});n.push(a),a.currentNode=i,this._currentSetFor.add(a),this._walkerStack=n}get doc(){return this._doc}firstChild(){let t=this.currentNode,n=this.nextNode();return Gc(t,n)?(n&&(this.currentNode=n),n):(this.currentNode=t,null)}lastChild(){let n=this._walkerStack[0].lastChild();return n&&(this.currentNode=n),n}nextNode(){const t=this._walkerStack[0].nextNode();if(t){if(t.shadowRoot){var n;let i;if(typeof this.filter=="function"?i=this.filter(t):!((n=this.filter)===null||n===void 0)&&n.acceptNode&&(i=this.filter.acceptNode(t)),i===NodeFilter.FILTER_ACCEPT)return this.currentNode=t,t;let a=this.nextNode();return a&&(this.currentNode=a),a}return t&&(this.currentNode=t),t}else if(this._walkerStack.length>1){this._walkerStack.shift();let r=this.nextNode();return r&&(this.currentNode=r),r}else return null}previousNode(){const t=this._walkerStack[0];if(t.currentNode===t.root){if(this._currentSetFor.has(t))if(this._currentSetFor.delete(t),this._walkerStack.length>1){this._walkerStack.shift();let i=this.previousNode();return i&&(this.currentNode=i),i}else return null;return null}const n=t.previousNode();if(n){if(n.shadowRoot){var r;let a;if(typeof this.filter=="function"?a=this.filter(n):!((r=this.filter)===null||r===void 0)&&r.acceptNode&&(a=this.filter.acceptNode(n)),a===NodeFilter.FILTER_ACCEPT)return n&&(this.currentNode=n),n;let u=this.lastChild();return u&&(this.currentNode=u),u}return n&&(this.currentNode=n),n}else if(this._walkerStack.length>1){this._walkerStack.shift();let i=this.previousNode();return i&&(this.currentNode=i),i}else return null}nextSibling(){return null}previousSibling(){return null}parentNode(){return null}constructor(t,n,r,i){this._walkerStack=[],this._currentSetFor=new Set,this._acceptNode=u=>{if(u.nodeType===Node.ELEMENT_NODE){const o=u.shadowRoot;if(o){const s=this._doc.createTreeWalker(o,this.whatToShow,{acceptNode:this._acceptNode});return this._walkerStack.unshift(s),NodeFilter.FILTER_ACCEPT}else{var l;if(typeof this.filter=="function")return this.filter(u);if(!((l=this.filter)===null||l===void 0)&&l.acceptNode)return this.filter.acceptNode(u);if(this.filter===null)return NodeFilter.FILTER_ACCEPT}}return NodeFilter.FILTER_SKIP},this._doc=t,this.root=n,this.filter=i??null,this.whatToShow=r??NodeFilter.SHOW_ALL,this._currentNode=n,this._walkerStack.unshift(t.createTreeWalker(n,r,this._acceptNode));const a=n.shadowRoot;if(a){const u=this._doc.createTreeWalker(a,this.whatToShow,{acceptNode:this._acceptNode});this._walkerStack.unshift(u)}}}function PSe(e,t,n,r){return MC()?new kSe(e,t,n,r):e.createTreeWalker(t,n,r)}function Uee(e){var t,n,r="";if(typeof e=="string"||typeof e=="number")r+=e;else if(typeof e=="object")if(Array.isArray(e)){var i=e.length;for(t=0;t<i;t++)e[t]&&(n=Uee(e[t]))&&(r&&(r+=" "),r+=n)}else for(n in e)e[n]&&(r&&(r+=" "),r+=n);return r}function MSe(){for(var e,t,n=0,r="",i=arguments.length;n<i;n++)(e=arguments[n])&&(t=Uee(e))&&(r&&(r+=" "),r+=t);return r}function Et(...e){let t={...e[0]};for(let n=1;n<e.length;n++){let r=e[n];for(let i in r){let a=t[i],u=r[i];typeof a=="function"&&typeof u=="function"&&i[0]==="o"&&i[1]==="n"&&i.charCodeAt(2)>=65&&i.charCodeAt(2)<=90?t[i]=rh(a,u):(i==="className"||i==="UNSAFE_className")&&typeof a=="string"&&typeof u=="string"?t[i]=MSe(a,u):i==="id"&&a&&u?t.id=wSe(a,u):t[i]=u!==void 0?u:a}}return t}function vg(...e){return e.length===1&&e[0]?e[0]:t=>{let n=!1;const r=e.map(i=>{const a=vU(i,t);return n||(n=typeof a=="function"),a});if(n)return()=>{r.forEach((i,a)=>{typeof i=="function"?i():vU(e[a],null)})}}}function vU(e,t){if(typeof e=="function")return e(t);e!=null&&(e.current=t)}const FSe=new Set(["id"]),NSe=new Set(["aria-label","aria-labelledby","aria-describedby","aria-details"]),ISe=new Set(["href","hrefLang","target","rel","download","ping","referrerPolicy"]),LSe=new Set(["dir","lang","hidden","inert","translate"]),yU=new Set(["onClick","onAuxClick","onContextMenu","onDoubleClick","onMouseDown","onMouseEnter","onMouseLeave","onMouseMove","onMouseOut","onMouseOver","onMouseUp","onTouchCancel","onTouchEnd","onTouchMove","onTouchStart","onPointerDown","onPointerMove","onPointerUp","onPointerCancel","onPointerEnter","onPointerLeave","onPointerOver","onPointerOut","onGotPointerCapture","onLostPointerCapture","onScroll","onWheel","onAnimationStart","onAnimationEnd","onAnimationIteration","onTransitionCancel","onTransitionEnd","onTransitionRun","onTransitionStart"]),BSe=/^(data-.*)$/;function Gt(e,t={}){let{labelable:n,isLink:r,global:i,events:a=i,propNames:u}=t,l={};for(const o in e)Object.prototype.hasOwnProperty.call(e,o)&&(FSe.has(o)||n&&NSe.has(o)||r&&ISe.has(o)||i&&LSe.has(o)||a&&yU.has(o)||o.endsWith("Capture")&&yU.has(o.slice(0,-7))||u!=null&&u.has(o)||BSe.test(o))&&(l[o]=e[o]);return l}function _u(e){if(QSe())e.focus({preventScroll:!0});else{let t=zSe(e);e.focus(),qSe(t)}}let M_=null;function QSe(){if(M_==null){M_=!1;try{document.createElement("div").focus({get preventScroll(){return M_=!0,!0}})}catch{}}return M_}function zSe(e){let t=e.parentNode,n=[],r=document.scrollingElement||document.documentElement;for(;t instanceof HTMLElement&&t!==r;)(t.offsetHeight<t.scrollHeight||t.offsetWidth<t.scrollWidth)&&n.push({element:t,scrollTop:t.scrollTop,scrollLeft:t.scrollLeft}),t=t.parentNode;return r instanceof HTMLElement&&n.push({element:r,scrollTop:r.scrollTop,scrollLeft:r.scrollLeft}),n}function qSe(e){for(let{element:t,scrollTop:n,scrollLeft:r}of e)t.scrollTop=n,t.scrollLeft=r}function FC(e){var t;if(typeof window>"u"||window.navigator==null)return!1;let n=(t=window.navigator.userAgentData)===null||t===void 0?void 0:t.brands;return Array.isArray(n)&&n.some(r=>e.test(r.brand))||e.test(window.navigator.userAgent)}function iN(e){var t;return typeof window<"u"&&window.navigator!=null?e.test(((t=window.navigator.userAgentData)===null||t===void 0?void 0:t.platform)||window.navigator.platform):!1}function yg(e){let t=null;return()=>(t==null&&(t=e()),t)}const sg=yg(function(){return iN(/^Mac/i)}),jee=yg(function(){return iN(/^iPhone/i)}),Zee=yg(function(){return iN(/^iPad/i)||sg()&&navigator.maxTouchPoints>1}),Db=yg(function(){return jee()||Zee()}),jE=yg(function(){return sg()||Db()}),aN=yg(function(){return FC(/AppleWebKit/i)&&!uN()}),uN=yg(function(){return FC(/Chrome/i)}),uS=yg(function(){return FC(/Android/i)}),VSe=yg(function(){return FC(/Firefox/i)}),USe=P.createContext({isNative:!0,open:HSe,useHref:e=>e});function Z3(){return P.useContext(USe)}function jSe(e,t){let n=e.getAttribute("target");return(!n||n==="_self")&&e.origin===location.origin&&!e.hasAttribute("download")&&!t.metaKey&&!t.ctrlKey&&!t.altKey&&!t.shiftKey}function ib(e,t,n=!0){var r,i;let{metaKey:a,ctrlKey:u,altKey:l,shiftKey:o}=t;VSe()&&(!((i=window.event)===null||i===void 0||(r=i.type)===null||r===void 0)&&r.startsWith("key"))&&e.target==="_blank"&&(sg()?a=!0:u=!0);let s=aN()&&sg()&&!Zee()?new KeyboardEvent("keydown",{keyIdentifier:"Enter",metaKey:a,ctrlKey:u,altKey:l,shiftKey:o}):new MouseEvent("click",{metaKey:a,ctrlKey:u,altKey:l,shiftKey:o,bubbles:!0,cancelable:!0});ib.isOpening=n,_u(e),e.dispatchEvent(s),ib.isOpening=!1}ib.isOpening=!1;function ZSe(e,t){if(e instanceof HTMLAnchorElement)t(e);else if(e.hasAttribute("data-href")){let n=document.createElement("a");n.href=e.getAttribute("data-href"),e.hasAttribute("data-target")&&(n.target=e.getAttribute("data-target")),e.hasAttribute("data-rel")&&(n.rel=e.getAttribute("data-rel")),e.hasAttribute("data-download")&&(n.download=e.getAttribute("data-download")),e.hasAttribute("data-ping")&&(n.ping=e.getAttribute("data-ping")),e.hasAttribute("data-referrer-policy")&&(n.referrerPolicy=e.getAttribute("data-referrer-policy")),e.appendChild(n),t(n),e.removeChild(n)}}function HSe(e,t){ZSe(e,n=>ib(n,t))}function Hee(e){let t=Z3();var n;const r=t.useHref((n=e.href)!==null&&n!==void 0?n:"");return{"data-href":e.href?r:void 0,"data-target":e.target,"data-rel":e.rel,"data-download":e.download,"data-ping":e.ping,"data-referrer-policy":e.referrerPolicy}}function lN(e){let t=Z3();var n;const r=t.useHref((n=e==null?void 0:e.href)!==null&&n!==void 0?n:"");return{href:e!=null&&e.href?r:void 0,target:e==null?void 0:e.target,rel:e==null?void 0:e.rel,download:e==null?void 0:e.download,ping:e==null?void 0:e.ping,referrerPolicy:e==null?void 0:e.referrerPolicy}}function XSe(e,t,n,r){!t.isNative&&e.currentTarget instanceof HTMLAnchorElement&&e.currentTarget.href&&!e.isDefaultPrevented()&&jSe(e.currentTarget,e)&&n&&(e.preventDefault(),t.open(e.currentTarget,e,n,r))}let wv=new Map,g9=new Set;function bU(){if(typeof window>"u")return;function e(r){return"propertyName"in r}let t=r=>{if(!e(r)||!r.target)return;let i=wv.get(r.target);i||(i=new Set,wv.set(r.target,i),r.target.addEventListener("transitioncancel",n,{once:!0})),i.add(r.propertyName)},n=r=>{if(!e(r)||!r.target)return;let i=wv.get(r.target);if(i&&(i.delete(r.propertyName),i.size===0&&(r.target.removeEventListener("transitioncancel",n),wv.delete(r.target)),wv.size===0)){for(let a of g9)a();g9.clear()}};document.body.addEventListener("transitionrun",t),document.body.addEventListener("transitionend",n)}typeof document<"u"&&(document.readyState!=="loading"?bU():document.addEventListener("DOMContentLoaded",bU));function YSe(){for(const[e]of wv)"isConnected"in e&&!e.isConnected&&wv.delete(e)}function Xee(e){requestAnimationFrame(()=>{YSe(),wv.size===0?e():g9.add(e)})}function py(){let e=P.useRef(new Map),t=P.useCallback((i,a,u,l)=>{let o=l!=null&&l.once?(...s)=>{e.current.delete(u),u(...s)}:u;e.current.set(u,{type:a,eventTarget:i,fn:o,options:l}),i.addEventListener(a,o,l)},[]),n=P.useCallback((i,a,u,l)=>{var o;let s=((o=e.current.get(u))===null||o===void 0?void 0:o.fn)||u;i.removeEventListener(a,s,l),e.current.delete(u)},[]),r=P.useCallback(()=>{e.current.forEach((i,a)=>{n(i.eventTarget,i.type,a,i.options)})},[n]);return P.useEffect(()=>r,[r]),{addGlobalListener:t,removeGlobalListener:n,removeAllGlobalListeners:r}}function Yv(e,t){let{id:n,"aria-label":r,"aria-labelledby":i}=e;return n=pi(n),i&&r?i=[...new Set([n,...i.trim().split(/\s+/)])].join(" "):i&&(i=i.trim().split(/\s+/).join(" ")),!r&&!i&&t&&(r=t),{id:n,"aria-label":r,"aria-labelledby":i}}function $u(e){const t=P.useRef(null),n=P.useRef(void 0),r=P.useCallback(i=>{if(typeof e=="function"){const a=e,u=a(i);return()=>{typeof u=="function"?u():a(null)}}else if(e)return e.current=i,()=>{e.current=null}},[e]);return P.useMemo(()=>({get current(){return t.current},set current(i){t.current=i,n.current&&(n.current(),n.current=void 0),i!=null&&(n.current=r(i))}}),[r])}function Yee(e,t){const n=P.useRef(!0),r=P.useRef(null);P.useEffect(()=>(n.current=!0,()=>{n.current=!1}),[]),P.useEffect(()=>{let i=r.current;n.current?n.current=!1:(!i||t.some((a,u)=>!Object.is(a,i[u])))&&e(),r.current=t},t)}function OU(e,t){const n=P.useRef(!0),r=P.useRef(null);qr(()=>(n.current=!0,()=>{n.current=!1}),[]),qr(()=>{n.current?n.current=!1:(!r.current||t.some((i,a)=>!Object.is(i,r[a])))&&e(),r.current=t},t)}function GSe(){return typeof window.ResizeObserver<"u"}function ab(e){const{ref:t,box:n,onResize:r}=e;P.useEffect(()=>{let i=t==null?void 0:t.current;if(i)if(GSe()){const a=new window.ResizeObserver(u=>{u.length&&r()});return a.observe(i,{box:n}),()=>{i&&a.unobserve(i)}}else return window.addEventListener("resize",r,!1),()=>{window.removeEventListener("resize",r,!1)}},[r,t,n])}function oN(e,t){qr(()=>{if(e&&e.ref&&t)return e.ref.current=t.current,()=>{e.ref&&(e.ref.current=null)}})}function ub(e,t){if(!e)return!1;let n=window.getComputedStyle(e),r=/(auto|scroll)/.test(n.overflow+n.overflowX+n.overflowY);return r&&t&&(r=e.scrollHeight!==e.clientHeight||e.scrollWidth!==e.clientWidth),r}function g0(e,t){let n=e;for(ub(n,t)&&(n=n.parentElement);n&&!ub(n,t);)n=n.parentElement;return n||document.scrollingElement||document.documentElement}function KSe(e,t){const n=[];for(;e&&e!==document.documentElement;)ub(e,t)&&n.push(e),e=e.parentElement;return n}function T1(e){return sg()?e.metaKey:e.ctrlKey}const WSe=new Set(["checkbox","radio","range","color","file","image","button","submit","reset"]);function q2(e){return e instanceof HTMLInputElement&&!WSe.has(e.type)||e instanceof HTMLTextAreaElement||e instanceof HTMLElement&&e.isContentEditable}let Wc=typeof document<"u"&&window.visualViewport;function JSe(){let e=hp(),[t,n]=P.useState(()=>e?{width:0,height:0}:xU());return P.useEffect(()=>{let r=()=>{Wc&&Wc.scale>1||n(u=>{let l=xU();return l.width===u.width&&l.height===u.height?u:l})},i,a=u=>{Wc&&Wc.scale>1||q2(u.target)&&(i=requestAnimationFrame(()=>{(!document.activeElement||!q2(document.activeElement))&&n(l=>{let o={width:window.innerWidth,height:window.innerHeight};return o.width===l.width&&o.height===l.height?l:o})}))};return window.addEventListener("blur",a,!0),Wc?Wc.addEventListener("resize",r):window.addEventListener("resize",r),()=>{cancelAnimationFrame(i),window.removeEventListener("blur",a,!0),Wc?Wc.removeEventListener("resize",r):window.removeEventListener("resize",r)}},[]),t}function xU(){return{width:Wc?Wc.width*Wc.scale:window.innerWidth,height:Wc?Wc.height*Wc.scale:window.innerHeight}}let e_e=0;const zT=new Map;function NC(e){let[t,n]=P.useState();return qr(()=>{if(!e)return;let r=zT.get(e);if(r)n(r.element.id);else{let i=`react-aria-description-${e_e++}`;n(i);let a=document.createElement("div");a.id=i,a.style.display="none",a.textContent=e,document.body.appendChild(a),r={refCount:0,element:a},zT.set(e,r)}return r.refCount++,()=>{r&&--r.refCount===0&&(r.element.remove(),zT.delete(e))}},[e]),{"aria-describedby":e?t:void 0}}function Xd(e,t,n,r){let i=oi(n),a=n==null;P.useEffect(()=>{if(a||!e.current)return;let u=e.current;return u.addEventListener(t,i,r),()=>{u.removeEventListener(t,i,r)}},[e,t,r,a,i])}function Gee(e,t){let n=SU(e,t,"left"),r=SU(e,t,"top"),i=t.offsetWidth,a=t.offsetHeight,u=e.scrollLeft,l=e.scrollTop,{borderTopWidth:o,borderLeftWidth:s,scrollPaddingTop:c,scrollPaddingRight:d,scrollPaddingBottom:h,scrollPaddingLeft:m}=getComputedStyle(e),{scrollMarginTop:y,scrollMarginRight:v,scrollMarginBottom:_,scrollMarginLeft:S}=getComputedStyle(t),E=u+parseInt(s,10),C=l+parseInt(o,10),T=E+e.clientWidth,R=C+e.clientHeight,$=parseInt(c,10)||0,k=parseInt(h,10)||0,F=parseInt(d,10)||0,L=parseInt(m,10)||0,j=parseInt(y,10)||0,V=parseInt(_,10)||0,q=parseInt(v,10)||0,N=parseInt(S,10)||0,U=n-N,W=n+i+q,G=r-j,J=r+a+V,te=u+parseInt(s,10)+L,H=T-F,M=l+parseInt(o,10)+$,K=R-k;(U>te||W<H)&&(U<=u+L?u=U-parseInt(s,10)-L:W>T-F&&(u+=W-T+F)),(G>M||J<K)&&(G<=C+$?l=G-parseInt(o,10)-$:J>R-k&&(l+=J-R+k)),e.scrollTo({left:u,top:l})}function SU(e,t,n){const r=n==="left"?"offsetLeft":"offsetTop";let i=0;for(;t.offsetParent&&(i+=t[r],t.offsetParent!==e);){if(t.offsetParent.contains(e)){i-=e[r];break}t=t.offsetParent}return i}function Vm(e,t){if(e&&document.contains(e)){let u=document.scrollingElement||document.documentElement;if(!(window.getComputedStyle(u).overflow==="hidden")&&!uN()){var n;let{left:o,top:s}=e.getBoundingClientRect();e==null||(n=e.scrollIntoView)===null||n===void 0||n.call(e,{block:"nearest"});let{left:c,top:d}=e.getBoundingClientRect();if(Math.abs(o-c)>1||Math.abs(s-d)>1){var r,i,a;t==null||(i=t.containingElement)===null||i===void 0||(r=i.scrollIntoView)===null||r===void 0||r.call(i,{block:"center",inline:"center"}),(a=e.scrollIntoView)===null||a===void 0||a.call(e,{block:"nearest"})}}else{let o=KSe(e);for(let s of o)Gee(s,e)}}}function Kee(e){return e.pointerType===""&&e.isTrusted?!0:uS()&&e.pointerType?e.type==="click"&&e.buttons===1:e.detail===0&&!e.pointerType}function t_e(e){return!uS()&&e.width===0&&e.height===0||e.width===1&&e.height===1&&e.pressure===0&&e.detail===0&&e.pointerType==="mouse"}function n_e(e,t){let n=P.useRef(null);return e&&n.current&&t(e,n.current)&&(e=n.current),n.current=e,e}function my(e,t,n){let r=oi(()=>{n&&n(t)});P.useEffect(()=>{var i;let a=e==null||(i=e.current)===null||i===void 0?void 0:i.form;return a==null||a.addEventListener("reset",r),()=>{a==null||a.removeEventListener("reset",r)}},[e,r])}function r_e(e,t){let{collection:n,onLoadMore:r,scrollOffset:i=1}=e,a=P.useRef(null),u=oi(l=>{for(let o of l)o.isIntersecting&&r&&r()});qr(()=>(t.current&&(a.current=new IntersectionObserver(u,{root:g0(t==null?void 0:t.current),rootMargin:`0px ${100*i}% ${100*i}% ${100*i}%`}),a.current.observe(t.current)),()=>{a.current&&a.current.disconnect()}),[n,u,t,i])}function v9(e){const t=P.version.split(".");return parseInt(t[0],10)>=19?e:e?"true":void 0}const Wee="react-aria-clear-focus",y9="react-aria-focus";var Vf=OJ();const Jee=sa(Vf);function IC(e,t=!0){let[n,r]=P.useState(!0),i=n&&t;return qr(()=>{if(i&&e.current&&"getAnimations"in e.current)for(let a of e.current.getAnimations())a instanceof CSSTransition&&a.cancel()},[e,i]),ete(e,i,P.useCallback(()=>r(!1),[])),i}function QD(e,t){let[n,r]=P.useState(t?"open":"closed");switch(n){case"open":t||r("exiting");break;case"closed":case"exiting":t&&r("open");break}let i=n==="exiting";return ete(e,i,P.useCallback(()=>{r(a=>a==="exiting"?"closed":a)},[])),i}function ete(e,t,n){qr(()=>{if(t&&e.current){if(!("getAnimations"in e.current)){n();return}let r=e.current.getAnimations();if(r.length===0){n();return}let i=!1;return Promise.all(r.map(a=>a.finished)).then(()=>{i||Vf.flushSync(()=>{n()})}).catch(()=>{}),()=>{i=!0}}},[e,t,n])}const i_e=typeof Element<"u"&&"checkVisibility"in Element.prototype;function a_e(e){const t=af(e);if(!(e instanceof t.HTMLElement)&&!(e instanceof t.SVGElement))return!1;let{display:n,visibility:r}=e.style,i=n!=="none"&&r!=="hidden"&&r!=="collapse";if(i){const{getComputedStyle:a}=e.ownerDocument.defaultView;let{display:u,visibility:l}=a(e);i=u!=="none"&&l!=="hidden"&&l!=="collapse"}return i}function u_e(e,t){return!e.hasAttribute("hidden")&&!e.hasAttribute("data-react-aria-prevent-focus")&&(e.nodeName==="DETAILS"&&t&&t.nodeName!=="SUMMARY"?e.hasAttribute("open"):!0)}function sN(e,t){return i_e?e.checkVisibility({visibilityProperty:!0})&&!e.closest("[data-react-aria-prevent-focus]"):e.nodeName!=="#comment"&&a_e(e)&&u_e(e,t)&&(!e.parentElement||sN(e.parentElement,e))}const cN=["input:not([disabled]):not([type=hidden])","select:not([disabled])","textarea:not([disabled])","button:not([disabled])","a[href]","area[href]","summary","iframe","object","embed","audio[controls]","video[controls]",'[contenteditable]:not([contenteditable^="false"])',"permission"],l_e=cN.join(":not([hidden]),")+",[tabindex]:not([disabled]):not([hidden])";cN.push('[tabindex]:not([tabindex="-1"]):not([disabled])');const o_e=cN.join(':not([hidden]):not([tabindex="-1"]),');function tte(e){return e.matches(l_e)&&sN(e)&&!nte(e)}function s_e(e){return e.matches(o_e)&&sN(e)&&!nte(e)}function nte(e){let t=e;for(;t!=null;){if(t instanceof t.ownerDocument.defaultView.HTMLElement&&t.inert)return!0;t=t.parentElement}return!1}function Zu(e,t,n){let[r,i]=P.useState(e||t),a=P.useRef(e!==void 0),u=e!==void 0;P.useEffect(()=>{a.current,a.current=u},[u]);let l=u?e:r,o=P.useCallback((s,...c)=>{let d=(h,...m)=>{n&&(Object.is(l,h)||n(h,...m)),u||(l=h)};typeof s=="function"?i((m,...y)=>{let v=s(u?l:m,...y);return d(v,...c),u?m:v}):(u||i(s),d(s,...c))},[u,l,n]);return[l,o]}function ro(e,t=-1/0,n=1/0){return Math.min(Math.max(e,t),n)}function F_(e,t){let n=e,r=0,i=t.toString(),a=i.toLowerCase().indexOf("e-");if(a>0)r=Math.abs(Math.floor(Math.log10(Math.abs(t))))+a;else{let u=i.indexOf(".");u>=0&&(r=i.length-u)}if(r>0){let u=Math.pow(10,r);n=Math.round(n*u)/u}return n}function Kc(e,t,n,r){t=Number(t),n=Number(n);let i=(e-(isNaN(t)?0:t))%r,a=F_(Math.abs(i)*2>=r?e+Math.sign(i)*(r-Math.abs(i)):e-i,r);return isNaN(t)?!isNaN(n)&&a>n&&(a=Math.floor(F_(n/r,r))*r):a<t?a=t:!isNaN(n)&&a>n&&(a=t+Math.floor(F_((n-t)/r,r))*r),a=F_(a,r),a}function ml(e,t,n=10){const r=Math.pow(n,t);return Math.round(e*r)/r}const Gv=Symbol("default");function ki({values:e,children:t}){for(let[n,r]of e)t=ye.createElement(n.Provider,{value:r},t);return t}function wn(e){let{className:t,style:n,children:r,defaultClassName:i,defaultChildren:a,defaultStyle:u,values:l}=e;return P.useMemo(()=>{let o,s,c;return typeof t=="function"?o=t({...l,defaultClassName:i}):o=t,typeof n=="function"?s=n({...l,defaultStyle:u||{}}):s=n,typeof r=="function"?c=r({...l,defaultChildren:a}):r==null?c=a:c=r,{className:o??i,style:s||u?{...u,...s}:void 0,children:c??a,"data-rac":""}},[t,n,r,i,a,u,l])}function c_e(e,t){return n=>t(typeof e=="function"?e(n):e,n)}function vs(e,t){let n=P.useContext(e);if(t===null)return null;if(n&&typeof n=="object"&&"slots"in n&&n.slots){let r=t||Gv;if(!n.slots[r]){let i=new Intl.ListFormat().format(Object.keys(n.slots).map(u=>`"${u}"`)),a=t?`Invalid slot "${t}".`:"A slot prop is required.";throw new Error(`${a} Valid slot names are ${i}.`)}return n.slots[r]}return n}function In(e,t,n){let r=vs(n,e.slot)||{},{ref:i,...a}=r,u=$u(P.useMemo(()=>vg(t,i),[t,i])),l=Et(a,e);return"style"in a&&a.style&&"style"in e&&e.style&&(typeof a.style=="function"||typeof e.style=="function"?l.style=o=>{let s=typeof a.style=="function"?a.style(o):a.style,c={...o.defaultStyle,...s},d=typeof e.style=="function"?e.style({...o,defaultStyle:c}):e.style;return{...c,...d}}:l.style={...a.style,...e.style}),[l,u]}function ys(e=!0){let[t,n]=P.useState(e),r=P.useRef(!1),i=P.useCallback(a=>{r.current=!0,n(!!a)},[]);return qr(()=>{r.current||n(!1)},[]),[i,t]}function dc(e){const t=/^(data-.*)$/;let n={};for(const r in e)t.test(r)||(n[r]=e[r]);return n}var rte={};rte={buttonLabel:"عرض المقترحات",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} خيار`,other:()=>`${t.number(e.optionCount)} خيارات`})} متاحة.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`المجموعة المدخلة ${e.groupTitle}, مع ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} خيار`,other:()=>`${t.number(e.groupCount)} خيارات`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", محدد",other:""},e.isSelected)}`,listboxLabel:"مقترحات",selectedAnnouncement:e=>`${e.optionText}، محدد`};var ite={};ite={buttonLabel:"Покажи предложения",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} опция`,other:()=>`${t.number(e.optionCount)} опции`})} на разположение.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Въведена група ${e.groupTitle}, с ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} опция`,other:()=>`${t.number(e.groupCount)} опции`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", избрани",other:""},e.isSelected)}`,listboxLabel:"Предложения",selectedAnnouncement:e=>`${e.optionText}, избрани`};var ate={};ate={buttonLabel:"Zobrazit doporučení",countAnnouncement:(e,t)=>`K dispozici ${t.plural(e.optionCount,{one:()=>`je ${t.number(e.optionCount)} možnost`,other:()=>`jsou/je ${t.number(e.optionCount)} možnosti/-í`})}.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Zadaná skupina „${e.groupTitle}“ ${t.plural(e.groupCount,{one:()=>`s ${t.number(e.groupCount)} možností`,other:()=>`se ${t.number(e.groupCount)} možnostmi`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:" (vybráno)",other:""},e.isSelected)}`,listboxLabel:"Návrhy",selectedAnnouncement:e=>`${e.optionText}, vybráno`};var ute={};ute={buttonLabel:"Vis forslag",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} mulighed tilgængelig`,other:()=>`${t.number(e.optionCount)} muligheder tilgængelige`})}.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Angivet gruppe ${e.groupTitle}, med ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} mulighed`,other:()=>`${t.number(e.groupCount)} muligheder`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", valgt",other:""},e.isSelected)}`,listboxLabel:"Forslag",selectedAnnouncement:e=>`${e.optionText}, valgt`};var lte={};lte={buttonLabel:"Empfehlungen anzeigen",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} Option`,other:()=>`${t.number(e.optionCount)} Optionen`})} verfügbar.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Eingetretene Gruppe ${e.groupTitle}, mit ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} Option`,other:()=>`${t.number(e.groupCount)} Optionen`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", ausgewählt",other:""},e.isSelected)}`,listboxLabel:"Empfehlungen",selectedAnnouncement:e=>`${e.optionText}, ausgewählt`};var ote={};ote={buttonLabel:"Προβολή προτάσεων",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} επιλογή`,other:()=>`${t.number(e.optionCount)} επιλογές `})} διαθέσιμες.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Εισαγμένη ομάδα ${e.groupTitle}, με ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} επιλογή`,other:()=>`${t.number(e.groupCount)} επιλογές`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", επιλεγμένο",other:""},e.isSelected)}`,listboxLabel:"Προτάσεις",selectedAnnouncement:e=>`${e.optionText}, επιλέχθηκε`};var ste={};ste={focusAnnouncement:(e,t)=>`${t.select({true:()=>`Entered group ${e.groupTitle}, with ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} option`,other:()=>`${t.number(e.groupCount)} options`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", selected",other:""},e.isSelected)}`,countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} option`,other:()=>`${t.number(e.optionCount)} options`})} available.`,selectedAnnouncement:e=>`${e.optionText}, selected`,buttonLabel:"Show suggestions",listboxLabel:"Suggestions"};var cte={};cte={buttonLabel:"Mostrar sugerencias",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} opción`,other:()=>`${t.number(e.optionCount)} opciones`})} disponible(s).`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Se ha unido al grupo ${e.groupTitle}, con ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} opción`,other:()=>`${t.number(e.groupCount)} opciones`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", seleccionado",other:""},e.isSelected)}`,listboxLabel:"Sugerencias",selectedAnnouncement:e=>`${e.optionText}, seleccionado`};var fte={};fte={buttonLabel:"Kuva soovitused",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} valik`,other:()=>`${t.number(e.optionCount)} valikud`})} saadaval.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Sisestatud rühm ${e.groupTitle}, valikuga ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} valik`,other:()=>`${t.number(e.groupCount)} valikud`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", valitud",other:""},e.isSelected)}`,listboxLabel:"Soovitused",selectedAnnouncement:e=>`${e.optionText}, valitud`};var dte={};dte={buttonLabel:"Näytä ehdotukset",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} vaihtoehto`,other:()=>`${t.number(e.optionCount)} vaihtoehdot`})} saatavilla.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Mentiin ryhmään ${e.groupTitle}, ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} vaihtoehdon`,other:()=>`${t.number(e.groupCount)} vaihtoehdon`})} kanssa.`,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", valittu",other:""},e.isSelected)}`,listboxLabel:"Ehdotukset",selectedAnnouncement:e=>`${e.optionText}, valittu`};var hte={};hte={buttonLabel:"Afficher les suggestions",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} option`,other:()=>`${t.number(e.optionCount)} options`})} disponible(s).`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Groupe ${e.groupTitle} rejoint, avec ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} option`,other:()=>`${t.number(e.groupCount)} options`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", sélectionné(s)",other:""},e.isSelected)}`,listboxLabel:"Suggestions",selectedAnnouncement:e=>`${e.optionText}, sélectionné`};var pte={};pte={buttonLabel:"הצג הצעות",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`אפשרות ${t.number(e.optionCount)}`,other:()=>`${t.number(e.optionCount)} אפשרויות`})} במצב זמין.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`נכנס לקבוצה ${e.groupTitle}, עם ${t.plural(e.groupCount,{one:()=>`אפשרות ${t.number(e.groupCount)}`,other:()=>`${t.number(e.groupCount)} אפשרויות`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", נבחר",other:""},e.isSelected)}`,listboxLabel:"הצעות",selectedAnnouncement:e=>`${e.optionText}, נבחר`};var mte={};mte={buttonLabel:"Prikaži prijedloge",countAnnouncement:(e,t)=>`Dostupno još: ${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} opcija`,other:()=>`${t.number(e.optionCount)} opcije/a`})}.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Unesena skupina ${e.groupTitle}, s ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} opcijom`,other:()=>`${t.number(e.groupCount)} opcije/a`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", odabranih",other:""},e.isSelected)}`,listboxLabel:"Prijedlozi",selectedAnnouncement:e=>`${e.optionText}, odabrano`};var gte={};gte={buttonLabel:"Javaslatok megjelenítése",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} lehetőség`,other:()=>`${t.number(e.optionCount)} lehetőség`})} áll rendelkezésre.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Belépett a(z) ${e.groupTitle} csoportba, amely ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} lehetőséget`,other:()=>`${t.number(e.groupCount)} lehetőséget`})} tartalmaz. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", kijelölve",other:""},e.isSelected)}`,listboxLabel:"Javaslatok",selectedAnnouncement:e=>`${e.optionText}, kijelölve`};var vte={};vte={buttonLabel:"Mostra suggerimenti",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} opzione disponibile`,other:()=>`${t.number(e.optionCount)} opzioni disponibili`})}.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Ingresso nel gruppo ${e.groupTitle}, con ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} opzione`,other:()=>`${t.number(e.groupCount)} opzioni`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", selezionato",other:""},e.isSelected)}`,listboxLabel:"Suggerimenti",selectedAnnouncement:e=>`${e.optionText}, selezionato`};var yte={};yte={buttonLabel:"候補を表示",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} 個のオプション`,other:()=>`${t.number(e.optionCount)} 個のオプション`})}を利用できます。`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`入力されたグループ ${e.groupTitle}、${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} 個のオプション`,other:()=>`${t.number(e.groupCount)} 個のオプション`})}を含む。`,other:""},e.isGroupChange)}${e.optionText}${t.select({true:"、選択済み",other:""},e.isSelected)}`,listboxLabel:"候補",selectedAnnouncement:e=>`${e.optionText}、選択済み`};var bte={};bte={buttonLabel:"제안 사항 표시",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)}개 옵션`,other:()=>`${t.number(e.optionCount)}개 옵션`})}을 사용할 수 있습니다.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`입력한 그룹 ${e.groupTitle}, ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)}개 옵션`,other:()=>`${t.number(e.groupCount)}개 옵션`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", 선택됨",other:""},e.isSelected)}`,listboxLabel:"제안",selectedAnnouncement:e=>`${e.optionText}, 선택됨`};var Ote={};Ote={buttonLabel:"Rodyti pasiūlymus",countAnnouncement:(e,t)=>`Yra ${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} parinktis`,other:()=>`${t.number(e.optionCount)} parinktys (-ių)`})}.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Įvesta grupė ${e.groupTitle}, su ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} parinktimi`,other:()=>`${t.number(e.groupCount)} parinktimis (-ių)`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", pasirinkta",other:""},e.isSelected)}`,listboxLabel:"Pasiūlymai",selectedAnnouncement:e=>`${e.optionText}, pasirinkta`};var xte={};xte={buttonLabel:"Rādīt ieteikumus",countAnnouncement:(e,t)=>`Pieejamo opciju skaits: ${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} opcija`,other:()=>`${t.number(e.optionCount)} opcijas`})}.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Ievadīta grupa ${e.groupTitle}, ar ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} opciju`,other:()=>`${t.number(e.groupCount)} opcijām`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", atlasīta",other:""},e.isSelected)}`,listboxLabel:"Ieteikumi",selectedAnnouncement:e=>`${e.optionText}, atlasīta`};var Ste={};Ste={buttonLabel:"Vis forslag",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} alternativ`,other:()=>`${t.number(e.optionCount)} alternativer`})} finnes.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Angitt gruppe ${e.groupTitle}, med ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} alternativ`,other:()=>`${t.number(e.groupCount)} alternativer`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", valgt",other:""},e.isSelected)}`,listboxLabel:"Forslag",selectedAnnouncement:e=>`${e.optionText}, valgt`};var _te={};_te={buttonLabel:"Suggesties weergeven",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} optie`,other:()=>`${t.number(e.optionCount)} opties`})} beschikbaar.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Groep ${e.groupTitle} ingevoerd met ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} optie`,other:()=>`${t.number(e.groupCount)} opties`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", geselecteerd",other:""},e.isSelected)}`,listboxLabel:"Suggesties",selectedAnnouncement:e=>`${e.optionText}, geselecteerd`};var Ete={};Ete={buttonLabel:"Wyświetlaj sugestie",countAnnouncement:(e,t)=>`dostępna/dostępne(-nych) ${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} opcja`,other:()=>`${t.number(e.optionCount)} opcje(-i)`})}.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Dołączono do grupy ${e.groupTitle}, z ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} opcją`,other:()=>`${t.number(e.groupCount)} opcjami`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", wybrano",other:""},e.isSelected)}`,listboxLabel:"Sugestie",selectedAnnouncement:e=>`${e.optionText}, wybrano`};var Dte={};Dte={buttonLabel:"Mostrar sugestões",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} opção`,other:()=>`${t.number(e.optionCount)} opções`})} disponível.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Grupo inserido ${e.groupTitle}, com ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} opção`,other:()=>`${t.number(e.groupCount)} opções`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", selecionado",other:""},e.isSelected)}`,listboxLabel:"Sugestões",selectedAnnouncement:e=>`${e.optionText}, selecionado`};var $te={};$te={buttonLabel:"Apresentar sugestões",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} opção`,other:()=>`${t.number(e.optionCount)} opções`})} disponível.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Grupo introduzido ${e.groupTitle}, com ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} opção`,other:()=>`${t.number(e.groupCount)} opções`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", selecionado",other:""},e.isSelected)}`,listboxLabel:"Sugestões",selectedAnnouncement:e=>`${e.optionText}, selecionado`};var Cte={};Cte={buttonLabel:"Afișare sugestii",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} opțiune`,other:()=>`${t.number(e.optionCount)} opțiuni`})} disponibile.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Grup ${e.groupTitle} introdus, cu ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} opțiune`,other:()=>`${t.number(e.groupCount)} opțiuni`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", selectat",other:""},e.isSelected)}`,listboxLabel:"Sugestii",selectedAnnouncement:e=>`${e.optionText}, selectat`};var wte={};wte={buttonLabel:"Показать предложения",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} параметр`,other:()=>`${t.number(e.optionCount)} параметров`})} доступно.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Введенная группа ${e.groupTitle}, с ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} параметром`,other:()=>`${t.number(e.groupCount)} параметрами`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", выбранными",other:""},e.isSelected)}`,listboxLabel:"Предложения",selectedAnnouncement:e=>`${e.optionText}, выбрано`};var Rte={};Rte={buttonLabel:"Zobraziť návrhy",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} možnosť`,other:()=>`${t.number(e.optionCount)} možnosti/-í`})} k dispozícii.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Zadaná skupina ${e.groupTitle}, s ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} možnosťou`,other:()=>`${t.number(e.groupCount)} možnosťami`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", vybraté",other:""},e.isSelected)}`,listboxLabel:"Návrhy",selectedAnnouncement:e=>`${e.optionText}, vybraté`};var Ate={};Ate={buttonLabel:"Prikaži predloge",countAnnouncement:(e,t)=>`Na voljo je ${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} opcija`,other:()=>`${t.number(e.optionCount)} opcije`})}.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Vnesena skupina ${e.groupTitle}, z ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} opcija`,other:()=>`${t.number(e.groupCount)} opcije`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", izbrano",other:""},e.isSelected)}`,listboxLabel:"Predlogi",selectedAnnouncement:e=>`${e.optionText}, izbrano`};var Tte={};Tte={buttonLabel:"Prikaži predloge",countAnnouncement:(e,t)=>`Dostupno još: ${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} opcija`,other:()=>`${t.number(e.optionCount)} opcije/a`})}.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Unesena grupa ${e.groupTitle}, s ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} opcijom`,other:()=>`${t.number(e.groupCount)} optione/a`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", izabranih",other:""},e.isSelected)}`,listboxLabel:"Predlozi",selectedAnnouncement:e=>`${e.optionText}, izabrano`};var kte={};kte={buttonLabel:"Visa förslag",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} alternativ`,other:()=>`${t.number(e.optionCount)} alternativ`})} tillgängliga.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Ingick i gruppen ${e.groupTitle} med ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} alternativ`,other:()=>`${t.number(e.groupCount)} alternativ`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", valda",other:""},e.isSelected)}`,listboxLabel:"Förslag",selectedAnnouncement:e=>`${e.optionText}, valda`};var Pte={};Pte={buttonLabel:"Önerileri göster",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} seçenek`,other:()=>`${t.number(e.optionCount)} seçenekler`})} kullanılabilir.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Girilen grup ${e.groupTitle}, ile ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} seçenek`,other:()=>`${t.number(e.groupCount)} seçenekler`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", seçildi",other:""},e.isSelected)}`,listboxLabel:"Öneriler",selectedAnnouncement:e=>`${e.optionText}, seçildi`};var Mte={};Mte={buttonLabel:"Показати пропозиції",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} параметр`,other:()=>`${t.number(e.optionCount)} параметри(-ів)`})} доступно.`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`Введена група ${e.groupTitle}, з ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} параметр`,other:()=>`${t.number(e.groupCount)} параметри(-ів)`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", вибрано",other:""},e.isSelected)}`,listboxLabel:"Пропозиції",selectedAnnouncement:e=>`${e.optionText}, вибрано`};var Fte={};Fte={buttonLabel:"显示建议",countAnnouncement:(e,t)=>`有 ${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} 个选项`,other:()=>`${t.number(e.optionCount)} 个选项`})}可用。`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`进入了 ${e.groupTitle} 组，其中有 ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} 个选项`,other:()=>`${t.number(e.groupCount)} 个选项`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", 已选择",other:""},e.isSelected)}`,listboxLabel:"建议",selectedAnnouncement:e=>`${e.optionText}, 已选择`};var Nte={};Nte={buttonLabel:"顯示建議",countAnnouncement:(e,t)=>`${t.plural(e.optionCount,{one:()=>`${t.number(e.optionCount)} 選項`,other:()=>`${t.number(e.optionCount)} 選項`})} 可用。`,focusAnnouncement:(e,t)=>`${t.select({true:()=>`輸入的群組 ${e.groupTitle}, 有 ${t.plural(e.groupCount,{one:()=>`${t.number(e.groupCount)} 選項`,other:()=>`${t.number(e.groupCount)} 選項`})}. `,other:""},e.isGroupChange)}${e.optionText}${t.select({true:", 已選取",other:""},e.isSelected)}`,listboxLabel:"建議",selectedAnnouncement:e=>`${e.optionText}, 已選取`};var Ite={};Ite={"ar-AE":rte,"bg-BG":ite,"cs-CZ":ate,"da-DK":ute,"de-DE":lte,"el-GR":ote,"en-US":ste,"es-ES":cte,"et-EE":fte,"fi-FI":dte,"fr-FR":hte,"he-IL":pte,"hr-HR":mte,"hu-HU":gte,"it-IT":vte,"ja-JP":yte,"ko-KR":bte,"lt-LT":Ote,"lv-LV":xte,"nb-NO":Ste,"nl-NL":_te,"pl-PL":Ete,"pt-BR":Dte,"pt-PT":$te,"ro-RO":Cte,"ru-RU":wte,"sk-SK":Rte,"sl-SI":Ate,"sr-SP":Tte,"sv-SE":kte,"tr-TR":Pte,"uk-UA":Mte,"zh-CN":Fte,"zh-TW":Nte};const Lte=7e3;let Ld=null;function j1(e,t="assertive",n=Lte){Ld?Ld.announce(e,t,n):(Ld=new d_e,(typeof IS_REACT_ACT_ENVIRONMENT=="boolean"?IS_REACT_ACT_ENVIRONMENT:typeof jest<"u")?Ld.announce(e,t,n):setTimeout(()=>{Ld!=null&&Ld.isAttached()&&(Ld==null||Ld.announce(e,t,n))},100))}function f_e(e){Ld&&Ld.clear(e)}class d_e{isAttached(){var t;return(t=this.node)===null||t===void 0?void 0:t.isConnected}createLog(t){let n=document.createElement("div");return n.setAttribute("role","log"),n.setAttribute("aria-live",t),n.setAttribute("aria-relevant","additions"),n}destroy(){this.node&&(document.body.removeChild(this.node),this.node=null)}announce(t,n="assertive",r=Lte){var i,a;if(!this.node)return;let u=document.createElement("div");typeof t=="object"?(u.setAttribute("role","img"),u.setAttribute("aria-labelledby",t["aria-labelledby"])):u.textContent=t,n==="assertive"?(i=this.assertiveLog)===null||i===void 0||i.appendChild(u):(a=this.politeLog)===null||a===void 0||a.appendChild(u),t!==""&&setTimeout(()=>{u.remove()},r)}clear(t){this.node&&((!t||t==="assertive")&&this.assertiveLog&&(this.assertiveLog.innerHTML=""),(!t||t==="polite")&&this.politeLog&&(this.politeLog.innerHTML=""))}constructor(){this.node=null,this.assertiveLog=null,this.politeLog=null,typeof document<"u"&&(this.node=document.createElement("div"),this.node.dataset.liveAnnouncer="true",Object.assign(this.node.style,{border:0,clip:"rect(0 0 0 0)",clipPath:"inset(50%)",height:"1px",margin:"-1px",overflow:"hidden",padding:0,position:"absolute",width:"1px",whiteSpace:"nowrap"}),this.assertiveLog=this.createLog("assertive"),this.node.appendChild(this.assertiveLog),this.politeLog=this.createLog("polite"),this.node.appendChild(this.politeLog),document.body.prepend(this.node))}}const b0={top:"top",bottom:"top",left:"left",right:"left"},zD={top:"bottom",bottom:"top",left:"right",right:"left"},h_e={top:"left",left:"top"},b9={top:"height",left:"width"},Bte={width:"totalWidth",height:"totalHeight"},N_={};let Gl=typeof document<"u"?window.visualViewport:null;function _U(e){let t=0,n=0,r=0,i=0,a=0,u=0,l={};var o;let s=((o=Gl==null?void 0:Gl.scale)!==null&&o!==void 0?o:1)>1;if(e.tagName==="BODY"){let y=document.documentElement;r=y.clientWidth,i=y.clientHeight;var c;t=(c=Gl==null?void 0:Gl.width)!==null&&c!==void 0?c:r;var d;n=(d=Gl==null?void 0:Gl.height)!==null&&d!==void 0?d:i,l.top=y.scrollTop||e.scrollTop,l.left=y.scrollLeft||e.scrollLeft,Gl&&(a=Gl.offsetTop,u=Gl.offsetLeft)}else({width:t,height:n,top:a,left:u}=n3(e,!1)),l.top=e.scrollTop,l.left=e.scrollLeft,r=t,i=n;if(aN()&&(e.tagName==="BODY"||e.tagName==="HTML")&&s){l.top=0,l.left=0;var h;a=(h=Gl==null?void 0:Gl.pageTop)!==null&&h!==void 0?h:0;var m;u=(m=Gl==null?void 0:Gl.pageLeft)!==null&&m!==void 0?m:0}return{width:t,height:n,totalWidth:r,totalHeight:i,scroll:l,top:a,left:u}}function p_e(e){return{top:e.scrollTop,left:e.scrollLeft,width:e.scrollWidth,height:e.scrollHeight}}function EU(e,t,n,r,i,a,u){var l;let o=(l=i.scroll[e])!==null&&l!==void 0?l:0,s=r[b9[e]],c=r.scroll[b0[e]]+a,d=s+r.scroll[b0[e]]-a,h=t-o+u[e]-r[b0[e]],m=t-o+n+u[e]-r[b0[e]];return h<c?c-h:m>d?Math.max(d-m,c-h):0}function m_e(e){let t=window.getComputedStyle(e);return{top:parseInt(t.marginTop,10)||0,bottom:parseInt(t.marginBottom,10)||0,left:parseInt(t.marginLeft,10)||0,right:parseInt(t.marginRight,10)||0}}function DU(e){if(N_[e])return N_[e];let[t,n]=e.split(" "),r=b0[t]||"right",i=h_e[r];b0[n]||(n="center");let a=b9[r],u=b9[i];return N_[e]={placement:t,crossPlacement:n,axis:r,crossAxis:i,size:a,crossSize:u},N_[e]}function qT(e,t,n,r,i,a,u,l,o,s){let{placement:c,crossPlacement:d,axis:h,crossAxis:m,size:y,crossSize:v}=r,_={};var S;_[m]=(S=e[m])!==null&&S!==void 0?S:0;var E,C,T,R;d==="center"?_[m]+=(((E=e[v])!==null&&E!==void 0?E:0)-((C=n[v])!==null&&C!==void 0?C:0))/2:d!==m&&(_[m]+=((T=e[v])!==null&&T!==void 0?T:0)-((R=n[v])!==null&&R!==void 0?R:0)),_[m]+=a;const $=e[m]-n[v]+o+s,k=e[m]+e[v]-o-s;if(_[m]=ro(_[m],$,k),c===h){const F=l?u[y]:t[Bte[y]];_[zD[h]]=Math.floor(F-e[h]+i)}else _[h]=Math.floor(e[h]+e[y]+i);return _}function g_e(e,t,n,r,i,a,u,l){const o=r?n.height:t[Bte.height];var s;let c=e.top!=null?n.top+e.top:n.top+(o-((s=e.bottom)!==null&&s!==void 0?s:0)-u);var d,h,m,y,v,_;let S=l!=="top"?Math.max(0,t.height+t.top+((d=t.scroll.top)!==null&&d!==void 0?d:0)-c-(((h=i.top)!==null&&h!==void 0?h:0)+((m=i.bottom)!==null&&m!==void 0?m:0)+a)):Math.max(0,c+u-(t.top+((y=t.scroll.top)!==null&&y!==void 0?y:0))-(((v=i.top)!==null&&v!==void 0?v:0)+((_=i.bottom)!==null&&_!==void 0?_:0)+a));return Math.min(t.height-a*2,S)}function $U(e,t,n,r,i,a){let{placement:u,axis:l,size:o}=a;var s,c;if(u===l)return Math.max(0,n[l]-e[l]-((s=e.scroll[l])!==null&&s!==void 0?s:0)+t[l]-((c=r[l])!==null&&c!==void 0?c:0)-r[zD[l]]-i);var d;return Math.max(0,e[o]+e[l]+e.scroll[l]-t[l]-n[l]-n[o]-((d=r[l])!==null&&d!==void 0?d:0)-r[zD[l]]-i)}function v_e(e,t,n,r,i,a,u,l,o,s,c,d,h,m,y,v){let _=DU(e),{size:S,crossAxis:E,crossSize:C,placement:T,crossPlacement:R}=_,$=qT(t,l,n,_,c,d,s,h,y,v),k=c,F=$U(l,s,t,i,a+c,_);if(u&&r[S]>F){let de=DU(`${zD[T]} ${R}`),be=qT(t,l,n,de,c,d,s,h,y,v);$U(l,s,t,i,a+c,de)>F&&(_=de,$=be,k=c)}let L="bottom";_.axis==="top"?_.placement==="top"?L="top":_.placement==="bottom"&&(L="bottom"):_.crossAxis==="top"&&(_.crossPlacement==="top"?L="bottom":_.crossPlacement==="bottom"&&(L="top"));let j=EU(E,$[E],n[C],l,o,a,s);$[E]+=j;let V=g_e($,l,s,h,i,a,n.height,L);m&&m<V&&(V=m),n.height=Math.min(n.height,V),$=qT(t,l,n,_,k,d,s,h,y,v),j=EU(E,$[E],n[C],l,o,a,s),$[E]+=j;let q={},N=t[E]-$[E]-i[b0[E]],U=N+.5*t[C];const W=y/2+v;var G,J,te,H;const M=b0[E]==="left"?((G=i.left)!==null&&G!==void 0?G:0)+((J=i.right)!==null&&J!==void 0?J:0):((te=i.top)!==null&&te!==void 0?te:0)+((H=i.bottom)!==null&&H!==void 0?H:0),K=n[C]-M-y/2-v,X=t[E]+y/2-($[E]+i[b0[E]]),B=t[E]+t[C]-y/2-($[E]+i[b0[E]]),ne=ro(U,X,B);q[E]=ro(ne,W,K),{placement:T,crossPlacement:R}=_,y?N=q[E]:R==="right"?N+=t[C]:R==="center"&&(N+=t[C]/2);let oe=T==="left"||T==="top"?n[S]:0,ie={x:T==="top"||T==="bottom"?N:oe,y:T==="left"||T==="right"?N:oe};return{position:$,maxHeight:V,arrowOffsetLeft:q.left,arrowOffsetTop:q.top,placement:T,triggerAnchorPoint:ie}}function y_e(e){let{placement:t,targetNode:n,overlayNode:r,scrollNode:i,padding:a,shouldFlip:u,boundaryElement:l,offset:o,crossOffset:s,maxHeight:c,arrowSize:d=0,arrowBoundaryOffset:h=0}=e,m=r instanceof HTMLElement?b_e(r):document.documentElement,y=m===document.documentElement;const v=window.getComputedStyle(m).position;let _=!!v&&v!=="static",S=y?n3(n,!1):CU(n,m,!1);if(!y){let{marginTop:q,marginLeft:N}=window.getComputedStyle(n);S.top+=parseInt(q,10)||0,S.left+=parseInt(N,10)||0}let E=n3(r,!0),C=m_e(r);var T,R;E.width+=((T=C.left)!==null&&T!==void 0?T:0)+((R=C.right)!==null&&R!==void 0?R:0);var $,k;E.height+=(($=C.top)!==null&&$!==void 0?$:0)+((k=C.bottom)!==null&&k!==void 0?k:0);let F=p_e(i),L=_U(l),j=_U(m),V=l.tagName==="BODY"?n3(m,!1):CU(m,l,!1);return m.tagName==="HTML"&&l.tagName==="BODY"&&(j.scroll.top=0,j.scroll.left=0),v_e(t,S,E,F,C,a,u,L,j,V,o,s,_,c,d,h)}function fN(e,t){let{top:n,left:r,width:i,height:a}=e.getBoundingClientRect();return t&&e instanceof e.ownerDocument.defaultView.HTMLElement&&(i=e.offsetWidth,a=e.offsetHeight),{top:n,left:r,width:i,height:a}}function n3(e,t){let{top:n,left:r,width:i,height:a}=fN(e,t),{scrollTop:u,scrollLeft:l,clientTop:o,clientLeft:s}=document.documentElement;return{top:n+u-o,left:r+l-s,width:i,height:a}}function CU(e,t,n){let r=window.getComputedStyle(e),i;if(r.position==="fixed")i=fN(e,n);else{i=n3(e,n);let a=n3(t,n),u=window.getComputedStyle(t);a.top+=(parseInt(u.borderTopWidth,10)||0)-t.scrollTop,a.left+=(parseInt(u.borderLeftWidth,10)||0)-t.scrollLeft,i.top-=a.top,i.left-=a.left}return i.top-=parseInt(r.marginTop,10)||0,i.left-=parseInt(r.marginLeft,10)||0,i}function b_e(e){let t=e.offsetParent;if(t&&t===document.body&&window.getComputedStyle(t).position==="static"&&!wU(t)&&(t=document.documentElement),t==null)for(t=e.parentElement;t&&!wU(t);)t=t.parentElement;return t||document.documentElement}function wU(e){let t=window.getComputedStyle(e);return t.transform!=="none"||/transform|perspective/.test(t.willChange)||t.filter!=="none"||t.contain==="paint"||"backdropFilter"in t&&t.backdropFilter!=="none"||"WebkitBackdropFilter"in t&&t.WebkitBackdropFilter!=="none"}const Qte=new WeakMap;function O_e(e){let{triggerRef:t,isOpen:n,onClose:r}=e;P.useEffect(()=>{if(!n||r===null)return;let i=a=>{let u=a.target;if(!t.current||u instanceof Node&&!u.contains(t.current)||a.target instanceof HTMLInputElement||a.target instanceof HTMLTextAreaElement)return;let l=r||Qte.get(t.current);l&&l()};return window.addEventListener("scroll",i,!0),()=>{window.removeEventListener("scroll",i,!0)}},[n,r,t])}const x_e=new Set(["Arab","Syrc","Samr","Mand","Thaa","Mend","Nkoo","Adlm","Rohg","Hebr"]),S_e=new Set(["ae","ar","arc","bcc","bqi","ckb","dv","fa","glk","he","ku","mzn","nqo","pnb","ps","sd","ug","ur","yi"]);function __e(e){if(Intl.Locale){let n=new Intl.Locale(e).maximize(),r=typeof n.getTextInfo=="function"?n.getTextInfo():n.textInfo;if(r)return r.direction==="rtl";if(n.script)return x_e.has(n.script)}let t=e.split("-")[0];return S_e.has(t)}const E_e=Symbol.for("react-aria.i18n.locale");function zte(){let e=typeof window<"u"&&window[E_e]||typeof navigator<"u"&&(navigator.language||navigator.userLanguage)||"en-US";try{Intl.DateTimeFormat.supportedLocalesOf([e])}catch{e="en-US"}return{locale:e,direction:__e(e)?"rtl":"ltr"}}let O9=zte(),k2=new Set;function RU(){O9=zte();for(let e of k2)e(O9)}function D_e(){let e=hp(),[t,n]=P.useState(O9);return P.useEffect(()=>(k2.size===0&&window.addEventListener("languagechange",RU),k2.add(n),()=>{k2.delete(n),k2.size===0&&window.removeEventListener("languagechange",RU)}),[]),e?{locale:"en-US",direction:"ltr"}:t}const $_e=ye.createContext(null);function Hi(){let e=D_e();return P.useContext($_e)||e}var x9=function(e,t){return x9=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(n,r){n.__proto__=r}||function(n,r){for(var i in r)Object.prototype.hasOwnProperty.call(r,i)&&(n[i]=r[i])},x9(e,t)};function qte(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");x9(e,t);function n(){this.constructor=e}e.prototype=t===null?Object.create(t):(n.prototype=t.prototype,new n)}var jd=function(){return jd=Object.assign||function(t){for(var n,r=1,i=arguments.length;r<i;r++){n=arguments[r];for(var a in n)Object.prototype.hasOwnProperty.call(n,a)&&(t[a]=n[a])}return t},jd.apply(this,arguments)};function C_e(e,t,n,r){function i(a){return a instanceof n?a:new n(function(u){u(a)})}return new(n||(n=Promise))(function(a,u){function l(c){try{s(r.next(c))}catch(d){u(d)}}function o(c){try{s(r.throw(c))}catch(d){u(d)}}function s(c){c.done?a(c.value):i(c.value).then(l,o)}s((r=r.apply(e,t||[])).next())})}function w_e(e,t){var n={label:0,sent:function(){if(a[0]&1)throw a[1];return a[1]},trys:[],ops:[]},r,i,a,u=Object.create((typeof Iterator=="function"?Iterator:Object).prototype);return u.next=l(0),u.throw=l(1),u.return=l(2),typeof Symbol=="function"&&(u[Symbol.iterator]=function(){return this}),u;function l(s){return function(c){return o([s,c])}}function o(s){if(r)throw new TypeError("Generator is already executing.");for(;u&&(u=0,s[0]&&(n=0)),n;)try{if(r=1,i&&(a=s[0]&2?i.return:s[0]?i.throw||((a=i.return)&&a.call(i),0):i.next)&&!(a=a.call(i,s[1])).done)return a;switch(i=0,a&&(s=[s[0]&2,a.value]),s[0]){case 0:case 1:a=s;break;case 4:return n.label++,{value:s[1],done:!1};case 5:n.label++,i=s[1],s=[0];continue;case 7:s=n.ops.pop(),n.trys.pop();continue;default:if(a=n.trys,!(a=a.length>0&&a[a.length-1])&&(s[0]===6||s[0]===2)){n=0;continue}if(s[0]===3&&(!a||s[1]>a[0]&&s[1]<a[3])){n.label=s[1];break}if(s[0]===6&&n.label<a[1]){n.label=a[1],a=s;break}if(a&&n.label<a[2]){n.label=a[2],n.ops.push(s);break}a[2]&&n.ops.pop(),n.trys.pop();continue}s=t.call(e,n)}catch(c){s=[6,c],i=0}finally{r=a=0}if(s[0]&5)throw s[1];return{value:s[0]?s[1]:void 0,done:!0}}}function r3(e,t,n){if(n||arguments.length===2)for(var r=0,i=t.length,a;r<i;r++)(a||!(r in t))&&(a||(a=Array.prototype.slice.call(t,0,r)),a[r]=t[r]);return e.concat(a||Array.prototype.slice.call(t))}const R_e=Symbol.for("react-aria.i18n.locale"),A_e=Symbol.for("react-aria.i18n.strings");let vO;class tp{getStringForLocale(t,n){let i=this.getStringsForLocale(n)[t];if(!i)throw new Error(`Could not find intl message ${t} in ${n} locale`);return i}getStringsForLocale(t){let n=this.strings[t];return n||(n=T_e(t,this.strings,this.defaultLocale),this.strings[t]=n),n}static getGlobalDictionaryForPackage(t){if(typeof window>"u")return null;let n=window[R_e];if(vO===void 0){let i=window[A_e];if(!i)return null;vO={};for(let a in i)vO[a]=new tp({[n]:i[a]},n)}let r=vO==null?void 0:vO[t];if(!r)throw new Error(`Strings for package "${t}" were not included by LocalizedStringProvider. Please add it to the list passed to createLocalizedStringDictionary.`);return r}constructor(t,n="en-US"){this.strings=Object.fromEntries(Object.entries(t).filter(([,r])=>r)),this.defaultLocale=n}}function T_e(e,t,n="en-US"){if(t[e])return t[e];let r=k_e(e);if(t[r])return t[r];for(let i in t)if(i.startsWith(r+"-"))return t[i];return t[n]}function k_e(e){return Intl.Locale?new Intl.Locale(e).language:e.split("-")[0]}const AU=new Map,TU=new Map;class dN{format(t,n){let r=this.strings.getStringForLocale(t,this.locale);return typeof r=="function"?r(n,this):r}plural(t,n,r="cardinal"){let i=n["="+t];if(i)return typeof i=="function"?i():i;let a=this.locale+":"+r,u=AU.get(a);u||(u=new Intl.PluralRules(this.locale,{type:r}),AU.set(a,u));let l=u.select(t);return i=n[l]||n.other,typeof i=="function"?i():i}number(t){let n=TU.get(this.locale);return n||(n=new Intl.NumberFormat(this.locale),TU.set(this.locale,n)),n.format(t)}select(t,n){let r=t[n]||t.other;return typeof r=="function"?r():r}constructor(t,n){this.locale=t,this.strings=n}}const kU=new WeakMap;function P_e(e){let t=kU.get(e);return t||(t=new tp(e),kU.set(e,t)),t}function Vte(e,t){return t&&tp.getGlobalDictionaryForPackage(t)||P_e(e)}function Fo(e,t){let{locale:n}=Hi(),r=Vte(e,t);return P.useMemo(()=>new dN(n,r),[n,r])}function M_e(e={}){let{locale:t}=Hi();return P.useMemo(()=>new Intl.ListFormat(t,e),[t,e])}function i3(e,t){return e-t*Math.floor(e/t)}const Ute=1721426;function F1(e,t,n,r){t=lS(e,t);let i=t-1,a=-2;return n<=2?a=0:Nv(t)&&(a=-1),Ute-1+365*i+Math.floor(i/4)-Math.floor(i/100)+Math.floor(i/400)+Math.floor((367*n-362)/12+a+r)}function Nv(e){return e%4===0&&(e%100!==0||e%400===0)}function lS(e,t){return e==="BC"?1-t:t}function LC(e){let t="AD";return e<=0&&(t="BC",e=1-e),[t,e]}const F_e={standard:[31,28,31,30,31,30,31,31,30,31,30,31],leapyear:[31,29,31,30,31,30,31,31,30,31,30,31]};class Hf{fromJulianDay(t){let n=t,r=n-Ute,i=Math.floor(r/146097),a=i3(r,146097),u=Math.floor(a/36524),l=i3(a,36524),o=Math.floor(l/1461),s=i3(l,1461),c=Math.floor(s/365),d=i*400+u*100+o*4+c+(u!==4&&c!==4?1:0),[h,m]=LC(d),y=n-F1(h,m,1,1),v=2;n<F1(h,m,3,1)?v=0:Nv(m)&&(v=1);let _=Math.floor(((y+v)*12+373)/367),S=n-F1(h,m,_,1)+1;return new ju(h,m,_,S)}toJulianDay(t){return F1(t.era,t.year,t.month,t.day)}getDaysInMonth(t){return F_e[Nv(t.year)?"leapyear":"standard"][t.month-1]}getMonthsInYear(t){return 12}getDaysInYear(t){return Nv(t.year)?366:365}getYearsInEra(t){return 9999}getEras(){return["BC","AD"]}isInverseEra(t){return t.era==="BC"}balanceDate(t){t.year<=0&&(t.era=t.era==="BC"?"AD":"BC",t.year=1-t.year)}constructor(){this.identifier="gregory"}}function jte(e,t){var n,r,i,a;return(a=(i=(n=e.isEqual)===null||n===void 0?void 0:n.call(e,t))!==null&&i!==void 0?i:(r=t.isEqual)===null||r===void 0?void 0:r.call(t,e))!==null&&a!==void 0?a:e.identifier===t.identifier}function Zte(e){return Km(Date.now(),e)}function N_e(e){return Wte(Zte(e))}function Hte(e,t){return e.calendar.toJulianDay(e)-t.calendar.toJulianDay(t)}function Xte(e,t){return PU(e)-PU(t)}function PU(e){return e.hour*36e5+e.minute*6e4+e.second*1e3+e.millisecond}let VT=null;function oS(){return VT==null&&(VT=new Intl.DateTimeFormat().resolvedOptions().timeZone),VT}function I_e(e){return e.calendar.getMinimumMonthInYear?e.calendar.getMinimumMonthInYear(e):1}function L_e(e){return e.calendar.getMinimumDayInMonth?e.calendar.getMinimumDayInMonth(e):1}function C3(e){e=sc(e,new Hf);let t=lS(e.era,e.year);return Yte(t,e.month,e.day,e.hour,e.minute,e.second,e.millisecond)}function Yte(e,t,n,r,i,a,u){let l=new Date;return l.setUTCHours(r,i,a,u),l.setUTCFullYear(e,t-1,n),l.getTime()}function S9(e,t){if(t==="UTC")return 0;if(e>0&&t===oS())return new Date(e).getTimezoneOffset()*-6e4;let{year:n,month:r,day:i,hour:a,minute:u,second:l}=Gte(e,t);return Yte(n,r,i,a,u,l,0)-Math.floor(e/1e3)*1e3}const MU=new Map;function Gte(e,t){let n=MU.get(t);n||(n=new Intl.DateTimeFormat("en-US",{timeZone:t,hour12:!1,era:"short",year:"numeric",month:"numeric",day:"numeric",hour:"numeric",minute:"numeric",second:"numeric"}),MU.set(t,n));let r=n.formatToParts(new Date(e)),i={};for(let a of r)a.type!=="literal"&&(i[a.type]=a.value);return{year:i.era==="BC"||i.era==="B"?-i.year+1:+i.year,month:+i.month,day:+i.day,hour:i.hour==="24"?0:+i.hour,minute:+i.minute,second:+i.second}}const FU=864e5;function B_e(e,t,n,r){return(n===r?[n]:[n,r]).filter(a=>Q_e(e,t,a))}function Q_e(e,t,n){let r=Gte(n,t);return e.year===r.year&&e.month===r.month&&e.day===r.day&&e.hour===r.hour&&e.minute===r.minute&&e.second===r.second}function Um(e,t,n="compatible"){let r=Kv(e);if(t==="UTC")return C3(r);if(t===oS()&&n==="compatible"){r=sc(r,new Hf);let o=new Date,s=lS(r.era,r.year);return o.setFullYear(s,r.month-1,r.day),o.setHours(r.hour,r.minute,r.second,r.millisecond),o.getTime()}let i=C3(r),a=S9(i-FU,t),u=S9(i+FU,t),l=B_e(r,t,i-a,i-u);if(l.length===1)return l[0];if(l.length>1)switch(n){case"compatible":case"earlier":return l[0];case"later":return l[l.length-1];case"reject":throw new RangeError("Multiple possible absolute times found")}switch(n){case"earlier":return Math.min(i-a,i-u);case"compatible":case"later":return Math.max(i-a,i-u);case"reject":throw new RangeError("No such absolute time found")}}function Kte(e,t,n="compatible"){return new Date(Um(e,t,n))}function Km(e,t){let n=S9(e,t),r=new Date(e+n),i=r.getUTCFullYear(),a=r.getUTCMonth()+1,u=r.getUTCDate(),l=r.getUTCHours(),o=r.getUTCMinutes(),s=r.getUTCSeconds(),c=r.getUTCMilliseconds();return new w3(i<1?"BC":"AD",i<1?-i+1:i,a,u,t,n,l,o,s,c)}function Wte(e){return new ju(e.calendar,e.era,e.year,e.month,e.day)}function Kv(e,t){let n=0,r=0,i=0,a=0;if("timeZone"in e)({hour:n,minute:r,second:i,millisecond:a}=e);else if("hour"in e&&!t)return e;return t&&({hour:n,minute:r,second:i,millisecond:a}=t),new px(e.calendar,e.era,e.year,e.month,e.day,n,r,i,a)}function NU(e){return new QC(e.hour,e.minute,e.second,e.millisecond)}function sc(e,t){if(jte(e.calendar,t))return e;let n=t.fromJulianDay(e.calendar.toJulianDay(e)),r=e.copy();return r.calendar=t,r.era=n.era,r.year=n.year,r.month=n.month,r.day=n.day,lb(r),r}function Jte(e,t,n){if(e instanceof w3)return e.timeZone===t?e:ene(e,t);let r=Um(e,t,n);return Km(r,t)}function z_e(e){let t=C3(e)-e.offset;return new Date(t)}function ene(e,t){let n=C3(e)-e.offset;return sc(Km(n,t),e.calendar)}const Y4=36e5;function BC(e,t){let n=e.copy(),r="hour"in n?ine(n,t):0;_9(n,t.years||0),n.calendar.balanceYearMonth&&n.calendar.balanceYearMonth(n,e),n.month+=t.months||0,E9(n),tne(n),n.day+=(t.weeks||0)*7,n.day+=t.days||0,n.day+=r,q_e(n),n.calendar.balanceDate&&n.calendar.balanceDate(n),n.year<1&&(n.year=1,n.month=1,n.day=1);let i=n.calendar.getYearsInEra(n);if(n.year>i){var a,u;let o=(a=(u=n.calendar).isInverseEra)===null||a===void 0?void 0:a.call(u,n);n.year=i,n.month=o?1:n.calendar.getMonthsInYear(n),n.day=o?1:n.calendar.getDaysInMonth(n)}n.month<1&&(n.month=1,n.day=1);let l=n.calendar.getMonthsInYear(n);return n.month>l&&(n.month=l,n.day=n.calendar.getDaysInMonth(n)),n.day=Math.max(1,Math.min(n.calendar.getDaysInMonth(n),n.day)),n}function _9(e,t){var n,r;!((n=(r=e.calendar).isInverseEra)===null||n===void 0)&&n.call(r,e)&&(t=-t),e.year+=t}function E9(e){for(;e.month<1;)_9(e,-1),e.month+=e.calendar.getMonthsInYear(e);let t=0;for(;e.month>(t=e.calendar.getMonthsInYear(e));)e.month-=t,_9(e,1)}function q_e(e){for(;e.day<1;)e.month--,E9(e),e.day+=e.calendar.getDaysInMonth(e);for(;e.day>e.calendar.getDaysInMonth(e);)e.day-=e.calendar.getDaysInMonth(e),e.month++,E9(e)}function tne(e){e.month=Math.max(1,Math.min(e.calendar.getMonthsInYear(e),e.month)),e.day=Math.max(1,Math.min(e.calendar.getDaysInMonth(e),e.day))}function lb(e){e.calendar.constrainDate&&e.calendar.constrainDate(e),e.year=Math.max(1,Math.min(e.calendar.getYearsInEra(e),e.year)),tne(e)}function hN(e){let t={};for(let n in e)typeof e[n]=="number"&&(t[n]=-e[n]);return t}function nne(e,t){return BC(e,hN(t))}function pN(e,t){let n=e.copy();return t.era!=null&&(n.era=t.era),t.year!=null&&(n.year=t.year),t.month!=null&&(n.month=t.month),t.day!=null&&(n.day=t.day),lb(n),n}function hx(e,t){let n=e.copy();return t.hour!=null&&(n.hour=t.hour),t.minute!=null&&(n.minute=t.minute),t.second!=null&&(n.second=t.second),t.millisecond!=null&&(n.millisecond=t.millisecond),rne(n),n}function V_e(e){e.second+=Math.floor(e.millisecond/1e3),e.millisecond=I_(e.millisecond,1e3),e.minute+=Math.floor(e.second/60),e.second=I_(e.second,60),e.hour+=Math.floor(e.minute/60),e.minute=I_(e.minute,60);let t=Math.floor(e.hour/24);return e.hour=I_(e.hour,24),t}function rne(e){e.millisecond=Math.max(0,Math.min(e.millisecond,1e3)),e.second=Math.max(0,Math.min(e.second,59)),e.minute=Math.max(0,Math.min(e.minute,59)),e.hour=Math.max(0,Math.min(e.hour,23))}function I_(e,t){let n=e%t;return n<0&&(n+=t),n}function ine(e,t){return e.hour+=t.hours||0,e.minute+=t.minutes||0,e.second+=t.seconds||0,e.millisecond+=t.milliseconds||0,V_e(e)}function ane(e,t){let n=e.copy();return ine(n,t),n}function U_e(e,t){return ane(e,hN(t))}function mN(e,t,n,r){let i=e.copy();switch(t){case"era":{let l=e.calendar.getEras(),o=l.indexOf(e.era);if(o<0)throw new Error("Invalid era: "+e.era);o=Wm(o,n,0,l.length-1,r==null?void 0:r.round),i.era=l[o],lb(i);break}case"year":var a,u;!((a=(u=i.calendar).isInverseEra)===null||a===void 0)&&a.call(u,i)&&(n=-n),i.year=Wm(e.year,n,-1/0,9999,r==null?void 0:r.round),i.year===-1/0&&(i.year=1),i.calendar.balanceYearMonth&&i.calendar.balanceYearMonth(i,e);break;case"month":i.month=Wm(e.month,n,1,e.calendar.getMonthsInYear(e),r==null?void 0:r.round);break;case"day":i.day=Wm(e.day,n,1,e.calendar.getDaysInMonth(e),r==null?void 0:r.round);break;default:throw new Error("Unsupported field "+t)}return e.calendar.balanceDate&&e.calendar.balanceDate(i),lb(i),i}function gN(e,t,n,r){let i=e.copy();switch(t){case"hour":{let a=e.hour,u=0,l=23;if((r==null?void 0:r.hourCycle)===12){let o=a>=12;u=o?12:0,l=o?23:11}i.hour=Wm(a,n,u,l,r==null?void 0:r.round);break}case"minute":i.minute=Wm(e.minute,n,0,59,r==null?void 0:r.round);break;case"second":i.second=Wm(e.second,n,0,59,r==null?void 0:r.round);break;case"millisecond":i.millisecond=Wm(e.millisecond,n,0,999,r==null?void 0:r.round);break;default:throw new Error("Unsupported field "+t)}return i}function Wm(e,t,n,r,i=!1){if(i){e+=Math.sign(t),e<n&&(e=r);let a=Math.abs(t);t>0?e=Math.ceil(e/a)*a:e=Math.floor(e/a)*a,e>r&&(e=n)}else e+=t,e<n?e=r-(n-e-1):e>r&&(e=n+(e-r-1));return e}function une(e,t){let n;if(t.years!=null&&t.years!==0||t.months!=null&&t.months!==0||t.weeks!=null&&t.weeks!==0||t.days!=null&&t.days!==0){let i=BC(Kv(e),{years:t.years,months:t.months,weeks:t.weeks,days:t.days});n=Um(i,e.timeZone)}else n=C3(e)-e.offset;n+=t.milliseconds||0,n+=(t.seconds||0)*1e3,n+=(t.minutes||0)*6e4,n+=(t.hours||0)*36e5;let r=Km(n,e.timeZone);return sc(r,e.calendar)}function j_e(e,t){return une(e,hN(t))}function Z_e(e,t,n,r){switch(t){case"hour":{let i=0,a=23;if((r==null?void 0:r.hourCycle)===12){let y=e.hour>=12;i=y?12:0,a=y?23:11}let u=Kv(e),l=sc(hx(u,{hour:i}),new Hf),o=[Um(l,e.timeZone,"earlier"),Um(l,e.timeZone,"later")].filter(y=>Km(y,e.timeZone).day===l.day)[0],s=sc(hx(u,{hour:a}),new Hf),c=[Um(s,e.timeZone,"earlier"),Um(s,e.timeZone,"later")].filter(y=>Km(y,e.timeZone).day===s.day).pop(),d=C3(e)-e.offset,h=Math.floor(d/Y4),m=d%Y4;return d=Wm(h,n,Math.floor(o/Y4),Math.floor(c/Y4),r==null?void 0:r.round)*Y4+m,sc(Km(d,e.timeZone),e.calendar)}case"minute":case"second":case"millisecond":return gN(e,t,n,r);case"era":case"year":case"month":case"day":{let i=mN(Kv(e),t,n,r),a=Um(i,e.timeZone);return sc(Km(a,e.timeZone),e.calendar)}default:throw new Error("Unsupported field "+t)}}function H_e(e,t,n){let r=Kv(e),i=hx(pN(r,t),t);if(i.compare(r)===0)return e;let a=Um(i,e.timeZone,n);return sc(Km(a,e.timeZone),e.calendar)}const X_e=/^([+-]\d{6}|\d{4})-(\d{2})-(\d{2})$/,Y_e=/^([+-]\d{6}|\d{4})-(\d{2})-(\d{2})(?:T(\d{2}))?(?::(\d{2}))?(?::(\d{2}))?(\.\d+)?$/,G_e=/^([+-]\d{6}|\d{4})-(\d{2})-(\d{2})(?:T(\d{2}))?(?::(\d{2}))?(?::(\d{2}))?(\.\d+)?(?:(?:([+-]\d{2})(?::?(\d{2}))?)|Z)$/;function K_e(e){let t=e.match(X_e);if(!t)throw new Error("Invalid ISO 8601 date string: "+e);let n=new ju(Dl(t[1],0,9999),Dl(t[2],1,12),1);return n.day=Dl(t[3],1,n.calendar.getDaysInMonth(n)),n}function W_e(e){let t=e.match(Y_e);if(!t)throw new Error("Invalid ISO 8601 date time string: "+e);let n=Dl(t[1],-9999,9999),r=n<1?"BC":"AD",i=new px(r,n<1?-n+1:n,Dl(t[2],1,12),1,t[4]?Dl(t[4],0,23):0,t[5]?Dl(t[5],0,59):0,t[6]?Dl(t[6],0,59):0,t[7]?Dl(t[7],0,1/0)*1e3:0);return i.day=Dl(t[3],0,i.calendar.getDaysInMonth(i)),i}function J_e(e,t){let n=e.match(G_e);if(!n)throw new Error("Invalid ISO 8601 date time string: "+e);let r=Dl(n[1],-9999,9999),i=r<1?"BC":"AD",a=new w3(i,r<1?-r+1:r,Dl(n[2],1,12),1,t,0,n[4]?Dl(n[4],0,23):0,n[5]?Dl(n[5],0,59):0,n[6]?Dl(n[6],0,59):0,n[7]?Dl(n[7],0,1/0)*1e3:0);a.day=Dl(n[3],0,a.calendar.getDaysInMonth(a));var u;return n[8]&&(a.offset=Dl(n[8],-23,23)*36e5+Dl((u=n[9])!==null&&u!==void 0?u:"0",0,59)*6e4),ene(a,t)}function Rrt(e){return J_e(e,oS())}function Dl(e,t,n){let r=Number(e);if(r<t||r>n)throw new RangeError(`Value out of range: ${t} <= ${r} <= ${n}`);return r}function lne(e){return`${String(e.hour).padStart(2,"0")}:${String(e.minute).padStart(2,"0")}:${String(e.second).padStart(2,"0")}${e.millisecond?String(e.millisecond/1e3).slice(1):""}`}function one(e){let t=sc(e,new Hf),n;return t.era==="BC"?n=t.year===1?"0000":"-"+String(Math.abs(1-t.year)).padStart(6,"00"):n=String(t.year).padStart(4,"0"),`${n}-${String(t.month).padStart(2,"0")}-${String(t.day).padStart(2,"0")}`}function sne(e){return`${one(e)}T${lne(e)}`}function eEe(e){let t=Math.sign(e)<0?"-":"+";e=Math.abs(e);let n=Math.floor(e/36e5),r=Math.floor(e%36e5/6e4),i=Math.floor(e%36e5%6e4/1e3),a=`${t}${String(n).padStart(2,"0")}:${String(r).padStart(2,"0")}`;return i!==0&&(a+=`:${String(i).padStart(2,"0")}`),a}function tEe(e){return`${sne(e)}${eEe(e.offset)}[${e.timeZone}]`}function nEe(e,t){if(t.has(e))throw new TypeError("Cannot initialize the same private elements twice on an object")}function sS(e,t,n){nEe(e,t),t.set(e,n)}function vN(e){let t=typeof e[0]=="object"?e.shift():new Hf,n;if(typeof e[0]=="string")n=e.shift();else{let u=t.getEras();n=u[u.length-1]}let r=e.shift(),i=e.shift(),a=e.shift();return[t,n,r,i,a]}var rEe=new WeakMap;class ju{copy(){return this.era?new ju(this.calendar,this.era,this.year,this.month,this.day):new ju(this.calendar,this.year,this.month,this.day)}add(t){return BC(this,t)}subtract(t){return nne(this,t)}set(t){return pN(this,t)}cycle(t,n,r){return mN(this,t,n,r)}toDate(t){return Kte(this,t)}toString(){return one(this)}compare(t){return Hte(this,t)}constructor(...t){sS(this,rEe,{writable:!0,value:void 0});let[n,r,i,a,u]=vN(t);this.calendar=n,this.era=r,this.year=i,this.month=a,this.day=u,lb(this)}}var iEe=new WeakMap;class QC{copy(){return new QC(this.hour,this.minute,this.second,this.millisecond)}add(t){return ane(this,t)}subtract(t){return U_e(this,t)}set(t){return hx(this,t)}cycle(t,n,r){return gN(this,t,n,r)}toString(){return lne(this)}compare(t){return Xte(this,t)}constructor(t=0,n=0,r=0,i=0){sS(this,iEe,{writable:!0,value:void 0}),this.hour=t,this.minute=n,this.second=r,this.millisecond=i,rne(this)}}var aEe=new WeakMap;class px{copy(){return this.era?new px(this.calendar,this.era,this.year,this.month,this.day,this.hour,this.minute,this.second,this.millisecond):new px(this.calendar,this.year,this.month,this.day,this.hour,this.minute,this.second,this.millisecond)}add(t){return BC(this,t)}subtract(t){return nne(this,t)}set(t){return pN(hx(this,t),t)}cycle(t,n,r){switch(t){case"era":case"year":case"month":case"day":return mN(this,t,n,r);default:return gN(this,t,n,r)}}toDate(t,n){return Kte(this,t,n)}toString(){return sne(this)}compare(t){let n=Hte(this,t);return n===0?Xte(this,Kv(t)):n}constructor(...t){sS(this,aEe,{writable:!0,value:void 0});let[n,r,i,a,u]=vN(t);this.calendar=n,this.era=r,this.year=i,this.month=a,this.day=u,this.hour=t.shift()||0,this.minute=t.shift()||0,this.second=t.shift()||0,this.millisecond=t.shift()||0,lb(this)}}var uEe=new WeakMap;class w3{copy(){return this.era?new w3(this.calendar,this.era,this.year,this.month,this.day,this.timeZone,this.offset,this.hour,this.minute,this.second,this.millisecond):new w3(this.calendar,this.year,this.month,this.day,this.timeZone,this.offset,this.hour,this.minute,this.second,this.millisecond)}add(t){return une(this,t)}subtract(t){return j_e(this,t)}set(t,n){return H_e(this,t,n)}cycle(t,n,r){return Z_e(this,t,n,r)}toDate(){return z_e(this)}toString(){return tEe(this)}toAbsoluteString(){return this.toDate().toISOString()}compare(t){return this.toDate().getTime()-Jte(t,this.timeZone).toDate().getTime()}constructor(...t){sS(this,uEe,{writable:!0,value:void 0});let[n,r,i,a,u]=vN(t),l=t.shift(),o=t.shift();this.calendar=n,this.era=r,this.year=i,this.month=a,this.day=u,this.timeZone=l,this.offset=o,this.hour=t.shift()||0,this.minute=t.shift()||0,this.second=t.shift()||0,this.millisecond=t.shift()||0,lb(this)}}const a3=[[1868,9,8],[1912,7,30],[1926,12,25],[1989,1,8],[2019,5,1]],lEe=[[1912,7,29],[1926,12,24],[1989,1,7],[2019,4,30]],ZE=[1867,1911,1925,1988,2018],xv=["meiji","taisho","showa","heisei","reiwa"];function IU(e){const t=a3.findIndex(([n,r,i])=>e.year<n||e.year===n&&e.month<r||e.year===n&&e.month===r&&e.day<i);return t===-1?a3.length-1:t===0?0:t-1}function UT(e){let t=ZE[xv.indexOf(e.era)];if(!t)throw new Error("Unknown era: "+e.era);return new ju(e.year+t,e.month,e.day)}class oEe extends Hf{fromJulianDay(t){let n=super.fromJulianDay(t),r=IU(n);return new ju(this,xv[r],n.year-ZE[r],n.month,n.day)}toJulianDay(t){return super.toJulianDay(UT(t))}balanceDate(t){let n=UT(t),r=IU(n);xv[r]!==t.era&&(t.era=xv[r],t.year=n.year-ZE[r]),this.constrainDate(t)}constrainDate(t){let n=xv.indexOf(t.era),r=lEe[n];if(r!=null){let[i,a,u]=r,l=i-ZE[n];t.year=Math.max(1,Math.min(l,t.year)),t.year===l&&(t.month=Math.min(a,t.month),t.month===a&&(t.day=Math.min(u,t.day)))}if(t.year===1&&n>=0){let[,i,a]=a3[n];t.month=Math.max(i,t.month),t.month===i&&(t.day=Math.max(a,t.day))}}getEras(){return xv}getYearsInEra(t){let n=xv.indexOf(t.era),r=a3[n],i=a3[n+1];if(i==null)return 9999-r[0]+1;let a=i[0]-r[0];return(t.month<i[1]||t.month===i[1]&&t.day<i[2])&&a++,a}getDaysInMonth(t){return super.getDaysInMonth(UT(t))}getMinimumMonthInYear(t){let n=LU(t);return n?n[1]:1}getMinimumDayInMonth(t){let n=LU(t);return n&&t.month===n[1]?n[2]:1}constructor(...t){super(...t),this.identifier="japanese"}}function LU(e){if(e.year===1){let t=xv.indexOf(e.era);return a3[t]}}const cne=-543;class sEe extends Hf{fromJulianDay(t){let n=super.fromJulianDay(t),r=lS(n.era,n.year);return new ju(this,r-cne,n.month,n.day)}toJulianDay(t){return super.toJulianDay(BU(t))}getEras(){return["BE"]}getDaysInMonth(t){return super.getDaysInMonth(BU(t))}balanceDate(){}constructor(...t){super(...t),this.identifier="buddhist"}}function BU(e){let[t,n]=LC(e.year+cne);return new ju(t,n,e.month,e.day)}const qD=1911;function fne(e){return e.era==="minguo"?e.year+qD:1-e.year+qD}function QU(e){let t=e-qD;return t>0?["minguo",t]:["before_minguo",1-t]}class cEe extends Hf{fromJulianDay(t){let n=super.fromJulianDay(t),r=lS(n.era,n.year),[i,a]=QU(r);return new ju(this,i,a,n.month,n.day)}toJulianDay(t){return super.toJulianDay(zU(t))}getEras(){return["before_minguo","minguo"]}balanceDate(t){let[n,r]=QU(fne(t));t.era=n,t.year=r}isInverseEra(t){return t.era==="before_minguo"}getDaysInMonth(t){return super.getDaysInMonth(zU(t))}getYearsInEra(t){return t.era==="before_minguo"?9999:9999-qD}constructor(...t){super(...t),this.identifier="roc"}}function zU(e){let[t,n]=LC(fne(e));return new ju(t,n,e.month,e.day)}const qU=1948320,VU=[0,31,62,93,124,155,186,216,246,276,306,336];class fEe{fromJulianDay(t){let n=t-qU,r=1+Math.floor((33*n+3)/12053),i=365*(r-1)+Math.floor((8*r+21)/33),a=n-i,u=a<216?Math.floor(a/31):Math.floor((a-6)/30),l=a-VU[u]+1;return new ju(this,r,u+1,l)}toJulianDay(t){let n=qU-1+365*(t.year-1)+Math.floor((8*t.year+21)/33);return n+=VU[t.month-1],n+=t.day,n}getMonthsInYear(){return 12}getDaysInMonth(t){return t.month<=6?31:t.month<=11||i3(25*t.year+11,33)<8?30:29}getEras(){return["AP"]}getYearsInEra(){return 9377}constructor(){this.identifier="persian"}}const jT=78,UU=80;class dEe extends Hf{fromJulianDay(t){let n=super.fromJulianDay(t),r=n.year-jT,i=t-F1(n.era,n.year,1,1),a;i<UU?(r--,a=Nv(n.year-1)?31:30,i+=a+155+90+10):(a=Nv(n.year)?31:30,i-=UU);let u,l;if(i<a)u=1,l=i+1;else{let o=i-a;o<155?(u=Math.floor(o/31)+2,l=o%31+1):(o-=155,u=Math.floor(o/30)+7,l=o%30+1)}return new ju(this,r,u,l)}toJulianDay(t){let n=t.year+jT,[r,i]=LC(n),a,u;return Nv(i)?(a=31,u=F1(r,i,3,21)):(a=30,u=F1(r,i,3,22)),t.month===1?u+t.day-1:(u+=a+Math.min(t.month-2,5)*31,t.month>=8&&(u+=(t.month-7)*30),u+=t.day-1,u)}getDaysInMonth(t){return t.month===1&&Nv(t.year+jT)||t.month>=2&&t.month<=6?31:30}getYearsInEra(){return 9919}getEras(){return["saka"]}balanceDate(){}constructor(...t){super(...t),this.identifier="indian"}}const VD=1948440,jU=1948439,Bd=1300,yO=1600,hEe=460322;function UD(e,t,n,r){return r+Math.ceil(29.5*(n-1))+(t-1)*354+Math.floor((3+11*t)/30)+e-1}function dne(e,t,n){let r=Math.floor((30*(n-t)+10646)/10631),i=Math.min(12,Math.ceil((n-(29+UD(t,r,1,1)))/29.5)+1),a=n-UD(t,r,i,1)+1;return new ju(e,r,i,a)}function ZU(e){return(14+11*e)%30<11}class yN{fromJulianDay(t){return dne(this,VD,t)}toJulianDay(t){return UD(VD,t.year,t.month,t.day)}getDaysInMonth(t){let n=29+t.month%2;return t.month===12&&ZU(t.year)&&n++,n}getMonthsInYear(){return 12}getDaysInYear(t){return ZU(t.year)?355:354}getYearsInEra(){return 9665}getEras(){return["AH"]}constructor(){this.identifier="islamic-civil"}}class pEe extends yN{fromJulianDay(t){return dne(this,jU,t)}toJulianDay(t){return UD(jU,t.year,t.month,t.day)}constructor(...t){super(...t),this.identifier="islamic-tbla"}}const mEe="qgpUDckO1AbqBmwDrQpVBakGkgepC9QF2gpcBS0NlQZKB1QLagutBa4ETwoXBYsGpQbVCtYCWwmdBE0KJg2VDawFtgm6AlsKKwWVCsoG6Qr0AnYJtgJWCcoKpAvSC9kF3AJtCU0FpQpSC6ULtAW2CVcFlwJLBaMGUgdlC2oFqworBZUMSg2lDcoF1gpXCasESwmlClILagt1BXYCtwhbBFUFqQW0BdoJ3QRuAjYJqgpUDbIN1QXaAlsJqwRVCkkLZAtxC7QFtQpVCiUNkg7JDtQG6QprCasEkwpJDaQNsg25CroEWworBZUKKgtVC1wFvQQ9Ah0JlQpKC1oLbQW2AjsJmwRVBqkGVAdqC2wFrQpVBSkLkgupC9QF2gpaBasKlQVJB2QHqgu1BbYCVgpNDiULUgtqC60FrgIvCZcESwalBqwG1gpdBZ0ETQoWDZUNqgW1BdoCWwmtBJUFygbkBuoK9QS2AlYJqgpUC9IL2QXqAm0JrQSVCkoLpQuyBbUJ1gSXCkcFkwZJB1ULagVrCisFiwpGDaMNygXWCtsEawJLCaUKUgtpC3UFdgG3CFsCKwVlBbQF2gntBG0BtgimClINqQ3UBdoKWwmrBFMGKQdiB6kLsgW1ClUFJQuSDckO0gbpCmsFqwRVCikNVA2qDbUJugQ7CpsETQqqCtUK2gJdCV4ELgqaDFUNsga5BroEXQotBZUKUguoC7QLuQXaAloJSgukDdEO6AZqC20FNQWVBkoNqA3UDdoGWwWdAisGFQtKC5ULqgWuCi4JjwwnBZUGqgbWCl0FnQI=";let D9,u3;function HE(e){return hEe+u3[e-Bd]}function P2(e,t){let n=e-Bd,r=1<<11-(t-1);return(D9[n]&r)===0?29:30}function HU(e,t){let n=HE(e);for(let r=1;r<t;r++)n+=P2(e,r);return n}function XU(e){return u3[e+1-Bd]-u3[e-Bd]}class gEe extends yN{fromJulianDay(t){let n=t-VD,r=HE(Bd),i=HE(yO);if(n<r||n>i)return super.fromJulianDay(t);{let a=Bd-1,u=1,l=1;for(;l>0;){a++,l=n-HE(a)+1;let o=XU(a);if(l===o){u=12;break}else if(l<o){let s=P2(a,u);for(u=1;l>s;)l-=s,u++,s=P2(a,u);break}}return new ju(this,a,u,n-HU(a,u)+1)}}toJulianDay(t){return t.year<Bd||t.year>yO?super.toJulianDay(t):VD+HU(t.year,t.month)+(t.day-1)}getDaysInMonth(t){return t.year<Bd||t.year>yO?super.getDaysInMonth(t):P2(t.year,t.month)}getDaysInYear(t){return t.year<Bd||t.year>yO?super.getDaysInYear(t):XU(t.year)}constructor(){if(super(),this.identifier="islamic-umalqura",D9||(D9=new Uint16Array(Uint8Array.from(atob(mEe),t=>t.charCodeAt(0)).buffer)),!u3){u3=new Uint32Array(yO-Bd+1);let t=0;for(let n=Bd;n<=yO;n++){u3[n-Bd]=t;for(let r=1;r<=12;r++)t+=P2(n,r)}}}}const YU=347997,hne=1080,pne=24*hne,vEe=29,yEe=12*hne+793,bEe=vEe*pne+yEe;function k1(e){return i3(e*7+1,19)<7}function XE(e){let t=Math.floor((235*e-234)/19),n=12084+13753*t,r=t*29+Math.floor(n/25920);return i3(3*(r+1),7)<3&&(r+=1),r}function OEe(e){let t=XE(e-1),n=XE(e);return XE(e+1)-n===356?2:n-t===382?1:0}function V2(e){return XE(e)+OEe(e)}function mne(e){return V2(e+1)-V2(e)}function xEe(e){let t=mne(e);switch(t>380&&(t-=30),t){case 353:return 0;case 354:return 1;case 355:return 2}}function L_(e,t){if(t>=6&&!k1(e)&&t++,t===4||t===7||t===9||t===11||t===13)return 29;let n=xEe(e);return t===2?n===2?30:29:t===3?n===0?29:30:t===6?k1(e)?30:0:30}class SEe{fromJulianDay(t){let n=t-YU,r=n*pne/bEe,i=Math.floor((19*r+234)/235)+1,a=V2(i),u=Math.floor(n-a);for(;u<1;)i--,a=V2(i),u=Math.floor(n-a);let l=1,o=0;for(;o<u;)o+=L_(i,l),l++;l--,o-=L_(i,l);let s=u-o;return new ju(this,i,l,s)}toJulianDay(t){let n=V2(t.year);for(let r=1;r<t.month;r++)n+=L_(t.year,r);return n+t.day+YU}getDaysInMonth(t){return L_(t.year,t.month)}getMonthsInYear(t){return k1(t.year)?13:12}getDaysInYear(t){return mne(t.year)}getYearsInEra(){return 9999}getEras(){return["AM"]}balanceYearMonth(t,n){n.year!==t.year&&(k1(n.year)&&!k1(t.year)&&n.month>6?t.month--:!k1(n.year)&&k1(t.year)&&n.month>6&&t.month++)}constructor(){this.identifier="hebrew"}}const $9=1723856,GU=1824665,C9=5500;function jD(e,t,n,r){return e+365*t+Math.floor(t/4)+30*(n-1)+r-1}function bN(e,t){let n=Math.floor(4*(t-e)/1461),r=1+Math.floor((t-jD(e,n,1,1))/30),i=t+1-jD(e,n,r,1);return[n,r,i]}function gne(e){return Math.floor(e%4/3)}function vne(e,t){return t%13!==0?30:gne(e)+5}class ON{fromJulianDay(t){let[n,r,i]=bN($9,t),a="AM";return n<=0&&(a="AA",n+=C9),new ju(this,a,n,r,i)}toJulianDay(t){let n=t.year;return t.era==="AA"&&(n-=C9),jD($9,n,t.month,t.day)}getDaysInMonth(t){return vne(t.year,t.month)}getMonthsInYear(){return 13}getDaysInYear(t){return 365+gne(t.year)}getYearsInEra(t){return t.era==="AA"?9999:9991}getEras(){return["AA","AM"]}constructor(){this.identifier="ethiopic"}}class _Ee extends ON{fromJulianDay(t){let[n,r,i]=bN($9,t);return n+=C9,new ju(this,"AA",n,r,i)}getEras(){return["AA"]}getYearsInEra(){return 9999}constructor(...t){super(...t),this.identifier="ethioaa"}}class EEe extends ON{fromJulianDay(t){let[n,r,i]=bN(GU,t),a="CE";return n<=0&&(a="BCE",n=1-n),new ju(this,a,n,r,i)}toJulianDay(t){let n=t.year;return t.era==="BCE"&&(n=1-n),jD(GU,n,t.month,t.day)}getDaysInMonth(t){let n=t.year;return t.era==="BCE"&&(n=1-n),vne(n,t.month)}isInverseEra(t){return t.era==="BCE"}balanceDate(t){t.year<=0&&(t.era=t.era==="BCE"?"CE":"BCE",t.year=1-t.year)}getEras(){return["BCE","CE"]}getYearsInEra(t){return t.era==="BCE"?9999:9715}constructor(...t){super(...t),this.identifier="coptic"}}function yne(e){switch(e){case"buddhist":return new sEe;case"ethiopic":return new ON;case"ethioaa":return new _Ee;case"coptic":return new EEe;case"hebrew":return new SEe;case"indian":return new dEe;case"islamic-civil":return new yN;case"islamic-tbla":return new pEe;case"islamic-umalqura":return new gEe;case"japanese":return new oEe;case"persian":return new fEe;case"roc":return new cEe;case"gregory":default:return new Hf}}let ZT=new Map;class VO{format(t){return this.formatter.format(t)}formatToParts(t){return this.formatter.formatToParts(t)}formatRange(t,n){if(typeof this.formatter.formatRange=="function")return this.formatter.formatRange(t,n);if(n<t)throw new RangeError("End date must be >= start date");return`${this.formatter.format(t)} – ${this.formatter.format(n)}`}formatRangeToParts(t,n){if(typeof this.formatter.formatRangeToParts=="function")return this.formatter.formatRangeToParts(t,n);if(n<t)throw new RangeError("End date must be >= start date");let r=this.formatter.formatToParts(t),i=this.formatter.formatToParts(n);return[...r.map(a=>({...a,source:"startRange"})),{type:"literal",value:" – ",source:"shared"},...i.map(a=>({...a,source:"endRange"}))]}resolvedOptions(){let t=this.formatter.resolvedOptions();return CEe()&&(this.resolvedHourCycle||(this.resolvedHourCycle=wEe(t.locale,this.options)),t.hourCycle=this.resolvedHourCycle,t.hour12=this.resolvedHourCycle==="h11"||this.resolvedHourCycle==="h12"),t.calendar==="ethiopic-amete-alem"&&(t.calendar="ethioaa"),t}constructor(t,n={}){this.formatter=bne(t,n),this.options=n}}const DEe={true:{ja:"h11"},false:{}};function bne(e,t={}){if(typeof t.hour12=="boolean"&&$Ee()){t={...t};let i=DEe[String(t.hour12)][e.split("-")[0]],a=t.hour12?"h12":"h23";t.hourCycle=i??a,delete t.hour12}let n=e+(t?Object.entries(t).sort((i,a)=>i[0]<a[0]?-1:1).join():"");if(ZT.has(n))return ZT.get(n);let r=new Intl.DateTimeFormat(e,t);return ZT.set(n,r),r}let HT=null;function $Ee(){return HT==null&&(HT=new Intl.DateTimeFormat("en-US",{hour:"numeric",hour12:!1}).format(new Date(2020,2,3,0))==="24"),HT}let XT=null;function CEe(){return XT==null&&(XT=new Intl.DateTimeFormat("fr",{hour:"numeric",hour12:!1}).resolvedOptions().hourCycle==="h12"),XT}function wEe(e,t){if(!t.timeStyle&&!t.hour)return;e=e.replace(/(-u-)?-nu-[a-zA-Z0-9]+/,""),e+=(e.includes("-u-")?"":"-u")+"-nu-latn";let n=bne(e,{...t,timeZone:void 0}),r=parseInt(n.formatToParts(new Date(2020,2,3,0)).find(a=>a.type==="hour").value,10),i=parseInt(n.formatToParts(new Date(2020,2,3,23)).find(a=>a.type==="hour").value,10);if(r===0&&i===23)return"h23";if(r===24&&i===23)return"h24";if(r===0&&i===11)return"h11";if(r===12&&i===11)return"h12";throw new Error("Unexpected hour cycle result")}function B_(e){e=n_e(e??{},REe);let{locale:t}=Hi();return P.useMemo(()=>new VO(t,e),[t,e])}function REe(e,t){if(e===t)return!0;let n=Object.keys(e),r=Object.keys(t);if(n.length!==r.length)return!1;for(let i of n)if(t[i]!==e[i])return!1;return!0}let YT=new Map,w9=!1;try{w9=new Intl.NumberFormat("de-DE",{signDisplay:"exceptZero"}).resolvedOptions().signDisplay==="exceptZero"}catch{}let ZD=!1;try{ZD=new Intl.NumberFormat("de-DE",{style:"unit",unit:"degree"}).resolvedOptions().style==="unit"}catch{}const One={degree:{narrow:{default:"°","ja-JP":" 度","zh-TW":"度","sl-SI":" °"}}};class Wv{format(t){let n="";if(!w9&&this.options.signDisplay!=null?n=TEe(this.numberFormatter,this.options.signDisplay,t):n=this.numberFormatter.format(t),this.options.style==="unit"&&!ZD){var r;let{unit:i,unitDisplay:a="short",locale:u}=this.resolvedOptions();if(!i)return n;let l=(r=One[i])===null||r===void 0?void 0:r[a];n+=l[u]||l.default}return n}formatToParts(t){return this.numberFormatter.formatToParts(t)}formatRange(t,n){if(typeof this.numberFormatter.formatRange=="function")return this.numberFormatter.formatRange(t,n);if(n<t)throw new RangeError("End date must be >= start date");return`${this.format(t)} – ${this.format(n)}`}formatRangeToParts(t,n){if(typeof this.numberFormatter.formatRangeToParts=="function")return this.numberFormatter.formatRangeToParts(t,n);if(n<t)throw new RangeError("End date must be >= start date");let r=this.numberFormatter.formatToParts(t),i=this.numberFormatter.formatToParts(n);return[...r.map(a=>({...a,source:"startRange"})),{type:"literal",value:" – ",source:"shared"},...i.map(a=>({...a,source:"endRange"}))]}resolvedOptions(){let t=this.numberFormatter.resolvedOptions();return!w9&&this.options.signDisplay!=null&&(t={...t,signDisplay:this.options.signDisplay}),!ZD&&this.options.style==="unit"&&(t={...t,style:"unit",unit:this.options.unit,unitDisplay:this.options.unitDisplay}),t}constructor(t,n={}){this.numberFormatter=AEe(t,n),this.options=n}}function AEe(e,t={}){let{numberingSystem:n}=t;if(n&&e.includes("-nu-")&&(e.includes("-u-")||(e+="-u-"),e+=`-nu-${n}`),t.style==="unit"&&!ZD){var r;let{unit:u,unitDisplay:l="short"}=t;if(!u)throw new Error('unit option must be provided with style: "unit"');if(!(!((r=One[u])===null||r===void 0)&&r[l]))throw new Error(`Unsupported unit ${u} with unitDisplay = ${l}`);t={...t,style:"decimal"}}let i=e+(t?Object.entries(t).sort((u,l)=>u[0]<l[0]?-1:1).join():"");if(YT.has(i))return YT.get(i);let a=new Intl.NumberFormat(e,t);return YT.set(i,a),a}function TEe(e,t,n){if(t==="auto")return e.format(n);if(t==="never")return e.format(Math.abs(n));{let r=!1;if(t==="always"?r=n>0||Object.is(n,0):t==="exceptZero"&&(Object.is(n,-0)||Object.is(n,0)?n=Math.abs(n):r=n>0),r){let i=e.format(-n),a=e.format(n),u=i.replace(a,"").replace(/\u200e|\u061C/,"");return[...u].length!==1&&console.warn("@react-aria/i18n polyfill for NumberFormat signDisplay: Unsupported case"),i.replace(a,"!!!").replace(u,"+").replace("!!!",a)}else return e.format(n)}}const kEe=new RegExp("^.*\\(.*\\).*$"),PEe=["latn","arab","hanidec","deva","beng","fullwide"];class xN{parse(t){return GT(this.locale,this.options,t).parse(t)}isValidPartialNumber(t,n,r){return GT(this.locale,this.options,t).isValidPartialNumber(t,n,r)}getNumberingSystem(t){return GT(this.locale,this.options,t).options.numberingSystem}constructor(t,n={}){this.locale=t,this.options=n}}const KU=new Map;function GT(e,t,n){let r=WU(e,t);if(!e.includes("-nu-")&&!r.isValidPartialNumber(n)){for(let i of PEe)if(i!==r.options.numberingSystem){let a=WU(e+(e.includes("-u-")?"-nu-":"-u-nu-")+i,t);if(a.isValidPartialNumber(n))return a}}return r}function WU(e,t){let n=e+(t?Object.entries(t).sort((i,a)=>i[0]<a[0]?-1:1).join():""),r=KU.get(n);return r||(r=new MEe(e,t),KU.set(n,r)),r}class MEe{parse(t){let n=this.sanitize(t);if(this.symbols.group&&(n=bO(n,this.symbols.group,"")),this.symbols.decimal&&(n=n.replace(this.symbols.decimal,".")),this.symbols.minusSign&&(n=n.replace(this.symbols.minusSign,"-")),n=n.replace(this.symbols.numeral,this.symbols.index),this.options.style==="percent"){let u=n.indexOf("-");n=n.replace("-",""),n=n.replace("+","");let l=n.indexOf(".");l===-1&&(l=n.length),n=n.replace(".",""),l-2===0?n=`0.${n}`:l-2===-1?n=`0.0${n}`:l-2===-2?n="0.00":n=`${n.slice(0,l-2)}.${n.slice(l-2)}`,u>-1&&(n=`-${n}`)}let r=n?+n:NaN;if(isNaN(r))return NaN;if(this.options.style==="percent"){var i,a;let u={...this.options,style:"decimal",minimumFractionDigits:Math.min(((i=this.options.minimumFractionDigits)!==null&&i!==void 0?i:0)+2,20),maximumFractionDigits:Math.min(((a=this.options.maximumFractionDigits)!==null&&a!==void 0?a:0)+2,20)};return new xN(this.locale,u).parse(new Wv(this.locale,u).format(r))}return this.options.currencySign==="accounting"&&kEe.test(t)&&(r=-1*r),r}sanitize(t){return t=t.replace(this.symbols.literals,""),this.symbols.minusSign&&(t=t.replace("-",this.symbols.minusSign)),this.options.numberingSystem==="arab"&&(this.symbols.decimal&&(t=t.replace(",",this.symbols.decimal),t=t.replace("،",this.symbols.decimal)),this.symbols.group&&(t=bO(t,".",this.symbols.group))),this.symbols.group==="’"&&t.includes("'")&&(t=bO(t,"'",this.symbols.group)),this.options.locale==="fr-FR"&&this.symbols.group&&(t=bO(t," ",this.symbols.group),t=bO(t,/\u00A0/g,this.symbols.group)),t}isValidPartialNumber(t,n=-1/0,r=1/0){return t=this.sanitize(t),this.symbols.minusSign&&t.startsWith(this.symbols.minusSign)&&n<0?t=t.slice(this.symbols.minusSign.length):this.symbols.plusSign&&t.startsWith(this.symbols.plusSign)&&r>0&&(t=t.slice(this.symbols.plusSign.length)),this.symbols.group&&t.startsWith(this.symbols.group)||this.symbols.decimal&&t.indexOf(this.symbols.decimal)>-1&&this.options.maximumFractionDigits===0?!1:(this.symbols.group&&(t=bO(t,this.symbols.group,"")),t=t.replace(this.symbols.numeral,""),this.symbols.decimal&&(t=t.replace(this.symbols.decimal,"")),t.length===0)}constructor(t,n={}){this.locale=t,n.roundingIncrement!==1&&n.roundingIncrement!=null&&(n.maximumFractionDigits==null&&n.minimumFractionDigits==null?(n.maximumFractionDigits=0,n.minimumFractionDigits=0):n.maximumFractionDigits==null?n.maximumFractionDigits=n.minimumFractionDigits:n.minimumFractionDigits==null&&(n.minimumFractionDigits=n.maximumFractionDigits)),this.formatter=new Intl.NumberFormat(t,n),this.options=this.formatter.resolvedOptions(),this.symbols=NEe(t,this.formatter,this.options,n);var r,i;this.options.style==="percent"&&(((r=this.options.minimumFractionDigits)!==null&&r!==void 0?r:0)>18||((i=this.options.maximumFractionDigits)!==null&&i!==void 0?i:0)>18)&&console.warn("NumberParser cannot handle percentages with greater than 18 decimal places, please reduce the number in your options.")}}const JU=new Set(["decimal","fraction","integer","minusSign","plusSign","group"]),FEe=[0,4,2,1,11,20,3,7,100,21,.1,1.1];function NEe(e,t,n,r){var i,a,u,l;let o=new Intl.NumberFormat(e,{...n,minimumSignificantDigits:1,maximumSignificantDigits:21,roundingIncrement:1,roundingPriority:"auto",roundingMode:"halfExpand"}),s=o.formatToParts(-10000.111),c=o.formatToParts(10000.111),d=FEe.map(j=>o.formatToParts(j));var h;let m=(h=(i=s.find(j=>j.type==="minusSign"))===null||i===void 0?void 0:i.value)!==null&&h!==void 0?h:"-",y=(a=c.find(j=>j.type==="plusSign"))===null||a===void 0?void 0:a.value;!y&&((r==null?void 0:r.signDisplay)==="exceptZero"||(r==null?void 0:r.signDisplay)==="always")&&(y="+");let _=(u=new Intl.NumberFormat(e,{...n,minimumFractionDigits:2,maximumFractionDigits:2}).formatToParts(.001).find(j=>j.type==="decimal"))===null||u===void 0?void 0:u.value,S=(l=s.find(j=>j.type==="group"))===null||l===void 0?void 0:l.value,E=s.filter(j=>!JU.has(j.type)).map(j=>ej(j.value)),C=d.flatMap(j=>j.filter(V=>!JU.has(V.type)).map(V=>ej(V.value))),T=[...new Set([...E,...C])].sort((j,V)=>V.length-j.length),R=T.length===0?new RegExp("[\\p{White_Space}]","gu"):new RegExp(`${T.join("|")}|[\\p{White_Space}]`,"gu"),$=[...new Intl.NumberFormat(n.locale,{useGrouping:!1}).format(9876543210)].reverse(),k=new Map($.map((j,V)=>[j,V])),F=new RegExp(`[${$.join("")}]`,"g");return{minusSign:m,plusSign:y,decimal:_,group:S,literals:R,numeral:F,index:j=>String(k.get(j))}}function bO(e,t,n){return e.replaceAll?e.replaceAll(t,n):e.split(t).join(n)}function ej(e){return e.replace(/[.*+?^${}()|[\]\\]/g,"\\$&")}function HD(e={}){let{locale:t}=Hi();return P.useMemo(()=>new Wv(t,e),[t,e])}let KT=new Map;function zC(e){let{locale:t}=Hi(),n=t+(e?Object.entries(e).sort((i,a)=>i[0]<a[0]?-1:1).join():"");if(KT.has(n))return KT.get(n);let r=new Intl.Collator(t,e);return KT.set(n,r),r}function xne(e){let t=zC({usage:"search",...e}),n=P.useCallback((a,u)=>u.length===0?!0:(a=a.normalize("NFC"),u=u.normalize("NFC"),t.compare(a.slice(0,u.length),u)===0),[t]),r=P.useCallback((a,u)=>u.length===0?!0:(a=a.normalize("NFC"),u=u.normalize("NFC"),t.compare(a.slice(-u.length),u)===0),[t]),i=P.useCallback((a,u)=>{if(u.length===0)return!0;a=a.normalize("NFC"),u=u.normalize("NFC");let l=0,o=u.length;for(;l+o<=a.length;l++){let s=a.slice(l,l+o);if(t.compare(u,s)===0)return!0}return!1},[t]);return P.useMemo(()=>({startsWith:n,endsWith:r,contains:i}),[n,r,i])}let Bu=typeof document<"u"?window.visualViewport:null;function Sne(e){let{direction:t}=Hi(),{arrowSize:n,targetRef:r,overlayRef:i,arrowRef:a,scrollRef:u=i,placement:l="bottom",containerPadding:o=12,shouldFlip:s=!0,boundaryElement:c=typeof document<"u"?document.body:null,offset:d=0,crossOffset:h=0,shouldUpdatePosition:m=!0,isOpen:y=!0,onClose:v,maxHeight:_,arrowBoundaryOffset:S=0}=e,[E,C]=P.useState(null),T=[m,l,i.current,r.current,a==null?void 0:a.current,u.current,o,s,c,d,h,y,t,_,S,n],R=P.useRef(Bu==null?void 0:Bu.scale);P.useEffect(()=>{y&&(R.current=Bu==null?void 0:Bu.scale)},[y]);let $=P.useCallback(()=>{if(m===!1||!y||!i.current||!r.current||!c||(Bu==null?void 0:Bu.scale)!==R.current)return;let q=null;if(u.current&&u.current.contains(document.activeElement)){var N;let M=(N=document.activeElement)===null||N===void 0?void 0:N.getBoundingClientRect(),K=u.current.getBoundingClientRect();var U;if(q={type:"top",offset:((U=M==null?void 0:M.top)!==null&&U!==void 0?U:0)-K.top},q.offset>K.height/2){q.type="bottom";var W;q.offset=((W=M==null?void 0:M.bottom)!==null&&W!==void 0?W:0)-K.bottom}}let G=i.current;if(!_&&i.current){var J;G.style.top="0px",G.style.bottom="";var te;G.style.maxHeight=((te=(J=window.visualViewport)===null||J===void 0?void 0:J.height)!==null&&te!==void 0?te:window.innerHeight)+"px"}let H=y_e({placement:LEe(l,t),overlayNode:i.current,targetNode:r.current,scrollNode:u.current||i.current,padding:o,shouldFlip:s,boundaryElement:c,offset:d,crossOffset:h,maxHeight:_,arrowSize:n??(a!=null&&a.current?fN(a.current,!0).width:0),arrowBoundaryOffset:S});if(H.position){if(G.style.top="",G.style.bottom="",G.style.left="",G.style.right="",Object.keys(H.position).forEach(M=>G.style[M]=H.position[M]+"px"),G.style.maxHeight=H.maxHeight!=null?H.maxHeight+"px":"",q&&document.activeElement&&u.current){let M=document.activeElement.getBoundingClientRect(),K=u.current.getBoundingClientRect(),X=M[q.type]-K[q.type];u.current.scrollTop+=X-q.offset}C(H)}},T);qr($,T),IEe($),ab({ref:i,onResize:$}),ab({ref:r,onResize:$});let k=P.useRef(!1);qr(()=>{let q,N=()=>{k.current=!0,clearTimeout(q),q=setTimeout(()=>{k.current=!1},500),$()},U=()=>{k.current&&N()};return Bu==null||Bu.addEventListener("resize",N),Bu==null||Bu.addEventListener("scroll",U),()=>{Bu==null||Bu.removeEventListener("resize",N),Bu==null||Bu.removeEventListener("scroll",U)}},[$]);let F=P.useCallback(()=>{k.current||v==null||v()},[v,k]);O_e({triggerRef:r,isOpen:y,onClose:v&&F});var L,j,V;return{overlayProps:{style:{position:E?"absolute":"fixed",top:E?void 0:0,left:E?void 0:0,zIndex:1e5,...E==null?void 0:E.position,maxHeight:(L=E==null?void 0:E.maxHeight)!==null&&L!==void 0?L:"100vh"}},placement:(j=E==null?void 0:E.placement)!==null&&j!==void 0?j:null,triggerAnchorPoint:(V=E==null?void 0:E.triggerAnchorPoint)!==null&&V!==void 0?V:null,arrowProps:{"aria-hidden":"true",role:"presentation",style:{left:E==null?void 0:E.arrowOffsetLeft,top:E==null?void 0:E.arrowOffsetTop}},updatePosition:$}}function IEe(e){qr(()=>(window.addEventListener("resize",e,!1),()=>{window.removeEventListener("resize",e,!1)}),[e])}function LEe(e,t){return t==="rtl"?e.replace("start","right").replace("end","left"):e.replace("start","left").replace("end","right")}function SN(e){let t=e;return t.nativeEvent=e,t.isDefaultPrevented=()=>t.defaultPrevented,t.isPropagationStopped=()=>t.cancelBubble,t.persist=()=>{},t}function _ne(e,t){Object.defineProperty(e,"target",{value:t}),Object.defineProperty(e,"currentTarget",{value:t})}function Ene(e){let t=P.useRef({isFocused:!1,observer:null});qr(()=>{const r=t.current;return()=>{r.observer&&(r.observer.disconnect(),r.observer=null)}},[]);let n=oi(r=>{e==null||e(r)});return P.useCallback(r=>{if(r.target instanceof HTMLButtonElement||r.target instanceof HTMLInputElement||r.target instanceof HTMLTextAreaElement||r.target instanceof HTMLSelectElement){t.current.isFocused=!0;let i=r.target,a=u=>{if(t.current.isFocused=!1,i.disabled){let l=SN(u);n(l)}t.current.observer&&(t.current.observer.disconnect(),t.current.observer=null)};i.addEventListener("focusout",a,{once:!0}),t.current.observer=new MutationObserver(()=>{if(t.current.isFocused&&i.disabled){var u;(u=t.current.observer)===null||u===void 0||u.disconnect();let l=i===document.activeElement?null:document.activeElement;i.dispatchEvent(new FocusEvent("blur",{relatedTarget:l})),i.dispatchEvent(new FocusEvent("focusout",{bubbles:!0,relatedTarget:l}))}}),t.current.observer.observe(i,{attributes:!0,attributeFilter:["disabled"]})}},[n])}let XD=!1;function BEe(e){for(;e&&!tte(e);)e=e.parentElement;let t=af(e),n=t.document.activeElement;if(!n||n===e)return;XD=!0;let r=!1,i=c=>{(c.target===n||r)&&c.stopImmediatePropagation()},a=c=>{(c.target===n||r)&&(c.stopImmediatePropagation(),!e&&!r&&(r=!0,_u(n),o()))},u=c=>{(c.target===e||r)&&c.stopImmediatePropagation()},l=c=>{(c.target===e||r)&&(c.stopImmediatePropagation(),r||(r=!0,_u(n),o()))};t.addEventListener("blur",i,!0),t.addEventListener("focusout",a,!0),t.addEventListener("focusin",l,!0),t.addEventListener("focus",u,!0);let o=()=>{cancelAnimationFrame(s),t.removeEventListener("blur",i,!0),t.removeEventListener("focusout",a,!0),t.removeEventListener("focusin",l,!0),t.removeEventListener("focus",u,!0),XD=!1,r=!1},s=requestAnimationFrame(o);return o}let UO="default",R9="",YE=new WeakMap;function Dne(e){if(Db()){if(UO==="default"){const t=ci(e);R9=t.documentElement.style.webkitUserSelect,t.documentElement.style.webkitUserSelect="none"}UO="disabled"}else if(e instanceof HTMLElement||e instanceof SVGElement){let t="userSelect"in e.style?"userSelect":"webkitUserSelect";YE.set(e,e.style[t]),e.style[t]="none"}}function A9(e){if(Db()){if(UO!=="disabled")return;UO="restoring",setTimeout(()=>{Xee(()=>{if(UO==="restoring"){const t=ci(e);t.documentElement.style.webkitUserSelect==="none"&&(t.documentElement.style.webkitUserSelect=R9||""),R9="",UO="default"}})},300)}else if((e instanceof HTMLElement||e instanceof SVGElement)&&e&&YE.has(e)){let t=YE.get(e),n="userSelect"in e.style?"userSelect":"webkitUserSelect";e.style[n]==="none"&&(e.style[n]=t),e.getAttribute("style")===""&&e.removeAttribute("style"),YE.delete(e)}}const mx=ye.createContext({register:()=>{}});mx.displayName="PressResponderContext";function QEe(e,t){return t.get?t.get.call(e):t.value}function $ne(e,t,n){if(!t.has(e))throw new TypeError("attempted to "+n+" private field on non-instance");return t.get(e)}function zEe(e,t){var n=$ne(e,t,"get");return QEe(e,n)}function qEe(e,t,n){if(t.set)t.set.call(e,n);else{if(!t.writable)throw new TypeError("attempted to set read only private field");t.value=n}}function tj(e,t,n){var r=$ne(e,t,"set");return qEe(e,r,n),n}function VEe(e){let t=P.useContext(mx);if(t){let{register:n,...r}=t;e=Et(r,e),n()}return oN(t,e.ref),e}var Q_=new WeakMap;class z_{continuePropagation(){tj(this,Q_,!1)}get shouldStopPropagation(){return zEe(this,Q_)}constructor(t,n,r,i){sS(this,Q_,{writable:!0,value:void 0}),tj(this,Q_,!0);var a;let u=(a=i==null?void 0:i.target)!==null&&a!==void 0?a:r.currentTarget;const l=u==null?void 0:u.getBoundingClientRect();let o,s=0,c,d=null;r.clientX!=null&&r.clientY!=null&&(c=r.clientX,d=r.clientY),l&&(c!=null&&d!=null?(o=c-l.left,s=d-l.top):(o=l.width/2,s=l.height/2)),this.type=t,this.pointerType=n,this.target=r.currentTarget,this.shiftKey=r.shiftKey,this.metaKey=r.metaKey,this.ctrlKey=r.ctrlKey,this.altKey=r.altKey,this.x=o,this.y=s}}const nj=Symbol("linkClicked"),rj="react-aria-pressable-style",ij="data-react-aria-pressable";function up(e){let{onPress:t,onPressChange:n,onPressStart:r,onPressEnd:i,onPressUp:a,onClick:u,isDisabled:l,isPressed:o,preventFocusOnPress:s,shouldCancelOnPointerExit:c,allowTextSelectionOnPress:d,ref:h,...m}=VEe(e),[y,v]=P.useState(!1),_=P.useRef({isPressed:!1,ignoreEmulatedMouseEvents:!1,didFirePressStart:!1,isTriggeringEvent:!1,activePointerId:null,target:null,isOverTarget:!1,pointerType:null,disposables:[]}),{addGlobalListener:S,removeAllGlobalListeners:E}=py(),C=oi((V,q)=>{let N=_.current;if(l||N.didFirePressStart)return!1;let U=!0;if(N.isTriggeringEvent=!0,r){let W=new z_("pressstart",q,V);r(W),U=W.shouldStopPropagation}return n&&n(!0),N.isTriggeringEvent=!1,N.didFirePressStart=!0,v(!0),U}),T=oi((V,q,N=!0)=>{let U=_.current;if(!U.didFirePressStart)return!1;U.didFirePressStart=!1,U.isTriggeringEvent=!0;let W=!0;if(i){let G=new z_("pressend",q,V);i(G),W=G.shouldStopPropagation}if(n&&n(!1),v(!1),t&&N&&!l){let G=new z_("press",q,V);t(G),W&&(W=G.shouldStopPropagation)}return U.isTriggeringEvent=!1,W}),R=oi((V,q)=>{let N=_.current;if(l)return!1;if(a){N.isTriggeringEvent=!0;let U=new z_("pressup",q,V);return a(U),N.isTriggeringEvent=!1,U.shouldStopPropagation}return!0}),$=oi(V=>{let q=_.current;if(q.isPressed&&q.target){q.didFirePressStart&&q.pointerType!=null&&T(m1(q.target,V),q.pointerType,!1),q.isPressed=!1,q.isOverTarget=!1,q.activePointerId=null,q.pointerType=null,E(),d||A9(q.target);for(let N of q.disposables)N();q.disposables=[]}}),k=oi(V=>{c&&$(V)}),F=oi(V=>{l||u==null||u(V)}),L=oi((V,q)=>{if(!l&&u){let N=new MouseEvent("click",V);_ne(N,q),u(SN(N))}}),j=P.useMemo(()=>{let V=_.current,q={onKeyDown(U){if(WT(U.nativeEvent,U.currentTarget)&&Gc(U.currentTarget,qu(U.nativeEvent))){var W;aj(qu(U.nativeEvent),U.key)&&U.preventDefault();let G=!0;if(!V.isPressed&&!U.repeat){V.target=U.currentTarget,V.isPressed=!0,V.pointerType="keyboard",G=C(U,"keyboard");let J=U.currentTarget,te=H=>{WT(H,J)&&!H.repeat&&Gc(J,qu(H))&&V.target&&R(m1(V.target,H),"keyboard")};S(ci(U.currentTarget),"keyup",rh(te,N),!0)}G&&U.stopPropagation(),U.metaKey&&sg()&&((W=V.metaKeyEvents)===null||W===void 0||W.set(U.key,U.nativeEvent))}else U.key==="Meta"&&(V.metaKeyEvents=new Map)},onClick(U){if(!(U&&!Gc(U.currentTarget,qu(U.nativeEvent)))&&U&&U.button===0&&!V.isTriggeringEvent&&!ib.isOpening){let W=!0;if(l&&U.preventDefault(),!V.ignoreEmulatedMouseEvents&&!V.isPressed&&(V.pointerType==="virtual"||Kee(U.nativeEvent))){let G=C(U,"virtual"),J=R(U,"virtual"),te=T(U,"virtual");F(U),W=G&&J&&te}else if(V.isPressed&&V.pointerType!=="keyboard"){let G=V.pointerType||U.nativeEvent.pointerType||"virtual",J=R(m1(U.currentTarget,U),G),te=T(m1(U.currentTarget,U),G,!0);W=J&&te,V.isOverTarget=!1,F(U),$(U)}V.ignoreEmulatedMouseEvents=!1,W&&U.stopPropagation()}}},N=U=>{var W;if(V.isPressed&&V.target&&WT(U,V.target)){var G;aj(qu(U),U.key)&&U.preventDefault();let te=qu(U),H=Gc(V.target,qu(U));T(m1(V.target,U),"keyboard",H),H&&L(U,V.target),E(),U.key!=="Enter"&&_N(V.target)&&Gc(V.target,te)&&!U[nj]&&(U[nj]=!0,ib(V.target,U,!1)),V.isPressed=!1,(G=V.metaKeyEvents)===null||G===void 0||G.delete(U.key)}else if(U.key==="Meta"&&(!((W=V.metaKeyEvents)===null||W===void 0)&&W.size)){var J;let te=V.metaKeyEvents;V.metaKeyEvents=void 0;for(let H of te.values())(J=V.target)===null||J===void 0||J.dispatchEvent(new KeyboardEvent("keyup",H))}};if(typeof PointerEvent<"u"){q.onPointerDown=G=>{if(G.button!==0||!Gc(G.currentTarget,qu(G.nativeEvent)))return;if(t_e(G.nativeEvent)){V.pointerType="virtual";return}V.pointerType=G.pointerType;let J=!0;if(!V.isPressed){V.isPressed=!0,V.isOverTarget=!0,V.activePointerId=G.pointerId,V.target=G.currentTarget,d||Dne(V.target),J=C(G,V.pointerType);let te=qu(G.nativeEvent);"releasePointerCapture"in te&&te.releasePointerCapture(G.pointerId),S(ci(G.currentTarget),"pointerup",U,!1),S(ci(G.currentTarget),"pointercancel",W,!1)}J&&G.stopPropagation()},q.onMouseDown=G=>{if(Gc(G.currentTarget,qu(G.nativeEvent))&&G.button===0){if(s){let J=BEe(G.target);J&&V.disposables.push(J)}G.stopPropagation()}},q.onPointerUp=G=>{!Gc(G.currentTarget,qu(G.nativeEvent))||V.pointerType==="virtual"||G.button===0&&!V.isPressed&&R(G,V.pointerType||G.pointerType)},q.onPointerEnter=G=>{G.pointerId===V.activePointerId&&V.target&&!V.isOverTarget&&V.pointerType!=null&&(V.isOverTarget=!0,C(m1(V.target,G),V.pointerType))},q.onPointerLeave=G=>{G.pointerId===V.activePointerId&&V.target&&V.isOverTarget&&V.pointerType!=null&&(V.isOverTarget=!1,T(m1(V.target,G),V.pointerType,!1),k(G))};let U=G=>{if(G.pointerId===V.activePointerId&&V.isPressed&&G.button===0&&V.target){if(Gc(V.target,qu(G))&&V.pointerType!=null){let J=!1,te=setTimeout(()=>{V.isPressed&&V.target instanceof HTMLElement&&(J?$(G):(_u(V.target),V.target.click()))},80);S(G.currentTarget,"click",()=>J=!0,!0),V.disposables.push(()=>clearTimeout(te))}else $(G);V.isOverTarget=!1}},W=G=>{$(G)};q.onDragStart=G=>{Gc(G.currentTarget,qu(G.nativeEvent))&&$(G)}}return q},[S,l,s,E,d,$,k,T,C,R,F,L]);return P.useEffect(()=>{if(!h)return;const V=ci(h.current);if(!V||!V.head||V.getElementById(rj))return;const q=V.createElement("style");q.id=rj,q.textContent=`
@layer {
  [${ij}] {
    touch-action: pan-x pan-y pinch-zoom;
  }
}
    `.trim(),V.head.prepend(q)},[h]),P.useEffect(()=>{let V=_.current;return()=>{var q;d||A9((q=V.target)!==null&&q!==void 0?q:void 0);for(let N of V.disposables)N();V.disposables=[]}},[d]),{isPressed:o||y,pressProps:Et(m,j,{[ij]:!0})}}function _N(e){return e.tagName==="A"&&e.hasAttribute("href")}function WT(e,t){const{key:n,code:r}=e,i=t,a=i.getAttribute("role");return(n==="Enter"||n===" "||n==="Spacebar"||r==="Space")&&!(i instanceof af(i).HTMLInputElement&&!Cne(i,n)||i instanceof af(i).HTMLTextAreaElement||i.isContentEditable)&&!((a==="link"||!a&&_N(i))&&n!=="Enter")}function m1(e,t){let n=t.clientX,r=t.clientY;return{currentTarget:e,shiftKey:t.shiftKey,ctrlKey:t.ctrlKey,metaKey:t.metaKey,altKey:t.altKey,clientX:n,clientY:r}}function UEe(e){return e instanceof HTMLInputElement?!1:e instanceof HTMLButtonElement?e.type!=="submit"&&e.type!=="reset":!_N(e)}function aj(e,t){return e instanceof HTMLInputElement?!Cne(e,t):UEe(e)}const jEe=new Set(["checkbox","radio","range","color","file","image","button","submit","reset"]);function Cne(e,t){return e.type==="checkbox"||e.type==="radio"?t===" ":jEe.has(e.type)}let cg=null,gx=new Set,U2=new Map,ob=!1,T9=!1;const ZEe={Tab:!0,Escape:!0};function qC(e,t){for(let n of gx)n(e,t)}function HEe(e){return!(e.metaKey||!sg()&&e.altKey||e.ctrlKey||e.key==="Control"||e.key==="Shift"||e.key==="Meta")}function YD(e){ob=!0,HEe(e)&&(cg="keyboard",qC("keyboard",e))}function l3(e){cg="pointer",(e.type==="mousedown"||e.type==="pointerdown")&&(ob=!0,qC("pointer",e))}function wne(e){Kee(e)&&(ob=!0,cg="virtual")}function Rne(e){e.target===window||e.target===document||XD||!e.isTrusted||(!ob&&!T9&&(cg="virtual",qC("virtual",e)),ob=!1,T9=!1)}function Ane(){XD||(ob=!1,T9=!0)}function GD(e){if(typeof window>"u"||typeof document>"u"||U2.get(af(e)))return;const t=af(e),n=ci(e);let r=t.HTMLElement.prototype.focus;t.HTMLElement.prototype.focus=function(){ob=!0,r.apply(this,arguments)},n.addEventListener("keydown",YD,!0),n.addEventListener("keyup",YD,!0),n.addEventListener("click",wne,!0),t.addEventListener("focus",Rne,!0),t.addEventListener("blur",Ane,!1),typeof PointerEvent<"u"&&(n.addEventListener("pointerdown",l3,!0),n.addEventListener("pointermove",l3,!0),n.addEventListener("pointerup",l3,!0)),t.addEventListener("beforeunload",()=>{Tne(e)},{once:!0}),U2.set(t,{focus:r})}const Tne=(e,t)=>{const n=af(e),r=ci(e);t&&r.removeEventListener("DOMContentLoaded",t),U2.has(n)&&(n.HTMLElement.prototype.focus=U2.get(n).focus,r.removeEventListener("keydown",YD,!0),r.removeEventListener("keyup",YD,!0),r.removeEventListener("click",wne,!0),n.removeEventListener("focus",Rne,!0),n.removeEventListener("blur",Ane,!1),typeof PointerEvent<"u"&&(r.removeEventListener("pointerdown",l3,!0),r.removeEventListener("pointermove",l3,!0),r.removeEventListener("pointerup",l3,!0)),U2.delete(n))};function XEe(e){const t=ci(e);let n;return t.readyState!=="loading"?GD(e):(n=()=>{GD(e)},t.addEventListener("DOMContentLoaded",n)),()=>Tne(e,n)}typeof document<"u"&&XEe();function Jv(){return cg!=="pointer"}function rg(){return cg}function EN(e){cg=e,qC(e,null)}function DN(){GD();let[e,t]=P.useState(cg);return P.useEffect(()=>{let n=()=>{t(cg)};return gx.add(n),()=>{gx.delete(n)}},[]),hp()?null:e}const YEe=new Set(["checkbox","radio","range","color","file","image","button","submit","reset"]);function GEe(e,t,n){let r=ci(n==null?void 0:n.target);const i=typeof window<"u"?af(n==null?void 0:n.target).HTMLInputElement:HTMLInputElement,a=typeof window<"u"?af(n==null?void 0:n.target).HTMLTextAreaElement:HTMLTextAreaElement,u=typeof window<"u"?af(n==null?void 0:n.target).HTMLElement:HTMLElement,l=typeof window<"u"?af(n==null?void 0:n.target).KeyboardEvent:KeyboardEvent;return e=e||r.activeElement instanceof i&&!YEe.has(r.activeElement.type)||r.activeElement instanceof a||r.activeElement instanceof u&&r.activeElement.isContentEditable,!(e&&t==="keyboard"&&n instanceof l&&!ZEe[n.key])}function KEe(e,t,n){GD(),P.useEffect(()=>{let r=(i,a)=>{GEe(!!(n!=null&&n.isTextInput),i,a)&&e(Jv())};return gx.add(r),()=>{gx.delete(r)}},t)}function ac(e){const t=ci(e),n=Vu(t);if(rg()==="virtual"){let r=n;Xee(()=>{Vu(t)===r&&e.isConnected&&_u(e)})}else _u(e)}function VC(e){let{isDisabled:t,onFocus:n,onBlur:r,onFocusChange:i}=e;const a=P.useCallback(o=>{if(o.target===o.currentTarget)return r&&r(o),i&&i(!1),!0},[r,i]),u=Ene(a),l=P.useCallback(o=>{const s=ci(o.target),c=s?Vu(s):Vu();o.target===o.currentTarget&&c===qu(o.nativeEvent)&&(n&&n(o),i&&i(!0),u(o))},[i,n,u]);return{focusProps:{onFocus:!t&&(n||i||r)?l:void 0,onBlur:!t&&(r||i)?a:void 0}}}function uj(e){if(!e)return;let t=!0;return n=>{let r={...n,preventDefault(){n.preventDefault()},isDefaultPrevented(){return n.isDefaultPrevented()},stopPropagation(){t=!0},continuePropagation(){t=!1},isPropagationStopped(){return t}};e(r),t&&n.stopPropagation()}}function $N(e){return{keyboardProps:e.isDisabled?{}:{onKeyDown:uj(e.onKeyDown),onKeyUp:uj(e.onKeyUp)}}}let KD=ye.createContext(null);function WEe(e){let t=P.useContext(KD)||{};oN(t,e);let{ref:n,...r}=t;return r}const JEe=ye.forwardRef(function(t,n){let{children:r,...i}=t,a=$u(n),u={...i,ref:a};return ye.createElement(KD.Provider,{value:u},r)});function L0(e,t){let{focusProps:n}=VC(e),{keyboardProps:r}=$N(e),i=Et(n,r),a=WEe(t),u=e.isDisabled?{}:a,l=P.useRef(e.autoFocus);P.useEffect(()=>{l.current&&t.current&&ac(t.current),l.current=!1},[t]);let o=e.excludeFromTabOrder?-1:0;return e.isDisabled&&(o=void 0),{focusableProps:Et({...i,tabIndex:o},u)}}const Art=P.forwardRef(({children:e,...t},n)=>{n=$u(n);let{focusableProps:r}=L0(t,n),i=ye.Children.only(e);P.useEffect(()=>{},[n,t.isDisabled]);let a=parseInt(ye.version,10)<19?i.ref:i.props.ref;return ye.cloneElement(i,{...Et(r,i.props),ref:vg(a,n)})}),Trt=ye.forwardRef(({children:e,...t},n)=>{n=$u(n);let{pressProps:r}=up({...t,ref:n}),{focusableProps:i}=L0(t,n),a=ye.Children.only(e);P.useEffect(()=>{},[n,t.isDisabled]);let u=parseInt(ye.version,10)<19?a.ref:a.props.ref;return ye.cloneElement(a,{...Et(r,i,a.props),ref:vg(u,n)})}),kne=ye.forwardRef(({children:e,...t},n)=>{let r=P.useRef(!1),i=P.useContext(mx);n=$u(n||(i==null?void 0:i.ref));let a=Et(i||{},{...t,ref:n,register(){r.current=!0,i&&i.register()}});return oN(i,n),P.useEffect(()=>{r.current||(r.current=!0)},[]),ye.createElement(mx.Provider,{value:a},e)});function eDe({children:e}){let t=P.useMemo(()=>({register:()=>{}}),[]);return ye.createElement(mx.Provider,{value:t},e)}function B0(e){let{isDisabled:t,onBlurWithin:n,onFocusWithin:r,onFocusWithinChange:i}=e,a=P.useRef({isFocusWithin:!1}),{addGlobalListener:u,removeAllGlobalListeners:l}=py(),o=P.useCallback(d=>{d.currentTarget.contains(d.target)&&a.current.isFocusWithin&&!d.currentTarget.contains(d.relatedTarget)&&(a.current.isFocusWithin=!1,l(),n&&n(d),i&&i(!1))},[n,i,a,l]),s=Ene(o),c=P.useCallback(d=>{if(!d.currentTarget.contains(d.target))return;const h=ci(d.target),m=Vu(h);if(!a.current.isFocusWithin&&m===qu(d.nativeEvent)){r&&r(d),i&&i(!0),a.current.isFocusWithin=!0,s(d);let y=d.currentTarget;u(h,"focus",v=>{if(a.current.isFocusWithin&&!Gc(y,v.target)){let _=new h.defaultView.FocusEvent("blur",{relatedTarget:v.target});_ne(_,y);let S=SN(_);o(S)}},{capture:!0})}},[r,i,s,u,o]);return t?{focusWithinProps:{onFocus:void 0,onBlur:void 0}}:{focusWithinProps:{onFocus:c,onBlur:o}}}let k9=!1,q_=0;function tDe(){k9=!0,setTimeout(()=>{k9=!1},50)}function lj(e){e.pointerType==="touch"&&tDe()}function nDe(){if(!(typeof document>"u"))return q_===0&&typeof PointerEvent<"u"&&document.addEventListener("pointerup",lj),q_++,()=>{q_--,!(q_>0)&&typeof PointerEvent<"u"&&document.removeEventListener("pointerup",lj)}}function Cu(e){let{onHoverStart:t,onHoverChange:n,onHoverEnd:r,isDisabled:i}=e,[a,u]=P.useState(!1),l=P.useRef({isHovered:!1,ignoreEmulatedMouseEvents:!1,pointerType:"",target:null}).current;P.useEffect(nDe,[]);let{addGlobalListener:o,removeAllGlobalListeners:s}=py(),{hoverProps:c,triggerHoverEnd:d}=P.useMemo(()=>{let h=(v,_)=>{if(l.pointerType=_,i||_==="touch"||l.isHovered||!v.currentTarget.contains(v.target))return;l.isHovered=!0;let S=v.currentTarget;l.target=S,o(ci(v.target),"pointerover",E=>{l.isHovered&&l.target&&!Gc(l.target,E.target)&&m(E,E.pointerType)},{capture:!0}),t&&t({type:"hoverstart",target:S,pointerType:_}),n&&n(!0),u(!0)},m=(v,_)=>{let S=l.target;l.pointerType="",l.target=null,!(_==="touch"||!l.isHovered||!S)&&(l.isHovered=!1,s(),r&&r({type:"hoverend",target:S,pointerType:_}),n&&n(!1),u(!1))},y={};return typeof PointerEvent<"u"&&(y.onPointerEnter=v=>{k9&&v.pointerType==="mouse"||h(v,v.pointerType)},y.onPointerLeave=v=>{!i&&v.currentTarget.contains(v.target)&&m(v,v.pointerType)}),{hoverProps:y,triggerHoverEnd:m}},[t,n,r,i,l,o,s]);return P.useEffect(()=>{i&&d({currentTarget:l.target},l.pointerType)},[i]),{hoverProps:c,isHovered:a}}function rDe(e){let{ref:t,onInteractOutside:n,isDisabled:r,onInteractOutsideStart:i}=e,a=P.useRef({isPointerDown:!1,ignoreEmulatedMouseEvents:!1}),u=oi(o=>{n&&oj(o,t)&&(i&&i(o),a.current.isPointerDown=!0)}),l=oi(o=>{n&&n(o)});P.useEffect(()=>{let o=a.current;if(r)return;const s=t.current,c=ci(s);if(typeof PointerEvent<"u"){let d=h=>{o.isPointerDown&&oj(h,t)&&l(h),o.isPointerDown=!1};return c.addEventListener("pointerdown",u,!0),c.addEventListener("click",d,!0),()=>{c.removeEventListener("pointerdown",u,!0),c.removeEventListener("click",d,!0)}}},[t,r,u,l])}function oj(e,t){if(e.button>0)return!1;if(e.target){const n=e.target.ownerDocument;if(!n||!n.documentElement.contains(e.target)||e.target.closest("[data-react-aria-top-layer]"))return!1}return t.current?!e.composedPath().includes(t.current):!1}function Pne(e){let{onMoveStart:t,onMove:n,onMoveEnd:r}=e,i=P.useRef({didMove:!1,lastPosition:null,id:null}),{addGlobalListener:a,removeGlobalListener:u}=py(),l=oi((c,d,h,m)=>{h===0&&m===0||(i.current.didMove||(i.current.didMove=!0,t==null||t({type:"movestart",pointerType:d,shiftKey:c.shiftKey,metaKey:c.metaKey,ctrlKey:c.ctrlKey,altKey:c.altKey})),n==null||n({type:"move",pointerType:d,deltaX:h,deltaY:m,shiftKey:c.shiftKey,metaKey:c.metaKey,ctrlKey:c.ctrlKey,altKey:c.altKey}))}),o=oi((c,d)=>{A9(),i.current.didMove&&(r==null||r({type:"moveend",pointerType:d,shiftKey:c.shiftKey,metaKey:c.metaKey,ctrlKey:c.ctrlKey,altKey:c.altKey}))});return{moveProps:P.useMemo(()=>{let c={},d=()=>{Dne(),i.current.didMove=!1};{let m=v=>{if(v.pointerId===i.current.id){var _,S;let T=v.pointerType||"mouse";var E,C;l(v,T,v.pageX-((E=(_=i.current.lastPosition)===null||_===void 0?void 0:_.pageX)!==null&&E!==void 0?E:0),v.pageY-((C=(S=i.current.lastPosition)===null||S===void 0?void 0:S.pageY)!==null&&C!==void 0?C:0)),i.current.lastPosition={pageX:v.pageX,pageY:v.pageY}}},y=v=>{if(v.pointerId===i.current.id){let _=v.pointerType||"mouse";o(v,_),i.current.id=null,u(window,"pointermove",m,!1),u(window,"pointerup",y,!1),u(window,"pointercancel",y,!1)}};c.onPointerDown=v=>{v.button===0&&i.current.id==null&&(d(),v.stopPropagation(),v.preventDefault(),i.current.lastPosition={pageX:v.pageX,pageY:v.pageY},i.current.id=v.pointerId,a(window,"pointermove",m,!1),a(window,"pointerup",y,!1),a(window,"pointercancel",y,!1))}}let h=(m,y,v)=>{d(),l(m,"keyboard",y,v),o(m,"keyboard")};return c.onKeyDown=m=>{switch(m.key){case"Left":case"ArrowLeft":m.preventDefault(),m.stopPropagation(),h(m,-1,0);break;case"Right":case"ArrowRight":m.preventDefault(),m.stopPropagation(),h(m,1,0);break;case"Up":case"ArrowUp":m.preventDefault(),m.stopPropagation(),h(m,0,-1);break;case"Down":case"ArrowDown":m.preventDefault(),m.stopPropagation(),h(m,0,1);break}},c},[i,a,u,l,o])}}function Mne(e,t){let{onScroll:n,isDisabled:r}=e,i=P.useCallback(a=>{a.ctrlKey||(a.preventDefault(),a.stopPropagation(),n&&n({deltaX:a.deltaX,deltaY:a.deltaY}))},[n]);Xd(t,"wheel",r?void 0:i)}const iDe=500;function Fne(e){let{isDisabled:t,onLongPressStart:n,onLongPressEnd:r,onLongPress:i,threshold:a=iDe,accessibilityDescription:u}=e;const l=P.useRef(void 0);let{addGlobalListener:o,removeGlobalListener:s}=py(),{pressProps:c}=up({isDisabled:t,onPressStart(h){if(h.continuePropagation(),(h.pointerType==="mouse"||h.pointerType==="touch")&&(n&&n({...h,type:"longpressstart"}),l.current=setTimeout(()=>{h.target.dispatchEvent(new PointerEvent("pointercancel",{bubbles:!0})),ci(h.target).activeElement!==h.target&&_u(h.target),i&&i({...h,type:"longpress"}),l.current=void 0},a),h.pointerType==="touch")){let m=y=>{y.preventDefault()};o(h.target,"contextmenu",m,{once:!0}),o(window,"pointerup",()=>{setTimeout(()=>{s(h.target,"contextmenu",m)},30)},{once:!0})}},onPressEnd(h){l.current&&clearTimeout(l.current),r&&(h.pointerType==="mouse"||h.pointerType==="touch")&&r({...h,type:"longpressend"})}}),d=NC(i&&!t?u:void 0);return{longPressProps:Et(c,d)}}const P9=ye.createContext(null),M9="react-aria-focus-scope-restore";let Oa=null;function CN(e){let{children:t,contain:n,restoreFocus:r,autoFocus:i}=e,a=P.useRef(null),u=P.useRef(null),l=P.useRef([]),{parentNode:o}=P.useContext(P9)||{},s=P.useMemo(()=>new N9({scopeRef:l}),[l]);qr(()=>{let h=o||pl.root;if(pl.getTreeNode(h.scopeRef)&&Oa&&!WD(Oa,h.scopeRef)){let m=pl.getTreeNode(Oa);m&&(h=m)}h.addChild(s),pl.addNode(s)},[s,o]),qr(()=>{let h=pl.getTreeNode(l);h&&(h.contain=!!n)},[n]),qr(()=>{var h;let m=(h=a.current)===null||h===void 0?void 0:h.nextSibling,y=[],v=_=>_.stopPropagation();for(;m&&m!==u.current;)y.push(m),m.addEventListener(M9,v),m=m.nextSibling;return l.current=y,()=>{for(let _ of y)_.removeEventListener(M9,v)}},[t]),cDe(l,r,n),lDe(l,n),fDe(l,r,n),sDe(l,i),P.useEffect(()=>{const h=Vu(ci(l.current?l.current[0]:void 0));let m=null;if(Wd(h,l.current)){for(let y of pl.traverse())y.scopeRef&&Wd(h,y.scopeRef.current)&&(m=y);m===pl.getTreeNode(l)&&(Oa=m.scopeRef)}},[l]),qr(()=>()=>{var h,m,y;let v=(y=(m=pl.getTreeNode(l))===null||m===void 0||(h=m.parent)===null||h===void 0?void 0:h.scopeRef)!==null&&y!==void 0?y:null;(l===Oa||WD(l,Oa))&&(!v||pl.getTreeNode(v))&&(Oa=v),pl.removeTreeNode(l)},[l]);let c=P.useMemo(()=>aDe(l),[]),d=P.useMemo(()=>({focusManager:c,parentNode:s}),[s,c]);return ye.createElement(P9.Provider,{value:d},ye.createElement("span",{"data-focus-scope-start":!0,hidden:!0,ref:a}),t,ye.createElement("span",{"data-focus-scope-end":!0,hidden:!0,ref:u}))}function krt(){var e;return(e=P.useContext(P9))===null||e===void 0?void 0:e.focusManager}function aDe(e){return{focusNext(t={}){let n=e.current,{from:r,tabbable:i,wrap:a,accept:u}=t;var l;let o=r||Vu(ci((l=n[0])!==null&&l!==void 0?l:void 0)),s=n[0].previousElementSibling,c=N1(n),d=Cl(c,{tabbable:i,accept:u},n);d.currentNode=Wd(o,n)?o:s;let h=d.nextNode();return!h&&a&&(d.currentNode=s,h=d.nextNode()),h&&rf(h,!0),h},focusPrevious(t={}){let n=e.current,{from:r,tabbable:i,wrap:a,accept:u}=t;var l;let o=r||Vu(ci((l=n[0])!==null&&l!==void 0?l:void 0)),s=n[n.length-1].nextElementSibling,c=N1(n),d=Cl(c,{tabbable:i,accept:u},n);d.currentNode=Wd(o,n)?o:s;let h=d.previousNode();return!h&&a&&(d.currentNode=s,h=d.previousNode()),h&&rf(h,!0),h},focusFirst(t={}){let n=e.current,{tabbable:r,accept:i}=t,a=N1(n),u=Cl(a,{tabbable:r,accept:i},n);u.currentNode=n[0].previousElementSibling;let l=u.nextNode();return l&&rf(l,!0),l},focusLast(t={}){let n=e.current,{tabbable:r,accept:i}=t,a=N1(n),u=Cl(a,{tabbable:r,accept:i},n);u.currentNode=n[n.length-1].nextElementSibling;let l=u.previousNode();return l&&rf(l,!0),l}}}function N1(e){return e[0].parentElement}function M2(e){let t=pl.getTreeNode(Oa);for(;t&&t.scopeRef!==e;){if(t.contain)return!1;t=t.parent}return!0}function uDe(e){if(e.checked)return!0;let t=[];if(!e.form)t=[...ci(e).querySelectorAll(`input[type="radio"][name="${CSS.escape(e.name)}"]`)].filter(a=>!a.form);else{var n,r;let a=(r=e.form)===null||r===void 0||(n=r.elements)===null||n===void 0?void 0:n.namedItem(e.name);t=[...a??[]]}return t?!t.some(a=>a.checked):!1}function lDe(e,t){let n=P.useRef(void 0),r=P.useRef(void 0);qr(()=>{let i=e.current;if(!t){r.current&&(cancelAnimationFrame(r.current),r.current=void 0);return}const a=ci(i?i[0]:void 0);let u=s=>{if(s.key!=="Tab"||s.altKey||s.ctrlKey||s.metaKey||!M2(e)||s.isComposing)return;let c=Vu(a),d=e.current;if(!d||!Wd(c,d))return;let h=N1(d),m=Cl(h,{tabbable:!0},d);if(!c)return;m.currentNode=c;let y=s.shiftKey?m.previousNode():m.nextNode();y||(m.currentNode=s.shiftKey?d[d.length-1].nextElementSibling:d[0].previousElementSibling,y=s.shiftKey?m.previousNode():m.nextNode()),s.preventDefault(),y&&rf(y,!0)},l=s=>{(!Oa||WD(Oa,e))&&Wd(qu(s),e.current)?(Oa=e,n.current=qu(s)):M2(e)&&!Iv(qu(s),e)?n.current?n.current.focus():Oa&&Oa.current&&F9(Oa.current):M2(e)&&(n.current=qu(s))},o=s=>{r.current&&cancelAnimationFrame(r.current),r.current=requestAnimationFrame(()=>{let c=rg(),d=(c==="virtual"||c===null)&&uS()&&uN(),h=Vu(a);if(!d&&h&&M2(e)&&!Iv(h,e)){Oa=e;let y=qu(s);if(y&&y.isConnected){var m;n.current=y,(m=n.current)===null||m===void 0||m.focus()}else Oa.current&&F9(Oa.current)}})};return a.addEventListener("keydown",u,!1),a.addEventListener("focusin",l,!1),i==null||i.forEach(s=>s.addEventListener("focusin",l,!1)),i==null||i.forEach(s=>s.addEventListener("focusout",o,!1)),()=>{a.removeEventListener("keydown",u,!1),a.removeEventListener("focusin",l,!1),i==null||i.forEach(s=>s.removeEventListener("focusin",l,!1)),i==null||i.forEach(s=>s.removeEventListener("focusout",o,!1))}},[e,t]),qr(()=>()=>{r.current&&cancelAnimationFrame(r.current)},[r])}function Nne(e){return Iv(e)}function Wd(e,t){return!e||!t?!1:t.some(n=>n.contains(e))}function Iv(e,t=null){if(e instanceof Element&&e.closest("[data-react-aria-top-layer]"))return!0;for(let{scopeRef:n}of pl.traverse(pl.getTreeNode(t)))if(n&&Wd(e,n.current))return!0;return!1}function oDe(e){return Iv(e,Oa)}function WD(e,t){var n;let r=(n=pl.getTreeNode(t))===null||n===void 0?void 0:n.parent;for(;r;){if(r.scopeRef===e)return!0;r=r.parent}return!1}function rf(e,t=!1){if(e!=null&&!t)try{ac(e)}catch{}else if(e!=null)try{e.focus()}catch{}}function Ine(e,t=!0){let n=e[0].previousElementSibling,r=N1(e),i=Cl(r,{tabbable:t},e);i.currentNode=n;let a=i.nextNode();return t&&!a&&(r=N1(e),i=Cl(r,{tabbable:!1},e),i.currentNode=n,a=i.nextNode()),a}function F9(e,t=!0){rf(Ine(e,t))}function sDe(e,t){const n=ye.useRef(t);P.useEffect(()=>{if(n.current){Oa=e;const r=ci(e.current?e.current[0]:void 0);!Wd(Vu(r),Oa.current)&&e.current&&F9(e.current)}n.current=!1},[e])}function cDe(e,t,n){qr(()=>{if(t||n)return;let r=e.current;const i=ci(r?r[0]:void 0);let a=u=>{let l=qu(u);Wd(l,e.current)?Oa=e:Nne(l)||(Oa=null)};return i.addEventListener("focusin",a,!1),r==null||r.forEach(u=>u.addEventListener("focusin",a,!1)),()=>{i.removeEventListener("focusin",a,!1),r==null||r.forEach(u=>u.removeEventListener("focusin",a,!1))}},[e,t,n])}function sj(e){let t=pl.getTreeNode(Oa);for(;t&&t.scopeRef!==e;){if(t.nodeToRestore)return!1;t=t.parent}return(t==null?void 0:t.scopeRef)===e}function fDe(e,t,n){const r=P.useRef(typeof document<"u"?Vu(ci(e.current?e.current[0]:void 0)):null);qr(()=>{let i=e.current;const a=ci(i?i[0]:void 0);if(!t||n)return;let u=()=>{(!Oa||WD(Oa,e))&&Wd(Vu(a),e.current)&&(Oa=e)};return a.addEventListener("focusin",u,!1),i==null||i.forEach(l=>l.addEventListener("focusin",u,!1)),()=>{a.removeEventListener("focusin",u,!1),i==null||i.forEach(l=>l.removeEventListener("focusin",u,!1))}},[e,n]),qr(()=>{const i=ci(e.current?e.current[0]:void 0);if(!t)return;let a=u=>{if(u.key!=="Tab"||u.altKey||u.ctrlKey||u.metaKey||!M2(e)||u.isComposing)return;let l=i.activeElement;if(!Iv(l,e)||!sj(e))return;let o=pl.getTreeNode(e);if(!o)return;let s=o.nodeToRestore,c=Cl(i.body,{tabbable:!0});c.currentNode=l;let d=u.shiftKey?c.previousNode():c.nextNode();if((!s||!s.isConnected||s===i.body)&&(s=void 0,o.nodeToRestore=void 0),(!d||!Iv(d,e))&&s){c.currentNode=s;do d=u.shiftKey?c.previousNode():c.nextNode();while(Iv(d,e));u.preventDefault(),u.stopPropagation(),d?rf(d,!0):Nne(s)?rf(s,!0):l.blur()}};return n||i.addEventListener("keydown",a,!0),()=>{n||i.removeEventListener("keydown",a,!0)}},[e,t,n]),qr(()=>{const i=ci(e.current?e.current[0]:void 0);if(!t)return;let a=pl.getTreeNode(e);if(a){var u;return a.nodeToRestore=(u=r.current)!==null&&u!==void 0?u:void 0,()=>{let l=pl.getTreeNode(e);if(!l)return;let o=l.nodeToRestore,s=Vu(i);if(t&&o&&(s&&Iv(s,e)||s===i.body&&sj(e))){let c=pl.clone();requestAnimationFrame(()=>{if(i.activeElement===i.body){let d=c.getTreeNode(e);for(;d;){if(d.nodeToRestore&&d.nodeToRestore.isConnected){cj(d.nodeToRestore);return}d=d.parent}for(d=c.getTreeNode(e);d;){if(d.scopeRef&&d.scopeRef.current&&pl.getTreeNode(d.scopeRef)){let h=Ine(d.scopeRef.current,!0);cj(h);return}d=d.parent}}})}}}},[e,t])}function cj(e){e.dispatchEvent(new CustomEvent(M9,{bubbles:!0,cancelable:!0}))&&rf(e)}function Cl(e,t,n){let r=t!=null&&t.tabbable?s_e:tte,i=(e==null?void 0:e.nodeType)===Node.ELEMENT_NODE?e:null,a=ci(i),u=PSe(a,e||a,NodeFilter.SHOW_ELEMENT,{acceptNode(l){var o;return!(t==null||(o=t.from)===null||o===void 0)&&o.contains(l)||t!=null&&t.tabbable&&l.tagName==="INPUT"&&l.getAttribute("type")==="radio"&&(!uDe(l)||u.currentNode.tagName==="INPUT"&&u.currentNode.type==="radio"&&u.currentNode.name===l.name)?NodeFilter.FILTER_REJECT:r(l)&&(!n||Wd(l,n))&&(!(t!=null&&t.accept)||t.accept(l))?NodeFilter.FILTER_ACCEPT:NodeFilter.FILTER_SKIP}});return t!=null&&t.from&&(u.currentNode=t.from),u}function wN(e,t={}){return{focusNext(n={}){let r=e.current;if(!r)return null;let{from:i,tabbable:a=t.tabbable,wrap:u=t.wrap,accept:l=t.accept}=n,o=i||Vu(ci(r)),s=Cl(r,{tabbable:a,accept:l});r.contains(o)&&(s.currentNode=o);let c=s.nextNode();return!c&&u&&(s.currentNode=r,c=s.nextNode()),c&&rf(c,!0),c},focusPrevious(n=t){let r=e.current;if(!r)return null;let{from:i,tabbable:a=t.tabbable,wrap:u=t.wrap,accept:l=t.accept}=n,o=i||Vu(ci(r)),s=Cl(r,{tabbable:a,accept:l});if(r.contains(o))s.currentNode=o;else{let d=JT(s);return d&&rf(d,!0),d??null}let c=s.previousNode();if(!c&&u){s.currentNode=r;let d=JT(s);if(!d)return null;c=d}return c&&rf(c,!0),c??null},focusFirst(n=t){let r=e.current;if(!r)return null;let{tabbable:i=t.tabbable,accept:a=t.accept}=n,l=Cl(r,{tabbable:i,accept:a}).nextNode();return l&&rf(l,!0),l},focusLast(n=t){let r=e.current;if(!r)return null;let{tabbable:i=t.tabbable,accept:a=t.accept}=n,u=Cl(r,{tabbable:i,accept:a}),l=JT(u);return l&&rf(l,!0),l??null}}}function JT(e){let t,n;do n=e.lastChild(),n&&(t=n);while(n);return t}class RN{get size(){return this.fastMap.size}getTreeNode(t){return this.fastMap.get(t)}addTreeNode(t,n,r){let i=this.fastMap.get(n??null);if(!i)return;let a=new N9({scopeRef:t});i.addChild(a),a.parent=i,this.fastMap.set(t,a),r&&(a.nodeToRestore=r)}addNode(t){this.fastMap.set(t.scopeRef,t)}removeTreeNode(t){if(t===null)return;let n=this.fastMap.get(t);if(!n)return;let r=n.parent;for(let a of this.traverse())a!==n&&n.nodeToRestore&&a.nodeToRestore&&n.scopeRef&&n.scopeRef.current&&Wd(a.nodeToRestore,n.scopeRef.current)&&(a.nodeToRestore=n.nodeToRestore);let i=n.children;r&&(r.removeChild(n),i.size>0&&i.forEach(a=>r&&r.addChild(a))),this.fastMap.delete(n.scopeRef)}*traverse(t=this.root){if(t.scopeRef!=null&&(yield t),t.children.size>0)for(let n of t.children)yield*this.traverse(n)}clone(){var t;let n=new RN;var r;for(let i of this.traverse())n.addTreeNode(i.scopeRef,(r=(t=i.parent)===null||t===void 0?void 0:t.scopeRef)!==null&&r!==void 0?r:null,i.nodeToRestore);return n}constructor(){this.fastMap=new Map,this.root=new N9({scopeRef:null}),this.fastMap.set(null,this.root)}}class N9{addChild(t){this.children.add(t),t.parent=this}removeChild(t){this.children.delete(t),t.parent=void 0}constructor(t){this.children=new Set,this.contain=!1,this.scopeRef=t.scopeRef}}let pl=new RN;function Hu(e={}){let{autoFocus:t=!1,isTextInput:n,within:r}=e,i=P.useRef({isFocused:!1,isFocusVisible:t||Jv()}),[a,u]=P.useState(!1),[l,o]=P.useState(()=>i.current.isFocused&&i.current.isFocusVisible),s=P.useCallback(()=>o(i.current.isFocused&&i.current.isFocusVisible),[]),c=P.useCallback(m=>{i.current.isFocused=m,u(m),s()},[s]);KEe(m=>{i.current.isFocusVisible=m,s()},[],{isTextInput:n});let{focusProps:d}=VC({isDisabled:r,onFocusChange:c}),{focusWithinProps:h}=B0({isDisabled:!r,onFocusWithinChange:c});return{isFocused:a,isFocusVisible:l,focusProps:r?h:d}}function Lne(e,t){let n=t==null?void 0:t.isDisabled,[r,i]=P.useState(!1);return qr(()=>{if(e!=null&&e.current&&!n){let a=()=>{if(e.current){let l=Cl(e.current,{tabbable:!0});i(!!l.nextNode())}};a();let u=new MutationObserver(a);return u.observe(e.current,{subtree:!0,childList:!0,attributes:!0,attributeFilter:["tabIndex","disabled"]}),()=>{u.disconnect()}}}),n?!1:r}function AN(e){let t=Bne(ci(e));t!==e&&(t&&I9(t,e),e&&vx(e,t))}function I9(e,t){e.dispatchEvent(new FocusEvent("blur",{relatedTarget:t})),e.dispatchEvent(new FocusEvent("focusout",{bubbles:!0,relatedTarget:t}))}function vx(e,t){e.dispatchEvent(new FocusEvent("focus",{relatedTarget:t})),e.dispatchEvent(new FocusEvent("focusin",{bubbles:!0,relatedTarget:t}))}function Bne(e){let t=Vu(e),n=t==null?void 0:t.getAttribute("aria-activedescendant");return n&&e.getElementById(n)||t}const u0=[];function Qne(e,t){let{onClose:n,shouldCloseOnBlur:r,isOpen:i,isDismissable:a=!1,isKeyboardDismissDisabled:u=!1,shouldCloseOnInteractOutside:l}=e;P.useEffect(()=>{if(i&&!u0.includes(t))return u0.push(t),()=>{let y=u0.indexOf(t);y>=0&&u0.splice(y,1)}},[i,t]);let o=()=>{u0[u0.length-1]===t&&n&&n()},s=y=>{(!l||l(y.target))&&u0[u0.length-1]===t&&(y.stopPropagation(),y.preventDefault())},c=y=>{(!l||l(y.target))&&(u0[u0.length-1]===t&&(y.stopPropagation(),y.preventDefault()),o())},d=y=>{y.key==="Escape"&&!u&&!y.nativeEvent.isComposing&&(y.stopPropagation(),y.preventDefault(),o())};rDe({ref:t,onInteractOutside:a&&i?c:void 0,onInteractOutsideStart:s});let{focusWithinProps:h}=B0({isDisabled:!r,onBlurWithin:y=>{!y.relatedTarget||oDe(y.relatedTarget)||(!l||l(y.relatedTarget))&&(n==null||n())}}),m=y=>{y.target===y.currentTarget&&y.preventDefault()};return{overlayProps:{onKeyDown:d,...h},underlayProps:{onPointerDown:m}}}function zne(e,t,n){let{type:r}=e,{isOpen:i}=t;P.useEffect(()=>{n&&n.current&&Qte.set(n.current,t.close)});let a;r==="menu"?a=!0:r==="listbox"&&(a="listbox");let u=pi();return{triggerProps:{"aria-haspopup":a,"aria-expanded":i,"aria-controls":i?u:void 0,onPress:t.toggle},overlayProps:{id:u}}}const j2=typeof document<"u"&&window.visualViewport;let V_=0,ek;function qne(e={}){let{isDisabled:t}=e;qr(()=>{if(!t)return V_++,V_===1&&(Db()?ek=hDe():ek=dDe()),()=>{V_--,V_===0&&ek()}},[t])}function dDe(){let e=window.innerWidth-document.documentElement.clientWidth;return rh(e>0&&("scrollbarGutter"in document.documentElement.style?tk(document.documentElement,"scrollbarGutter","stable"):tk(document.documentElement,"paddingRight",`${e}px`)),tk(document.documentElement,"overflow","hidden"))}function hDe(){let e,t=!1,n=o=>{let s=o.target;e=ub(s)?s:g0(s,!0),t=!1;let c=s.ownerDocument.defaultView.getSelection();c&&!c.isCollapsed&&c.containsNode(s,!0)&&(t=!0),"selectionStart"in s&&"selectionEnd"in s&&s.selectionStart<s.selectionEnd&&s.ownerDocument.activeElement===s&&(t=!0)},r=document.createElement("style");r.textContent=`
@layer {
  * {
    overscroll-behavior: contain;
  }
}`.trim(),document.head.prepend(r);let i=o=>{if(!(o.touches.length===2||t)){if(!e||e===document.documentElement||e===document.body){o.preventDefault();return}e.scrollHeight===e.clientHeight&&e.scrollWidth===e.clientWidth&&o.preventDefault()}},a=o=>{let s=o.target,c=o.relatedTarget;if(c&&q2(c))c.focus({preventScroll:!0}),fj(c,q2(s));else if(!c){var d;let h=(d=s.parentElement)===null||d===void 0?void 0:d.closest("[tabindex]");h==null||h.focus({preventScroll:!0})}},u=HTMLElement.prototype.focus;HTMLElement.prototype.focus=function(o){let s=document.activeElement!=null&&q2(document.activeElement);u.call(this,{...o,preventScroll:!0}),(!o||!o.preventScroll)&&fj(this,s)};let l=rh(nk(document,"touchstart",n,{passive:!1,capture:!0}),nk(document,"touchmove",i,{passive:!1,capture:!0}),nk(document,"blur",a,!0));return()=>{l(),r.remove(),HTMLElement.prototype.focus=u}}function tk(e,t,n){let r=e.style[t];return e.style[t]=n,()=>{e.style[t]=r}}function nk(e,t,n,r){return e.addEventListener(t,n,r),()=>{e.removeEventListener(t,n,r)}}function fj(e,t){t||!j2?dj(e):j2.addEventListener("resize",()=>dj(e),{once:!0})}function dj(e){let t=document.scrollingElement||document.documentElement,n=e;for(;n&&n!==t;){let r=g0(n);if(r!==document.documentElement&&r!==document.body&&r!==n){let i=r.getBoundingClientRect(),a=n.getBoundingClientRect();if(a.top<i.top||a.bottom>i.top+n.clientHeight){let u=i.bottom;j2&&(u=Math.min(u,j2.offsetTop+j2.height));let l=a.top-i.top-((u-i.top)/2-a.height/2);r.scrollTo({top:Math.max(0,Math.min(r.scrollHeight-r.clientHeight,r.scrollTop+l)),behavior:"smooth"})}}n=r.parentElement}}const pDe=P.createContext({});function TN(){var e;return(e=P.useContext(pDe))!==null&&e!==void 0?e:{}}const L9=ye.createContext(null);function mDe(e){let{children:t}=e,n=P.useContext(L9),[r,i]=P.useState(0),a=P.useMemo(()=>({parent:n,modalCount:r,addModal(){i(u=>u+1),n&&n.addModal()},removeModal(){i(u=>u-1),n&&n.removeModal()}}),[n,r]);return ye.createElement(L9.Provider,{value:a},t)}function gDe(){let e=P.useContext(L9);return{modalProviderProps:{"aria-hidden":e&&e.modalCount>0?!0:void 0}}}function vDe(e){let{modalProviderProps:t}=gDe();return ye.createElement("div",{"data-overlay-container":!0,...e,...t})}function yDe(e){return ye.createElement(mDe,null,ye.createElement(vDe,e))}function bDe(e){let t=hp(),{portalContainer:n=t?null:document.body,...r}=e,{getContainer:i}=TN();if(!e.portalContainer&&i&&(n=i()),ye.useEffect(()=>{if(n!=null&&n.closest("[data-overlay-container]"))throw new Error("An OverlayContainer must not be inside another container. Please change the portalContainer prop.")},[n]),!n)return null;let a=ye.createElement(yDe,r);return Jee.createPortal(a,n)}var Vne={};Vne={dismiss:"تجاهل"};var Une={};Une={dismiss:"Отхвърляне"};var jne={};jne={dismiss:"Odstranit"};var Zne={};Zne={dismiss:"Luk"};var Hne={};Hne={dismiss:"Schließen"};var Xne={};Xne={dismiss:"Απόρριψη"};var Yne={};Yne={dismiss:"Dismiss"};var Gne={};Gne={dismiss:"Descartar"};var Kne={};Kne={dismiss:"Lõpeta"};var Wne={};Wne={dismiss:"Hylkää"};var Jne={};Jne={dismiss:"Rejeter"};var ere={};ere={dismiss:"התעלם"};var tre={};tre={dismiss:"Odbaci"};var nre={};nre={dismiss:"Elutasítás"};var rre={};rre={dismiss:"Ignora"};var ire={};ire={dismiss:"閉じる"};var are={};are={dismiss:"무시"};var ure={};ure={dismiss:"Atmesti"};var lre={};lre={dismiss:"Nerādīt"};var ore={};ore={dismiss:"Lukk"};var sre={};sre={dismiss:"Negeren"};var cre={};cre={dismiss:"Zignoruj"};var fre={};fre={dismiss:"Descartar"};var dre={};dre={dismiss:"Dispensar"};var hre={};hre={dismiss:"Revocare"};var pre={};pre={dismiss:"Пропустить"};var mre={};mre={dismiss:"Zrušiť"};var gre={};gre={dismiss:"Opusti"};var vre={};vre={dismiss:"Odbaci"};var yre={};yre={dismiss:"Avvisa"};var bre={};bre={dismiss:"Kapat"};var Ore={};Ore={dismiss:"Скасувати"};var xre={};xre={dismiss:"取消"};var Sre={};Sre={dismiss:"關閉"};var _re={};_re={"ar-AE":Vne,"bg-BG":Une,"cs-CZ":jne,"da-DK":Zne,"de-DE":Hne,"el-GR":Xne,"en-US":Yne,"es-ES":Gne,"et-EE":Kne,"fi-FI":Wne,"fr-FR":Jne,"he-IL":ere,"hr-HR":tre,"hu-HU":nre,"it-IT":rre,"ja-JP":ire,"ko-KR":are,"lt-LT":ure,"lv-LV":lre,"nb-NO":ore,"nl-NL":sre,"pl-PL":cre,"pt-BR":fre,"pt-PT":dre,"ro-RO":hre,"ru-RU":pre,"sk-SK":mre,"sl-SI":gre,"sr-SP":vre,"sv-SE":yre,"tr-TR":bre,"uk-UA":Ore,"zh-CN":xre,"zh-TW":Sre};const hj={border:0,clip:"rect(0 0 0 0)",clipPath:"inset(50%)",height:"1px",margin:"-1px",overflow:"hidden",padding:0,position:"absolute",width:"1px",whiteSpace:"nowrap"};function kN(e={}){let{style:t,isFocusable:n}=e,[r,i]=P.useState(!1),{focusWithinProps:a}=B0({isDisabled:!n,onFocusWithinChange:l=>i(l)}),u=P.useMemo(()=>r?t:t?{...hj,...t}:hj,[r]);return{visuallyHiddenProps:{...a,style:u}}}function cS(e){let{children:t,elementType:n="div",isFocusable:r,style:i,...a}=e,{visuallyHiddenProps:u}=kN(e);return ye.createElement(n,Et(a,u),t)}function ODe(e){return e&&e.__esModule?e.default:e}function B9(e){let{onDismiss:t,...n}=e,r=Fo(ODe(_re),"@react-aria/overlays"),i=Yv(n,r.format("dismiss")),a=()=>{t&&t()};return ye.createElement(cS,null,ye.createElement("button",{...i,tabIndex:-1,onClick:a,style:{width:1,height:1}}))}const xDe=typeof HTMLElement<"u"&&"inert"in HTMLElement.prototype;let G4=new WeakMap,Yc=[];function PN(e,t){let n=af(e==null?void 0:e[0]),r=t instanceof n.Element?{root:t}:t;var i;let a=(i=r==null?void 0:r.root)!==null&&i!==void 0?i:document.body,u=(r==null?void 0:r.shouldUseInert)&&xDe,l=new Set(e),o=new Set,s=v=>u&&v instanceof n.HTMLElement?v.inert:v.getAttribute("aria-hidden")==="true",c=(v,_)=>{u&&v instanceof n.HTMLElement?v.inert=_:_?v.setAttribute("aria-hidden","true"):(v.removeAttribute("aria-hidden"),v instanceof n.HTMLElement&&(v.inert=!1))},d=v=>{for(let C of v.querySelectorAll("[data-live-announcer], [data-react-aria-top-layer]"))l.add(C);let _=C=>{if(o.has(C)||l.has(C)||C.parentElement&&o.has(C.parentElement)&&C.parentElement.getAttribute("role")!=="row")return NodeFilter.FILTER_REJECT;for(let T of l)if(C.contains(T))return NodeFilter.FILTER_SKIP;return NodeFilter.FILTER_ACCEPT},S=document.createTreeWalker(v,NodeFilter.SHOW_ELEMENT,{acceptNode:_}),E=_(v);if(E===NodeFilter.FILTER_ACCEPT&&h(v),E!==NodeFilter.FILTER_REJECT){let C=S.nextNode();for(;C!=null;)h(C),C=S.nextNode()}},h=v=>{var _;let S=(_=G4.get(v))!==null&&_!==void 0?_:0;s(v)&&S===0||(S===0&&c(v,!0),o.add(v),G4.set(v,S+1))};Yc.length&&Yc[Yc.length-1].disconnect(),d(a);let m=new MutationObserver(v=>{for(let _ of v)if(_.type==="childList"&&![...l,...o].some(S=>S.contains(_.target)))for(let S of _.addedNodes)(S instanceof HTMLElement||S instanceof SVGElement)&&(S.dataset.liveAnnouncer==="true"||S.dataset.reactAriaTopLayer==="true")?l.add(S):S instanceof Element&&d(S)});m.observe(a,{childList:!0,subtree:!0});let y={visibleNodes:l,hiddenNodes:o,observe(){m.observe(a,{childList:!0,subtree:!0})},disconnect(){m.disconnect()}};return Yc.push(y),()=>{m.disconnect();for(let v of o){let _=G4.get(v);_!=null&&(_===1?(c(v,!1),G4.delete(v)):G4.set(v,_-1))}y===Yc[Yc.length-1]?(Yc.pop(),Yc.length&&Yc[Yc.length-1].observe()):Yc.splice(Yc.indexOf(y),1)}}function SDe(e){let t=Yc[Yc.length-1];if(t&&!t.visibleNodes.has(e))return t.visibleNodes.add(e),()=>{t.visibleNodes.delete(e)}}function _De(e,t){let{triggerRef:n,popoverRef:r,groupRef:i,isNonModal:a,isKeyboardDismissDisabled:u,shouldCloseOnInteractOutside:l,...o}=e,s=o.trigger==="SubmenuTrigger",{overlayProps:c,underlayProps:d}=Qne({isOpen:t.isOpen,onClose:t.close,shouldCloseOnBlur:!0,isDismissable:!a||s,isKeyboardDismissDisabled:u,shouldCloseOnInteractOutside:l},i??r),{overlayProps:h,arrowProps:m,placement:y,triggerAnchorPoint:v}=Sne({...o,targetRef:n,overlayRef:r,isOpen:t.isOpen,onClose:a&&!s?t.close:null});return qne({isDisabled:a||!t.isOpen}),P.useEffect(()=>{if(t.isOpen&&r.current){var _,S;return a?SDe((_=i==null?void 0:i.current)!==null&&_!==void 0?_:r.current):PN([(S=i==null?void 0:i.current)!==null&&S!==void 0?S:r.current],{shouldUseInert:!0})}},[a,t.isOpen,r,i]),{popoverProps:Et(c,h),arrowProps:m,underlayProps:d,placement:y,triggerAnchorPoint:v}}const Ere=ye.createContext(null);function Q9(e){let t=hp(),{portalContainer:n=t?null:document.body,isExiting:r}=e,[i,a]=P.useState(!1),u=P.useMemo(()=>({contain:i,setContain:a}),[i,a]),{getContainer:l}=TN();if(!e.portalContainer&&l&&(n=l()),!n)return null;let o=e.children;return e.disableFocusManagement||(o=ye.createElement(CN,{restoreFocus:!0,contain:(e.shouldContainFocus||i)&&!r},o)),o=ye.createElement(Ere.Provider,{value:u},ye.createElement(eDe,null,o)),Jee.createPortal(o,n)}function Dre(){let e=P.useContext(Ere),t=e==null?void 0:e.setContain;qr(()=>{t==null||t(!0)},[t])}function EDe(e,t,n){let{overlayProps:r,underlayProps:i}=Qne({...e,isOpen:t.isOpen,onClose:t.close},n);return qne({isDisabled:!t.isOpen}),Dre(),P.useEffect(()=>{if(t.isOpen&&n.current)return PN([n.current],{shouldUseInert:!0})},[t.isOpen,n]),{modalProps:Et(r),underlayProps:i}}const UC=new WeakMap;function DDe(e){return typeof e=="string"?e.replace(/\s*/g,""):""+e}function $re(e,t){let n=UC.get(e);if(!n)throw new Error("Unknown list");return`${n.id}-option-${DDe(t)}`}function fS(e){let{id:t,label:n,"aria-labelledby":r,"aria-label":i,labelElementType:a="label"}=e;t=pi(t);let u=pi(),l={};n&&(r=r?`${u} ${r}`:u,l={id:u,htmlFor:a==="label"?t:void 0});let o=Yv({id:t,"aria-label":i,"aria-labelledby":r});return{labelProps:l,fieldProps:o}}function dS(e){let{description:t,errorMessage:n,isInvalid:r,validationState:i}=e,{labelProps:a,fieldProps:u}=fS(e),l=C0([!!t,!!n,r,i]),o=C0([!!t,!!n,r,i]);return u=Et(u,{"aria-describedby":[l,o,e["aria-describedby"]].filter(Boolean).join(" ")||void 0}),{labelProps:a,fieldProps:u,descriptionProps:{id:l},errorMessageProps:{id:o}}}function z9(e){return jE()?e.altKey:e.ctrlKey}function GE(e,t){var n,r;let i=`[data-key="${CSS.escape(String(t))}"]`,a=(n=e.current)===null||n===void 0?void 0:n.dataset.collection;return a&&(i=`[data-collection="${CSS.escape(a)}"]${i}`),(r=e.current)===null||r===void 0?void 0:r.querySelector(i)}const Cre=new WeakMap;function $De(e){let t=pi();return Cre.set(e,t),t}function CDe(e){return Cre.get(e)}const wDe=1e3;function wre(e){let{keyboardDelegate:t,selectionManager:n,onTypeSelect:r}=e,i=P.useRef({search:"",timeout:void 0}).current,a=u=>{let l=RDe(u.key);if(!(!l||u.ctrlKey||u.metaKey||!u.currentTarget.contains(u.target)||i.search.length===0&&l===" ")){if(l===" "&&i.search.trim().length>0&&(u.preventDefault(),"continuePropagation"in u||u.stopPropagation()),i.search+=l,t.getKeyForSearch!=null){let o=t.getKeyForSearch(i.search,n.focusedKey);o==null&&(o=t.getKeyForSearch(i.search)),o!=null&&(n.setFocusedKey(o),r&&r(o))}clearTimeout(i.timeout),i.timeout=setTimeout(()=>{i.search=""},wDe)}};return{typeSelectProps:{onKeyDownCapture:t.getKeyForSearch?a:void 0}}}function RDe(e){return e.length===1||!/^[A-Z]/i.test(e)?e:""}function MN(e){let{selectionManager:t,keyboardDelegate:n,ref:r,autoFocus:i=!1,shouldFocusWrap:a=!1,disallowEmptySelection:u=!1,disallowSelectAll:l=!1,escapeKeyBehavior:o="clearSelection",selectOnFocus:s=t.selectionBehavior==="replace",disallowTypeAhead:c=!1,shouldUseVirtualFocus:d,allowsTabNavigation:h=!1,isVirtualized:m,scrollRef:y=r,linkBehavior:v="action"}=e,{direction:_}=Hi(),S=Z3(),E=J=>{var te;if(J.altKey&&J.key==="Tab"&&J.preventDefault(),!(!((te=r.current)===null||te===void 0)&&te.contains(J.target)))return;const H=(se,me)=>{if(se!=null){if(t.isLink(se)&&v==="selection"&&s&&!z9(J)){Vf.flushSync(()=>{t.setFocusedKey(se,me)});let ge=GE(r,se),we=t.getItemProps(se);ge&&S.open(ge,J,we.href,we.routerOptions);return}if(t.setFocusedKey(se,me),t.isLink(se)&&v==="override")return;J.shiftKey&&t.selectionMode==="multiple"?t.extendSelection(se):s&&!z9(J)&&t.replaceSelection(se)}};switch(J.key){case"ArrowDown":if(n.getKeyBelow){var M,K,X;let se=t.focusedKey!=null?(M=n.getKeyBelow)===null||M===void 0?void 0:M.call(n,t.focusedKey):(K=n.getFirstKey)===null||K===void 0?void 0:K.call(n);se==null&&a&&(se=(X=n.getFirstKey)===null||X===void 0?void 0:X.call(n,t.focusedKey)),se!=null&&(J.preventDefault(),H(se))}break;case"ArrowUp":if(n.getKeyAbove){var B,ne,oe;let se=t.focusedKey!=null?(B=n.getKeyAbove)===null||B===void 0?void 0:B.call(n,t.focusedKey):(ne=n.getLastKey)===null||ne===void 0?void 0:ne.call(n);se==null&&a&&(se=(oe=n.getLastKey)===null||oe===void 0?void 0:oe.call(n,t.focusedKey)),se!=null&&(J.preventDefault(),H(se))}break;case"ArrowLeft":if(n.getKeyLeftOf){var ie,de,be;let se=t.focusedKey!=null?(ie=n.getKeyLeftOf)===null||ie===void 0?void 0:ie.call(n,t.focusedKey):null;se==null&&a&&(se=_==="rtl"?(de=n.getFirstKey)===null||de===void 0?void 0:de.call(n,t.focusedKey):(be=n.getLastKey)===null||be===void 0?void 0:be.call(n,t.focusedKey)),se!=null&&(J.preventDefault(),H(se,_==="rtl"?"first":"last"))}break;case"ArrowRight":if(n.getKeyRightOf){var ve,pe,_e;let se=t.focusedKey!=null?(ve=n.getKeyRightOf)===null||ve===void 0?void 0:ve.call(n,t.focusedKey):null;se==null&&a&&(se=_==="rtl"?(pe=n.getLastKey)===null||pe===void 0?void 0:pe.call(n,t.focusedKey):(_e=n.getFirstKey)===null||_e===void 0?void 0:_e.call(n,t.focusedKey)),se!=null&&(J.preventDefault(),H(se,_==="rtl"?"last":"first"))}break;case"Home":if(n.getFirstKey){if(t.focusedKey===null&&J.shiftKey)return;J.preventDefault();let se=n.getFirstKey(t.focusedKey,T1(J));t.setFocusedKey(se),se!=null&&(T1(J)&&J.shiftKey&&t.selectionMode==="multiple"?t.extendSelection(se):s&&t.replaceSelection(se))}break;case"End":if(n.getLastKey){if(t.focusedKey===null&&J.shiftKey)return;J.preventDefault();let se=n.getLastKey(t.focusedKey,T1(J));t.setFocusedKey(se),se!=null&&(T1(J)&&J.shiftKey&&t.selectionMode==="multiple"?t.extendSelection(se):s&&t.replaceSelection(se))}break;case"PageDown":if(n.getKeyPageBelow&&t.focusedKey!=null){let se=n.getKeyPageBelow(t.focusedKey);se!=null&&(J.preventDefault(),H(se))}break;case"PageUp":if(n.getKeyPageAbove&&t.focusedKey!=null){let se=n.getKeyPageAbove(t.focusedKey);se!=null&&(J.preventDefault(),H(se))}break;case"a":T1(J)&&t.selectionMode==="multiple"&&l!==!0&&(J.preventDefault(),t.selectAll());break;case"Escape":o==="clearSelection"&&!u&&t.selectedKeys.size!==0&&(J.stopPropagation(),J.preventDefault(),t.clearSelection());break;case"Tab":if(!h){if(J.shiftKey)r.current.focus();else{let se=Cl(r.current,{tabbable:!0}),me,ge;do ge=se.lastChild(),ge&&(me=ge);while(ge);me&&!me.contains(document.activeElement)&&_u(me)}break}}},C=P.useRef({top:0,left:0});Xd(y,"scroll",m?void 0:()=>{var J,te,H,M;C.current={top:(H=(J=y.current)===null||J===void 0?void 0:J.scrollTop)!==null&&H!==void 0?H:0,left:(M=(te=y.current)===null||te===void 0?void 0:te.scrollLeft)!==null&&M!==void 0?M:0}});let T=J=>{if(t.isFocused){J.currentTarget.contains(J.target)||t.setFocused(!1);return}if(J.currentTarget.contains(J.target)){if(t.setFocused(!0),t.focusedKey==null){var te,H;let X=ne=>{ne!=null&&(t.setFocusedKey(ne),s&&!t.isSelected(ne)&&t.replaceSelection(ne))},B=J.relatedTarget;var M,K;B&&J.currentTarget.compareDocumentPosition(B)&Node.DOCUMENT_POSITION_FOLLOWING?X((M=t.lastSelectedKey)!==null&&M!==void 0?M:(te=n.getLastKey)===null||te===void 0?void 0:te.call(n)):X((K=t.firstSelectedKey)!==null&&K!==void 0?K:(H=n.getFirstKey)===null||H===void 0?void 0:H.call(n))}else!m&&y.current&&(y.current.scrollTop=C.current.top,y.current.scrollLeft=C.current.left);if(t.focusedKey!=null&&y.current){let X=GE(r,t.focusedKey);X instanceof HTMLElement&&(!X.contains(document.activeElement)&&!d&&_u(X),rg()==="keyboard"&&Vm(X,{containingElement:r.current}))}}},R=J=>{J.currentTarget.contains(J.relatedTarget)||t.setFocused(!1)},$=P.useRef(!1);Xd(r,y9,d?J=>{let{detail:te}=J;J.stopPropagation(),t.setFocused(!0),(te==null?void 0:te.focusStrategy)==="first"&&($.current=!0)}:void 0);let k=oi(()=>{var J,te;let H=(te=(J=n.getFirstKey)===null||J===void 0?void 0:J.call(n))!==null&&te!==void 0?te:null;if(H==null){let M=Vu();AN(r.current),vx(M,null),t.collection.size>0&&($.current=!1)}else t.setFocusedKey(H),$.current=!1});OU(()=>{$.current&&k()},[t.collection,k]);let F=oi(()=>{t.collection.size>0&&($.current=!1)});OU(()=>{F()},[t.focusedKey,F]),Xd(r,Wee,d?J=>{var te;J.stopPropagation(),t.setFocused(!1),!((te=J.detail)===null||te===void 0)&&te.clearFocusKey&&t.setFocusedKey(null)}:void 0);const L=P.useRef(i),j=P.useRef(!1);P.useEffect(()=>{if(L.current){var J,te;let K=null;var H;i==="first"&&(K=(H=(J=n.getFirstKey)===null||J===void 0?void 0:J.call(n))!==null&&H!==void 0?H:null);var M;i==="last"&&(K=(M=(te=n.getLastKey)===null||te===void 0?void 0:te.call(n))!==null&&M!==void 0?M:null);let X=t.selectedKeys;if(X.size){for(let B of X)if(t.canSelectItem(B)){K=B;break}}t.setFocused(!0),t.setFocusedKey(K),K==null&&!d&&r.current&&ac(r.current),t.collection.size>0&&(L.current=!1,j.current=!0)}});let V=P.useRef(t.focusedKey),q=P.useRef(null);P.useEffect(()=>{if(t.isFocused&&t.focusedKey!=null&&(t.focusedKey!==V.current||j.current)&&y.current&&r.current){let J=rg(),te=GE(r,t.focusedKey);if(!(te instanceof HTMLElement))return;(J==="keyboard"||j.current)&&(q.current&&cancelAnimationFrame(q.current),q.current=requestAnimationFrame(()=>{y.current&&(Gee(y.current,te),J!=="virtual"&&Vm(te,{containingElement:r.current}))}))}!d&&t.isFocused&&t.focusedKey==null&&V.current!=null&&r.current&&ac(r.current),V.current=t.focusedKey,j.current=!1}),P.useEffect(()=>()=>{q.current&&cancelAnimationFrame(q.current)},[]),Xd(r,"react-aria-focus-scope-restore",J=>{J.preventDefault(),t.setFocused(!0)});let N={onKeyDown:E,onFocus:T,onBlur:R,onMouseDown(J){y.current===J.target&&J.preventDefault()}},{typeSelectProps:U}=wre({keyboardDelegate:n,selectionManager:t});c||(N=Et(U,N));let W;d||(W=t.focusedKey==null?0:-1);let G=$De(t.collection);return{collectionProps:Et(N,{tabIndex:W,"data-collection":G})}}function jC(e){let{id:t,selectionManager:n,key:r,ref:i,shouldSelectOnPressUp:a,shouldUseVirtualFocus:u,focus:l,isDisabled:o,onAction:s,allowsDifferentPressOrigin:c,linkBehavior:d="action"}=e,h=Z3();t=pi(t);let m=M=>{if(M.pointerType==="keyboard"&&z9(M))n.toggleSelection(r);else{if(n.selectionMode==="none")return;if(n.isLink(r)){if(d==="selection"&&i.current){let K=n.getItemProps(r);h.open(i.current,M,K.href,K.routerOptions),n.setSelectedKeys(n.selectedKeys);return}else if(d==="override"||d==="none")return}n.selectionMode==="single"?n.isSelected(r)&&!n.disallowEmptySelection?n.toggleSelection(r):n.replaceSelection(r):M&&M.shiftKey?n.extendSelection(r):n.selectionBehavior==="toggle"||M&&(T1(M)||M.pointerType==="touch"||M.pointerType==="virtual")?n.toggleSelection(r):n.replaceSelection(r)}};P.useEffect(()=>{r===n.focusedKey&&n.isFocused&&(u?AN(i.current):l?l():document.activeElement!==i.current&&i.current&&ac(i.current))},[i,r,n.focusedKey,n.childFocusStrategy,n.isFocused,u]),o=o||n.isDisabled(r);let y={};!u&&!o?y={tabIndex:r===n.focusedKey?0:-1,onFocus(M){M.target===i.current&&n.setFocusedKey(r)}}:o&&(y.onMouseDown=M=>{M.preventDefault()});let v=n.isLink(r)&&d==="override",_=s&&e.UNSTABLE_itemBehavior==="action",S=n.isLink(r)&&d!=="selection"&&d!=="none",E=!o&&n.canSelectItem(r)&&!v&&!_,C=(s||S)&&!o,T=C&&(n.selectionBehavior==="replace"?!E:!E||n.isEmpty),R=C&&E&&n.selectionBehavior==="replace",$=T||R,k=P.useRef(null),F=$&&E,L=P.useRef(!1),j=P.useRef(!1),V=n.getItemProps(r),q=M=>{if(s){var K;s(),(K=i.current)===null||K===void 0||K.dispatchEvent(new CustomEvent("react-aria-item-action",{bubbles:!0}))}S&&i.current&&h.open(i.current,M,V.href,V.routerOptions)},N={ref:i};if(a?(N.onPressStart=M=>{k.current=M.pointerType,L.current=F,M.pointerType==="keyboard"&&(!$||mj())&&m(M)},c?(N.onPressUp=T?void 0:M=>{M.pointerType==="mouse"&&E&&m(M)},N.onPress=T?q:M=>{M.pointerType!=="keyboard"&&M.pointerType!=="mouse"&&E&&m(M)}):N.onPress=M=>{if(T||R&&M.pointerType!=="mouse"){if(M.pointerType==="keyboard"&&!pj())return;q(M)}else M.pointerType!=="keyboard"&&E&&m(M)}):(N.onPressStart=M=>{k.current=M.pointerType,L.current=F,j.current=T,E&&(M.pointerType==="mouse"&&!T||M.pointerType==="keyboard"&&(!C||mj()))&&m(M)},N.onPress=M=>{(M.pointerType==="touch"||M.pointerType==="pen"||M.pointerType==="virtual"||M.pointerType==="keyboard"&&$&&pj()||M.pointerType==="mouse"&&j.current)&&($?q(M):E&&m(M))}),y["data-collection"]=CDe(n.collection),y["data-key"]=r,N.preventFocusOnPress=u,u&&(N=Et(N,{onPressStart(M){M.pointerType!=="touch"&&(n.setFocused(!0),n.setFocusedKey(r))},onPress(M){M.pointerType==="touch"&&(n.setFocused(!0),n.setFocusedKey(r))}})),V)for(let M of["onPressStart","onPressEnd","onPressChange","onPress","onPressUp","onClick"])V[M]&&(N[M]=rh(N[M],V[M]));let{pressProps:U,isPressed:W}=up(N),G=R?M=>{k.current==="mouse"&&(M.stopPropagation(),M.preventDefault(),q(M))}:void 0,{longPressProps:J}=Fne({isDisabled:!F,onLongPress(M){M.pointerType==="touch"&&(m(M),n.setSelectionBehavior("toggle"))}}),te=M=>{k.current==="touch"&&L.current&&M.preventDefault()},H=d!=="none"&&n.isLink(r)?M=>{ib.isOpening||M.preventDefault()}:void 0;return{itemProps:Et(y,E||T||u&&!o?U:{},F?J:{},{onDoubleClick:G,onDragStartCapture:te,onClick:H,id:t},u?{onMouseDown:M=>M.preventDefault()}:void 0),isPressed:W,isSelected:n.isSelected(r),isFocused:n.isFocused&&n.focusedKey===r,isDisabled:o,allowsSelection:E,hasAction:$}}function pj(){let e=window.event;return(e==null?void 0:e.key)==="Enter"}function mj(){let e=window.event;return(e==null?void 0:e.key)===" "||(e==null?void 0:e.code)==="Space"}class gj{getItemRect(t){let n=this.ref.current;if(!n)return null;let r=t!=null?GE(this.ref,t):null;if(!r)return null;let i=n.getBoundingClientRect(),a=r.getBoundingClientRect();return{x:a.left-i.left-n.clientLeft+n.scrollLeft,y:a.top-i.top-n.clientTop+n.scrollTop,width:a.width,height:a.height}}getContentSize(){let t=this.ref.current;var n,r;return{width:(n=t==null?void 0:t.scrollWidth)!==null&&n!==void 0?n:0,height:(r=t==null?void 0:t.scrollHeight)!==null&&r!==void 0?r:0}}getVisibleRect(){let t=this.ref.current;var n,r,i,a;return{x:(n=t==null?void 0:t.scrollLeft)!==null&&n!==void 0?n:0,y:(r=t==null?void 0:t.scrollTop)!==null&&r!==void 0?r:0,width:(i=t==null?void 0:t.clientWidth)!==null&&i!==void 0?i:0,height:(a=t==null?void 0:t.clientHeight)!==null&&a!==void 0?a:0}}constructor(t){this.ref=t}}class hS{isDisabled(t){var n;return this.disabledBehavior==="all"&&(((n=t.props)===null||n===void 0?void 0:n.isDisabled)||this.disabledKeys.has(t.key))}findNextNonDisabled(t,n){let r=t;for(;r!=null;){let i=this.collection.getItem(r);if((i==null?void 0:i.type)==="item"&&!this.isDisabled(i))return r;r=n(r)}return null}getNextKey(t){let n=t;return n=this.collection.getKeyAfter(n),this.findNextNonDisabled(n,r=>this.collection.getKeyAfter(r))}getPreviousKey(t){let n=t;return n=this.collection.getKeyBefore(n),this.findNextNonDisabled(n,r=>this.collection.getKeyBefore(r))}findKey(t,n,r){let i=t,a=this.layoutDelegate.getItemRect(i);if(!a||i==null)return null;let u=a;do{if(i=n(i),i==null)break;a=this.layoutDelegate.getItemRect(i)}while(a&&r(u,a)&&i!=null);return i}isSameRow(t,n){return t.y===n.y||t.x!==n.x}isSameColumn(t,n){return t.x===n.x||t.y!==n.y}getKeyBelow(t){return this.layout==="grid"&&this.orientation==="vertical"?this.findKey(t,n=>this.getNextKey(n),this.isSameRow):this.getNextKey(t)}getKeyAbove(t){return this.layout==="grid"&&this.orientation==="vertical"?this.findKey(t,n=>this.getPreviousKey(n),this.isSameRow):this.getPreviousKey(t)}getNextColumn(t,n){return n?this.getPreviousKey(t):this.getNextKey(t)}getKeyRightOf(t){let n=this.direction==="ltr"?"getKeyRightOf":"getKeyLeftOf";return this.layoutDelegate[n]?(t=this.layoutDelegate[n](t),this.findNextNonDisabled(t,r=>this.layoutDelegate[n](r))):this.layout==="grid"?this.orientation==="vertical"?this.getNextColumn(t,this.direction==="rtl"):this.findKey(t,r=>this.getNextColumn(r,this.direction==="rtl"),this.isSameColumn):this.orientation==="horizontal"?this.getNextColumn(t,this.direction==="rtl"):null}getKeyLeftOf(t){let n=this.direction==="ltr"?"getKeyLeftOf":"getKeyRightOf";return this.layoutDelegate[n]?(t=this.layoutDelegate[n](t),this.findNextNonDisabled(t,r=>this.layoutDelegate[n](r))):this.layout==="grid"?this.orientation==="vertical"?this.getNextColumn(t,this.direction==="ltr"):this.findKey(t,r=>this.getNextColumn(r,this.direction==="ltr"),this.isSameColumn):this.orientation==="horizontal"?this.getNextColumn(t,this.direction==="ltr"):null}getFirstKey(){let t=this.collection.getFirstKey();return this.findNextNonDisabled(t,n=>this.collection.getKeyAfter(n))}getLastKey(){let t=this.collection.getLastKey();return this.findNextNonDisabled(t,n=>this.collection.getKeyBefore(n))}getKeyPageAbove(t){let n=this.ref.current,r=this.layoutDelegate.getItemRect(t);if(!r)return null;if(n&&!ub(n))return this.getFirstKey();let i=t;if(this.orientation==="horizontal"){let a=Math.max(0,r.x+r.width-this.layoutDelegate.getVisibleRect().width);for(;r&&r.x>a&&i!=null;)i=this.getKeyAbove(i),r=i==null?null:this.layoutDelegate.getItemRect(i)}else{let a=Math.max(0,r.y+r.height-this.layoutDelegate.getVisibleRect().height);for(;r&&r.y>a&&i!=null;)i=this.getKeyAbove(i),r=i==null?null:this.layoutDelegate.getItemRect(i)}return i??this.getFirstKey()}getKeyPageBelow(t){let n=this.ref.current,r=this.layoutDelegate.getItemRect(t);if(!r)return null;if(n&&!ub(n))return this.getLastKey();let i=t;if(this.orientation==="horizontal"){let a=Math.min(this.layoutDelegate.getContentSize().width,r.y-r.width+this.layoutDelegate.getVisibleRect().width);for(;r&&r.x<a&&i!=null;)i=this.getKeyBelow(i),r=i==null?null:this.layoutDelegate.getItemRect(i)}else{let a=Math.min(this.layoutDelegate.getContentSize().height,r.y-r.height+this.layoutDelegate.getVisibleRect().height);for(;r&&r.y<a&&i!=null;)i=this.getKeyBelow(i),r=i==null?null:this.layoutDelegate.getItemRect(i)}return i??this.getLastKey()}getKeyForSearch(t,n){if(!this.collator)return null;let r=this.collection,i=n||this.getFirstKey();for(;i!=null;){let a=r.getItem(i);if(!a)return null;let u=a.textValue.slice(0,t.length);if(a.textValue&&this.collator.compare(u,t)===0)return i;i=this.getNextKey(i)}return null}constructor(...t){if(t.length===1){let n=t[0];this.collection=n.collection,this.ref=n.ref,this.collator=n.collator,this.disabledKeys=n.disabledKeys||new Set,this.disabledBehavior=n.disabledBehavior||"all",this.orientation=n.orientation||"vertical",this.direction=n.direction,this.layout=n.layout||"stack",this.layoutDelegate=n.layoutDelegate||new gj(n.ref)}else this.collection=t[0],this.disabledKeys=t[1],this.ref=t[2],this.collator=t[3],this.layout="stack",this.orientation="vertical",this.disabledBehavior="all",this.layoutDelegate=new gj(this.ref);this.layout==="stack"&&this.orientation==="vertical"&&(this.getKeyLeftOf=void 0,this.getKeyRightOf=void 0)}}function FN(e){let{selectionManager:t,collection:n,disabledKeys:r,ref:i,keyboardDelegate:a,layoutDelegate:u}=e,l=zC({usage:"search",sensitivity:"base"}),o=t.disabledBehavior,s=P.useMemo(()=>a||new hS({collection:n,disabledKeys:r,disabledBehavior:o,ref:i,collator:l,layoutDelegate:u}),[a,u,n,r,i,l,o]),{collectionProps:c}=MN({...e,ref:i,selectionManager:t,keyboardDelegate:s});return{listProps:c}}function ADe(e,t,n){let r=Gt(e,{labelable:!0}),i=e.selectionBehavior||"toggle",a=e.linkBehavior||(i==="replace"?"action":"override");i==="toggle"&&a==="action"&&(a="override");let{listProps:u}=FN({...e,ref:n,selectionManager:t.selectionManager,collection:t.collection,disabledKeys:t.disabledKeys,linkBehavior:a}),{focusWithinProps:l}=B0({onFocusWithin:e.onFocus,onBlurWithin:e.onBlur,onFocusWithinChange:e.onFocusChange}),o=pi(e.id);UC.set(t,{id:o,shouldUseVirtualFocus:e.shouldUseVirtualFocus,shouldSelectOnPressUp:e.shouldSelectOnPressUp,shouldFocusOnHover:e.shouldFocusOnHover,isVirtualized:e.isVirtualized,onAction:e.onAction,linkBehavior:a,UNSTABLE_itemBehavior:e.UNSTABLE_itemBehavior});let{labelProps:s,fieldProps:c}=fS({...e,id:o,labelElementType:"span"});return{labelProps:s,listBoxProps:Et(r,l,t.selectionManager.selectionMode==="multiple"?{"aria-multiselectable":"true"}:{},{role:"listbox",...Et(c,u)})}}class TDe{build(t,n){return this.context=n,vj(()=>this.iterateCollection(t))}*iterateCollection(t){let{children:n,items:r}=t;if(ye.isValidElement(n)&&n.type===ye.Fragment)yield*this.iterateCollection({children:n.props.children,items:r});else if(typeof n=="function"){if(!r)throw new Error("props.children was a function but props.items is missing");let i=0;for(let a of r)yield*this.getFullNode({value:a,index:i},{renderer:n}),i++}else{let i=[];ye.Children.forEach(n,u=>{u&&i.push(u)});let a=0;for(let u of i){let l=this.getFullNode({element:u,index:a},{});for(let o of l)a++,yield o}}}getKey(t,n,r,i){if(t.key!=null)return t.key;if(n.type==="cell"&&n.key!=null)return`${i}${n.key}`;let a=n.value;if(a!=null){var u;let l=(u=a.key)!==null&&u!==void 0?u:a.id;if(l==null)throw new Error("No key found for item");return l}return i?`${i}.${n.index}`:`$.${n.index}`}getChildState(t,n){return{renderer:n.renderer||t.renderer}}*getFullNode(t,n,r,i){if(ye.isValidElement(t.element)&&t.element.type===ye.Fragment){let _=[];ye.Children.forEach(t.element.props.children,E=>{_.push(E)});var a;let S=(a=t.index)!==null&&a!==void 0?a:0;for(const E of _)yield*this.getFullNode({element:E,index:S++},n,r,i);return}let u=t.element;if(!u&&t.value&&n&&n.renderer){let _=this.cache.get(t.value);if(_&&(!_.shouldInvalidate||!_.shouldInvalidate(this.context))){_.index=t.index,_.parentKey=i?i.key:null,yield _;return}u=n.renderer(t.value)}if(ye.isValidElement(u)){let _=u.type;if(typeof _!="function"&&typeof _.getCollectionNode!="function"){let T=u.type;throw new Error(`Unknown element <${T}> in collection.`)}let S=_.getCollectionNode(u.props,this.context);var l;let E=(l=t.index)!==null&&l!==void 0?l:0,C=S.next();for(;!C.done&&C.value;){let T=C.value;t.index=E;var o;let R=(o=T.key)!==null&&o!==void 0?o:null;R==null&&(R=T.element?null:this.getKey(u,t,n,r));let k=[...this.getFullNode({...T,key:R,index:E,wrapper:kDe(t.wrapper,T.wrapper)},this.getChildState(n,T),r?`${r}${u.key}`:u.key,i)];for(let F of k){var s,c;F.value=(c=(s=T.value)!==null&&s!==void 0?s:t.value)!==null&&c!==void 0?c:null,F.value&&this.cache.set(F.value,F);var d;if(t.type&&F.type!==t.type)throw new Error(`Unsupported type <${rk(F.type)}> in <${rk((d=i==null?void 0:i.type)!==null&&d!==void 0?d:"unknown parent type")}>. Only <${rk(t.type)}> is supported.`);E++,yield F}C=S.next(k)}return}if(t.key==null||t.type==null)return;let h=this;var m,y;let v={type:t.type,props:t.props,key:t.key,parentKey:i?i.key:null,value:(m=t.value)!==null&&m!==void 0?m:null,level:i?i.level+1:0,index:t.index,rendered:t.rendered,textValue:(y=t.textValue)!==null&&y!==void 0?y:"","aria-label":t["aria-label"],wrapper:t.wrapper,shouldInvalidate:t.shouldInvalidate,hasChildNodes:t.hasChildNodes||!1,childNodes:vj(function*(){if(!t.hasChildNodes||!t.childNodes)return;let _=0;for(let S of t.childNodes()){S.key!=null&&(S.key=`${v.key}${S.key}`);let E=h.getFullNode({...S,index:_},h.getChildState(n,S),v.key,v);for(let C of E)_++,yield C}})};yield v}constructor(){this.cache=new WeakMap}}function vj(e){let t=[],n=null;return{*[Symbol.iterator](){for(let r of t)yield r;n||(n=e());for(let r of n)t.push(r),yield r}}}function kDe(e,t){if(e&&t)return n=>e(t(n));if(e)return e;if(t)return t}function rk(e){return e[0].toUpperCase()+e.slice(1)}function Rre(e,t,n){let r=P.useMemo(()=>new TDe,[]),{children:i,items:a,collection:u}=e;return P.useMemo(()=>{if(u)return u;let o=r.build({children:i,items:a},n);return t(o)},[r,i,a,u,n,t])}function ZC(e,t){return typeof t.getChildren=="function"?t.getChildren(e.key):e.childNodes}function PDe(e){return MDe(e)}function MDe(e,t){for(let n of e)return n}function ik(e,t,n){if(t.parentKey===n.parentKey)return t.index-n.index;let r=[...yj(e,t),t],i=[...yj(e,n),n],a=r.slice(0,i.length).findIndex((u,l)=>u!==i[l]);return a!==-1?(t=r[a],n=i[a],t.index-n.index):r.findIndex(u=>u===n)>=0?1:(i.findIndex(u=>u===t)>=0,-1)}function yj(e,t){let n=[],r=t;for(;(r==null?void 0:r.parentKey)!=null;)r=e.getItem(r.parentKey),r&&n.unshift(r);return n}const bj=new WeakMap;function NN(e){let t=bj.get(e);if(t!=null)return t;let n=0,r=i=>{for(let a of i)a.type==="section"?r(ZC(a,e)):a.type==="item"&&n++};return r(e),bj.set(e,n),n}function FDe(e,t,n){var r,i;let{key:a}=e,u=UC.get(t);var l;let o=(l=e.isDisabled)!==null&&l!==void 0?l:t.selectionManager.isDisabled(a);var s;let c=(s=e.isSelected)!==null&&s!==void 0?s:t.selectionManager.isSelected(a);var d;let h=(d=e.shouldSelectOnPressUp)!==null&&d!==void 0?d:u==null?void 0:u.shouldSelectOnPressUp;var m;let y=(m=e.shouldFocusOnHover)!==null&&m!==void 0?m:u==null?void 0:u.shouldFocusOnHover;var v;let _=(v=e.shouldUseVirtualFocus)!==null&&v!==void 0?v:u==null?void 0:u.shouldUseVirtualFocus;var S;let E=(S=e.isVirtualized)!==null&&S!==void 0?S:u==null?void 0:u.isVirtualized,C=C0(),T=C0(),R={role:"option","aria-disabled":o||void 0,"aria-selected":t.selectionManager.selectionMode!=="none"?c:void 0};sg()&&aN()||(R["aria-label"]=e["aria-label"],R["aria-labelledby"]=C,R["aria-describedby"]=T);let $=t.collection.getItem(a);if(E){let J=Number($==null?void 0:$.index);R["aria-posinset"]=Number.isNaN(J)?void 0:J+1,R["aria-setsize"]=NN(t.collection)}let k=u!=null&&u.onAction?()=>{var J;return u==null||(J=u.onAction)===null||J===void 0?void 0:J.call(u,a)}:void 0,F=$re(t,a),{itemProps:L,isPressed:j,isFocused:V,hasAction:q,allowsSelection:N}=jC({selectionManager:t.selectionManager,key:a,ref:n,shouldSelectOnPressUp:h,allowsDifferentPressOrigin:h&&y,isVirtualized:E,shouldUseVirtualFocus:_,isDisabled:o,onAction:k||!($==null||(r=$.props)===null||r===void 0)&&r.onAction?rh($==null||(i=$.props)===null||i===void 0?void 0:i.onAction,k):void 0,linkBehavior:u==null?void 0:u.linkBehavior,UNSTABLE_itemBehavior:u==null?void 0:u.UNSTABLE_itemBehavior,id:F}),{hoverProps:U}=Cu({isDisabled:o||!y,onHoverStart(){Jv()||(t.selectionManager.setFocused(!0),t.selectionManager.setFocusedKey(a))}}),W=Gt($==null?void 0:$.props);delete W.id;let G=lN($==null?void 0:$.props);return{optionProps:{...R,...Et(W,L,U,G),id:F},labelProps:{id:C},descriptionProps:{id:T},isFocused:V,isFocusVisible:V&&t.selectionManager.isFocused&&Jv(),isSelected:c,isDisabled:o,isPressed:j,allowsSelection:N,hasAction:q}}function NDe(e){let{heading:t,"aria-label":n}=e,r=pi();return{itemProps:{role:"presentation"},headingProps:t?{id:r,role:"presentation"}:{},groupProps:{role:"group","aria-label":n,"aria-labelledby":t?r:void 0}}}const Are={badInput:!1,customError:!1,patternMismatch:!1,rangeOverflow:!1,rangeUnderflow:!1,stepMismatch:!1,tooLong:!1,tooShort:!1,typeMismatch:!1,valueMissing:!1,valid:!0},Tre={...Are,customError:!0,valid:!1},NO={isInvalid:!1,validationDetails:Are,validationErrors:[]},kre=P.createContext({}),sb="__formValidationState"+Date.now();function bg(e){if(e[sb]){let{realtimeValidation:t,displayValidation:n,updateValidation:r,resetValidation:i,commitValidation:a}=e[sb];return{realtimeValidation:t,displayValidation:n,updateValidation:r,resetValidation:i,commitValidation:a}}return IDe(e)}function IDe(e){let{isInvalid:t,validationState:n,name:r,value:i,builtinValidation:a,validate:u,validationBehavior:l="aria"}=e;n&&(t||(t=n==="invalid"));let o=t!==void 0?{isInvalid:t,validationErrors:[],validationDetails:Tre}:null,s=P.useMemo(()=>{if(!u||i==null)return null;let j=LDe(u,i);return Oj(j)},[u,i]);a!=null&&a.validationDetails.valid&&(a=void 0);let c=P.useContext(kre),d=P.useMemo(()=>r?Array.isArray(r)?r.flatMap(j=>q9(c[j])):q9(c[r]):[],[c,r]),[h,m]=P.useState(c),[y,v]=P.useState(!1);c!==h&&(m(c),v(!1));let _=P.useMemo(()=>Oj(y?[]:d),[y,d]),S=P.useRef(NO),[E,C]=P.useState(NO),T=P.useRef(NO),R=()=>{if(!$)return;k(!1);let j=s||a||S.current;ak(j,T.current)||(T.current=j,C(j))},[$,k]=P.useState(!1);return P.useEffect(R),{realtimeValidation:o||_||s||a||NO,displayValidation:l==="native"?o||_||E:o||_||s||a||E,updateValidation(j){l==="aria"&&!ak(E,j)?C(j):S.current=j},resetValidation(){let j=NO;ak(j,T.current)||(T.current=j,C(j)),l==="native"&&k(!1),v(!0)},commitValidation(){l==="native"&&k(!0),v(!0)}}}function q9(e){return e?Array.isArray(e)?e:[e]:[]}function LDe(e,t){if(typeof e=="function"){let n=e(t);if(n&&typeof n!="boolean")return q9(n)}return[]}function Oj(e){return e.length?{isInvalid:!0,validationErrors:e,validationDetails:Tre}:null}function ak(e,t){return e===t?!0:!!e&&!!t&&e.isInvalid===t.isInvalid&&e.validationErrors.length===t.validationErrors.length&&e.validationErrors.every((n,r)=>n===t.validationErrors[r])&&Object.entries(e.validationDetails).every(([n,r])=>t.validationDetails[n]===r)}var Pre={};Pre={longPressMessage:"اضغط مطولاً أو اضغط على Alt + السهم لأسفل لفتح القائمة"};var Mre={};Mre={longPressMessage:"Натиснете продължително или натиснете Alt+ стрелка надолу, за да отворите менюто"};var Fre={};Fre={longPressMessage:"Dlouhým stiskem nebo stisknutím kláves Alt + šipka dolů otevřete nabídku"};var Nre={};Nre={longPressMessage:"Langt tryk eller tryk på Alt + pil ned for at åbne menuen"};var Ire={};Ire={longPressMessage:"Drücken Sie lange oder drücken Sie Alt + Nach-unten, um das Menü zu öffnen"};var Lre={};Lre={longPressMessage:"Πιέστε παρατεταμένα ή πατήστε Alt + κάτω βέλος για να ανοίξετε το μενού"};var Bre={};Bre={longPressMessage:"Long press or press Alt + ArrowDown to open menu"};var Qre={};Qre={longPressMessage:"Mantenga pulsado o pulse Alt + flecha abajo para abrir el menú"};var zre={};zre={longPressMessage:"Menüü avamiseks vajutage pikalt või vajutage klahve Alt + allanool"};var qre={};qre={longPressMessage:"Avaa valikko painamalla pohjassa tai näppäinyhdistelmällä Alt + Alanuoli"};var Vre={};Vre={longPressMessage:"Appuyez de manière prolongée ou appuyez sur Alt + Flèche vers le bas pour ouvrir le menu."};var Ure={};Ure={longPressMessage:"לחץ לחיצה ארוכה או הקש Alt + ArrowDown כדי לפתוח את התפריט"};var jre={};jre={longPressMessage:"Dugo pritisnite ili pritisnite Alt + strelicu prema dolje za otvaranje izbornika"};var Zre={};Zre={longPressMessage:"Nyomja meg hosszan, vagy nyomja meg az Alt + lefele nyíl gombot a menü megnyitásához"};var Hre={};Hre={longPressMessage:"Premere a lungo o premere Alt + Freccia giù per aprire il menu"};var Xre={};Xre={longPressMessage:"長押しまたは Alt+下矢印キーでメニューを開く"};var Yre={};Yre={longPressMessage:"길게 누르거나 Alt + 아래쪽 화살표를 눌러 메뉴 열기"};var Gre={};Gre={longPressMessage:"Norėdami atidaryti meniu, nuspaudę palaikykite arba paspauskite „Alt + ArrowDown“."};var Kre={};Kre={longPressMessage:"Lai atvērtu izvēlni, turiet nospiestu vai nospiediet taustiņu kombināciju Alt + lejupvērstā bultiņa"};var Wre={};Wre={longPressMessage:"Langt trykk eller trykk Alt + PilNed for å åpne menyen"};var Jre={};Jre={longPressMessage:"Druk lang op Alt + pijl-omlaag of druk op Alt om het menu te openen"};var eie={};eie={longPressMessage:"Naciśnij i przytrzymaj lub naciśnij klawisze Alt + Strzałka w dół, aby otworzyć menu"};var tie={};tie={longPressMessage:"Pressione e segure ou pressione Alt + Seta para baixo para abrir o menu"};var nie={};nie={longPressMessage:"Prima continuamente ou prima Alt + Seta Para Baixo para abrir o menu"};var rie={};rie={longPressMessage:"Apăsați lung sau apăsați pe Alt + săgeată în jos pentru a deschide meniul"};var iie={};iie={longPressMessage:"Нажмите и удерживайте или нажмите Alt + Стрелка вниз, чтобы открыть меню"};var aie={};aie={longPressMessage:"Ponuku otvoríte dlhým stlačením alebo stlačením klávesu Alt + klávesu so šípkou nadol"};var uie={};uie={longPressMessage:"Za odprtje menija pritisnite in držite gumb ali pritisnite Alt+puščica navzdol"};var lie={};lie={longPressMessage:"Dugo pritisnite ili pritisnite Alt + strelicu prema dole da otvorite meni"};var oie={};oie={longPressMessage:"Håll nedtryckt eller tryck på Alt + pil nedåt för att öppna menyn"};var sie={};sie={longPressMessage:"Menüyü açmak için uzun basın veya Alt + Aşağı Ok tuşuna basın"};var cie={};cie={longPressMessage:"Довго або звичайно натисніть комбінацію клавіш Alt і стрілка вниз, щоб відкрити меню"};var fie={};fie={longPressMessage:"长按或按 Alt + 向下方向键以打开菜单"};var die={};die={longPressMessage:"長按或按 Alt+向下鍵以開啟功能表"};var hie={};hie={"ar-AE":Pre,"bg-BG":Mre,"cs-CZ":Fre,"da-DK":Nre,"de-DE":Ire,"el-GR":Lre,"en-US":Bre,"es-ES":Qre,"et-EE":zre,"fi-FI":qre,"fr-FR":Vre,"he-IL":Ure,"hr-HR":jre,"hu-HU":Zre,"it-IT":Hre,"ja-JP":Xre,"ko-KR":Yre,"lt-LT":Gre,"lv-LV":Kre,"nb-NO":Wre,"nl-NL":Jre,"pl-PL":eie,"pt-BR":tie,"pt-PT":nie,"ro-RO":rie,"ru-RU":iie,"sk-SK":aie,"sl-SI":uie,"sr-SP":lie,"sv-SE":oie,"tr-TR":sie,"uk-UA":cie,"zh-CN":fie,"zh-TW":die};function BDe(e){return e&&e.__esModule?e.default:e}function IN(e,t,n){let{type:r="menu",isDisabled:i,trigger:a="press"}=e,u=pi(),{triggerProps:l,overlayProps:o}=zne({type:r},t,n),s=m=>{if(!i&&!(a==="longPress"&&!m.altKey)&&n&&n.current)switch(m.key){case"Enter":case" ":if(a==="longPress"||m.isDefaultPrevented())return;case"ArrowDown":"continuePropagation"in m||m.stopPropagation(),m.preventDefault(),t.toggle("first");break;case"ArrowUp":"continuePropagation"in m||m.stopPropagation(),m.preventDefault(),t.toggle("last");break;default:"continuePropagation"in m&&m.continuePropagation()}},c=Fo(BDe(hie),"@react-aria/menu"),{longPressProps:d}=Fne({isDisabled:i||a!=="longPress",accessibilityDescription:c.format("longPressMessage"),onLongPressStart(){t.close()},onLongPress(){t.open("first")}}),h={preventFocusOnPress:!0,onPressStart(m){m.pointerType!=="touch"&&m.pointerType!=="keyboard"&&!i&&(_u(m.target),t.open(m.pointerType==="virtual"?"first":null))},onPress(m){m.pointerType==="touch"&&!i&&(_u(m.target),t.toggle())}};return delete l.onPress,{menuTriggerProps:{...l,...a==="press"?h:d,id:u,onKeyDown:s},menuProps:{...o,"aria-labelledby":u,autoFocus:t.focusStrategy||!0,onClose:t.close}}}const pie=new WeakMap;function QDe(e,t,n){let{shouldFocusWrap:r=!0,onKeyDown:i,onKeyUp:a,...u}=e;!e["aria-label"]&&e["aria-labelledby"];let l=Gt(e,{labelable:!0}),{listProps:o}=FN({...u,ref:n,selectionManager:t.selectionManager,collection:t.collection,disabledKeys:t.disabledKeys,shouldFocusWrap:r,linkBehavior:"override"});return pie.set(t,{onClose:e.onClose,onAction:e.onAction,shouldUseVirtualFocus:e.shouldUseVirtualFocus}),{menuProps:Et(l,{onKeyDown:i,onKeyUp:a},{role:"menu",...o,onKeyDown:s=>{var c;(s.key!=="Escape"||e.shouldUseVirtualFocus)&&((c=o.onKeyDown)===null||c===void 0||c.call(o,s))}})}}function zDe(e,t,n){let{id:r,key:i,closeOnSelect:a,isVirtualized:u,"aria-haspopup":l,onPressStart:o,onPressUp:s,onPress:c,onPressChange:d,onPressEnd:h,onClick:m,onHoverStart:y,onHoverChange:v,onHoverEnd:_,onKeyDown:S,onKeyUp:E,onFocus:C,onFocusChange:T,onBlur:R,selectionManager:$=t.selectionManager}=e,k=!!l,F=k&&e["aria-expanded"]==="true";var L;let j=(L=e.isDisabled)!==null&&L!==void 0?L:$.isDisabled(i);var V;let q=(V=e.isSelected)!==null&&V!==void 0?V:$.isSelected(i),N=pie.get(t),U=t.collection.getItem(i),W=e.onClose||N.onClose,G=Z3(),J=()=>{var Re;if(!k&&(!(U==null||(Re=U.props)===null||Re===void 0)&&Re.onAction?U.props.onAction():e.onAction&&e.onAction(i),N.onAction)){let et=N.onAction;et(i)}},te="menuitem";k||($.selectionMode==="single"?te="menuitemradio":$.selectionMode==="multiple"&&(te="menuitemcheckbox"));let H=C0(),M=C0(),K=C0(),X={id:r,"aria-disabled":j||void 0,role:te,"aria-label":e["aria-label"],"aria-labelledby":H,"aria-describedby":[M,K].filter(Boolean).join(" ")||void 0,"aria-controls":e["aria-controls"],"aria-haspopup":l,"aria-expanded":e["aria-expanded"]};$.selectionMode!=="none"&&!k&&(X["aria-checked"]=q),u&&(X["aria-posinset"]=U==null?void 0:U.index,X["aria-setsize"]=NN(t.collection));let B=P.useRef(!1),ne=Re=>{d==null||d(Re),B.current=Re},oe=P.useRef(null),ie=Re=>{Re.pointerType!=="keyboard"&&(oe.current={pointerType:Re.pointerType}),Re.pointerType==="mouse"&&(B.current||Re.target.click()),s==null||s(Re)},de=Re=>{var et,tt;m==null||m(Re),J(),XSe(Re,G,U.props.href,U==null?void 0:U.props.routerOptions);let Oe=((et=oe.current)===null||et===void 0?void 0:et.pointerType)==="keyboard"?((tt=oe.current)===null||tt===void 0?void 0:tt.key)==="Enter"||$.selectionMode==="none"||$.isLink(i):$.selectionMode!=="multiple"||$.isLink(i);Oe=a??Oe,W&&!k&&Oe&&W(),oe.current=null},{itemProps:be,isFocused:ve}=jC({id:r,selectionManager:$,key:i,ref:n,shouldSelectOnPressUp:!0,allowsDifferentPressOrigin:!0,linkBehavior:"none",shouldUseVirtualFocus:N.shouldUseVirtualFocus}),{pressProps:pe,isPressed:_e}=up({onPressStart:o,onPress:c,onPressUp:ie,onPressChange:ne,onPressEnd:h,isDisabled:j}),{hoverProps:se}=Cu({isDisabled:j,onHoverStart(Re){!Jv()&&!(F&&l)&&($.setFocused(!0),$.setFocusedKey(i)),y==null||y(Re)},onHoverChange:v,onHoverEnd:_}),{keyboardProps:me}=$N({onKeyDown:Re=>{if(Re.repeat){Re.continuePropagation();return}switch(Re.key){case" ":oe.current={pointerType:"keyboard",key:" "},Re.target.click();break;case"Enter":oe.current={pointerType:"keyboard",key:"Enter"},Re.target.tagName!=="A"&&Re.target.click();break;default:k||Re.continuePropagation(),S==null||S(Re);break}},onKeyUp:E}),{focusProps:ge}=VC({onBlur:R,onFocus:C,onFocusChange:T}),we=Gt(U==null?void 0:U.props);delete we.id;let Ne=lN(U==null?void 0:U.props);return{menuItemProps:{...X,...Et(we,Ne,k?{onFocus:be.onFocus,"data-collection":be["data-collection"],"data-key":be["data-key"]}:be,pe,se,me,ge,N.shouldUseVirtualFocus||k?{onMouseDown:Re=>Re.preventDefault()}:void 0,j?void 0:{onClick:de}),tabIndex:be.tabIndex!=null&&F&&!N.shouldUseVirtualFocus?-1:be.tabIndex},labelProps:{id:H},descriptionProps:{id:M},keyboardShortcutProps:{id:K},isFocused:ve,isFocusVisible:ve&&$.isFocused&&Jv()&&!F,isSelected:q,isPressed:_e,isDisabled:j}}function qDe(e){let{heading:t,"aria-label":n}=e,r=pi();return{itemProps:{role:"presentation"},headingProps:t?{id:r,role:"presentation"}:{},groupProps:{role:"group","aria-label":n,"aria-labelledby":t?r:void 0}}}const U_=2,VDe=50,UDe=1e3,xj=Math.PI/12;function jDe(e){let{menuRef:t,submenuRef:n,isOpen:r,isDisabled:i}=e,a=P.useRef(void 0),u=P.useRef(void 0),l=P.useRef(0),o=P.useRef(void 0),s=P.useRef(void 0),c=P.useRef(void 0),d=P.useRef(2),[h,m]=P.useState(!1);ab({ref:n,onResize:()=>{n.current&&(u.current=n.current.getBoundingClientRect(),c.current=void 0)}});let v=()=>{m(!1),d.current=U_,a.current=void 0},_=DN(),S=oi(E=>{h&&E.preventDefault()});P.useEffect(()=>{h&&t.current?t.current.style.pointerEvents="none":t.current.style.pointerEvents=""},[t,h]),P.useEffect(()=>{let E=n.current,C=t.current;if(i||!E||!r||_!=="pointer"||!C){v();return}u.current=E.getBoundingClientRect();let T=R=>{if(R.pointerType==="touch"||R.pointerType==="pen")return;let $=Date.now();if($-l.current<VDe)return;clearTimeout(o.current),clearTimeout(s.current);let{clientX:k,clientY:F}=R;if(!a.current){a.current={x:k,y:F};return}if(!u.current)return;if(c.current||(c.current=k>u.current.right?"left":"right"),k<C.getBoundingClientRect().left||k>C.getBoundingClientRect().right||F<C.getBoundingClientRect().top||F>C.getBoundingClientRect().bottom){v();return}let L=a.current.x,j=a.current.y,V=c.current==="right"?u.current.left-L:L-u.current.right,q=Math.atan2(j-u.current.top,V)+xj,N=Math.atan2(j-u.current.bottom,V)-xj,U=Math.atan2(j-F,c.current==="left"?-(k-L):k-L),W=U<q&&U>N;d.current=W?Math.min(d.current+1,U_):Math.max(d.current-1,0),d.current>=U_?m(!0):m(!1),l.current=$,a.current={x:k,y:F},W&&(o.current=setTimeout(()=>{v(),s.current=setTimeout(()=>{let G=document.elementFromPoint(k,F);G&&C.contains(G)&&G.dispatchEvent(new PointerEvent("pointerover",{bubbles:!0,cancelable:!0}))},100)},UDe))};return window.addEventListener("pointermove",T),window.addEventListener("pointerdown",S,!0),()=>{window.removeEventListener("pointermove",T),window.removeEventListener("pointerdown",S,!0),clearTimeout(o.current),clearTimeout(s.current),d.current=U_}},[i,r,t,_,m,S,n])}function ZDe(e,t,n){let{parentMenuRef:r,submenuRef:i,type:a="menu",isDisabled:u,delay:l=200,shouldUseVirtualFocus:o}=e,s=pi(),c=pi(),{direction:d}=Hi(),h=P.useRef(void 0),m=P.useCallback(()=>{h.current&&(clearTimeout(h.current),h.current=void 0)},[h]),y=oi(F=>{m(),t.open(F)}),v=oi(()=>{m(),t.close()});qr(()=>()=>{m()},[m]);let _=F=>{if(F.currentTarget.contains(document.activeElement))switch(F.key){case"ArrowLeft":d==="ltr"&&F.currentTarget.contains(F.target)&&(F.preventDefault(),F.stopPropagation(),v(),!o&&n.current&&_u(n.current));break;case"ArrowRight":d==="rtl"&&F.currentTarget.contains(F.target)&&(F.preventDefault(),F.stopPropagation(),v(),!o&&n.current&&_u(n.current));break;case"Escape":var L;!((L=i.current)===null||L===void 0)&&L.contains(F.target)&&(F.stopPropagation(),v(),!o&&n.current&&_u(n.current));break}};var S;let E={id:c,"aria-labelledby":s,submenuLevel:t.submenuLevel,...a==="menu"&&{onClose:t.closeAll,autoFocus:(S=t.focusStrategy)!==null&&S!==void 0?S:void 0,onKeyDown:_}},C=F=>{switch(F.key){case"ArrowRight":u||(d==="ltr"?(F.preventDefault(),t.isOpen||y("first"),a==="menu"&&(i!=null&&i.current)&&document.activeElement===(n==null?void 0:n.current)&&_u(i.current)):t.isOpen?v():F.continuePropagation());break;case"ArrowLeft":u||(d==="rtl"?(F.preventDefault(),t.isOpen||y("first"),a==="menu"&&(i!=null&&i.current)&&document.activeElement===(n==null?void 0:n.current)&&_u(i.current)):t.isOpen?v():F.continuePropagation());break;default:F.continuePropagation();break}},T=F=>{!u&&(F.pointerType==="virtual"||F.pointerType==="keyboard")&&y("first")},R=F=>{!u&&(F.pointerType==="touch"||F.pointerType==="mouse")&&y()},$=F=>{u||(F&&!t.isOpen?h.current||(h.current=setTimeout(()=>{y()},l)):F||m())};Xd(r,"focusin",F=>{var L;t.isOpen&&(!((L=r.current)===null||L===void 0)&&L.contains(F.target))&&F.target!==n.current&&v()});let k=F=>F!==n.current;return jDe({menuRef:r,submenuRef:i,isOpen:t.isOpen,isDisabled:u}),{submenuTriggerProps:{id:s,"aria-controls":t.isOpen?c:void 0,"aria-haspopup":u?void 0:a,"aria-expanded":t.isOpen?"true":"false",onPressStart:T,onPress:R,onHoverChange:$,onKeyDown:C,isOpen:t.isOpen},submenuProps:E,popoverProps:{isNonModal:!0,shouldCloseOnInteractOutside:k}}}function pS(e,t,n){let{validationBehavior:r,focus:i}=e;qr(()=>{if(r==="native"&&(n!=null&&n.current)&&!n.current.disabled){let s=t.realtimeValidation.isInvalid?t.realtimeValidation.validationErrors.join(" ")||"Invalid value.":"";n.current.setCustomValidity(s),n.current.hasAttribute("title")||(n.current.title=""),t.realtimeValidation.isInvalid||t.updateValidation(XDe(n.current))}});let a=P.useRef(!1),u=oi(()=>{a.current||t.resetValidation()}),l=oi(s=>{var c;t.displayValidation.isInvalid||t.commitValidation();let d=n==null||(c=n.current)===null||c===void 0?void 0:c.form;if(!s.defaultPrevented&&n&&d&&YDe(d)===n.current){var h;i?i():(h=n.current)===null||h===void 0||h.focus(),EN("keyboard")}s.preventDefault()}),o=oi(()=>{t.commitValidation()});P.useEffect(()=>{let s=n==null?void 0:n.current;if(!s)return;let c=s.form,d=c==null?void 0:c.reset;return c&&(c.reset=()=>{a.current=!window.event||window.event.type==="message"&&window.event.target instanceof MessagePort,d==null||d.call(c),a.current=!1}),s.addEventListener("invalid",l),s.addEventListener("change",o),c==null||c.addEventListener("reset",u),()=>{s.removeEventListener("invalid",l),s.removeEventListener("change",o),c==null||c.removeEventListener("reset",u),c&&(c.reset=d)}},[n,l,o,u,r])}function HDe(e){let t=e.validity;return{badInput:t.badInput,customError:t.customError,patternMismatch:t.patternMismatch,rangeOverflow:t.rangeOverflow,rangeUnderflow:t.rangeUnderflow,stepMismatch:t.stepMismatch,tooLong:t.tooLong,tooShort:t.tooShort,typeMismatch:t.typeMismatch,valueMissing:t.valueMissing,valid:t.valid}}function XDe(e){return{isInvalid:!e.validity.valid,validationDetails:HDe(e),validationErrors:e.validationMessage?[e.validationMessage]:[]}}function YDe(e){for(let t=0;t<e.elements.length;t++){let n=e.elements[t];if(!n.validity.valid)return n}return null}function HC(e,t){let{inputElementType:n="input",isDisabled:r=!1,isRequired:i=!1,isReadOnly:a=!1,type:u="text",validationBehavior:l="aria"}=e,[o,s]=Zu(e.value,e.defaultValue||"",e.onChange),{focusableProps:c}=L0(e,t),d=bg({...e,value:o}),{isInvalid:h,validationErrors:m,validationDetails:y}=d.displayValidation,{labelProps:v,fieldProps:_,descriptionProps:S,errorMessageProps:E}=dS({...e,isInvalid:h,errorMessage:e.errorMessage||m}),C=Gt(e,{labelable:!0});const T={type:u,pattern:e.pattern};let[R]=P.useState(o);var $;return my(t,($=e.defaultValue)!==null&&$!==void 0?$:R,s),pS(e,d,t),P.useEffect(()=>{if(t.current instanceof af(t.current).HTMLTextAreaElement){let k=t.current;Object.defineProperty(k,"defaultValue",{get:()=>k.value,set:()=>{},configurable:!0})}},[t]),{labelProps:v,inputProps:Et(C,n==="input"?T:void 0,{disabled:r,readOnly:a,required:i&&l==="native","aria-required":i&&l==="aria"||void 0,"aria-invalid":h||void 0,"aria-errormessage":e["aria-errormessage"],"aria-activedescendant":e["aria-activedescendant"],"aria-autocomplete":e["aria-autocomplete"],"aria-haspopup":e["aria-haspopup"],"aria-controls":e["aria-controls"],value:o,onChange:k=>s(k.target.value),autoComplete:e.autoComplete,autoCapitalize:e.autoCapitalize,maxLength:e.maxLength,minLength:e.minLength,name:e.name,form:e.form,placeholder:e.placeholder,inputMode:e.inputMode,autoCorrect:e.autoCorrect,spellCheck:e.spellCheck,[parseInt(ye.version,10)>=17?"enterKeyHint":"enterkeyhint"]:e.enterKeyHint,onCopy:e.onCopy,onCut:e.onCut,onPaste:e.onPaste,onCompositionEnd:e.onCompositionEnd,onCompositionStart:e.onCompositionStart,onCompositionUpdate:e.onCompositionUpdate,onSelect:e.onSelect,onBeforeInput:e.onBeforeInput,onInput:e.onInput,...c,..._}),descriptionProps:S,errorMessageProps:E,isInvalid:h,validationErrors:m,validationDetails:y}}function Sj(){return typeof window<"u"&&window.InputEvent&&typeof InputEvent.prototype.getTargetRanges=="function"}function mie(e,t,n){let r=oi(d=>{let h=n.current;if(!h)return;let m=null;switch(d.inputType){case"historyUndo":case"historyRedo":return;case"insertLineBreak":return;case"deleteContent":case"deleteByCut":case"deleteByDrag":m=h.value.slice(0,h.selectionStart)+h.value.slice(h.selectionEnd);break;case"deleteContentForward":m=h.selectionEnd===h.selectionStart?h.value.slice(0,h.selectionStart)+h.value.slice(h.selectionEnd+1):h.value.slice(0,h.selectionStart)+h.value.slice(h.selectionEnd);break;case"deleteContentBackward":m=h.selectionEnd===h.selectionStart?h.value.slice(0,h.selectionStart-1)+h.value.slice(h.selectionStart):h.value.slice(0,h.selectionStart)+h.value.slice(h.selectionEnd);break;case"deleteSoftLineBackward":case"deleteHardLineBackward":m=h.value.slice(h.selectionStart);break;default:d.data!=null&&(m=h.value.slice(0,h.selectionStart)+d.data+h.value.slice(h.selectionEnd));break}(m==null||!t.validate(m))&&d.preventDefault()});P.useEffect(()=>{if(!Sj()||!n.current)return;let d=n.current;return d.addEventListener("beforeinput",r,!1),()=>{d.removeEventListener("beforeinput",r,!1)}},[n,r]);let i=Sj()?null:d=>{let h=d.target.value.slice(0,d.target.selectionStart)+d.data+d.target.value.slice(d.target.selectionEnd);t.validate(h)||d.preventDefault()},{labelProps:a,inputProps:u,descriptionProps:l,errorMessageProps:o,...s}=HC(e,n),c=P.useRef(null);return{inputProps:Et(u,{onBeforeInput:i,onCompositionStart(){let{value:d,selectionStart:h,selectionEnd:m}=n.current;c.current={value:d,selectionStart:h,selectionEnd:m}},onCompositionEnd(){if(n.current&&!t.validate(n.current.value)){let{value:d,selectionStart:h,selectionEnd:m}=c.current;n.current.value=d,n.current.setSelectionRange(h,m),t.setInputValue(d)}}}),labelProps:a,descriptionProps:l,errorMessageProps:o,...s}}function GDe(e){return e&&e.__esModule?e.default:e}function KDe(e,t){let{buttonRef:n,popoverRef:r,inputRef:i,listBoxRef:a,keyboardDelegate:u,layoutDelegate:l,shouldFocusWrap:o,isReadOnly:s,isDisabled:c}=e,d=P.useRef(null);n=n??d;let h=Fo(GDe(Ite),"@react-aria/combobox"),{menuTriggerProps:m,menuProps:y}=IN({type:"listbox",isDisabled:c||s},t,n);UC.set(t,{id:y.id});let{collection:v}=t,{disabledKeys:_}=t.selectionManager,S=P.useMemo(()=>u||new hS({collection:v,disabledKeys:_,ref:a,layoutDelegate:l}),[u,l,v,_,a]),{collectionProps:E}=MN({selectionManager:t.selectionManager,keyboardDelegate:S,disallowTypeAhead:!0,disallowEmptySelection:!0,shouldFocusWrap:o,ref:i,isVirtualized:!0}),C=Z3(),T=_e=>{if(!_e.nativeEvent.isComposing)switch(_e.key){case"Enter":case"Tab":if(t.isOpen&&_e.key==="Enter"&&_e.preventDefault(),t.isOpen&&a.current&&t.selectionManager.focusedKey!=null){let se=t.collection.getItem(t.selectionManager.focusedKey);if(se!=null&&se.props.href){let me=a.current.querySelector(`[data-key="${CSS.escape(t.selectionManager.focusedKey.toString())}"]`);_e.key==="Enter"&&me instanceof HTMLAnchorElement&&C.open(me,_e,se.props.href,se.props.routerOptions),t.close();break}else if(se!=null&&se.props.onAction){se.props.onAction(),t.close();break}}t.commit();break;case"Escape":(t.selectedKey!==null||t.inputValue===""||e.allowsCustomValue)&&_e.continuePropagation(),t.revert();break;case"ArrowDown":t.open("first","manual");break;case"ArrowUp":t.open("last","manual");break;case"ArrowLeft":case"ArrowRight":t.selectionManager.setFocusedKey(null);break}},R=_e=>{var se;let me=(n==null?void 0:n.current)&&n.current===_e.relatedTarget,ge=(se=r.current)===null||se===void 0?void 0:se.contains(_e.relatedTarget);me||ge||(e.onBlur&&e.onBlur(_e),t.setFocused(!1))},$=_e=>{t.isFocused||(e.onFocus&&e.onFocus(_e),t.setFocused(!0))},{isInvalid:k,validationErrors:F,validationDetails:L}=t.displayValidation,{labelProps:j,inputProps:V,descriptionProps:q,errorMessageProps:N}=HC({...e,onChange:t.setInputValue,onKeyDown:s?e.onKeyDown:rh(t.isOpen&&E.onKeyDown,T,e.onKeyDown),onBlur:R,value:t.inputValue,defaultValue:t.defaultInputValue,onFocus:$,autoComplete:"off",validate:void 0,[sb]:t},i),U=_e=>{if(_e.pointerType==="touch"){var se;(se=i.current)===null||se===void 0||se.focus(),t.toggle(null,"manual")}},W=_e=>{if(_e.pointerType!=="touch"){var se;(se=i.current)===null||se===void 0||se.focus(),t.toggle(_e.pointerType==="keyboard"||_e.pointerType==="virtual"?"first":null,"manual")}},G=Yv({id:m.id,"aria-label":h.format("buttonLabel"),"aria-labelledby":e["aria-labelledby"]||j.id}),J=Yv({id:y.id,"aria-label":h.format("listboxLabel"),"aria-labelledby":e["aria-labelledby"]||j.id}),te=P.useRef(0),H=_e=>{if(c||s)return;if(_e.timeStamp-te.current<500){var se;_e.preventDefault(),(se=i.current)===null||se===void 0||se.focus();return}let me=_e.target.getBoundingClientRect(),ge=_e.changedTouches[0],we=Math.ceil(me.left+.5*me.width),Ne=Math.ceil(me.top+.5*me.height);if(ge.clientX===we&&ge.clientY===Ne){var Re;_e.preventDefault(),(Re=i.current)===null||Re===void 0||Re.focus(),t.toggle(null,"manual"),te.current=_e.timeStamp}},M=t.selectionManager.focusedKey!=null&&t.isOpen?t.collection.getItem(t.selectionManager.focusedKey):void 0;var K;let X=(K=M==null?void 0:M.parentKey)!==null&&K!==void 0?K:null;var B;let ne=(B=t.selectionManager.focusedKey)!==null&&B!==void 0?B:null,oe=P.useRef(X),ie=P.useRef(ne);P.useEffect(()=>{if(jE()&&M!=null&&ne!=null&&ne!==ie.current){let se=t.selectionManager.isSelected(ne),me=X!=null?t.collection.getItem(X):null,ge=(me==null?void 0:me["aria-label"])||(typeof(me==null?void 0:me.rendered)=="string"?me.rendered:"")||"";var _e;let we=h.format("focusAnnouncement",{isGroupChange:(_e=me&&X!==oe.current)!==null&&_e!==void 0?_e:!1,groupTitle:ge,groupCount:me?[...ZC(me,t.collection)].length:0,optionText:M["aria-label"]||M.textValue||"",isSelected:se});j1(we)}oe.current=X,ie.current=ne});let de=NN(t.collection),be=P.useRef(de),ve=P.useRef(t.isOpen);P.useEffect(()=>{let _e=t.isOpen!==ve.current&&(t.selectionManager.focusedKey==null||jE());if(t.isOpen&&(_e||de!==be.current)){let se=h.format("countAnnouncement",{optionCount:de});j1(se)}be.current=de,ve.current=t.isOpen});let pe=P.useRef(t.selectedKey);return P.useEffect(()=>{if(jE()&&t.isFocused&&t.selectedItem&&t.selectedKey!==pe.current){let _e=t.selectedItem["aria-label"]||t.selectedItem.textValue||"",se=h.format("selectedAnnouncement",{optionText:_e});j1(se)}pe.current=t.selectedKey}),P.useEffect(()=>{if(t.isOpen)return PN([i.current,r.current].filter(_e=>_e!=null))},[t.isOpen,i,r]),Yee(()=>{!M&&i.current&&Vu(ci(i.current))===i.current&&vx(i.current,null)},[M]),Xd(a,"react-aria-item-action",t.isOpen?()=>{t.close()}:void 0),{labelProps:j,buttonProps:{...m,...G,excludeFromTabOrder:!0,preventFocusOnPress:!0,onPress:U,onPressStart:W,isDisabled:c||s},inputProps:Et(V,{role:"combobox","aria-expanded":m["aria-expanded"],"aria-controls":t.isOpen?y.id:void 0,"aria-autocomplete":"list","aria-activedescendant":M?$re(t,M.key):void 0,onTouchEnd:H,autoCorrect:"off",spellCheck:"false"}),listBoxProps:Et(y,J,{autoFocus:t.focusStrategy||!0,shouldUseVirtualFocus:!0,shouldSelectOnPressUp:!0,shouldFocusOnHover:!0,linkBehavior:"selection",UNSTABLE_itemBehavior:"action"}),descriptionProps:q,errorMessageProps:N,isInvalid:k,validationErrors:F,validationDetails:L}}var gie={};gie={"Clear search":"مسح البحث"};var vie={};vie={"Clear search":"Изчистване на търсене"};var yie={};yie={"Clear search":"Vymazat hledání"};var bie={};bie={"Clear search":"Ryd søgning"};var Oie={};Oie={"Clear search":"Suche zurücksetzen"};var xie={};xie={"Clear search":"Απαλοιφή αναζήτησης"};var Sie={};Sie={"Clear search":"Clear search"};var _ie={};_ie={"Clear search":"Borrar búsqueda"};var Eie={};Eie={"Clear search":"Tühjenda otsing"};var Die={};Die={"Clear search":"Tyhjennä haku"};var $ie={};$ie={"Clear search":"Effacer la recherche"};var Cie={};Cie={"Clear search":"נקה חיפוש"};var wie={};wie={"Clear search":"Obriši pretragu"};var Rie={};Rie={"Clear search":"Keresés törlése"};var Aie={};Aie={"Clear search":"Cancella ricerca"};var Tie={};Tie={"Clear search":"検索をクリア"};var kie={};kie={"Clear search":"검색 지우기"};var Pie={};Pie={"Clear search":"Išvalyti iešką"};var Mie={};Mie={"Clear search":"Notīrīt meklēšanu"};var Fie={};Fie={"Clear search":"Tøm søk"};var Nie={};Nie={"Clear search":"Zoekactie wissen"};var Iie={};Iie={"Clear search":"Wyczyść zawartość wyszukiwania"};var Lie={};Lie={"Clear search":"Limpar pesquisa"};var Bie={};Bie={"Clear search":"Limpar pesquisa"};var Qie={};Qie={"Clear search":"Ştergeţi căutarea"};var zie={};zie={"Clear search":"Очистить поиск"};var qie={};qie={"Clear search":"Vymazať vyhľadávanie"};var Vie={};Vie={"Clear search":"Počisti iskanje"};var Uie={};Uie={"Clear search":"Obriši pretragu"};var jie={};jie={"Clear search":"Rensa sökning"};var Zie={};Zie={"Clear search":"Aramayı temizle"};var Hie={};Hie={"Clear search":"Очистити пошук"};var Xie={};Xie={"Clear search":"清除搜索"};var Yie={};Yie={"Clear search":"清除搜尋條件"};var Gie={};Gie={"ar-AE":gie,"bg-BG":vie,"cs-CZ":yie,"da-DK":bie,"de-DE":Oie,"el-GR":xie,"en-US":Sie,"es-ES":_ie,"et-EE":Eie,"fi-FI":Die,"fr-FR":$ie,"he-IL":Cie,"hr-HR":wie,"hu-HU":Rie,"it-IT":Aie,"ja-JP":Tie,"ko-KR":kie,"lt-LT":Pie,"lv-LV":Mie,"nb-NO":Fie,"nl-NL":Nie,"pl-PL":Iie,"pt-BR":Lie,"pt-PT":Bie,"ro-RO":Qie,"ru-RU":zie,"sk-SK":qie,"sl-SI":Vie,"sr-SP":Uie,"sv-SE":jie,"tr-TR":Zie,"uk-UA":Hie,"zh-CN":Xie,"zh-TW":Yie};function WDe(e){return e&&e.__esModule?e.default:e}function JDe(e,t,n){let r=Fo(WDe(Gie),"@react-aria/searchfield"),{isDisabled:i,isReadOnly:a,onSubmit:u,onClear:l,type:o="search"}=e,s=S=>{const E=S.key;E==="Enter"&&(i||a)&&S.preventDefault(),!(i||a)&&(E==="Enter"&&u&&(S.preventDefault(),u(t.value)),E==="Escape"&&(t.value===""&&(!n.current||n.current.value==="")?S.continuePropagation():(S.preventDefault(),t.setValue(""),l&&l())))},c=()=>{t.setValue(""),l&&l()},d=()=>{var S;(S=n.current)===null||S===void 0||S.focus()},{labelProps:h,inputProps:m,descriptionProps:y,errorMessageProps:v,..._}=HC({...e,value:t.value,onChange:t.setValue,onKeyDown:a?e.onKeyDown:rh(s,e.onKeyDown),type:o},n);return{labelProps:h,inputProps:{...m,defaultValue:void 0},clearButtonProps:{"aria-label":r.format("Clear search"),excludeFromTabOrder:!0,preventFocusOnPress:!0,isDisabled:i||a,onPress:c,onPressStart:d},descriptionProps:y,errorMessageProps:v,..._}}var Kie={};Kie={collectionLabel:"مقترحات"};var Wie={};Wie={collectionLabel:"Предложения"};var Jie={};Jie={collectionLabel:"Návrhy"};var eae={};eae={collectionLabel:"Forslag"};var tae={};tae={collectionLabel:"Empfehlungen"};var nae={};nae={collectionLabel:"Προτάσεις"};var rae={};rae={collectionLabel:"Suggestions"};var iae={};iae={collectionLabel:"Sugerencias"};var aae={};aae={collectionLabel:"Soovitused"};var uae={};uae={collectionLabel:"Ehdotukset"};var lae={};lae={collectionLabel:"Suggestions"};var oae={};oae={collectionLabel:"הצעות"};var sae={};sae={collectionLabel:"Prijedlozi"};var cae={};cae={collectionLabel:"Javaslatok"};var fae={};fae={collectionLabel:"Suggerimenti"};var dae={};dae={collectionLabel:"候補"};var hae={};hae={collectionLabel:"제안"};var pae={};pae={collectionLabel:"Pasiūlymai"};var mae={};mae={collectionLabel:"Ieteikumi"};var gae={};gae={collectionLabel:"Forslag"};var vae={};vae={collectionLabel:"Suggesties"};var yae={};yae={collectionLabel:"Sugestie"};var bae={};bae={collectionLabel:"Sugestões"};var Oae={};Oae={collectionLabel:"Sugestões"};var xae={};xae={collectionLabel:"Sugestii"};var Sae={};Sae={collectionLabel:"Предложения"};var _ae={};_ae={collectionLabel:"Návrhy"};var Eae={};Eae={collectionLabel:"Predlogi"};var Dae={};Dae={collectionLabel:"Predlozi"};var $ae={};$ae={collectionLabel:"Förslag"};var Cae={};Cae={collectionLabel:"Öneriler"};var wae={};wae={collectionLabel:"Пропозиції"};var Rae={};Rae={collectionLabel:"建议"};var Aae={};Aae={collectionLabel:"建議"};var Tae={};Tae={"ar-AE":Kie,"bg-BG":Wie,"cs-CZ":Jie,"da-DK":eae,"de-DE":tae,"el-GR":nae,"en-US":rae,"es-ES":iae,"et-EE":aae,"fi-FI":uae,"fr-FR":lae,"he-IL":oae,"hr-HR":sae,"hu-HU":cae,"it-IT":fae,"ja-JP":dae,"ko-KR":hae,"lt-LT":pae,"lv-LV":mae,"nb-NO":gae,"nl-NL":vae,"pl-PL":yae,"pt-BR":bae,"pt-PT":Oae,"ro-RO":xae,"ru-RU":Sae,"sk-SK":_ae,"sl-SI":Eae,"sr-SP":Dae,"sv-SE":$ae,"tr-TR":Cae,"uk-UA":wae,"zh-CN":Rae,"zh-TW":Aae};function e$e(e){return e&&e.__esModule?e.default:e}function t$e(e,t){let{inputRef:n,collectionRef:r,filter:i,disableAutoFocusFirst:a=!1,disableVirtualFocus:u=!1}=e,l=pi(),o=P.useRef(void 0),s=P.useRef(!1),c=P.useRef(null),d=P.useRef(null),h=rg()==="virtual"&&(Db()||uS()),[m,y]=P.useState(!h&&!u),[v,_]=P.useState(!1);P.useEffect(()=>()=>clearTimeout(o.current),[]);let S=oi(H=>{!H.isTrusted&&m&&n.current&&Vu(ci(n.current))!==n.current&&n.current.focus();let M=H.target;H.isTrusted||!M||c.current===M.id||(clearTimeout(o.current),M!==r.current?s.current?(c.current=M.id,o.current=setTimeout(()=>{t.setFocusedNodeId(M.id)},500)):(c.current=M.id,t.setFocusedNodeId(M.id)):c.current&&!document.getElementById(c.current)&&(c.current=null,t.setFocusedNodeId(null)),s.current=!1)}),E=P.useCallback(H=>{if(H!=null){var M;(M=d.current)===null||M===void 0||M.removeEventListener("focusin",S),d.current=H,H.addEventListener("focusin",S),H.getAttribute("tabindex")!=null&&y(!1),_(!0)}else{var K;(K=d.current)===null||K===void 0||K.removeEventListener("focusin",S),_(!1)}},[S]),C=$u(P.useMemo(()=>vg(r,E),[r,E])),T=oi(()=>{var H;s.current=!0,(H=r.current)===null||H===void 0||H.dispatchEvent(new CustomEvent(y9,{cancelable:!0,bubbles:!0,detail:{focusStrategy:"first"}}))}),R=oi(H=>{var M;AN(Vu()),c.current=null,t.setFocusedNodeId(null);let K=new CustomEvent(Wee,{cancelable:!0,bubbles:!0,detail:{clearFocusKey:H}});clearTimeout(o.current),s.current=!1,(M=r.current)===null||M===void 0||M.dispatchEvent(K)}),$=P.useRef("");Xd(n,"input",H=>{let{inputType:M}=H;$.current=M});let k=H=>{$.current==="insertText"&&!a?T():$.current&&($.current.includes("insert")||$.current.includes("delete")||$.current.includes("history"))&&(R(!0),Bne(document)===n.current&&vx(n.current,null)),t.setInputValue(H)},F=P.useRef(null),L=H=>{if(F.current=H.target,H.nativeEvent.isComposing)return;let M=c.current;switch(H.key){case"a":if(T1(H))return;break;case"Escape":if(H.isDefaultPrevented())return;break;case" ":return;case"Tab":"continuePropagation"in H&&H.continuePropagation();return;case"Home":case"End":case"PageDown":case"PageUp":case"ArrowUp":case"ArrowDown":{var K;if((H.key==="Home"||H.key==="End")&&M==null&&H.shiftKey)return;H.preventDefault();let ne=new CustomEvent(y9,{cancelable:!0,bubbles:!0});(K=r.current)===null||K===void 0||K.dispatchEvent(ne);break}}H.isPropagationStopped()||H.stopPropagation();let X=!0;if(r.current!==null){var B;if(M==null)X=((B=r.current)===null||B===void 0?void 0:B.dispatchEvent(new KeyboardEvent(H.nativeEvent.type,H.nativeEvent)))||!1;else{let ne=document.getElementById(M);ne&&(X=(ne==null?void 0:ne.dispatchEvent(new KeyboardEvent(H.nativeEvent.type,H.nativeEvent)))||!1)}}if(X)switch(H.key){case"ArrowLeft":case"ArrowRight":R();break;case"Enter":if(M!=null){let ne=document.getElementById(M);ne==null||ne.click()}break}else H.preventDefault()},j=oi(H=>{if(H.target===F.current){var M;H.stopImmediatePropagation();let K=c.current;if(K==null)(M=r.current)===null||M===void 0||M.dispatchEvent(new KeyboardEvent(H.type,H));else{let X=document.getElementById(K);X==null||X.dispatchEvent(new KeyboardEvent(H.type,H))}}});P.useEffect(()=>(document.addEventListener("keyup",j,!0),()=>{document.removeEventListener("keyup",j,!0)}),[j]);let V=Fo(e$e(Tae),"@react-aria/autocomplete"),q=Yv({id:l,"aria-label":V.format("collectionLabel")}),N=P.useCallback((H,M)=>i?i(H,t.inputValue,M):!0,[t.inputValue,i]),U=H=>{if(!H.isTrusted)return;let M=c.current?document.getElementById(c.current):null;M&&I9(M,H.relatedTarget)},W=H=>{if(!H.isTrusted)return;if(c.current?document.getElementById(c.current):null){let K=H.target;queueMicrotask(()=>{I9(K,r.current),vx(r.current,K)})}},G={value:t.inputValue,onChange:k};var J;let te={onKeyDown:L,"aria-activedescendant":(J=t.focusedNodeId)!==null&&J!==void 0?J:void 0,onBlur:U,onFocus:W};return v&&(G={...G,...m&&te,enterKeyHint:"go","aria-controls":l,"aria-autocomplete":"list",autoCorrect:"off",spellCheck:"false",autoComplete:"off"}),{inputProps:G,collectionProps:Et(q,{shouldUseVirtualFocus:m,disallowTypeAhead:m}),collectionRef:C,filter:i!=null?N:void 0}}function n$e(e){let{onInputChange:t,inputValue:n,defaultInputValue:r=""}=e,i=s=>{t&&t(s)},[a,u]=P.useState(null),[l,o]=Zu(n,r,i);return{inputValue:l,setInputValue:o,focusedNodeId:a,setFocusedNodeId:u}}const r$e=P.createContext(null),i$e=P.createContext(null);function Prt(e){let t=vs(r$e,e.slot);e=Et(t,e);let{filter:n,disableAutoFocusFirst:r}=e,i=n$e(e),a=P.useRef(null),u=P.useRef(null),{inputProps:l,collectionProps:o,collectionRef:s,filter:c}=t$e({...dc(e),filter:n,disableAutoFocusFirst:r,inputRef:a,collectionRef:u},i);return ye.createElement(ki,{values:[[i$e,i],[PC,{...l,ref:a}],[dx,{...o,filter:c,ref:s}]]},e.children)}class gy{get childNodes(){throw new Error("childNodes is not supported")}clone(){let t=new this.constructor(this.key);return t.value=this.value,t.level=this.level,t.hasChildNodes=this.hasChildNodes,t.rendered=this.rendered,t.textValue=this.textValue,t["aria-label"]=this["aria-label"],t.index=this.index,t.parentKey=this.parentKey,t.prevKey=this.prevKey,t.nextKey=this.nextKey,t.firstChildKey=this.firstChildKey,t.lastChildKey=this.lastChildKey,t.props=this.props,t.render=this.render,t.colSpan=this.colSpan,t.colIndex=this.colIndex,t}filter(t,n,r){let i=this.clone();return n.addDescendants(i,t),i}constructor(t){this.value=null,this.level=0,this.hasChildNodes=!1,this.rendered=null,this.textValue="",this["aria-label"]=void 0,this.index=0,this.parentKey=null,this.prevKey=null,this.nextKey=null,this.firstChildKey=null,this.lastChildKey=null,this.props={},this.colSpan=null,this.colIndex=null,this.type=this.constructor.type,this.key=t}}class kae extends gy{filter(t,n,r){let[i,a]=Mae(t,n,this.firstChildKey,r),u=this.clone();return u.firstChildKey=i,u.lastChildKey=a,u}}class a$e extends gy{}a$e.type="header";class Pae extends gy{}Pae.type="loader";class XC extends kae{filter(t,n,r){if(r(this.textValue,this)){let i=this.clone();return n.addDescendants(i,t),i}return null}}XC.type="item";class u$e extends kae{filter(t,n,r){let i=super.filter(t,n,r);if(i&&i.lastChildKey!==null){let a=t.getItem(i.lastChildKey);if(a&&a.type!=="header")return i}return null}}u$e.type="section";class l$e{get size(){return this.itemCount}getKeys(){return this.keyMap.keys()}*[Symbol.iterator](){let t=this.firstKey!=null?this.keyMap.get(this.firstKey):void 0;for(;t;)yield t,t=t.nextKey!=null?this.keyMap.get(t.nextKey):void 0}getChildren(t){let n=this.keyMap;return{*[Symbol.iterator](){let r=n.get(t),i=(r==null?void 0:r.firstChildKey)!=null?n.get(r.firstChildKey):null;for(;i;)yield i,i=i.nextKey!=null?n.get(i.nextKey):void 0}}}getKeyBefore(t){let n=this.keyMap.get(t);if(!n)return null;if(n.prevKey!=null){for(n=this.keyMap.get(n.prevKey);n&&n.type!=="item"&&n.lastChildKey!=null;)n=this.keyMap.get(n.lastChildKey);var r;return(r=n==null?void 0:n.key)!==null&&r!==void 0?r:null}return n.parentKey}getKeyAfter(t){let n=this.keyMap.get(t);if(!n)return null;if(n.type!=="item"&&n.firstChildKey!=null)return n.firstChildKey;for(;n;){if(n.nextKey!=null)return n.nextKey;if(n.parentKey!=null)n=this.keyMap.get(n.parentKey);else return null}return null}getFirstKey(){return this.firstKey}getLastKey(){let t=this.lastKey!=null?this.keyMap.get(this.lastKey):null;for(;(t==null?void 0:t.lastChildKey)!=null;)t=this.keyMap.get(t.lastChildKey);var n;return(n=t==null?void 0:t.key)!==null&&n!==void 0?n:null}getItem(t){var n;return(n=this.keyMap.get(t))!==null&&n!==void 0?n:null}at(){throw new Error("Not implemented")}clone(){let t=this.constructor,n=new t;return n.keyMap=new Map(this.keyMap),n.firstKey=this.firstKey,n.lastKey=this.lastKey,n.itemCount=this.itemCount,n}addNode(t){if(this.frozen)throw new Error("Cannot add a node to a frozen collection");t.type==="item"&&this.keyMap.get(t.key)==null&&this.itemCount++,this.keyMap.set(t.key,t)}addDescendants(t,n){this.addNode(t);let r=n.getChildren(t.key);for(let i of r)this.addDescendants(i,n)}removeNode(t){if(this.frozen)throw new Error("Cannot remove a node to a frozen collection");let n=this.keyMap.get(t);n!=null&&n.type==="item"&&this.itemCount--,this.keyMap.delete(t)}commit(t,n,r=!1){if(this.frozen)throw new Error("Cannot commit a frozen collection");this.firstKey=t,this.lastKey=n,this.frozen=!r}filter(t){let n=new this.constructor,[r,i]=Mae(this,n,this.firstKey,t);return n==null||n.commit(r,i),n}constructor(){this.keyMap=new Map,this.firstKey=null,this.lastKey=null,this.frozen=!1,this.itemCount=0}}function Mae(e,t,n,r){if(n==null)return[null,null];let i=null,a=null,u=e.getItem(n);for(;u!=null;){let s=u.filter(e,t,r);s!=null&&(s.nextKey=null,a&&(s.prevKey=a.key,a.nextKey=s.key),i==null&&(i=s),t.addNode(s),a=s),u=u.nextKey?e.getItem(u.nextKey):null}if(a&&a.type==="separator"){let s=a.prevKey;t.removeNode(a.key),s?(a=t.getItem(s),a.nextKey=null):a=null}var l,o;return[(l=i==null?void 0:i.key)!==null&&l!==void 0?l:null,(o=a==null?void 0:a.key)!==null&&o!==void 0?o:null]}class Fae{*[Symbol.iterator](){let t=this.firstChild;for(;t;)yield t,t=t.nextSibling}get firstChild(){return this._firstChild}set firstChild(t){this._firstChild=t,this.ownerDocument.markDirty(this)}get lastChild(){return this._lastChild}set lastChild(t){this._lastChild=t,this.ownerDocument.markDirty(this)}get previousSibling(){return this._previousSibling}set previousSibling(t){this._previousSibling=t,this.ownerDocument.markDirty(this)}get nextSibling(){return this._nextSibling}set nextSibling(t){this._nextSibling=t,this.ownerDocument.markDirty(this)}get parentNode(){return this._parentNode}set parentNode(t){this._parentNode=t,this.ownerDocument.markDirty(this)}get isConnected(){var t;return((t=this.parentNode)===null||t===void 0?void 0:t.isConnected)||!1}invalidateChildIndices(t){(this._minInvalidChildIndex==null||!this._minInvalidChildIndex.isConnected||t.index<this._minInvalidChildIndex.index)&&(this._minInvalidChildIndex=t,this.ownerDocument.markDirty(this))}updateChildIndices(){let t=this._minInvalidChildIndex;for(;t;)t.index=t.previousSibling?t.previousSibling.index+1:0,t=t.nextSibling;this._minInvalidChildIndex=null}appendChild(t){t.parentNode&&t.parentNode.removeChild(t),this.firstChild==null&&(this.firstChild=t),this.lastChild?(this.lastChild.nextSibling=t,t.index=this.lastChild.index+1,t.previousSibling=this.lastChild):(t.previousSibling=null,t.index=0),t.parentNode=this,t.nextSibling=null,this.lastChild=t,this.ownerDocument.markDirty(this),this.isConnected&&this.ownerDocument.queueUpdate()}insertBefore(t,n){if(n==null)return this.appendChild(t);t.parentNode&&t.parentNode.removeChild(t),t.nextSibling=n,t.previousSibling=n.previousSibling,t.index=n.index-1,this.firstChild===n?this.firstChild=t:n.previousSibling&&(n.previousSibling.nextSibling=t),n.previousSibling=t,t.parentNode=n.parentNode,this.invalidateChildIndices(t),this.isConnected&&this.ownerDocument.queueUpdate()}removeChild(t){t.parentNode===this&&(this._minInvalidChildIndex===t&&(this._minInvalidChildIndex=null),t.nextSibling&&(this.invalidateChildIndices(t.nextSibling),t.nextSibling.previousSibling=t.previousSibling),t.previousSibling&&(t.previousSibling.nextSibling=t.nextSibling),this.firstChild===t&&(this.firstChild=t.nextSibling),this.lastChild===t&&(this.lastChild=t.previousSibling),t.parentNode=null,t.nextSibling=null,t.previousSibling=null,t.index=0,this.ownerDocument.markDirty(t),this.isConnected&&this.ownerDocument.queueUpdate())}addEventListener(){}removeEventListener(){}get previousVisibleSibling(){let t=this.previousSibling;for(;t&&t.isHidden;)t=t.previousSibling;return t}get nextVisibleSibling(){let t=this.nextSibling;for(;t&&t.isHidden;)t=t.nextSibling;return t}get firstVisibleChild(){let t=this.firstChild;for(;t&&t.isHidden;)t=t.nextSibling;return t}get lastVisibleChild(){let t=this.lastChild;for(;t&&t.isHidden;)t=t.previousSibling;return t}constructor(t){this._firstChild=null,this._lastChild=null,this._previousSibling=null,this._nextSibling=null,this._parentNode=null,this._minInvalidChildIndex=null,this.ownerDocument=t}}class o3 extends Fae{get index(){return this._index}set index(t){this._index=t,this.ownerDocument.markDirty(this)}get level(){var t;return this.parentNode instanceof o3?this.parentNode.level+(((t=this.node)===null||t===void 0?void 0:t.type)==="item"?1:0):0}getMutableNode(){return this.node==null?null:(this.isMutated||(this.node=this.node.clone(),this.isMutated=!0),this.ownerDocument.markDirty(this),this.node)}updateNode(){var t,n,r,i,a,u,l,o;let s=this.nextVisibleSibling,c=this.getMutableNode();if(c!=null){c.index=this.index,c.level=this.level;var d;c.parentKey=this.parentNode instanceof o3&&(d=(t=this.parentNode.node)===null||t===void 0?void 0:t.key)!==null&&d!==void 0?d:null;var h;c.prevKey=(h=(r=this.previousVisibleSibling)===null||r===void 0||(n=r.node)===null||n===void 0?void 0:n.key)!==null&&h!==void 0?h:null;var m;c.nextKey=(m=s==null||(i=s.node)===null||i===void 0?void 0:i.key)!==null&&m!==void 0?m:null,c.hasChildNodes=!!this.firstChild;var y;c.firstChildKey=(y=(u=this.firstVisibleChild)===null||u===void 0||(a=u.node)===null||a===void 0?void 0:a.key)!==null&&y!==void 0?y:null;var v;if(c.lastChildKey=(v=(o=this.lastVisibleChild)===null||o===void 0||(l=o.node)===null||l===void 0?void 0:l.key)!==null&&v!==void 0?v:null,(c.colSpan!=null||c.colIndex!=null)&&s){var _,S;let E=((_=c.colIndex)!==null&&_!==void 0?_:c.index)+((S=c.colSpan)!==null&&S!==void 0?S:1);if(s.node!=null&&E!==s.node.colIndex){let C=s.getMutableNode();C.colIndex=E}}}}setProps(t,n,r,i,a){let u,{value:l,textValue:o,id:s,...c}=t;if(this.node==null?(u=new r(s??`react-aria-${++this.ownerDocument.nodeId}`),this.node=u):u=this.getMutableNode(),c.ref=n,u.props=c,u.rendered=i,u.render=a,u.value=l,u.textValue=o||(typeof c.children=="string"?c.children:"")||t["aria-label"]||"",s!=null&&s!==u.key)throw new Error("Cannot change the id of an item");c.colSpan!=null&&(u.colSpan=c.colSpan),this.isConnected&&this.ownerDocument.queueUpdate()}get style(){let t=this;return{get display(){return t.isHidden?"none":""},set display(n){let r=n==="none";if(t.isHidden!==r){var i,a;(((i=t.parentNode)===null||i===void 0?void 0:i.firstVisibleChild)===t||((a=t.parentNode)===null||a===void 0?void 0:a.lastVisibleChild)===t)&&t.ownerDocument.markDirty(t.parentNode);let u=t.previousVisibleSibling,l=t.nextVisibleSibling;u&&t.ownerDocument.markDirty(u),l&&t.ownerDocument.markDirty(l),t.isHidden=r,t.ownerDocument.markDirty(t)}}}}hasAttribute(){}setAttribute(){}setAttributeNS(){}removeAttribute(){}constructor(t,n){super(n),this.nodeType=8,this.isMutated=!0,this._index=0,this.isHidden=!1,this.node=null}}class o$e extends Fae{get isConnected(){return!0}createElement(t){return new o3(t,this)}getMutableCollection(){return this.nextCollection||(this.nextCollection=this.collection.clone()),this.nextCollection}markDirty(t){this.dirtyNodes.add(t)}addNode(t){if(t.isHidden||t.node==null)return;let n=this.getMutableCollection();if(!n.getItem(t.node.key))for(let r of t)this.addNode(r);n.addNode(t.node)}removeNode(t){for(let n of t)this.removeNode(n);t.node&&this.getMutableCollection().removeNode(t.node.key)}getCollection(){return this.inSubscription?this.collection.clone():(this.queuedRender=!1,this.updateCollection(),this.collection)}updateCollection(){for(let l of this.dirtyNodes)l instanceof o3&&(!l.isConnected||l.isHidden)?this.removeNode(l):l.updateChildIndices();for(let l of this.dirtyNodes)l instanceof o3?(l.isConnected&&!l.isHidden&&(l.updateNode(),this.addNode(l)),l.node&&this.dirtyNodes.delete(l),l.isMutated=!1):this.dirtyNodes.delete(l);if(this.nextCollection){var t,n,r,i,a,u;this.nextCollection.commit((a=(n=this.firstVisibleChild)===null||n===void 0||(t=n.node)===null||t===void 0?void 0:t.key)!==null&&a!==void 0?a:null,(u=(i=this.lastVisibleChild)===null||i===void 0||(r=i.node)===null||r===void 0?void 0:r.key)!==null&&u!==void 0?u:null,this.isSSR),this.isSSR||(this.collection=this.nextCollection,this.nextCollection=null)}}queueUpdate(){if(!(this.dirtyNodes.size===0||this.queuedRender)){this.queuedRender=!0,this.inSubscription=!0;for(let t of this.subscriptions)t();this.inSubscription=!1}}subscribe(t){return this.subscriptions.add(t),()=>this.subscriptions.delete(t)}resetAfterSSR(){this.isSSR&&(this.isSSR=!1,this.firstChild=null,this.lastChild=null,this.nodeId=0)}constructor(t){super(null),this.nodeType=11,this.ownerDocument=this,this.dirtyNodes=new Set,this.isSSR=!1,this.nodeId=0,this.nodesByProps=new WeakMap,this.nextCollection=null,this.subscriptions=new Set,this.queuedRender=!1,this.inSubscription=!1,this.collection=t,this.nextCollection=t}}function Nae(e){let{children:t,items:n,idScope:r,addIdAndValue:i,dependencies:a=[]}=e,u=P.useMemo(()=>new WeakMap,a);return P.useMemo(()=>{if(n&&typeof t=="function"){let s=[];for(let c of n){let d=u.get(c);if(!d){d=t(c);var l,o;let h=(o=(l=d.props.id)!==null&&l!==void 0?l:c.key)!==null&&o!==void 0?o:c.id;if(h==null)throw new Error("Could not determine key for item");r&&(h=r+":"+h),d=P.cloneElement(d,i?{key:h,id:h,value:c}:{key:h}),u.set(c,d)}s.push(d)}return s}else if(typeof t!="function")return t},[t,n,u,r,i])}if(typeof HTMLTemplateElement<"u"){const e=Object.getOwnPropertyDescriptor(Node.prototype,"firstChild").get;Object.defineProperty(HTMLTemplateElement.prototype,"firstChild",{configurable:!0,enumerable:!0,get:function(){return this.dataset.reactAriaHidden?this.content.firstChild:e.call(this)}})}const JD=P.createContext(!1);function s$e(e){if(P.useContext(JD))return ye.createElement(ye.Fragment,null,e.children);let n=ye.createElement(JD.Provider,{value:!0},e.children);return ye.createElement("template",{"data-react-aria-hidden":!0},n)}function $b(e){let t=(n,r)=>P.useContext(JD)?null:e(n,r);return t.displayName=e.displayName||e.name,P.forwardRef(t)}function c$e(){return P.useContext(JD)}var LN=fee();const Iae=P.createContext(!1),yx=P.createContext(null);function Cb(e){if(P.useContext(yx))return e.content;let{collection:n,document:r}=p$e(e.createCollection);return ye.createElement(ye.Fragment,null,ye.createElement(s$e,null,ye.createElement(yx.Provider,{value:r},e.content)),ye.createElement(f$e,{render:e.children,collection:n}))}function f$e({collection:e,render:t}){return t(e)}function d$e(e,t,n){let r=hp(),i=P.useRef(r);i.current=r;let a=P.useCallback(()=>i.current?n():t(),[t,n]);return LN.useSyncExternalStore(e,a)}const h$e=typeof ye.useSyncExternalStore=="function"?ye.useSyncExternalStore:d$e;function p$e(e){let[t]=P.useState(()=>new o$e((e==null?void 0:e())||new l$e)),n=P.useCallback(u=>t.subscribe(u),[t]),r=P.useCallback(()=>{let u=t.getCollection();return t.isSSR&&t.resetAfterSSR(),u},[t]),i=P.useCallback(()=>(t.isSSR=!0,t.getCollection()),[t]);return{collection:h$e(n,r,i),document:t}}const V9=P.createContext(null);function m$e(e){var t;return t=class extends gy{},t.type=e,t}function Lae(e,t,n,r,i,a){typeof e=="string"&&(e=m$e(e));let u=P.useCallback(o=>{o==null||o.setProps(t,n,e,r,a)},[t,n,r,a,e]),l=P.useContext(V9);if(l){let o=l.ownerDocument.nodesByProps.get(t);return o||(o=l.ownerDocument.createElement(e.type),o.setProps(t,n,e,r,a),l.appendChild(o),l.ownerDocument.updateCollection(),l.ownerDocument.nodesByProps.set(t,o)),i?ye.createElement(V9.Provider,{value:o},i):null}return ye.createElement(e.type,{ref:u},i)}function wb(e,t){let n=({node:i})=>t(i.props,i.props.ref,i),r=P.forwardRef((i,a)=>{let u=P.useContext(KD);if(!P.useContext(Iae)){if(t.length>=3)throw new Error(t.name+" cannot be rendered outside a collection.");return t(i,a)}return Lae(e,i,a,"children"in i?i.children:null,null,o=>ye.createElement(KD.Provider,{value:u},ye.createElement(n,{node:o})))});return r.displayName=t.name,r}function g$e(e,t,n=Bae){let r=({node:a})=>t(a.props,a.props.ref,a),i=P.forwardRef((a,u)=>{let l=n(a);var o;return(o=Lae(e,a,u,null,l,s=>ye.createElement(r,{node:s})))!==null&&o!==void 0?o:ye.createElement(ye.Fragment,null)});return i.displayName=t.name,i}function Bae(e){return Nae({...e,addIdAndValue:!0})}const _j=P.createContext(null);function mS(e){let t=P.useContext(_j),n=((t==null?void 0:t.dependencies)||[]).concat(e.dependencies),r=e.idScope||(t==null?void 0:t.idScope),i=Bae({...e,idScope:r,dependencies:n});return P.useContext(yx)&&(i=ye.createElement(v$e,null,i)),t=P.useMemo(()=>({dependencies:n,idScope:r}),[r,...n]),ye.createElement(_j.Provider,{value:t},i)}function v$e({children:e}){let t=P.useContext(yx),n=P.useMemo(()=>ye.createElement(yx.Provider,{value:null},ye.createElement(Iae.Provider,{value:!0},e)),[e]);return hp()?ye.createElement(V9.Provider,{value:t},n):Vf.createPortal(n,t)}const Qae=P.createContext(null),BN={CollectionRoot({collection:e,renderDropIndicator:t}){return Ej(e,null,t)},CollectionBranch({collection:e,parent:t,renderDropIndicator:n}){return Ej(e,t,n)}};function Ej(e,t,n){return Nae({items:t?e.getChildren(t.key):e,dependencies:[n],children(r){let i=r.render(r);return!n||r.type!=="item"?i:ye.createElement(ye.Fragment,null,n({type:"item",key:r.key,dropPosition:"before"}),i,y$e(e,r,n))}})}function y$e(e,t,n){let r=t.key,i=e.getKeyAfter(r),a=i!=null?e.getItem(i):null;for(;a!=null&&a.type!=="item";)i=e.getKeyAfter(a.key),a=i!=null?e.getItem(i):null;let u=t.nextKey!=null?e.getItem(t.nextKey):null;for(;u!=null&&u.type!=="item";)u=u.nextKey!=null?e.getItem(u.nextKey):null;let l=[];if(u==null){let o=t;for(;o&&(!a||o.parentKey!==a.parentKey&&a.level<o.level);){let s=n({type:"item",key:o.key,dropPosition:"after"});P.isValidElement(s)&&l.push(P.cloneElement(s,{key:`${o.key}-after`})),o=o.parentKey!=null?e.getItem(o.parentKey):null}}return l}const pp=P.createContext(BN);function QN(e){return P.useMemo(()=>e!=null?new Set([e]):null,[e])}var zae={};zae={breadcrumbs:"عناصر الواجهة"};var qae={};qae={breadcrumbs:"Трохи хляб"};var Vae={};Vae={breadcrumbs:"Popis cesty"};var Uae={};Uae={breadcrumbs:"Brødkrummer"};var jae={};jae={breadcrumbs:"Breadcrumbs"};var Zae={};Zae={breadcrumbs:"Πλοηγήσεις breadcrumb"};var Hae={};Hae={breadcrumbs:"Breadcrumbs"};var Xae={};Xae={breadcrumbs:"Migas de pan"};var Yae={};Yae={breadcrumbs:"Lingiread"};var Gae={};Gae={breadcrumbs:"Navigointilinkit"};var Kae={};Kae={breadcrumbs:"Chemin de navigation"};var Wae={};Wae={breadcrumbs:"שבילי ניווט"};var Jae={};Jae={breadcrumbs:"Navigacijski putovi"};var eue={};eue={breadcrumbs:"Morzsamenü"};var tue={};tue={breadcrumbs:"Breadcrumb"};var nue={};nue={breadcrumbs:"パンくずリスト"};var rue={};rue={breadcrumbs:"탐색 표시"};var iue={};iue={breadcrumbs:"Naršymo kelias"};var aue={};aue={breadcrumbs:"Atpakaļceļi"};var uue={};uue={breadcrumbs:"Navigasjonsstier"};var lue={};lue={breadcrumbs:"Broodkruimels"};var oue={};oue={breadcrumbs:"Struktura nawigacyjna"};var sue={};sue={breadcrumbs:"Caminho detalhado"};var cue={};cue={breadcrumbs:"Categorias"};var fue={};fue={breadcrumbs:"Miez de pâine"};var due={};due={breadcrumbs:"Навигация"};var hue={};hue={breadcrumbs:"Navigačné prvky Breadcrumbs"};var pue={};pue={breadcrumbs:"Drobtine"};var mue={};mue={breadcrumbs:"Putanje navigacije"};var gue={};gue={breadcrumbs:"Sökvägar"};var vue={};vue={breadcrumbs:"İçerik haritaları"};var yue={};yue={breadcrumbs:"Навігаційна стежка"};var bue={};bue={breadcrumbs:"导航栏"};var Oue={};Oue={breadcrumbs:"導覽列"};var xue={};xue={"ar-AE":zae,"bg-BG":qae,"cs-CZ":Vae,"da-DK":Uae,"de-DE":jae,"el-GR":Zae,"en-US":Hae,"es-ES":Xae,"et-EE":Yae,"fi-FI":Gae,"fr-FR":Kae,"he-IL":Wae,"hr-HR":Jae,"hu-HU":eue,"it-IT":tue,"ja-JP":nue,"ko-KR":rue,"lt-LT":iue,"lv-LV":aue,"nb-NO":uue,"nl-NL":lue,"pl-PL":oue,"pt-BR":sue,"pt-PT":cue,"ro-RO":fue,"ru-RU":due,"sk-SK":hue,"sl-SI":pue,"sr-SP":mue,"sv-SE":gue,"tr-TR":vue,"uk-UA":yue,"zh-CN":bue,"zh-TW":Oue};function b$e(e){return e&&e.__esModule?e.default:e}function O$e(e){let{"aria-label":t,...n}=e,r=Fo(b$e(xue),"@react-aria/breadcrumbs");return{navProps:{...Gt(n,{labelable:!0}),"aria-label":t||r.format("breadcrumbs")}}}function Sue(e,t){let{elementType:n="button",isDisabled:r,onPress:i,onPressStart:a,onPressEnd:u,onPressUp:l,onPressChange:o,preventFocusOnPress:s,allowFocusWhenDisabled:c,onClick:d,href:h,target:m,rel:y,type:v="button"}=e,_;n==="button"?_={type:v,disabled:r,form:e.form,formAction:e.formAction,formEncType:e.formEncType,formMethod:e.formMethod,formNoValidate:e.formNoValidate,formTarget:e.formTarget,name:e.name,value:e.value}:_={role:"button",href:n==="a"&&!r?h:void 0,target:n==="a"?m:void 0,type:n==="input"?v:void 0,disabled:n==="input"?r:void 0,"aria-disabled":!r||n==="input"?void 0:r,rel:n==="a"?y:void 0};let{pressProps:S,isPressed:E}=up({onPressStart:a,onPressEnd:u,onPressChange:o,onPress:i,onPressUp:l,onClick:d,isDisabled:r,preventFocusOnPress:s,ref:t}),{focusableProps:C}=L0(e,t);c&&(C.tabIndex=r?-1:C.tabIndex);let T=Et(C,S,Gt(e,{labelable:!0}));return{isPressed:E,buttonProps:Et(_,T,{"aria-haspopup":e["aria-haspopup"],"aria-expanded":e["aria-expanded"],"aria-controls":e["aria-controls"],"aria-pressed":e["aria-pressed"],"aria-current":e["aria-current"],"aria-disabled":e["aria-disabled"]})}}function _ue(e,t,n){const{isSelected:r}=t,{isPressed:i,buttonProps:a}=Sue({...e,onPress:rh(t.toggle,e.onPress)},n);return{isPressed:i,isSelected:r,isDisabled:e.isDisabled||!1,buttonProps:Et(a,{"aria-pressed":r})}}function Eue(e,t){const{"aria-label":n,"aria-labelledby":r,orientation:i="horizontal"}=e;let[a,u]=P.useState(!1);qr(()=>{var y;u(!!(t.current&&(!((y=t.current.parentElement)===null||y===void 0)&&y.closest('[role="toolbar"]'))))});const{direction:l}=Hi(),o=l==="rtl"&&i==="horizontal";let s=wN(t);const c=y=>{if(y.currentTarget.contains(y.target)){if(i==="horizontal"&&y.key==="ArrowRight"||i==="vertical"&&y.key==="ArrowDown")o?s.focusPrevious():s.focusNext();else if(i==="horizontal"&&y.key==="ArrowLeft"||i==="vertical"&&y.key==="ArrowUp")o?s.focusNext():s.focusPrevious();else if(y.key==="Tab"){y.stopPropagation(),d.current=document.activeElement,y.shiftKey?s.focusFirst():s.focusLast();return}else return;y.stopPropagation(),y.preventDefault()}},d=P.useRef(null),h=y=>{!y.currentTarget.contains(y.relatedTarget)&&!d.current&&(d.current=y.target)},m=y=>{var v;if(d.current&&!y.currentTarget.contains(y.relatedTarget)&&(!((v=t.current)===null||v===void 0)&&v.contains(y.target))){var _;(_=d.current)===null||_===void 0||_.focus(),d.current=null}};return{toolbarProps:{...Gt(e,{labelable:!0}),role:a?"group":"toolbar","aria-orientation":i,"aria-label":n,"aria-labelledby":n==null?r:void 0,onKeyDownCapture:a?void 0:c,onFocusCapture:a?void 0:m,onBlurCapture:a?void 0:h}}}function x$e(e,t,n){let{isDisabled:r}=e,{toolbarProps:i}=Eue(e,n);return{groupProps:{...i,role:t.selectionMode==="single"?"radiogroup":i.role,"aria-disabled":r}}}function S$e(e,t,n){let r={isSelected:t.selectedKeys.has(e.id),defaultSelected:!1,setSelected(o){t.setSelected(e.id,o)},toggle(){t.toggleKey(e.id)}},{isPressed:i,isSelected:a,isDisabled:u,buttonProps:l}=_ue({...e,id:void 0,isDisabled:e.isDisabled||t.isDisabled},r,n);return t.selectionMode==="single"&&(l.role="radio",l["aria-checked"]=r.isSelected,delete l["aria-pressed"]),{isPressed:i,isSelected:a,isDisabled:u,buttonProps:l}}function Due(e,t,n){let{isDisabled:r=!1,isReadOnly:i=!1,value:a,name:u,form:l,children:o,"aria-label":s,"aria-labelledby":c,validationState:d="valid",isInvalid:h,onPressStart:m,onPressEnd:y,onPressChange:v,onPress:_,onPressUp:S,onClick:E}=e,C=V=>{V.stopPropagation(),t.setSelected(V.target.checked)},{pressProps:T,isPressed:R}=up({onPressStart:m,onPressEnd:y,onPressChange:v,onPress:_,onPressUp:S,onClick:E,isDisabled:r}),{pressProps:$,isPressed:k}=up({onPressStart:m,onPressEnd:y,onPressChange:v,onPressUp:S,onClick:E,onPress(V){var q;_==null||_(V),t.toggle(),(q=n.current)===null||q===void 0||q.focus()},isDisabled:r||i}),{focusableProps:F}=L0(e,n),L=Et(T,F),j=Gt(e,{labelable:!0});return my(n,t.defaultSelected,t.setSelected),{labelProps:Et($,{onClick:V=>V.preventDefault()}),inputProps:Et(j,{"aria-invalid":h||d==="invalid"||void 0,"aria-errormessage":e["aria-errormessage"],"aria-controls":e["aria-controls"],"aria-readonly":i||void 0,onChange:C,disabled:r,...a==null?{}:{value:a},name:u,form:l,type:"checkbox",...L}),isSelected:t.isSelected,isPressed:R||k,isDisabled:r,isReadOnly:i,isInvalid:h||d==="invalid"}}function $ue(e,t,n){let r=bg({...e,value:t.isSelected}),{isInvalid:i,validationErrors:a,validationDetails:u}=r.displayValidation,{labelProps:l,inputProps:o,isSelected:s,isPressed:c,isDisabled:d,isReadOnly:h}=Due({...e,isInvalid:i},t,n);pS(e,r,n);let{isIndeterminate:m,isRequired:y,validationBehavior:v="aria"}=e;P.useEffect(()=>{n.current&&(n.current.indeterminate=!!m)});let{pressProps:_}=up({isDisabled:d||h,onPress(){let{[sb]:S}=e,{commitValidation:E}=S||r;E()}});return{labelProps:Et(l,_,P.useMemo(()=>({onMouseDown:S=>S.preventDefault()}),[])),inputProps:{...o,checked:s,"aria-required":y&&v==="aria"||void 0,required:y&&v==="native"},isSelected:s,isPressed:c,isDisabled:d,isReadOnly:h,isInvalid:i,validationErrors:a,validationDetails:u}}const _$e=new WeakMap;function YC(e={}){let{isReadOnly:t}=e,[n,r]=Zu(e.isSelected,e.defaultSelected||!1,e.onChange),[i]=P.useState(n);function a(o){t||r(o)}function u(){t||r(!n)}var l;return{isSelected:n,defaultSelected:(l=e.defaultSelected)!==null&&l!==void 0?l:i,setSelected:a,toggle:u}}function E$e(e){let{selectionMode:t="single",disallowEmptySelection:n,isDisabled:r=!1}=e,[i,a]=Zu(P.useMemo(()=>e.selectedKeys?new Set(e.selectedKeys):void 0,[e.selectedKeys]),P.useMemo(()=>e.defaultSelectedKeys?new Set(e.defaultSelectedKeys):new Set,[e.defaultSelectedKeys]),e.onSelectionChange);return{selectionMode:t,isDisabled:r,selectedKeys:i,setSelectedKeys:a,toggleKey(u){let l;t==="multiple"?(l=new Set(i),l.has(u)&&(!n||l.size>1)?l.delete(u):l.add(u)):l=new Set(i.has(u)&&!n?[]:[u]),a(l)},setSelected(u,l){l!==i.has(u)&&this.toggleKey(u)}}}function D$e(e,t,n){const r=YC({isReadOnly:e.isReadOnly||t.isReadOnly,isSelected:t.isSelected(e.value),defaultSelected:t.defaultValue.includes(e.value),onChange(S){S?t.addValue(e.value):t.removeValue(e.value),e.onChange&&e.onChange(S)}});let{name:i,form:a,descriptionId:u,errorMessageId:l,validationBehavior:o}=_$e.get(t);var s;o=(s=e.validationBehavior)!==null&&s!==void 0?s:o;let{realtimeValidation:c}=bg({...e,value:r.isSelected,name:void 0,validationBehavior:"aria"}),d=P.useRef(NO),h=()=>{t.setInvalid(e.value,c.isInvalid?c:d.current)};P.useEffect(h);let m=t.realtimeValidation.isInvalid?t.realtimeValidation:c,y=o==="native"?t.displayValidation:m;var v;let _=$ue({...e,isReadOnly:e.isReadOnly||t.isReadOnly,isDisabled:e.isDisabled||t.isDisabled,name:e.name||i,form:e.form||a,isRequired:(v=e.isRequired)!==null&&v!==void 0?v:t.isRequired,validationBehavior:o,[sb]:{realtimeValidation:m,displayValidation:y,resetValidation:t.resetValidation,commitValidation:t.commitValidation,updateValidation(S){d.current=S,h()}}},r,n);return{..._,inputProps:{..._.inputProps,"aria-describedby":[e["aria-describedby"],t.isInvalid?l:null,u].filter(Boolean).join(" ")||void 0}}}var Cue={};Cue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"أداة انتقاء اللون",colorSwatch:"تغيير الألوان",transparent:"شفاف",twoDimensionalSlider:"مُنزلق 2D"};var wue={};wue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Средство за избиране на цвят",colorSwatch:"цветна мостра",transparent:"прозрачен",twoDimensionalSlider:"2D плъзгач"};var Rue={};Rue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Výběr barvy",colorSwatch:"barevný vzorek",transparent:"průhledný",twoDimensionalSlider:"2D posuvník"};var Aue={};Aue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Farvevælger",colorSwatch:"farveprøve",transparent:"gennemsigtig",twoDimensionalSlider:"2D-skyder"};var Tue={};Tue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Farbwähler",colorSwatch:"Farbfeld",transparent:"transparent",twoDimensionalSlider:"2D-Schieberegler"};var kue={};kue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Επιλογέας χρωμάτων",colorSwatch:"χρωματικό δείγμα",transparent:"διαφανές",twoDimensionalSlider:"Ρυθμιστικό 2D"};var Pue={};Pue={colorPicker:"Color picker",twoDimensionalSlider:"2D slider",colorNameAndValue:e=>`${e.name}: ${e.value}`,colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorSwatch:"color swatch",transparent:"transparent"};var Mue={};Mue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Selector de color",colorSwatch:"muestra de color",transparent:"transparente",twoDimensionalSlider:"Regulador 2D"};var Fue={};Fue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Värvivalija",colorSwatch:"värvinäidis",transparent:"läbipaistev",twoDimensionalSlider:"2D-liugur"};var Nue={};Nue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Värimuokkain",colorSwatch:"värimalli",transparent:"läpinäkyvä",twoDimensionalSlider:"2D-liukusäädin"};var Iue={};Iue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name} : ${e.value}`,colorPicker:"Sélecteur de couleurs",colorSwatch:"Échantillon de couleurs",transparent:"Transparent",twoDimensionalSlider:"Curseur 2D"};var Lue={};Lue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"בוחר הצבעים",colorSwatch:"דוגמית צבע",transparent:"שקוף",twoDimensionalSlider:"מחוון דו מימדי"};var Bue={};Bue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Odabir boje",colorSwatch:"uzorak boje",transparent:"transparentno",twoDimensionalSlider:"2D klizač"};var Que={};Que={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Színválasztó",colorSwatch:"színtár",transparent:"átlátszó",twoDimensionalSlider:"2D-csúszka"};var zue={};zue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Selettore colore",colorSwatch:"campione di colore",transparent:"trasparente",twoDimensionalSlider:"Cursore 2D"};var que={};que={colorInputLabel:e=>`${e.label}、${e.channelLabel}`,colorNameAndValue:e=>`${e.name} : ${e.value}`,colorPicker:"カラーピッカー",colorSwatch:"カラースウォッチ",transparent:"透明",twoDimensionalSlider:"2D スライダー"};var Vue={};Vue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"색상 피커",colorSwatch:"색상 견본",transparent:"투명도",twoDimensionalSlider:"2D 슬라이더"};var Uue={};Uue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Spalvų parinkiklis",colorSwatch:"spalvų pavyzdys",transparent:"skaidrus",twoDimensionalSlider:"2D slankiklis"};var jue={};jue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Krāsu atlasītājs",colorSwatch:"krāsu paraugs",transparent:"caurspīdīgs",twoDimensionalSlider:"2D slīdnis"};var Zue={};Zue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Fargevelger",colorSwatch:"fargekart",transparent:"gjennomsiktig",twoDimensionalSlider:"2D-glidebryter"};var Hue={};Hue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Kleurkiezer",colorSwatch:"kleurstaal",transparent:"transparant",twoDimensionalSlider:"2D-schuifregelaar"};var Xue={};Xue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Próbnik kolorów",colorSwatch:"próbka koloru",transparent:"przezroczysty",twoDimensionalSlider:"Suwak 2D"};var Yue={};Yue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Seletor de cores",colorSwatch:"amostra de cores",transparent:"transparente",twoDimensionalSlider:"Controle deslizante 2D"};var Gue={};Gue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Seletor de cores",colorSwatch:"amostra de cor",transparent:"transparente",twoDimensionalSlider:"Controle deslizante 2D"};var Kue={};Kue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Selector de culori",colorSwatch:"specimen de culoare",transparent:"transparent",twoDimensionalSlider:"Glisor 2D"};var Wue={};Wue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Палитра цветов",colorSwatch:"цветовой образец",transparent:"прозрачный",twoDimensionalSlider:"Ползунок 2D"};var Jue={};Jue={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Výber farieb",colorSwatch:"vzorkovník farieb",transparent:"transparentný",twoDimensionalSlider:"2D jazdec"};var ele={};ele={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Izbirnik barv",colorSwatch:"barvna paleta",transparent:"prozorno",twoDimensionalSlider:"2D drsnik"};var tle={};tle={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Birač boja",colorSwatch:"Uzorak boje",transparent:"providno",twoDimensionalSlider:"2D klizač"};var nle={};nle={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Färgväljaren",colorSwatch:"färgruta",transparent:"genomskinlig",twoDimensionalSlider:"2D-reglage"};var rle={};rle={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Renk Seçici",colorSwatch:"renk örneği",transparent:"saydam",twoDimensionalSlider:"2D sürgü"};var ile={};ile={colorInputLabel:e=>`${e.label}, ${e.channelLabel}`,colorNameAndValue:e=>`${e.name}: ${e.value}`,colorPicker:"Палітра кольорів",colorSwatch:"зразок кольору",transparent:"прозорий",twoDimensionalSlider:"Повзунок 2D"};var ale={};ale={colorInputLabel:e=>`${e.label}、${e.channelLabel}`,colorNameAndValue:e=>`${e.name}：${e.value}`,colorPicker:"拾色器",colorSwatch:"颜色色板",transparent:"透明",twoDimensionalSlider:"2D 滑块"};var ule={};ule={colorInputLabel:e=>`${e.label}，${e.channelLabel}`,colorNameAndValue:e=>`${e.name}：${e.value}`,colorPicker:"檢色器",colorSwatch:"色票",transparent:"透明",twoDimensionalSlider:"2D 滑桿"};var lle={};lle={"ar-AE":Cue,"bg-BG":wue,"cs-CZ":Rue,"da-DK":Aue,"de-DE":Tue,"el-GR":kue,"en-US":Pue,"es-ES":Mue,"et-EE":Fue,"fi-FI":Nue,"fr-FR":Iue,"he-IL":Lue,"hr-HR":Bue,"hu-HU":Que,"it-IT":zue,"ja-JP":que,"ko-KR":Vue,"lt-LT":Uue,"lv-LV":jue,"nb-NO":Zue,"nl-NL":Hue,"pl-PL":Xue,"pt-BR":Yue,"pt-PT":Gue,"ro-RO":Kue,"ru-RU":Wue,"sk-SK":Jue,"sl-SI":ele,"sr-SP":tle,"sv-SE":nle,"tr-TR":rle,"uk-UA":ile,"zh-CN":ale,"zh-TW":ule};var ole={};ole={alpha:"ألفا",black:"أسود",blue:"أزرق","blue purple":"أرجواني مزرق",brightness:"السطوع",brown:"بني","brown yellow":"أصفر بني",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"سماوي","cyan blue":"أزرق سماوي",dark:"داكن",gray:"رمادي",grayish:"مائل للرمادي",green:"أخضر","green cyan":"سماوي مخضر",hue:"درجة اللون",light:"فاتح",lightness:"الإضاءة",magenta:"أرجواني","magenta pink":"أرجواني وردي",orange:"برتقالي","orange yellow":"أصفر برتقالي",pale:"باهت",pink:"وردي","pink red":"أحمر وردي",purple:"أرجواني","purple magenta":"بنفسجي",red:"أحمر","red orange":"برتقالي محمر",saturation:"التشبع",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} شفاف`,"very dark":"داكن جدًا","very light":"فاتح جدًا",vibrant:"ساطع",white:"أبيض",yellow:"أصفر","yellow green":"أخضر مصفر"};var sle={};sle={alpha:"Алфа",black:"черно",blue:"Синьо","blue purple":"синьо лилаво",brightness:"Яркост",brown:"кафяво","brown yellow":"кафяво жълто",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"циан","cyan blue":"циан синьо",dark:"тъмно",gray:"сиво",grayish:"сивкав",green:"Зелено","green cyan":"зелен циан",hue:"Оттенък",light:"светло",lightness:"Лекота",magenta:"магента","magenta pink":"магента розово",orange:"оранжево","orange yellow":"оранжево жълто",pale:"бледо",pink:"розово","pink red":"розово червено",purple:"лилаво","purple magenta":"лилаво магента",red:"Червено","red orange":"червен портокал",saturation:"Наситеност",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} прозрачен`,"very dark":"много тъмно","very light":"много светло",vibrant:" ярко",white:"бяло",yellow:"жълто","yellow green":"жълто зелен"};var cle={};cle={alpha:"Alfa",black:"černá",blue:"Modrá","blue purple":"modrofialová",brightness:"Jas",brown:"hnědá","brown yellow":"hnědožlutá",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"tyrkysová","cyan blue":"tyrkysovomodrá",dark:"tmavá",gray:"šedá",grayish:"našedlá",green:"Zelená","green cyan":"zelenotyrkysová",hue:"Odstín",light:"světlá",lightness:"Světlost",magenta:"purpurová","magenta pink":"purpurově růžová",orange:"oranžová","orange yellow":"oranžovožlutá",pale:"bledá",pink:"růžová","pink red":"růžovočervená",purple:"fialová","purple magenta":"fialově purpurová",red:"Červená","red orange":"červenooranžová",saturation:"Sytost",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} průhledné`,"very dark":"velmi tmavá","very light":"velmi světlá",vibrant:"zářivá",white:"bílá",yellow:"žlutá","yellow green":"žlutozelená"};var fle={};fle={alpha:"Alfa",black:"sort",blue:"Blå","blue purple":"blålilla",brightness:"Lysstyrke",brown:"brun","brown yellow":"brungul",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"cyan","cyan blue":"cyan blå",dark:"mørk",gray:"grå",grayish:"grålig",green:"Grøn","green cyan":"grøn cyan",hue:"Tone",light:"lys",lightness:"Lyshed",magenta:"magenta","magenta pink":"magenta pink",orange:"orange","orange yellow":"orangegul",pale:"bleg",pink:"lyserød","pink red":"lyserødlig rød",purple:"lilla","purple magenta":"lilla magenta",red:"Rød","red orange":"rødorange",saturation:"Farvemætning",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} gennemsigtig`,"very dark":"meget mørk","very light":"meget lys",vibrant:"klar",white:"hvid",yellow:"gul","yellow green":"gulgrøn"};var dle={};dle={alpha:"Alpha",black:"Schwarz",blue:"Blau","blue purple":"Blaulila",brightness:"Helligkeit",brown:"Braun","brown yellow":"Braungelb",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"Cyan","cyan blue":"Cyanblau",dark:"dunkles",gray:"Grau",grayish:"gräuliches",green:"Grün","green cyan":"Grüncyan",hue:"Farbton",light:"helles",lightness:"Leuchtkraft",magenta:"Magenta","magenta pink":"Magentarosa",orange:"Orange","orange yellow":"Orangegelb",pale:"blasses",pink:"Rosa","pink red":"Rosarot",purple:"Lila","purple magenta":"Lilamagenta",red:"Rot","red orange":"Rotorange",saturation:"Sättigung",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, zu ${e.percentTransparent} transparent`,"very dark":"sehr dunkles","very light":"sehr helles",vibrant:"lebhaftes",white:"Weiß",yellow:"Gelb","yellow green":"Gelbgrün"};var hle={};hle={alpha:"Άλφα",black:"μαύρο",blue:"Μπλε","blue purple":"μπλε μωβ",brightness:"Φωτεινότητα",brown:"καφέ","brown yellow":"καφέ κίτρινο",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"κυανό","cyan blue":"κυανό μπλε",dark:"σκούρο",gray:"γκρι",grayish:"γκριζωπό",green:"Πράσινο","green cyan":"πράσινο κυανό",hue:"Τόνος",light:"ανοιχτό",lightness:"Φωτεινότητα",magenta:"ματζέντα","magenta pink":"ματζέντα ροζ",orange:"πορτοκαλί","orange yellow":"πορτοκαλί κίτρινο",pale:"ανοιχτό",pink:"ροζ","pink red":"ροζ κόκκινο",purple:"μωβ","purple magenta":"μωβ ματζέντα",red:"Κόκκινο","red orange":"κόκκινο πορτοκαλί",saturation:"Κορεσμός",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} διαφανές`,"very dark":"πολύ σκούρο","very light":"πολύ ανοιχτό",vibrant:"έντονο",white:"λευκό",yellow:"κίτρινο","yellow green":"κίτρινο πράσινο"};var ple={};ple={hue:"Hue",saturation:"Saturation",lightness:"Lightness",brightness:"Brightness",red:"Red",green:"Green",blue:"Blue",alpha:"Alpha",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} transparent`,"very dark":"very dark",dark:"dark",light:"light","very light":"very light",pale:"pale",grayish:"grayish",vibrant:"vibrant",black:"black",white:"white",gray:"gray",pink:"pink","pink red":"pink red","red orange":"red orange",brown:"brown",orange:"orange","orange yellow":"orange yellow","brown yellow":"brown yellow",yellow:"yellow","yellow green":"yellow green","green cyan":"green cyan",cyan:"cyan","cyan blue":"cyan blue","blue purple":"blue purple",purple:"purple","purple magenta":"purple magenta",magenta:"magenta","magenta pink":"magenta pink"};var mle={};mle={alpha:"Alpha",black:"negro",blue:"Azul","blue purple":"púrpura azulado",brightness:"Brillo",brown:"marrón","brown yellow":"amarillo amarronado",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"cian","cyan blue":"azul cian",dark:"oscuro",gray:"gris",grayish:"grisáceo",green:"Verde","green cyan":"cian verdoso",hue:"Tono",light:"claro",lightness:"Luminosidad",magenta:"magenta","magenta pink":"rosa magenta",orange:"naranja","orange yellow":"amarillo anaranjado",pale:"pálido",pink:"rosa","pink red":"rojo rosado",purple:"morado","purple magenta":"magenta violáceo",red:"Rojo","red orange":"naranja rojizo",saturation:"Saturación",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} transparente`,"very dark":"muy oscuro","very light":"muy claro",vibrant:"intenso",white:"blanco",yellow:"amarillo","yellow green":"verde amarillento"};var gle={};gle={alpha:"Alfa",black:"must",blue:"Sinine","blue purple":"sinakaslilla",brightness:"Heledus",brown:"pruun","brown yellow":"pruunikaskollane",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"tsüaan","cyan blue":"tsüaansinine",dark:"tume",gray:"hall",grayish:"hallikas",green:"Roheline","green cyan":"tsüaanroheline",hue:"Värv",light:"valgus",lightness:"Valgus",magenta:"magentapunane","magenta pink":"magentaroosa",orange:"oranž","orange yellow":"oranžikaskollane",pale:"kahvatu",pink:"roosa","pink red":"vaarikapunane",purple:"lilla","purple magenta":"purpurne magenta",red:"Punane","red orange":"punakasoranž",saturation:"Küllastus",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} läbipaistev`,"very dark":"väga tume","very light":"väga hele",vibrant:"ere",white:"valge",yellow:"kollane","yellow green":"kollakasroheline"};var vle={};vle={alpha:"Alpha",black:"musta",blue:"Sininen","blue purple":"sinivioletti",brightness:"Kirkkaus",brown:"ruskea","brown yellow":"ruskeankeltainen",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"syaani","cyan blue":"syaaninsininen",dark:"tumma",gray:"harmaa",grayish:"harmahtava",green:"Vihreä","green cyan":"vihreänsyaani",hue:"Sävy",light:"vaalea",lightness:"Valomäärä",magenta:"magenta","magenta pink":"magentapinkki",orange:"oranssi","orange yellow":"oranssinkeltainen",pale:"vaalea",pink:"pinkki","pink red":"vaaleanpunainen",purple:"violetti","purple magenta":"violettimagenta",red:"Punainen","red orange":"punaoranssi",saturation:"Värikylläisyys",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} läpinäkyvä`,"very dark":"hyvin tumma","very light":"erittäin vaalea",vibrant:"eloisa",white:"valkea",yellow:"keltainen","yellow green":"keltavihreä"};var yle={};yle={alpha:"Alpha",black:"Noir",blue:"Bleu","blue purple":"Violet bleu",brightness:"Luminosité",brown:"Brun","brown yellow":"Jaune brun",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"Cyan","cyan blue":"Bleu cyan",dark:"Sombre",gray:"Gris",grayish:"Grisâtre",green:"Vert","green cyan":"Cyan vert",hue:"Teinte",light:"Clair",lightness:"Luminosité",magenta:"Magenta","magenta pink":"Rose magenta",orange:"Orange","orange yellow":"Jaune orangé",pale:"Pâle",pink:"Rose","pink red":"Rouge rosé",purple:"Violet","purple magenta":"Magenta violet",red:"Rouge","red orange":"Orange rouge",saturation:"Saturation",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} transparent`,"very dark":"Très sombre","very light":"Très clair",vibrant:"Vif",white:"Blanc",yellow:"Jaune","yellow green":"Vert jaune"};var ble={};ble={alpha:"אלפא",black:"שחור",blue:"כחול","blue purple":"כחול סגול",brightness:"בהירות",brown:"חום","brown yellow":"חום צהוב",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"טורקיז","cyan blue":"כחול ציאן",dark:"כהה",gray:"אפור",grayish:"אפרפר",green:"ירוק","green cyan":"ציאן ירוק",hue:"גוון",light:"אור",lightness:"כמות אור",magenta:"מג'נטה","magenta pink":"ורוד מג'נטה",orange:"כתום","orange yellow":"כתום צהוב",pale:"חיוור",pink:"ורוד","pink red":"ורוד אדום",purple:"סגול","purple magenta":"מג'נטה סגול",red:"אדום","red orange":"כתום אדום",saturation:"רוויה",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} שקוף`,"very dark":"כהה מאוד","very light":"בהיר מאוד",vibrant:"תוסס",white:"לבן",yellow:"צהוב","yellow green":"צהוב ירוק"};var Ole={};Ole={alpha:"Alfa",black:"crno",blue:"Plava","blue purple":"plavo ljubičasta",brightness:"Svjetlina",brown:"smeđa","brown yellow":"smeđe žuta",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"cijan","cyan blue":"cijan plava",dark:"tamno",gray:"siva",grayish:"sivkasto",green:"Zelena","green cyan":"zelena cijan",hue:"Nijansa",light:"svjetlo",lightness:"Osvijetljenost",magenta:"magenta","magenta pink":"magentno ružičasta",orange:"narančasta","orange yellow":"narančasto žuta",pale:"blijeda",pink:"ružičasta","pink red":"ružičasto crvena",purple:"ljubičasta","purple magenta":"ljubičasta magenta",red:"Crvena","red orange":"crveno narančasta",saturation:"Zasićenost",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} prozirnosti`,"very dark":"jako tamna","very light":"vrlo svijetlo",vibrant:"vibrantna",white:"bijela",yellow:"žuto","yellow green":"žuto zelena"};var xle={};xle={alpha:"Alfa",black:"fekete",blue:"Kék","blue purple":"kék lila",brightness:"Fényesség",brown:"barna","brown yellow":"barna sárga",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"ciánkék","cyan blue":"ciánkék",dark:"sötét",gray:"szürke",grayish:"szürkés",green:"Zöld","green cyan":"zöld ciánkék",hue:"Színárnyalat",light:"világos",lightness:"Világosság",magenta:"bíbor","magenta pink":"bíbor rózsaszín",orange:"narancs","orange yellow":"narancssárga",pale:"halvány",pink:"rózsaszín","pink red":"rózsaszín piros",purple:"lila","purple magenta":"lila bíbor",red:"Piros","red orange":"piros narancs",saturation:"Telítettség",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} átlátszó`,"very dark":"nagyon sötét","very light":"nagyon világos",vibrant:"élénk",white:"fehér",yellow:"sárga","yellow green":"sárga zöld"};var Sle={};Sle={alpha:"Alfa",black:"nero",blue:"Blu","blue purple":"blu viola",brightness:"Luminosità",brown:"marrone","brown yellow":"giallo bruno",colorName:e=>`${e.hue} ${e.chroma} ${e.lightness}`,cyan:"ciano","cyan blue":"blu ciano",dark:"scuro",gray:"grigio",grayish:"grigiastro",green:"Verde","green cyan":"verde ciano",hue:"Tonalità",light:"chiaro",lightness:"Luminosità",magenta:"magenta","magenta pink":"rosa magenta",orange:"arancio","orange yellow":"giallo arancio",pale:"tenue",pink:"rosa","pink red":"rosa rosso",purple:"viola","purple magenta":"viola magenta",red:"Rosso","red orange":"rosso arancio",saturation:"Saturazione",transparentColorName:e=>`${e.hue} ${e.chroma} ${e.lightness}, trasparenza ${e.percentTransparent}`,"very dark":"molto scuro","very light":"molto chiaro",vibrant:"vivace",white:"bianco",yellow:"giallo","yellow green":"giallo verde"};var _le={};_le={alpha:"アルファ",black:"ブラック",blue:"青","blue purple":"ブルーパープル",brightness:"明るさ",brown:"ブラウン","brown yellow":"ブラウンイエロー",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"シアン","cyan blue":"シアンブルー",dark:"ダーク",gray:"グレー",grayish:"グレイッシュ",green:"緑","green cyan":"グリーンシアン",hue:"色相",light:"ライト",lightness:"明度",magenta:"マゼンタ","magenta pink":"マゼンタピンク",orange:"オレンジ","orange yellow":"オレンジイエロー",pale:"ペール",pink:"ピンク","pink red":"ピンクレッド",purple:"パープル","purple magenta":"パープルマゼンタ",red:"赤","red orange":"レッドオレンジ",saturation:"彩度",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} 透明`,"very dark":"最も暗い","very light":"ベリーライト",vibrant:"鮮やか",white:"ホワイト",yellow:"イエロー","yellow green":"イエローグリーン"};var Ele={};Ele={alpha:"알파",black:"검은색",blue:"파랑","blue purple":"청자색",brightness:"명도",brown:"갈색","brown yellow":"황갈색",colorName:e=>`${e.lightness}, ${e.chroma}, ${e.hue}`,cyan:"청록색","cyan blue":"청록색",dark:"다크",gray:"회색",grayish:"회갈색",green:"초록","green cyan":"청록색",hue:"색조",light:"라이트",lightness:"밝기",magenta:"자홍색","magenta pink":"마젠타 핑크",orange:"주황색","orange yellow":"불그스름한 노랑",pale:"흙색",pink:"분홍색","pink red":"핑크 레드",purple:"자주색","purple magenta":"보라빛 자홍색",red:"빨강","red orange":"붉은 주황색",saturation:"채도",transparentColorName:e=>`${e.lightness}, ${e.chroma}, ${e.hue}, ${e.percentTransparent} 투명도`,"very dark":"매우 어두운","very light":"매우 연함",vibrant:"강렬한",white:"흰색",yellow:"노란색","yellow green":"연두색"};var Dle={};Dle={alpha:"Alfa",black:"juoda",blue:"Mėlyna","blue purple":"melsvai violetinė",brightness:"Ryškumas",brown:"ruda","brown yellow":"rusvai geltona",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"žalsvai mėlyna","cyan blue":"žalsvai mėlyna",dark:"tamsi",gray:"pilka",grayish:"pilkšva",green:"Žalia","green cyan":"žalsvai mėlyna",hue:"Atspalvis",light:"šviesi",lightness:"Šviesumas",magenta:"rausvai raudona","magenta pink":"purpurinė",orange:"oranžinė","orange yellow":"oranžinio atspalvio geltona",pale:"blyški",pink:"rožinė","pink red":"rožinė raudona",purple:"violetinė","purple magenta":"purpurinė rausvai raudona",red:"Raudona","red orange":"rausvai oranžinė",saturation:"Įsotinimas",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} skaidri`,"very dark":"labai tamsi","very light":"labai šviesi",vibrant:"ryški",white:"balta",yellow:"geltona","yellow green":"gelsvai žalia"};var $le={};$le={alpha:"Alfa",black:"melns",blue:"Zila","blue purple":"zili violets",brightness:"Spilgtums",brown:"brūns","brown yellow":"brūni dzeltens",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"ciāns","cyan blue":"ciāna zils",dark:"tumšs",gray:"pelēks",grayish:"pelēcīgs",green:"Zaļa","green cyan":"zaļš ciāns",hue:"Nokrāsa",light:"gaišs",lightness:"Gaišums",magenta:"fuksiju","magenta pink":"fuksiju rozā",orange:"oranžs","orange yellow":"oranži dzeltens",pale:"bāls",pink:"rozā","pink red":"rozīgi sarkans",purple:"violets","purple magenta":"violets fuksiju",red:"Sarkana","red orange":"sarkanīgi oranžs",saturation:"Piesātinājums",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} caurspīdīgs`,"very dark":"ļoti tumšs","very light":"ļoti gaišs",vibrant:"košs",white:"balts",yellow:"dzeltens","yellow green":"dzelteni zaļš"};var Cle={};Cle={alpha:"Alfa",black:"svart",blue:"Blå","blue purple":"blålilla",brightness:"Lysstyrke",brown:"brun","brown yellow":"brungul",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"cyan","cyan blue":"cyanblå",dark:"mørk",gray:"grå",grayish:"gråaktig",green:"Grønn","green cyan":"grønncyan",hue:"Fargetone",light:"lys",lightness:"Lyshet",magenta:"magenta","magenta pink":"magentarosa",orange:"oransje","orange yellow":"oransjegul",pale:"blek",pink:"rosa","pink red":"rosarød",purple:"lilla","purple magenta":"lillamagenta",red:"Rød","red orange":"rødoransje",saturation:"Metning",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} gjennomsiktig`,"very dark":"svært mørk","very light":"svært lys",vibrant:"levende",white:"hvit",yellow:"gul","yellow green":"gulgrønn"};var wle={};wle={alpha:"Alfa",black:"zwart",blue:"Blauw","blue purple":"paarsblauw",brightness:"Helderheid",brown:"bruin","brown yellow":"bruingeel",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"cyaan","cyan blue":"cyaanblauw",dark:"donker",gray:"grijs",grayish:"grijsachtig",green:"Groen","green cyan":"cyaangroen",hue:"Kleurtoon",light:"licht",lightness:"Lichtsterkte",magenta:"magenta","magenta pink":"magentaroze",orange:"oranje","orange yellow":"oranjegeel",pale:"bleek",pink:"roze","pink red":"rozerood",purple:"paars","purple magenta":"magentapaars",red:"Rood","red orange":"roodoranje",saturation:"Verzadiging",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} transparant`,"very dark":"heel donker","very light":"heel licht",vibrant:"levendig",white:"wit",yellow:"geel","yellow green":"geelgroen"};var Rle={};Rle={alpha:"Alfa",black:"czarny",blue:"Niebieski","blue purple":"niebiesko-fioletowy",brightness:"Jasność",brown:"brązowy","brown yellow":"brązowo-żółty",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"cyjanowy","cyan blue":"cyjanowo-niebieski",dark:"ciemny",gray:"szary",grayish:"szarawy",green:"Zielony","green cyan":"zielono-cyjanowy",hue:"Odcień",light:"jasny",lightness:"Jaskrawość",magenta:"purpurowy","magenta pink":"purpurowo-różowy",orange:"pomarańczowy","orange yellow":"pomarańczowo-żółty",pale:"blady",pink:"różowy","pink red":"różowo-czerwony",purple:"fioletowy","purple magenta":"fioletowo-purpurowy",red:"Czerwony","red orange":"czerwono-pomarańczowy",saturation:"Nasycenie",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} przezroczystości`,"very dark":"bardzo ciemny","very light":"bardzo jasny",vibrant:"intensywny",white:"biały",yellow:"żółty","yellow green":"żółto-zielony"};var Ale={};Ale={alpha:"Alfa",black:"preto",blue:"Azul","blue purple":"roxo azulado",brightness:"Brilho",brown:"marrom","brown yellow":"marrom amarelado",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"ciano","cyan blue":"azul-ciano",dark:"escuro",gray:"cinza",grayish:"acinzentado",green:"Verde","green cyan":"verde-ciano",hue:"Matiz",light:"claro",lightness:"Luminosidade",magenta:"magenta","magenta pink":"rosa-magenta",orange:"laranja","orange yellow":"amarelo alaranjado",pale:"pálido",pink:"rosa","pink red":"rosa avermelhado",purple:"roxo","purple magenta":"roxo-magenta",red:"Vermelho","red orange":"laranja avermelhado",saturation:"Saturação",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} transparente`,"very dark":"muito escuro","very light":"muito claro",vibrant:"vibrante",white:"branco",yellow:"amarelo","yellow green":"verde amarelado"};var Tle={};Tle={alpha:"Alfa",black:"preto",blue:"Azul","blue purple":"azul-púrpura",brightness:"Luminosidade",brown:"castanho","brown yellow":"amarelo-castanho",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"ciano","cyan blue":"azul-ciano",dark:"escuro",gray:"cinzento",grayish:"acinzentado",green:"Verde","green cyan":"verde-ciano",hue:"Tonalidade",light:"claro",lightness:"Claridade",magenta:"magenta","magenta pink":"rosa-magenta",orange:"laranja","orange yellow":"amarelo-laranja",pale:"pálido",pink:"cor-de-rosa","pink red":"vermelho-rosa",purple:"púrpura","purple magenta":"púrpura-magenta",red:"Vermelho","red orange":"laranja-vermelho",saturation:"Saturação",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} transparente`,"very dark":"muito escuro","very light":"muito claro",vibrant:"vibrante",white:"branco",yellow:"amarelo","yellow green":"verde-amarelo"};var kle={};kle={alpha:"Alfa",black:"negru",blue:"Albastru","blue purple":"albastru-violet",brightness:"Luminozitate",brown:"maro","brown yellow":"galben maro",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"bleu","cyan blue":"albastru-bleu",dark:"închis",gray:"gri",grayish:"cenușiu",green:"Verde","green cyan":"verde bleu",hue:"Nuanță",light:"deschis",lightness:"Luminozitate",magenta:"fucsia","magenta pink":"roz-fucsia",orange:"portocaliu","orange yellow":"galben-portocaliu",pale:"pal",pink:"roz","pink red":"roz-roșu",purple:"violet","purple magenta":"violet-fucsia",red:"Roșu","red orange":"portocaliu-roșu",saturation:"Saturație",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} transparent`,"very dark":"foarte închis","very light":"foarte deschis",vibrant:"plin de viață",white:"alb",yellow:"galben","yellow green":"galben-verde"};var Ple={};Ple={alpha:"Альфа",black:"черный",blue:"Синий","blue purple":"сине-фиолетовый",brightness:"Яркость",brown:"коричневый","brown yellow":"коричнево-желтый",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"голубой","cyan blue":"цвет морской волны",dark:"темный",gray:"серый",grayish:"сероватый",green:"Зеленый","green cyan":"сине-зеленый",hue:"Оттенок",light:"светлый",lightness:"Освещенность",magenta:"пурпурный","magenta pink":"пурпурно-розовый",orange:"оранжевый","orange yellow":"оранжево-желтый",pale:"бледный",pink:"розовый","pink red":"розово-красный",purple:"фиолетовый","purple magenta":"фиолетово-пурпурный",red:"Красный","red orange":"красно-оранжевый",saturation:"Насыщенность",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, прозрачный на ${e.percentTransparent}`,"very dark":"очень темный","very light":"очень светлый",vibrant:"яркий",white:"белый",yellow:"желтый","yellow green":"желто-зеленый"};var Mle={};Mle={alpha:"Alfa",black:"čierna",blue:"Modrá","blue purple":"modrofialová",brightness:"Jas",brown:"hnedá","brown yellow":"hnedožltá",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"azúrová","cyan blue":"azúrová modrá",dark:"tmavá",gray:"sivá",grayish:"sivastá",green:"Zelená","green cyan":"zelená azúrová",hue:"Odtieň",light:"svetlá",lightness:"Svetlosť",magenta:"purpurová","magenta pink":"ružová purpurová",orange:"oranžová","orange yellow":"oranžovožltá",pale:"bledá",pink:"ružová","pink red":"ružovočervená",purple:"fialová","purple magenta":"fialová purpurová",red:"Červená","red orange":"červenooranžová",saturation:"Sýtosť",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} priehľadná`,"very dark":"veľmi tmavá","very light":"veľmi svetlá",vibrant:"energická",white:"biela",yellow:"žltá","yellow green":"žltozelená"};var Fle={};Fle={alpha:"Alfa",black:"črna",blue:"Modra","blue purple":"modro vijolična",brightness:"Svetlost",brown:"rjava","brown yellow":"rjavo rumena",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"cian","cyan blue":"cian modra",dark:"temna",gray:"siva",grayish:"sivkasta",green:"Zelena","green cyan":"zelena cian",hue:"Barva",light:"svetla",lightness:"Lahkost",magenta:"škrlatna","magenta pink":"škrlatno roza",orange:"oranžna","orange yellow":"oranžno rumena",pale:"bleda",pink:"roza","pink red":"roza rdeča",purple:"vijolična","purple magenta":"vijolično škrlatna",red:"Rdeča","red orange":"rdeče oranžna",saturation:"Nasičenost",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} prozorna`,"very dark":"zelo temna","very light":"zelo svetla",vibrant:"živahna",white:"bela",yellow:"rumena","yellow green":"rumeno zelena"};var Nle={};Nle={alpha:"Alfa",black:"crno",blue:"Plava","blue purple":"plavoljubičasta",brightness:"Osvetljenost",brown:"smeđa","brown yellow":"smeđežuta",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"cijan","cyan blue":"cijan plava",dark:"tamno",gray:"siva",grayish:"sivkasta",green:"Zelena","green cyan":"zeleno cijan",hue:"Nijansa",light:"svetla",lightness:"Osvetljenje",magenta:"purpurnocrvena","magenta pink":"magenta ružičasta",orange:"narandžasta","orange yellow":"narandžastožuta",pale:"bledo",pink:"ružičasta","pink red":"ružičastocrvena",purple:"ljubičasta","purple magenta":"ljubičasta magenta",red:"Crvena","red orange":"crvenonarandžasta",saturation:"Zasićenje",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} prozirna`,"very dark":"veoma tamno","very light":"vrlo svetlo",vibrant:"živopisna",white:"bela",yellow:"žuto","yellow green":"žutozelena"};var Ile={};Ile={alpha:"Alfa",black:"svart",blue:"Blått","blue purple":"blålila",brightness:"Ljusstyrka",brown:"brun","brown yellow":"brungul",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"cyan","cyan blue":"cyanblå",dark:"mörk",gray:"grå",grayish:"gråaktig",green:"Grönt","green cyan":"grön cyan",hue:"Nyans",light:"ljus",lightness:"Ljushet",magenta:"magenta","magenta pink":"magentarosa",orange:"orange","orange yellow":"orangegul",pale:"blek",pink:"rosa","pink red":"rosaröd",purple:"lila","purple magenta":"lila magenta",red:"Rött","red orange":"rödorange",saturation:"Mättnad",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} genomskinlig`,"very dark":"mycket mörk","very light":"mycket ljus",vibrant:"livfull",white:"vit",yellow:"gul","yellow green":"gulgrön"};var Lle={};Lle={alpha:"Alfa",black:"siyah",blue:"Mavi","blue purple":"mavi mor",brightness:"Parlaklık",brown:"kahverengi","brown yellow":"kahverengi sarı",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"camgöbeği","cyan blue":"camgöbeği mavi",dark:"koyu",gray:"gri",grayish:"grimsi",green:"Yeşil","green cyan":"yeşil camgöbeği",hue:"Ton",light:"açık",lightness:"Canlılık",magenta:"eflatun","magenta pink":"eflatun pembe",orange:"turuncu","orange yellow":"turuncu sarı",pale:"solgun",pink:"pembe","pink red":"pembe kırmızı",purple:"mor","purple magenta":"mor eflatun",red:"Kırmızı","red orange":"kırmızı portakal",saturation:"Doygunluk",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} saydam`,"very dark":"çok koyu","very light":"çok açık",vibrant:"canlı",white:"beyaz",yellow:"sarı","yellow green":"sarı yeşil"};var Ble={};Ble={alpha:"Альфа",black:"чорний",blue:"Синій","blue purple":"синьо-фіолетовий",brightness:"Яскравість",brown:"коричневий","brown yellow":"коричнево-жовтий",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"блакитний","cyan blue":"синьо-блакитний",dark:"темний",gray:"сірий",grayish:"сіруватий",green:"Зелений","green cyan":"зелено-блакитний",hue:"Тон",light:"світлий",lightness:"Освітленість",magenta:"пурпуровий","magenta pink":"пурпурово-рожевий",orange:"помаранчевий","orange yellow":"помаранчево-жовтий",pale:"блідий",pink:"рожевий","pink red":"рожево-червоний",purple:"фіолетовий","purple magenta":"фіолетово-пурпуровий",red:"Червоний","red orange":"червоно-помаранчевий",saturation:"Насиченість",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, прозорий на ${e.percentTransparent}`,"very dark":"дуже темний","very light":"дуже світлий",vibrant:"яскравий",white:"білий",yellow:"жовтий","yellow green":"жовто-зелений"};var Qle={};Qle={alpha:"Alpha",black:"黑色",blue:"蓝色","blue purple":"蓝紫色",brightness:"亮度",brown:"棕色的","brown yellow":"棕黄色",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"蓝绿色","cyan blue":"青蓝色",dark:"深色",gray:"灰色",grayish:"浅灰色的",green:"绿色","green cyan":"绿青色",hue:"色相",light:"浅色",lightness:"明亮度",magenta:"紫红色","magenta pink":"紫粉色",orange:"橙色","orange yellow":"橙黄色",pale:"苍白的",pink:"粉色","pink red":"粉红色",purple:"紫色","purple magenta":"紫洋红色",red:"红色","red orange":"红橙色",saturation:"饱和度",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} 透明`,"very dark":"很暗","very light":"很浅",vibrant:"生机勃勃",white:"白色",yellow:"黄色","yellow green":"黄色/绿色"};var zle={};zle={alpha:"Alpha",black:"黑",blue:"藍色","blue purple":"藍紫",brightness:"亮度",brown:"棕","brown yellow":"棕黃",colorName:e=>`${e.lightness} ${e.chroma} ${e.hue}`,cyan:"青","cyan blue":"青藍",dark:"暗",gray:"灰",grayish:"偏灰",green:"綠色","green cyan":"青綠",hue:"色相",light:"淺",lightness:"明亮",magenta:"洋紅","magenta pink":"淺洋紅",orange:"橙","orange yellow":"橙黃",pale:"淡",pink:"粉紅","pink red":"粉紅",purple:"紫","purple magenta":"紫洋紅",red:"紅色","red orange":"橙紅",saturation:"飽和度",transparentColorName:e=>`${e.lightness} ${e.chroma} ${e.hue}, ${e.percentTransparent} 透明`,"very dark":"很暗","very light":"很淺",vibrant:"鮮豔",white:"白",yellow:"黃","yellow green":"黃綠"};var qle={};qle={"ar-AE":ole,"bg-BG":sle,"cs-CZ":cle,"da-DK":fle,"de-DE":dle,"el-GR":hle,"en-US":ple,"es-ES":mle,"et-EE":gle,"fi-FI":vle,"fr-FR":yle,"he-IL":ble,"hr-HR":Ole,"hu-HU":xle,"it-IT":Sle,"ja-JP":_le,"ko-KR":Ele,"lt-LT":Dle,"lv-LV":$le,"nb-NO":Cle,"nl-NL":wle,"pl-PL":Rle,"pt-BR":Ale,"pt-PT":Tle,"ro-RO":kle,"ru-RU":Ple,"sk-SK":Mle,"sl-SI":Fle,"sr-SP":Nle,"sv-SE":Ile,"tr-TR":Lle,"uk-UA":Ble,"zh-CN":Qle,"zh-TW":zle};function $$e(e){return e&&e.__esModule?e.default:e}let uk=new tp($$e(qle));function vy(e){let t=zv.parse(e)||qv.parse(e)||Vv.parse(e);if(t)return t;throw new Error("Invalid color value: "+e)}function Vle(e){return e===360?e:(e%360+360)%360}const Dj=.68,C$e=.85,$j=.55,Cj=.001,lk=[[0,"pink"],[15,"red"],[48,"orange"],[94,"yellow"],[135,"green"],[175,"cyan"],[264,"blue"],[284,"purple"],[320,"magenta"],[349,"pink"]];class zN{toHexInt(){return this.toFormat("rgb").toHexInt()}getChannelValue(t){if(t in this)return this[t];throw new Error("Unsupported color channel: "+t)}withChannelValue(t,n){if(t in this){let r=this.clone();return r[t]=n,r}throw new Error("Unsupported color channel: "+t)}getChannelName(t,n){return(tp.getGlobalDictionaryForPackage("@react-stately/color")||uk).getStringForLocale(t,n)}getColorSpaceAxes(t){let{xChannel:n,yChannel:r}=t,i=n||this.getColorChannels().find(l=>l!==r),a=r||this.getColorChannels().find(l=>l!==i),u=this.getColorChannels().find(l=>l!==i&&l!==a);return{xChannel:i,yChannel:a,zChannel:u}}getColorName(t){let[n,r,i]=wj(this),a=tp.getGlobalDictionaryForPackage("@react-stately/color")||uk;if(n>.999)return a.getStringForLocale("white",t);if(n<.001)return a.getStringForLocale("black",t);let u;[u,n]=this.getOklchHue(n,r,i,t);let l="",o="";r<=.1&&r>=Cj?n>=.7?o="pale":o="grayish":r>=.15&&(o="vibrant"),n<.3?l="very dark":n<$j?l="dark":n<.7||(n<.85?l="light":l="very light"),o&&(o=a.getStringForLocale(o,t)),l&&(l=a.getStringForLocale(l,t));let s=this.getChannelValue("alpha"),c=new dN(t,a);if(s<1){let d=new Wv(t,{style:"percent"}).format(1-s);return c.format("transparentColorName",{lightness:l,chroma:o,hue:u,percentTransparent:d}).replace(/\s+/g," ").trim()}else return c.format("colorName",{lightness:l,chroma:o,hue:u}).replace(/\s+/g," ").trim()}getOklchHue(t,n,r,i){let a=tp.getGlobalDictionaryForPackage("@react-stately/color")||uk;if(n<Cj)return[a.getStringForLocale("gray",i),t];for(let u=0;u<lk.length;u++){let[l,o]=lk[u],[s,c]=lk[u+1]||[360,"pink"];if(r>=l&&r<s)return o==="orange"&&(t<Dj?o="brown":t=t-Dj+$j),r>l+(s-l)/2&&o!==c?o=`${o} ${c}`:o==="yellow"&&t<C$e&&(o="yellow green"),[a.getStringForLocale(o,i).toLocaleLowerCase(i),t]}throw new Error("Unexpected hue")}getHueName(t){let[n,r,i]=wj(this),[a]=this.getOklchHue(n,r,i,t);return a}}class zv extends zN{static parse(t){let n=[];if(/^#[\da-f]+$/i.test(t)&&[4,5,7,9].includes(t.length)){const a=(t.length<6?t.replace(/[^#]/gi,"$&$&"):t).slice(1).split("");for(;a.length>0;)n.push(parseInt(a.splice(0,2).join(""),16));n[3]=n[3]!==void 0?n[3]/255:void 0}const r=t.match(/^rgba?\((.*)\)$/);if(r!=null&&r[1]&&(n=r[1].split(",").map(a=>Number(a.trim())),n=n.map((a,u)=>ro(a??0,0,u<3?255:1))),!(n[0]===void 0||n[1]===void 0||n[2]===void 0)){var i;return n.length<3?void 0:new zv(n[0],n[1],n[2],(i=n[3])!==null&&i!==void 0?i:1)}}toString(t="css"){switch(t){case"hex":return"#"+(this.red.toString(16).padStart(2,"0")+this.green.toString(16).padStart(2,"0")+this.blue.toString(16).padStart(2,"0")).toUpperCase();case"hexa":return"#"+(this.red.toString(16).padStart(2,"0")+this.green.toString(16).padStart(2,"0")+this.blue.toString(16).padStart(2,"0")+Math.round(this.alpha*255).toString(16).padStart(2,"0")).toUpperCase();case"rgb":return`rgb(${this.red}, ${this.green}, ${this.blue})`;case"css":case"rgba":return`rgba(${this.red}, ${this.green}, ${this.blue}, ${this.alpha})`;default:return this.toFormat(t).toString(t)}}toFormat(t){switch(t){case"hex":case"hexa":case"rgb":case"rgba":return this;case"hsb":case"hsba":return this.toHSB();case"hsl":case"hsla":return this.toHSL();default:throw new Error("Unsupported color conversion: rgb -> "+t)}}toHexInt(){return this.red<<16|this.green<<8|this.blue}toHSB(){const t=this.red/255,n=this.green/255,r=this.blue/255,i=Math.min(t,n,r),a=Math.max(t,n,r),u=a-i,l=a===0?0:u/a;let o=0;if(u!==0){switch(a){case t:o=(n-r)/u+(n<r?6:0);break;case n:o=(r-t)/u+2;break;case r:o=(t-n)/u+4;break}o/=6}return new qv(ml(o*360,2),ml(l*100,2),ml(a*100,2),this.alpha)}toHSL(){const t=this.red/255,n=this.green/255,r=this.blue/255,i=Math.min(t,n,r),a=Math.max(t,n,r),u=(a+i)/2,l=a-i;let o,s;if(l===0)o=s=0;else{switch(s=l/(u<.5?a+i:2-a-i),a){case t:o=(n-r)/l+(n<r?6:0);break;case n:o=(r-t)/l+2;break;case r:default:o=(t-n)/l+4;break}o/=6}return new Vv(ml(o*360,2),ml(s*100,2),ml(u*100,2),this.alpha)}clone(){return new zv(this.red,this.green,this.blue,this.alpha)}getChannelRange(t){switch(t){case"red":case"green":case"blue":return{minValue:0,maxValue:255,step:1,pageSize:17};case"alpha":return{minValue:0,maxValue:1,step:.01,pageSize:.1};default:throw new Error("Unknown color channel: "+t)}}getChannelFormatOptions(t){switch(t){case"red":case"green":case"blue":return{style:"decimal"};case"alpha":return{style:"percent"};default:throw new Error("Unknown color channel: "+t)}}formatChannelValue(t,n){let r=this.getChannelFormatOptions(t),i=this.getChannelValue(t);return new Wv(n,r).format(i)}getColorSpace(){return"rgb"}getColorChannels(){return zv.colorChannels}constructor(t,n,r,i){super(),this.red=t,this.green=n,this.blue=r,this.alpha=i}}zv.colorChannels=["red","green","blue"];const w$e=/hsb\(([-+]?\d+(?:.\d+)?\s*,\s*[-+]?\d+(?:.\d+)?%\s*,\s*[-+]?\d+(?:.\d+)?%)\)|hsba\(([-+]?\d+(?:.\d+)?\s*,\s*[-+]?\d+(?:.\d+)?%\s*,\s*[-+]?\d+(?:.\d+)?%\s*,\s*[-+]?\d(.\d+)?)\)/;class qv extends zN{static parse(t){let n;if(n=t.match(w$e)){var r;const[i,a,u,l]=((r=n[1])!==null&&r!==void 0?r:n[2]).split(",").map(o=>Number(o.trim().replace("%","")));return new qv(Vle(i),ro(a,0,100),ro(u,0,100),ro(l??1,0,1))}}toString(t="css"){switch(t){case"css":return this.toHSL().toString("css");case"hex":return this.toRGB().toString("hex");case"hexa":return this.toRGB().toString("hexa");case"hsb":return`hsb(${this.hue}, ${ml(this.saturation,2)}%, ${ml(this.brightness,2)}%)`;case"hsba":return`hsba(${this.hue}, ${ml(this.saturation,2)}%, ${ml(this.brightness,2)}%, ${this.alpha})`;default:return this.toFormat(t).toString(t)}}toFormat(t){switch(t){case"hsb":case"hsba":return this;case"hsl":case"hsla":return this.toHSL();case"rgb":case"rgba":return this.toRGB();default:throw new Error("Unsupported color conversion: hsb -> "+t)}}toHSL(){let t=this.saturation/100,n=this.brightness/100,r=n*(1-t/2);return t=r===0||r===1?0:(n-r)/Math.min(r,1-r),new Vv(ml(this.hue,2),ml(t*100,2),ml(r*100,2),this.alpha)}toRGB(){let t=this.hue,n=this.saturation/100,r=this.brightness/100,i=(a,u=(a+t/60)%6)=>r-n*r*Math.max(Math.min(u,4-u,1),0);return new zv(Math.round(i(5)*255),Math.round(i(3)*255),Math.round(i(1)*255),this.alpha)}clone(){return new qv(this.hue,this.saturation,this.brightness,this.alpha)}getChannelRange(t){switch(t){case"hue":return{minValue:0,maxValue:360,step:1,pageSize:15};case"saturation":case"brightness":return{minValue:0,maxValue:100,step:1,pageSize:10};case"alpha":return{minValue:0,maxValue:1,step:.01,pageSize:.1};default:throw new Error("Unknown color channel: "+t)}}getChannelFormatOptions(t){switch(t){case"hue":return{style:"unit",unit:"degree",unitDisplay:"narrow"};case"saturation":case"brightness":case"alpha":return{style:"percent"};default:throw new Error("Unknown color channel: "+t)}}formatChannelValue(t,n){let r=this.getChannelFormatOptions(t),i=this.getChannelValue(t);return(t==="saturation"||t==="brightness")&&(i/=100),new Wv(n,r).format(i)}getColorSpace(){return"hsb"}getColorChannels(){return qv.colorChannels}constructor(t,n,r,i){super(),this.hue=t,this.saturation=n,this.brightness=r,this.alpha=i}}qv.colorChannels=["hue","saturation","brightness"];const R$e=/hsl\(([-+]?\d+(?:.\d+)?\s*,\s*[-+]?\d+(?:.\d+)?%\s*,\s*[-+]?\d+(?:.\d+)?%)\)|hsla\(([-+]?\d+(?:.\d+)?\s*,\s*[-+]?\d+(?:.\d+)?%\s*,\s*[-+]?\d+(?:.\d+)?%\s*,\s*[-+]?\d(.\d+)?)\)/;class Vv extends zN{static parse(t){let n;if(n=t.match(R$e)){var r;const[i,a,u,l]=((r=n[1])!==null&&r!==void 0?r:n[2]).split(",").map(o=>Number(o.trim().replace("%","")));return new Vv(Vle(i),ro(a,0,100),ro(u,0,100),ro(l??1,0,1))}}toString(t="css"){switch(t){case"hex":return this.toRGB().toString("hex");case"hexa":return this.toRGB().toString("hexa");case"hsl":return`hsl(${this.hue}, ${ml(this.saturation,2)}%, ${ml(this.lightness,2)}%)`;case"css":case"hsla":return`hsla(${this.hue}, ${ml(this.saturation,2)}%, ${ml(this.lightness,2)}%, ${this.alpha})`;default:return this.toFormat(t).toString(t)}}toFormat(t){switch(t){case"hsl":case"hsla":return this;case"hsb":case"hsba":return this.toHSB();case"rgb":case"rgba":return this.toRGB();default:throw new Error("Unsupported color conversion: hsl -> "+t)}}toHSB(){let t=this.saturation/100,n=this.lightness/100,r=n+t*Math.min(n,1-n);return t=r===0?0:2*(1-n/r),new qv(ml(this.hue,2),ml(t*100,2),ml(r*100,2),this.alpha)}toRGB(){let t=this.hue,n=this.saturation/100,r=this.lightness/100,i=n*Math.min(r,1-r),a=(u,l=(u+t/30)%12)=>r-i*Math.max(Math.min(l-3,9-l,1),-1);return new zv(Math.round(a(0)*255),Math.round(a(8)*255),Math.round(a(4)*255),this.alpha)}clone(){return new Vv(this.hue,this.saturation,this.lightness,this.alpha)}getChannelRange(t){switch(t){case"hue":return{minValue:0,maxValue:360,step:1,pageSize:15};case"saturation":case"lightness":return{minValue:0,maxValue:100,step:1,pageSize:10};case"alpha":return{minValue:0,maxValue:1,step:.01,pageSize:.1};default:throw new Error("Unknown color channel: "+t)}}getChannelFormatOptions(t){switch(t){case"hue":return{style:"unit",unit:"degree",unitDisplay:"narrow"};case"saturation":case"lightness":case"alpha":return{style:"percent"};default:throw new Error("Unknown color channel: "+t)}}formatChannelValue(t,n){let r=this.getChannelFormatOptions(t),i=this.getChannelValue(t);return(t==="saturation"||t==="lightness")&&(i/=100),new Wv(n,r).format(i)}getColorSpace(){return"hsl"}getColorChannels(){return Vv.colorChannels}constructor(t,n,r,i){super(),this.hue=t,this.saturation=n,this.lightness=r,this.alpha=i}}Vv.colorChannels=["hue","saturation","lightness"];function wj(e){let t=e.toFormat("rgb"),n=t.getChannelValue("red")/255,r=t.getChannelValue("green")/255,i=t.getChannelValue("blue")/255;[n,r,i]=T$e(n,r,i);let[a,u,l]=k$e(n,r,i),[o,s,c]=P$e(a,u,l);return A$e(o,s,c)}function A$e(e,t,n){var r=Math.atan2(n,t)*180/Math.PI;return[e,Math.sqrt(t**2+n**2),r>=0?r:r+360]}function T$e(e,t,n){return[ok(e),ok(t),ok(n)]}function ok(e){let t=e<0?-1:1,n=Math.abs(e);return n<=.04045?e/12.92:t*Math.pow((n+.055)/1.055,2.4)}function k$e(e,t,n){return U9([.4123907992659595,.35758433938387796,.1804807884018343,.21263900587151036,.7151686787677559,.07219231536073371,.01933081871559185,.11919477979462599,.9505321522496606],e,t,n)}function P$e(e,t,n){const r=[.819022437996703,.3619062600528904,-.1288737815209879,.0329836539323885,.9292868615863434,.0361446663506424,.0481771893596242,.2642395317527308,.6335478284694309],i=[.210454268309314,.7936177747023054,-.0040720430116193,1.9779985324311684,-2.42859224204858,.450593709617411,.0259040424655478,.7827717124575296,-.8086757549230774];let[a,u,l]=U9(r,e,t,n);return U9(i,Math.cbrt(a),Math.cbrt(u),Math.cbrt(l))}function U9(e,t,n,r){let i=e[0]*t+e[1]*n+e[2]*r,a=e[3]*t+e[4]*n+e[5]*r,u=e[6]*t+e[7]*n+e[8]*r;return[i,a,u]}const M$e=0,F$e=100,N$e=1;function I$e(e){const{isDisabled:t=!1,minValue:n=M$e,maxValue:r=F$e,numberFormatter:i,step:a=N$e,orientation:u="horizontal"}=e;let l=P.useMemo(()=>{let X=(r-n)/10;return X=Kc(X,0,X+a,a),Math.max(X,a)},[a,r,n]),o=P.useCallback(X=>X==null?void 0:X.map((B,ne)=>{let oe=ne===0?n:X[ne-1],ie=ne===X.length-1?r:X[ne+1];return Kc(B,oe,ie,a)}),[n,r,a]),s=P.useMemo(()=>o(Aj(e.value)),[e.value,o]),c=P.useMemo(()=>{var X;return o((X=Aj(e.defaultValue))!==null&&X!==void 0?X:[n])},[e.defaultValue,n,o]),d=Tj(e.value,e.defaultValue,e.onChange),h=Tj(e.value,e.defaultValue,e.onChangeEnd);const[m,y]=Zu(s,c,d);let[v]=P.useState(m);const[_,S]=P.useState(new Array(m.length).fill(!1)),E=P.useRef(new Array(m.length).fill(!0)),[C,T]=P.useState(void 0),R=P.useRef(m),$=P.useRef(_);let k=X=>{R.current=X,y(X)},F=X=>{$.current=X,S(X)};function L(X){return(X-n)/(r-n)}function j(X){return X===0?n:m[X-1]}function V(X){return X===m.length-1?r:m[X+1]}function q(X){return E.current[X]}function N(X,B){E.current[X]=B}function U(X,B){if(t||!q(X))return;const ne=j(X),oe=V(X);B=Kc(B,ne,oe,a);let ie=Rj(R.current,X,B);k(ie)}function W(X,B){if(t||!q(X))return;B&&(R.current=m);const ne=$.current[X];$.current=Rj($.current,X,B),F($.current),h&&ne&&!$.current.some(Boolean)&&h(R.current)}function G(X){return i.format(X)}function J(X,B){U(X,H(B))}function te(X){return Math.round((X-n)/a)*a+n}function H(X){const B=X*(r-n)+n;return ro(te(B),n,r)}function M(X,B=1){let ne=Math.max(B,a);U(X,Kc(m[X]+ne,n,r,a))}function K(X,B=1){let ne=Math.max(B,a);U(X,Kc(m[X]-ne,n,r,a))}return{values:m,defaultValues:e.defaultValue!==void 0?c:v,getThumbValue:X=>m[X],setThumbValue:U,setThumbPercent:J,isThumbDragging:X=>_[X],setThumbDragging:W,focusedThumb:C,setFocusedThumb:T,getThumbPercent:X=>L(m[X]),getValuePercent:L,getThumbValueLabel:X=>G(m[X]),getFormattedValue:G,getThumbMinValue:j,getThumbMaxValue:V,getPercentValue:H,isThumbEditable:q,setThumbEditable:N,incrementThumb:M,decrementThumb:K,step:a,pageSize:l,orientation:u,isDisabled:t}}function Rj(e,t,n){return e[t]===n?e:[...e.slice(0,t),n,...e.slice(t+1)]}function Aj(e){if(e!=null)return Array.isArray(e)?e:[e]}function Tj(e,t,n){return r=>{typeof e=="number"||typeof t=="number"?n==null||n(r[0]):n==null||n(r)}}function cb(e){return P.useMemo(()=>{if(typeof e=="string")try{return vy(e)}catch{return}return e},[e])}const e$=vy("#000000"),Ule=vy("#FFFFFF"),L$e=e$.toHexInt(),B$e=Ule.toHexInt();function Q$e(e){let{value:t,defaultValue:n,onChange:r}=e,{step:i}=e$.getChannelRange("red"),a=cb(n),[u,l]=Zu(cb(t),a,r),[o]=P.useState(u),[s,c]=P.useState(()=>(t||n)&&u?u.toString("hex"):""),d=bg({...e,value:u}),h=$=>{if(!u||!$){l($);return}if($.toHexInt()!==u.toHexInt()){l($);return}},[m,y]=P.useState(u);m!==u&&(c(u?u.toString("hex"):""),y(u));let v=P.useMemo(()=>{let $;try{$=vy(s.startsWith("#")?s:`#${s}`)}catch{$=null}return $},[s]);return{...d,validate:$=>{var k;return $===""||!!(!((k=$.match(/^#?[0-9a-f]{0,6}$/i))===null||k===void 0)&&k[0])},colorValue:u,defaultColorValue:a??o,setColorValue:l,inputValue:s,setInputValue:c,commit:()=>{if(!s.length){h(null),c(t===void 0||u===null?"":u.toString("hex"));return}if(v==null){c(u?u.toString("hex"):"");return}h(v);let $="";u&&($=u.toString("hex")),c($),d.commitValidation()},increment:()=>{let $=kj(v,i);$===u&&c($.toString("hex")),h($),d.commitValidation()},incrementToMax:()=>h(Ule),decrement:()=>{let $=kj(v,-i);$===u&&c($.toString("hex")),h($),d.commitValidation()},decrementToMin:()=>h(e$)}}function kj(e,t){let n=e||e$,r=n.toHexInt(),i=Math.min(Math.max(r+t,L$e),B$e);if(i!==r){let a=`#${i.toString(16).padStart(6,"0").toUpperCase()}`;n=vy(a)}return n}function jle(e){let{minValue:t,maxValue:n,step:r,formatOptions:i,value:a,defaultValue:u=NaN,onChange:l,locale:o,isDisabled:s,isReadOnly:c}=e;a===null&&(a=NaN),a!==void 0&&!isNaN(a)&&(r!==void 0&&!isNaN(r)?a=Kc(a,t,n,r):a=ro(a,t,n)),isNaN(u)||(r!==void 0&&!isNaN(r)?u=Kc(u,t,n,r):u=ro(u,t,n));let[d,h]=Zu(a,isNaN(u)?NaN:u,l),[m]=P.useState(d),[y,v]=P.useState(()=>isNaN(d)?"":new Wv(o,i).format(d)),_=P.useMemo(()=>new xN(o,i),[o,i]),S=P.useMemo(()=>_.getNumberingSystem(y),[_,y]),E=P.useMemo(()=>new Wv(o,{...i,numberingSystem:S}),[o,i,S]),C=P.useMemo(()=>E.resolvedOptions(),[E]),T=P.useCallback(B=>isNaN(B)||B===null?"":E.format(B),[E]),R=bg({...e,value:d}),$=r!==void 0&&!isNaN(r)?r:1;C.style==="percent"&&(r===void 0||isNaN(r))&&($=.01);let[k,F]=P.useState(d),[L,j]=P.useState(o),[V,q]=P.useState(i);(!Object.is(d,k)||o!==L||i!==V)&&(v(T(d)),F(d),j(o),q(i));let N=P.useMemo(()=>_.parse(y),[_,y]),U=()=>{if(!y.length){h(NaN),v(a===void 0?"":T(d));return}if(isNaN(N)){v(T(d));return}let B;r===void 0||isNaN(r)?B=ro(N,t,n):B=Kc(N,t,n,r),B=_.parse(T(B)),h(B),v(T(a===void 0?B:d)),R.commitValidation()},W=(B,ne=0)=>{let oe=N;if(isNaN(oe)){let ie=isNaN(ne)?0:ne;return Kc(ie,t,n,$)}else{let ie=Kc(oe,t,n,$);return B==="+"&&ie>oe||B==="-"&&ie<oe?ie:Kc(sk(B,oe,$),t,n,$)}},G=()=>{let B=W("+",t);B===d&&v(T(B)),h(B),R.commitValidation()},J=()=>{let B=W("-",n);B===d&&v(T(B)),h(B),R.commitValidation()},te=()=>{n!=null&&(h(Kc(n,t,n,$)),R.commitValidation())},H=()=>{t!=null&&(h(t),R.commitValidation())},M=P.useMemo(()=>!s&&!c&&(isNaN(N)||n===void 0||isNaN(n)||Kc(N,t,n,$)>N||sk("+",N,$)<=n),[s,c,t,n,$,N]),K=P.useMemo(()=>!s&&!c&&(isNaN(N)||t===void 0||isNaN(t)||Kc(N,t,n,$)<N||sk("-",N,$)>=t),[s,c,t,n,$,N]);return{...R,validate:B=>_.isValidPartialNumber(B,t,n),increment:G,incrementToMax:te,decrement:J,decrementToMin:H,canIncrement:M,canDecrement:K,minValue:t,maxValue:n,numberValue:N,defaultNumberValue:isNaN(u)?m:u,setNumberValue:h,setInputValue:v,inputValue:y,commit:U}}function sk(e,t,n){let r=e==="+"?t+n:t-n;if(t%1!==0||n%1!==0){const i=t.toString().split("."),a=n.toString().split("."),u=i[1]&&i[1].length||0,l=a[1]&&a[1].length||0,o=Math.pow(10,Math.max(u,l));t=Math.round(t*o),n=Math.round(n*o),r=e==="+"?t+n:t-n,r/=o}return r}function z$e(e){let{channel:t,colorSpace:n,locale:r}=e,i=cb(e.value),a=cb(e.defaultValue),[u,l]=Zu(i,a??null,e.onChange),o=Pj(u,n),[s]=P.useState(u),c=a??s,d=Pj(c,n),h=o.getChannelValue(t),m=o.getChannelRange(t),y=P.useMemo(()=>o.getChannelFormatOptions(t),[o,t]),v=y.style==="percent"&&m.maxValue===100?100:1;return{...jle({locale:r,value:u===null?NaN:h/v,defaultValue:c===null?NaN:d.getChannelValue(t)/v,onChange:S=>{Number.isNaN(S)?l(null):l(o.withChannelValue(t,S*v))},minValue:m.minValue/v,maxValue:m.maxValue/v,step:m.step/v,formatOptions:y}),colorValue:o,defaultColorValue:c,setColorValue:l}}function Pj(e,t){let n=cb("#000");return P.useMemo(()=>{let r=e||n;return t&&r?r.toFormat(t):r},[n,e,t])}function q$e(e){let t=cb(e.value),n=cb(e.defaultValue||"#000000"),[r,i]=Zu(t||void 0,n,e.onChange);return{color:r,setColor(a){a!=null&&i(a||vy("#000000"))}}}const qN=new WeakMap;function j9(e,t){let n=qN.get(e);if(!n)throw new Error("Unknown slider state");return`${n.id}-${t}`}function V$e(e,t,n){let{labelProps:r,fieldProps:i}=fS(e),a=e.orientation==="vertical";var u;qN.set(t,{id:(u=r.id)!==null&&u!==void 0?u:i.id,"aria-describedby":e["aria-describedby"],"aria-details":e["aria-details"]});let{direction:l}=Hi(),{addGlobalListener:o,removeGlobalListener:s}=py();const c=P.useRef(null),d=l==="rtl",h=P.useRef(null),{moveProps:m}=Pne({onMoveStart(){h.current=null},onMove({deltaX:S,deltaY:E}){if(!n.current)return;let{height:C,width:T}=n.current.getBoundingClientRect(),R=a?C:T;h.current==null&&c.current!=null&&(h.current=t.getThumbPercent(c.current)*R);let $=a?E:S;if((a||d)&&($=-$),h.current+=$,c.current!=null&&n.current){const k=ro(h.current/R,0,1);t.setThumbPercent(c.current,k)}},onMoveEnd(){c.current!=null&&(t.setThumbDragging(c.current,!1),c.current=null)}});let y=P.useRef(void 0),v=(S,E,C,T)=>{if(n.current&&!e.isDisabled&&t.values.every((R,$)=>!t.isThumbDragging($))){let{height:R,width:$,top:k,left:F}=n.current.getBoundingClientRect(),L=a?R:$,N=((a?T:C)-(a?k:F))/L;(l==="rtl"||a)&&(N=1-N);let U=t.getPercentValue(N),W,G=t.values.findIndex(J=>U-J<0);if(G===0)W=G;else if(G===-1)W=t.values.length-1;else{let J=t.values[G-1],te=t.values[G];Math.abs(J-U)<Math.abs(te-U)?W=G-1:W=G}W>=0&&t.isThumbEditable(W)?(S.preventDefault(),c.current=W,t.setFocusedThumb(W),y.current=E,t.setThumbDragging(c.current,!0),t.setThumbValue(W,U),o(window,"mouseup",_,!1),o(window,"touchend",_,!1),o(window,"pointerup",_,!1)):c.current=null}},_=S=>{var E,C;((C=S.pointerId)!==null&&C!==void 0?C:(E=S.changedTouches)===null||E===void 0?void 0:E[0].identifier)===y.current&&(c.current!=null&&(t.setThumbDragging(c.current,!1),c.current=null),s(window,"mouseup",_,!1),s(window,"touchend",_,!1),s(window,"pointerup",_,!1))};return"htmlFor"in r&&r.htmlFor&&(delete r.htmlFor,r.onClick=()=>{var S;(S=document.getElementById(j9(t,0)))===null||S===void 0||S.focus(),EN("keyboard")}),{labelProps:r,groupProps:{role:"group",...i},trackProps:Et({onMouseDown(S){S.button!==0||S.altKey||S.ctrlKey||S.metaKey||v(S,void 0,S.clientX,S.clientY)},onPointerDown(S){S.pointerType==="mouse"&&(S.button!==0||S.altKey||S.ctrlKey||S.metaKey)||v(S,S.pointerId,S.clientX,S.clientY)},onTouchStart(S){v(S,S.changedTouches[0].identifier,S.changedTouches[0].clientX,S.changedTouches[0].clientY)},style:{position:"relative",touchAction:"none"}},m),outputProps:{htmlFor:t.values.map((S,E)=>j9(t,E)).join(" "),"aria-live":"off"}}}function U$e(e,t){let{index:n=0,isRequired:r,validationState:i,isInvalid:a,trackRef:u,inputRef:l,orientation:o=t.orientation,name:s,form:c}=e,d=e.isDisabled||t.isDisabled,h=o==="vertical",{direction:m}=Hi(),{addGlobalListener:y,removeGlobalListener:v}=py(),_=qN.get(t);var S;const{labelProps:E,fieldProps:C}=fS({...e,id:j9(t,n),"aria-labelledby":`${_.id} ${(S=e["aria-labelledby"])!==null&&S!==void 0?S:""}`.trim()}),T=t.values[n],R=P.useCallback(()=>{l.current&&_u(l.current)},[l]),$=t.focusedThumb===n;P.useEffect(()=>{$&&R()},[$,R]);let k=m==="rtl",F=P.useRef(null),{keyboardProps:L}=$N({onKeyDown(J){let{getThumbMaxValue:te,getThumbMinValue:H,decrementThumb:M,incrementThumb:K,setThumbValue:X,setThumbDragging:B,pageSize:ne}=t;if(!/^(PageUp|PageDown|Home|End)$/.test(J.key)){J.continuePropagation();return}switch(J.preventDefault(),B(n,!0),J.key){case"PageUp":K(n,ne);break;case"PageDown":M(n,ne);break;case"Home":X(n,H(n));break;case"End":X(n,te(n));break}B(n,!1)}}),{moveProps:j}=Pne({onMoveStart(){F.current=null,t.setThumbDragging(n,!0)},onMove({deltaX:J,deltaY:te,pointerType:H,shiftKey:M}){const{getThumbPercent:K,setThumbPercent:X,decrementThumb:B,incrementThumb:ne,step:oe,pageSize:ie}=t;if(!u.current)return;let{width:de,height:be}=u.current.getBoundingClientRect(),ve=h?be:de;if(F.current==null&&(F.current=K(n)*ve),H==="keyboard")J>0&&k||J<0&&!k||te>0?B(n,M?ie:oe):ne(n,M?ie:oe);else{let pe=h?te:J;(h||k)&&(pe=-pe),F.current+=pe,X(n,ro(F.current/ve,0,1))}},onMoveEnd(){t.setThumbDragging(n,!1)}});t.setThumbEditable(n,!d);const{focusableProps:V}=L0(Et(e,{onFocus:()=>t.setFocusedThumb(n),onBlur:()=>t.setFocusedThumb(void 0)}),l);let q=P.useRef(void 0),N=J=>{R(),q.current=J,t.setThumbDragging(n,!0),y(window,"mouseup",U,!1),y(window,"touchend",U,!1),y(window,"pointerup",U,!1)},U=J=>{var te,H;((H=J.pointerId)!==null&&H!==void 0?H:(te=J.changedTouches)===null||te===void 0?void 0:te[0].identifier)===q.current&&(R(),t.setThumbDragging(n,!1),v(window,"mouseup",U,!1),v(window,"touchend",U,!1),v(window,"pointerup",U,!1))},W=t.getThumbPercent(n);(h||m==="rtl")&&(W=1-W);let G=d?{}:Et(L,j,{onMouseDown:J=>{J.button!==0||J.altKey||J.ctrlKey||J.metaKey||N()},onPointerDown:J=>{J.button!==0||J.altKey||J.ctrlKey||J.metaKey||N(J.pointerId)},onTouchStart:J=>{N(J.changedTouches[0].identifier)}});return my(l,t.defaultValues[n],J=>{t.setThumbValue(n,J)}),{inputProps:Et(V,C,{type:"range",tabIndex:d?void 0:0,min:t.getThumbMinValue(n),max:t.getThumbMaxValue(n),step:t.step,value:T,name:s,form:c,disabled:d,"aria-orientation":o,"aria-valuetext":t.getThumbValueLabel(n),"aria-required":r||void 0,"aria-invalid":a||i==="invalid"||void 0,"aria-errormessage":e["aria-errormessage"],"aria-describedby":[_["aria-describedby"],e["aria-describedby"]].filter(Boolean).join(" "),"aria-details":[_["aria-details"],e["aria-details"]].filter(Boolean).join(" "),onChange:J=>{t.setThumbValue(n,parseFloat(J.target.value))}}),thumbProps:{...G,style:{position:"absolute",[h?"top":"left"]:`${W*100}%`,transform:"translate(-50%, -50%)",touchAction:"none"}},labelProps:E,isDragging:t.isThumbDragging(n),isDisabled:d,isFocused:$}}var Zle={};Zle={Empty:"فارغ"};var Hle={};Hle={Empty:"Изпразни"};var Xle={};Xle={Empty:"Prázdné"};var Yle={};Yle={Empty:"Tom"};var Gle={};Gle={Empty:"Leer"};var Kle={};Kle={Empty:"Άδειο"};var Wle={};Wle={Empty:"Empty"};var Jle={};Jle={Empty:"Vacío"};var eoe={};eoe={Empty:"Tühjenda"};var toe={};toe={Empty:"Tyhjä"};var noe={};noe={Empty:"Vide"};var roe={};roe={Empty:"ריק"};var ioe={};ioe={Empty:"Prazno"};var aoe={};aoe={Empty:"Üres"};var uoe={};uoe={Empty:"Vuoto"};var loe={};loe={Empty:"空"};var ooe={};ooe={Empty:"비어 있음"};var soe={};soe={Empty:"Tuščias"};var coe={};coe={Empty:"Tukšs"};var foe={};foe={Empty:"Tom"};var doe={};doe={Empty:"Leeg"};var hoe={};hoe={Empty:"Pusty"};var poe={};poe={Empty:"Vazio"};var moe={};moe={Empty:"Vazio"};var goe={};goe={Empty:"Gol"};var voe={};voe={Empty:"Не заполнено"};var yoe={};yoe={Empty:"Prázdne"};var boe={};boe={Empty:"Prazen"};var Ooe={};Ooe={Empty:"Prazno"};var xoe={};xoe={Empty:"Tomt"};var Soe={};Soe={Empty:"Boş"};var _oe={};_oe={Empty:"Пусто"};var Eoe={};Eoe={Empty:"空"};var Doe={};Doe={Empty:"空白"};var $oe={};$oe={"ar-AE":Zle,"bg-BG":Hle,"cs-CZ":Xle,"da-DK":Yle,"de-DE":Gle,"el-GR":Kle,"en-US":Wle,"es-ES":Jle,"et-EE":eoe,"fi-FI":toe,"fr-FR":noe,"he-IL":roe,"hr-HR":ioe,"hu-HU":aoe,"it-IT":uoe,"ja-JP":loe,"ko-KR":ooe,"lt-LT":soe,"lv-LV":coe,"nb-NO":foe,"nl-NL":doe,"pl-PL":hoe,"pt-BR":poe,"pt-PT":moe,"ro-RO":goe,"ru-RU":voe,"sk-SK":yoe,"sl-SI":boe,"sr-SP":Ooe,"sv-SE":xoe,"tr-TR":Soe,"uk-UA":_oe,"zh-CN":Eoe,"zh-TW":Doe};function j$e(e){return e&&e.__esModule?e.default:e}function VN(e){const t=P.useRef(void 0);let{value:n,textValue:r,minValue:i,maxValue:a,isDisabled:u,isReadOnly:l,isRequired:o,onIncrement:s,onIncrementPage:c,onDecrement:d,onDecrementPage:h,onDecrementToMin:m,onIncrementToMax:y}=e;const v=Fo(j$e($oe),"@react-aria/spinbutton"),_=()=>clearTimeout(t.current);P.useEffect(()=>()=>_(),[]);let S=V=>{if(!(V.ctrlKey||V.metaKey||V.shiftKey||V.altKey||l||V.nativeEvent.isComposing))switch(V.key){case"PageUp":if(c){V.preventDefault(),c==null||c();break}case"ArrowUp":case"Up":s&&(V.preventDefault(),s==null||s());break;case"PageDown":if(h){V.preventDefault(),h==null||h();break}case"ArrowDown":case"Down":d&&(V.preventDefault(),d==null||d());break;case"Home":m&&(V.preventDefault(),m==null||m());break;case"End":y&&(V.preventDefault(),y==null||y());break}},E=P.useRef(!1),C=()=>{E.current=!0},T=()=>{E.current=!1},R=r===""?v.format("Empty"):(r||`${n}`).replace("-","−");P.useEffect(()=>{E.current&&(f_e("assertive"),j1(R,"assertive"))},[R]);const $=oi(V=>{_(),s==null||s(),t.current=window.setTimeout(()=>{(a===void 0||isNaN(a)||n===void 0||isNaN(n)||n<a)&&$(60)},V)}),k=oi(V=>{_(),d==null||d(),t.current=window.setTimeout(()=>{(i===void 0||isNaN(i)||n===void 0||isNaN(n)||n>i)&&k(60)},V)});let F=V=>{V.preventDefault()},{addGlobalListener:L,removeAllGlobalListeners:j}=py();return{spinButtonProps:{role:"spinbutton","aria-valuenow":n!==void 0&&!isNaN(n)?n:void 0,"aria-valuetext":R,"aria-valuemin":i,"aria-valuemax":a,"aria-disabled":u||void 0,"aria-readonly":l||void 0,"aria-required":o||void 0,onKeyDown:S,onFocus:C,onBlur:T},incrementButtonProps:{onPressStart:()=>{$(400),L(window,"contextmenu",F)},onPressEnd:()=>{_(),j()},onFocus:C,onBlur:T},decrementButtonProps:{onPressStart:()=>{k(400),L(window,"contextmenu",F)},onPressEnd:()=>{_(),j()},onFocus:C,onBlur:T}}}function Z$e(e,t,n){let{isDisabled:r,isReadOnly:i,isRequired:a,isWheelDisabled:u,validationBehavior:l="aria"}=e,{colorValue:o,inputValue:s,increment:c,decrement:d,incrementToMax:h,decrementToMin:m,commit:y}=t,v=pi(),{spinButtonProps:_}=VN({isDisabled:r,isReadOnly:i,isRequired:a,maxValue:16777215,minValue:0,onIncrement:c,onIncrementToMax:h,onDecrement:d,onDecrementToMin:m,value:o?o.toHexInt():void 0,textValue:o?o.toString("hex"):void 0}),[S,E]=P.useState(!1),{focusWithinProps:C}=B0({isDisabled:r,onFocusWithinChange:E}),T=P.useCallback(L=>{Math.abs(L.deltaY)<=Math.abs(L.deltaX)||(L.deltaY>0?c():L.deltaY<0&&d())},[d,c]);Mne({onScroll:T,isDisabled:u||r||i||!S},n);let $=L=>{t.validate(L)&&t.setInputValue(L)},{inputProps:k,...F}=mie({...e,id:v,value:s,defaultValue:"!",validate:void 0,[sb]:t,type:"text",autoComplete:"off",onChange:$},t,n);return my(n,t.defaultColorValue,t.setColorValue),k=Et(k,_,C,{role:"textbox","aria-valuemax":null,"aria-valuemin":null,"aria-valuenow":null,"aria-valuetext":null,autoCorrect:"off",spellCheck:"false",onBlur:y}),l==="native"&&(k["aria-required"]=void 0),{inputProps:k,...F}}function H$e(e){return e&&e.__esModule?e.default:e}function X$e(e){let{color:t,colorName:n}=e,r=t||"#fff0",i=P.useMemo(()=>typeof r=="string"?vy(r):r,[r]),{locale:a}=Hi(),u=Gt(e,{labelable:!0}),l=Fo(H$e(lle),"@react-aria/color"),o=pi(e.id);return n||(n=i.getChannelValue("alpha")===0?l.format("transparent"):i.getColorName(a)),{colorSwatchProps:{...u,role:"img","aria-roledescription":l.format("colorSwatch"),"aria-label":[n,e["aria-label"]||""].filter(Boolean).join(", "),"aria-labelledby":e["aria-labelledby"]?`${o} ${e["aria-labelledby"]}`:void 0,id:o,style:{backgroundColor:i.toString("css"),forcedColorAdjust:"none"}},color:i||null}}var Coe={};Coe={decrease:e=>`خفض ${e.fieldLabel}`,increase:e=>`زيادة ${e.fieldLabel}`,numberField:"حقل رقمي"};var woe={};woe={decrease:e=>`Намаляване ${e.fieldLabel}`,increase:e=>`Усилване ${e.fieldLabel}`,numberField:"Номер на полето"};var Roe={};Roe={decrease:e=>`Snížit ${e.fieldLabel}`,increase:e=>`Zvýšit ${e.fieldLabel}`,numberField:"Číselné pole"};var Aoe={};Aoe={decrease:e=>`Reducer ${e.fieldLabel}`,increase:e=>`Øg ${e.fieldLabel}`,numberField:"Talfelt"};var Toe={};Toe={decrease:e=>`${e.fieldLabel} verringern`,increase:e=>`${e.fieldLabel} erhöhen`,numberField:"Nummernfeld"};var koe={};koe={decrease:e=>`Μείωση ${e.fieldLabel}`,increase:e=>`Αύξηση ${e.fieldLabel}`,numberField:"Πεδίο αριθμού"};var Poe={};Poe={decrease:e=>`Decrease ${e.fieldLabel}`,increase:e=>`Increase ${e.fieldLabel}`,numberField:"Number field"};var Moe={};Moe={decrease:e=>`Reducir ${e.fieldLabel}`,increase:e=>`Aumentar ${e.fieldLabel}`,numberField:"Campo de número"};var Foe={};Foe={decrease:e=>`Vähenda ${e.fieldLabel}`,increase:e=>`Suurenda ${e.fieldLabel}`,numberField:"Numbri väli"};var Noe={};Noe={decrease:e=>`Vähennä ${e.fieldLabel}`,increase:e=>`Lisää ${e.fieldLabel}`,numberField:"Numerokenttä"};var Ioe={};Ioe={decrease:e=>`Diminuer ${e.fieldLabel}`,increase:e=>`Augmenter ${e.fieldLabel}`,numberField:"Champ de nombre"};var Loe={};Loe={decrease:e=>`הקטן ${e.fieldLabel}`,increase:e=>`הגדל ${e.fieldLabel}`,numberField:"שדה מספר"};var Boe={};Boe={decrease:e=>`Smanji ${e.fieldLabel}`,increase:e=>`Povećaj ${e.fieldLabel}`,numberField:"Polje broja"};var Qoe={};Qoe={decrease:e=>`${e.fieldLabel} csökkentése`,increase:e=>`${e.fieldLabel} növelése`,numberField:"Számmező"};var zoe={};zoe={decrease:e=>`Riduci ${e.fieldLabel}`,increase:e=>`Aumenta ${e.fieldLabel}`,numberField:"Campo numero"};var qoe={};qoe={decrease:e=>`${e.fieldLabel}を縮小`,increase:e=>`${e.fieldLabel}を拡大`,numberField:"数値フィールド"};var Voe={};Voe={decrease:e=>`${e.fieldLabel} 감소`,increase:e=>`${e.fieldLabel} 증가`,numberField:"번호 필드"};var Uoe={};Uoe={decrease:e=>`Sumažinti ${e.fieldLabel}`,increase:e=>`Padidinti ${e.fieldLabel}`,numberField:"Numerio laukas"};var joe={};joe={decrease:e=>`Samazināšana ${e.fieldLabel}`,increase:e=>`Palielināšana ${e.fieldLabel}`,numberField:"Skaitļu lauks"};var Zoe={};Zoe={decrease:e=>`Reduser ${e.fieldLabel}`,increase:e=>`Øk ${e.fieldLabel}`,numberField:"Tallfelt"};var Hoe={};Hoe={decrease:e=>`${e.fieldLabel} verlagen`,increase:e=>`${e.fieldLabel} verhogen`,numberField:"Getalveld"};var Xoe={};Xoe={decrease:e=>`Zmniejsz ${e.fieldLabel}`,increase:e=>`Zwiększ ${e.fieldLabel}`,numberField:"Pole numeru"};var Yoe={};Yoe={decrease:e=>`Diminuir ${e.fieldLabel}`,increase:e=>`Aumentar ${e.fieldLabel}`,numberField:"Campo de número"};var Goe={};Goe={decrease:e=>`Diminuir ${e.fieldLabel}`,increase:e=>`Aumentar ${e.fieldLabel}`,numberField:"Campo numérico"};var Koe={};Koe={decrease:e=>`Scădere ${e.fieldLabel}`,increase:e=>`Creștere ${e.fieldLabel}`,numberField:"Câmp numeric"};var Woe={};Woe={decrease:e=>`Уменьшение ${e.fieldLabel}`,increase:e=>`Увеличение ${e.fieldLabel}`,numberField:"Числовое поле"};var Joe={};Joe={decrease:e=>`Znížiť ${e.fieldLabel}`,increase:e=>`Zvýšiť ${e.fieldLabel}`,numberField:"Číselné pole"};var ese={};ese={decrease:e=>`Upadati ${e.fieldLabel}`,increase:e=>`Povečajte ${e.fieldLabel}`,numberField:"Številčno polje"};var tse={};tse={decrease:e=>`Smanji ${e.fieldLabel}`,increase:e=>`Povećaj ${e.fieldLabel}`,numberField:"Polje broja"};var nse={};nse={decrease:e=>`Minska ${e.fieldLabel}`,increase:e=>`Öka ${e.fieldLabel}`,numberField:"Nummerfält"};var rse={};rse={decrease:e=>`${e.fieldLabel} azalt`,increase:e=>`${e.fieldLabel} arttır`,numberField:"Sayı alanı"};var ise={};ise={decrease:e=>`Зменшити ${e.fieldLabel}`,increase:e=>`Збільшити ${e.fieldLabel}`,numberField:"Поле номера"};var ase={};ase={decrease:e=>`降低 ${e.fieldLabel}`,increase:e=>`提高 ${e.fieldLabel}`,numberField:"数字字段"};var use={};use={decrease:e=>`縮小 ${e.fieldLabel}`,increase:e=>`放大 ${e.fieldLabel}`,numberField:"數字欄位"};var lse={};lse={"ar-AE":Coe,"bg-BG":woe,"cs-CZ":Roe,"da-DK":Aoe,"de-DE":Toe,"el-GR":koe,"en-US":Poe,"es-ES":Moe,"et-EE":Foe,"fi-FI":Noe,"fr-FR":Ioe,"he-IL":Loe,"hr-HR":Boe,"hu-HU":Qoe,"it-IT":zoe,"ja-JP":qoe,"ko-KR":Voe,"lt-LT":Uoe,"lv-LV":joe,"nb-NO":Zoe,"nl-NL":Hoe,"pl-PL":Xoe,"pt-BR":Yoe,"pt-PT":Goe,"ro-RO":Koe,"ru-RU":Woe,"sk-SK":Joe,"sl-SI":ese,"sr-SP":tse,"sv-SE":nse,"tr-TR":rse,"uk-UA":ise,"zh-CN":ase,"zh-TW":use};function Y$e(e){return e&&e.__esModule?e.default:e}function ose(e,t,n){let{id:r,decrementAriaLabel:i,incrementAriaLabel:a,isDisabled:u,isReadOnly:l,isRequired:o,minValue:s,maxValue:c,autoFocus:d,label:h,formatOptions:m,onBlur:y=()=>{},onFocus:v,onFocusChange:_,onKeyDown:S,onKeyUp:E,description:C,errorMessage:T,isWheelDisabled:R,...$}=e,{increment:k,incrementToMax:F,decrement:L,decrementToMin:j,numberValue:V,inputValue:q,commit:N,commitValidation:U}=t;const W=Fo(Y$e(lse),"@react-aria/numberfield");let G=pi(r),{focusProps:J}=VC({onBlur(){N()}}),te=HD(m),H=P.useMemo(()=>te.resolvedOptions(),[te]),M=HD({...m,currencySign:void 0}),K=P.useMemo(()=>isNaN(V)?"":M.format(V),[M,V]),{spinButtonProps:X,incrementButtonProps:B,decrementButtonProps:ne}=VN({isDisabled:u,isReadOnly:l,isRequired:o,maxValue:c,minValue:s,onIncrement:k,onIncrementToMax:F,onDecrement:L,onDecrementToMin:j,value:V,textValue:K}),[oe,ie]=P.useState(!1),{focusWithinProps:de}=B0({isDisabled:u,onFocusWithinChange:ie}),be=P.useCallback(qt=>{Math.abs(qt.deltaY)<=Math.abs(qt.deltaX)||(qt.deltaY>0?k():qt.deltaY<0&&L())},[L,k]);Mne({onScroll:be,isDisabled:R||u||l||!oe},n);var pe;let _e=((pe=H.maximumFractionDigits)!==null&&pe!==void 0?pe:0)>0,se=t.minValue===void 0||isNaN(t.minValue)||t.minValue<0,me="numeric";jee()?se?me="text":_e&&(me="decimal"):uS()&&(se?me="numeric":_e&&(me="decimal"));let ge=qt=>{t.validate(qt)&&t.setInputValue(qt)},we=Gt(e),Ne=P.useCallback(qt=>{qt.nativeEvent.isComposing||(qt.key==="Enter"?(N(),U()):qt.continuePropagation())},[N,U]),{isInvalid:Re,validationErrors:et,validationDetails:tt}=t.displayValidation,{labelProps:Oe,inputProps:$e,descriptionProps:Ae,errorMessageProps:Ue}=mie({...$,...we,name:void 0,form:void 0,label:h,autoFocus:d,isDisabled:u,isReadOnly:l,isRequired:o,validate:void 0,[sb]:t,value:q,defaultValue:"!",autoComplete:"off","aria-label":e["aria-label"]||void 0,"aria-labelledby":e["aria-labelledby"]||void 0,id:G,type:"text",inputMode:me,onChange:ge,onBlur:y,onFocus:v,onFocusChange:_,onKeyDown:P.useMemo(()=>rh(Ne,S),[Ne,S]),onKeyUp:E,description:C,errorMessage:T},t,n);my(n,t.defaultNumberValue,t.setNumberValue);let Ze=Et(X,J,$e,{role:null,"aria-roledescription":Db()?null:W.format("numberField"),"aria-valuemax":null,"aria-valuemin":null,"aria-valuenow":null,"aria-valuetext":null,autoCorrect:"off",spellCheck:"false"});e.validationBehavior==="native"&&(Ze["aria-required"]=void 0);let Ye=qt=>{var zt;document.activeElement!==n.current&&(qt.pointerType==="mouse"?(zt=n.current)===null||zt===void 0||zt.focus():qt.target.focus())},Me=e["aria-label"]||(typeof e.label=="string"?e.label:""),ze;Me||(ze=e.label!=null?Oe.id:e["aria-labelledby"]);let st=pi(),Ot=pi(),Nt=Et(B,{"aria-label":a||W.format("increase",{fieldLabel:Me}).trim(),id:ze&&!a?st:null,"aria-labelledby":ze&&!a?`${st} ${ze}`:null,"aria-controls":G,excludeFromTabOrder:!0,preventFocusOnPress:!0,allowFocusWhenDisabled:!0,isDisabled:!t.canIncrement,onPressStart:Ye}),gt=Et(ne,{"aria-label":i||W.format("decrease",{fieldLabel:Me}).trim(),id:ze&&!i?Ot:null,"aria-labelledby":ze&&!i?`${Ot} ${ze}`:null,"aria-controls":G,excludeFromTabOrder:!0,preventFocusOnPress:!0,allowFocusWhenDisabled:!0,isDisabled:!t.canDecrement,onPressStart:Ye});return{groupProps:{...de,role:"group","aria-disabled":u,"aria-invalid":Re?"true":void 0},labelProps:Oe,inputProps:Ze,incrementButtonProps:Nt,decrementButtonProps:gt,errorMessageProps:Ue,descriptionProps:Ae,isInvalid:Re,validationErrors:et,validationDetails:tt}}function G$e(e,t,n){let{locale:r}=Hi();return ose({...e,value:void 0,defaultValue:void 0,onChange:void 0,validate:void 0,"aria-label":e["aria-label"]||(e.label||e["aria-labelledby"]?void 0:t.colorValue.getChannelName(e.channel,r))},t,n)}var sse={};sse={calendar:"التقويم",day:"يوم",dayPeriod:"ص/م",endDate:"تاريخ الانتهاء",era:"العصر",hour:"الساعات",minute:"الدقائق",month:"الشهر",second:"الثواني",selectedDateDescription:e=>`تاريخ محدد: ${e.date}`,selectedRangeDescription:e=>`المدى الزمني المحدد: ${e.startDate} إلى ${e.endDate}`,selectedTimeDescription:e=>`الوقت المحدد: ${e.time}`,startDate:"تاريخ البدء",timeZoneName:"التوقيت",weekday:"اليوم",year:"السنة"};var cse={};cse={calendar:"Календар",day:"ден",dayPeriod:"пр.об./сл.об.",endDate:"Крайна дата",era:"ера",hour:"час",minute:"минута",month:"месец",second:"секунда",selectedDateDescription:e=>`Избрана дата: ${e.date}`,selectedRangeDescription:e=>`Избран диапазон: ${e.startDate} до ${e.endDate}`,selectedTimeDescription:e=>`Избрано време: ${e.time}`,startDate:"Начална дата",timeZoneName:"часова зона",weekday:"ден от седмицата",year:"година"};var fse={};fse={calendar:"Kalendář",day:"den",dayPeriod:"část dne",endDate:"Konečné datum",era:"letopočet",hour:"hodina",minute:"minuta",month:"měsíc",second:"sekunda",selectedDateDescription:e=>`Vybrané datum: ${e.date}`,selectedRangeDescription:e=>`Vybrané období: ${e.startDate} až ${e.endDate}`,selectedTimeDescription:e=>`Vybraný čas: ${e.time}`,startDate:"Počáteční datum",timeZoneName:"časové pásmo",weekday:"den v týdnu",year:"rok"};var dse={};dse={calendar:"Kalender",day:"dag",dayPeriod:"AM/PM",endDate:"Slutdato",era:"æra",hour:"time",minute:"minut",month:"måned",second:"sekund",selectedDateDescription:e=>`Valgt dato: ${e.date}`,selectedRangeDescription:e=>`Valgt interval: ${e.startDate} til ${e.endDate}`,selectedTimeDescription:e=>`Valgt tidspunkt: ${e.time}`,startDate:"Startdato",timeZoneName:"tidszone",weekday:"ugedag",year:"år"};var hse={};hse={calendar:"Kalender",day:"Tag",dayPeriod:"Tageshälfte",endDate:"Enddatum",era:"Epoche",hour:"Stunde",minute:"Minute",month:"Monat",second:"Sekunde",selectedDateDescription:e=>`Ausgewähltes Datum: ${e.date}`,selectedRangeDescription:e=>`Ausgewählter Bereich: ${e.startDate} bis ${e.endDate}`,selectedTimeDescription:e=>`Ausgewählte Zeit: ${e.time}`,startDate:"Startdatum",timeZoneName:"Zeitzone",weekday:"Wochentag",year:"Jahr"};var pse={};pse={calendar:"Ημερολόγιο",day:"ημέρα",dayPeriod:"π.μ./μ.μ.",endDate:"Ημερομηνία λήξης",era:"περίοδος",hour:"ώρα",minute:"λεπτό",month:"μήνας",second:"δευτερόλεπτο",selectedDateDescription:e=>`Επιλεγμένη ημερομηνία: ${e.date}`,selectedRangeDescription:e=>`Επιλεγμένο εύρος: ${e.startDate} έως ${e.endDate}`,selectedTimeDescription:e=>`Επιλεγμένη ώρα: ${e.time}`,startDate:"Ημερομηνία έναρξης",timeZoneName:"ζώνη ώρας",weekday:"καθημερινή",year:"έτος"};var mse={};mse={era:"era",year:"year",month:"month",day:"day",hour:"hour",minute:"minute",second:"second",dayPeriod:"AM/PM",calendar:"Calendar",startDate:"Start Date",endDate:"End Date",weekday:"day of the week",timeZoneName:"time zone",selectedDateDescription:e=>`Selected Date: ${e.date}`,selectedRangeDescription:e=>`Selected Range: ${e.startDate} to ${e.endDate}`,selectedTimeDescription:e=>`Selected Time: ${e.time}`};var gse={};gse={calendar:"Calendario",day:"día",dayPeriod:"a. m./p. m.",endDate:"Fecha final",era:"era",hour:"hora",minute:"minuto",month:"mes",second:"segundo",selectedDateDescription:e=>`Fecha seleccionada: ${e.date}`,selectedRangeDescription:e=>`Rango seleccionado: ${e.startDate} a ${e.endDate}`,selectedTimeDescription:e=>`Hora seleccionada: ${e.time}`,startDate:"Fecha de inicio",timeZoneName:"zona horaria",weekday:"día de la semana",year:"año"};var vse={};vse={calendar:"Kalender",day:"päev",dayPeriod:"enne/pärast lõunat",endDate:"Lõppkuupäev",era:"ajastu",hour:"tund",minute:"minut",month:"kuu",second:"sekund",selectedDateDescription:e=>`Valitud kuupäev: ${e.date}`,selectedRangeDescription:e=>`Valitud vahemik: ${e.startDate} kuni ${e.endDate}`,selectedTimeDescription:e=>`Valitud aeg: ${e.time}`,startDate:"Alguskuupäev",timeZoneName:"ajavöönd",weekday:"nädalapäev",year:"aasta"};var yse={};yse={calendar:"Kalenteri",day:"päivä",dayPeriod:"vuorokaudenaika",endDate:"Päättymispäivä",era:"aikakausi",hour:"tunti",minute:"minuutti",month:"kuukausi",second:"sekunti",selectedDateDescription:e=>`Valittu päivämäärä: ${e.date}`,selectedRangeDescription:e=>`Valittu aikaväli: ${e.startDate} – ${e.endDate}`,selectedTimeDescription:e=>`Valittu aika: ${e.time}`,startDate:"Alkamispäivä",timeZoneName:"aikavyöhyke",weekday:"viikonpäivä",year:"vuosi"};var bse={};bse={calendar:"Calendrier",day:"jour",dayPeriod:"cadran",endDate:"Date de fin",era:"ère",hour:"heure",minute:"minute",month:"mois",second:"seconde",selectedDateDescription:e=>`Date sélectionnée : ${e.date}`,selectedRangeDescription:e=>`Plage sélectionnée : ${e.startDate} au ${e.endDate}`,selectedTimeDescription:e=>`Heure choisie : ${e.time}`,startDate:"Date de début",timeZoneName:"fuseau horaire",weekday:"jour de la semaine",year:"année"};var Ose={};Ose={calendar:"לוח שנה",day:"יום",dayPeriod:"לפנה״צ/אחה״צ",endDate:"תאריך סיום",era:"תקופה",hour:"שעה",minute:"דקה",month:"חודש",second:"שנייה",selectedDateDescription:e=>`תאריך נבחר: ${e.date}`,selectedRangeDescription:e=>`טווח נבחר: ${e.startDate} עד ${e.endDate}`,selectedTimeDescription:e=>`זמן נבחר: ${e.time}`,startDate:"תאריך התחלה",timeZoneName:"אזור זמן",weekday:"יום בשבוע",year:"שנה"};var xse={};xse={calendar:"Kalendar",day:"dan",dayPeriod:"AM/PM",endDate:"Datum završetka",era:"era",hour:"sat",minute:"minuta",month:"mjesec",second:"sekunda",selectedDateDescription:e=>`Odabrani datum: ${e.date}`,selectedRangeDescription:e=>`Odabrani raspon: ${e.startDate} do ${e.endDate}`,selectedTimeDescription:e=>`Odabrano vrijeme: ${e.time}`,startDate:"Datum početka",timeZoneName:"vremenska zona",weekday:"dan u tjednu",year:"godina"};var Sse={};Sse={calendar:"Naptár",day:"nap",dayPeriod:"napszak",endDate:"Befejező dátum",era:"éra",hour:"óra",minute:"perc",month:"hónap",second:"másodperc",selectedDateDescription:e=>`Kijelölt dátum: ${e.date}`,selectedRangeDescription:e=>`Kijelölt tartomány: ${e.startDate}–${e.endDate}`,selectedTimeDescription:e=>`Kijelölt idő: ${e.time}`,startDate:"Kezdő dátum",timeZoneName:"időzóna",weekday:"hét napja",year:"év"};var _se={};_se={calendar:"Calendario",day:"giorno",dayPeriod:"AM/PM",endDate:"Data finale",era:"era",hour:"ora",minute:"minuto",month:"mese",second:"secondo",selectedDateDescription:e=>`Data selezionata: ${e.date}`,selectedRangeDescription:e=>`Intervallo selezionato: da ${e.startDate} a ${e.endDate}`,selectedTimeDescription:e=>`Ora selezionata: ${e.time}`,startDate:"Data iniziale",timeZoneName:"fuso orario",weekday:"giorno della settimana",year:"anno"};var Ese={};Ese={calendar:"カレンダー",day:"日",dayPeriod:"午前/午後",endDate:"終了日",era:"時代",hour:"時",minute:"分",month:"月",second:"秒",selectedDateDescription:e=>`選択した日付 : ${e.date}`,selectedRangeDescription:e=>`選択範囲 : ${e.startDate} から ${e.endDate}`,selectedTimeDescription:e=>`選択した時間 : ${e.time}`,startDate:"開始日",timeZoneName:"タイムゾーン",weekday:"曜日",year:"年"};var Dse={};Dse={calendar:"달력",day:"일",dayPeriod:"오전/오후",endDate:"종료일",era:"연호",hour:"시",minute:"분",month:"월",second:"초",selectedDateDescription:e=>`선택 일자: ${e.date}`,selectedRangeDescription:e=>`선택 범위: ${e.startDate} ~ ${e.endDate}`,selectedTimeDescription:e=>`선택 시간: ${e.time}`,startDate:"시작일",timeZoneName:"시간대",weekday:"요일",year:"년"};var $se={};$se={calendar:"Kalendorius",day:"diena",dayPeriod:"iki pietų / po pietų",endDate:"Pabaigos data",era:"era",hour:"valanda",minute:"minutė",month:"mėnuo",second:"sekundė",selectedDateDescription:e=>`Pasirinkta data: ${e.date}`,selectedRangeDescription:e=>`Pasirinktas intervalas: nuo ${e.startDate} iki ${e.endDate}`,selectedTimeDescription:e=>`Pasirinktas laikas: ${e.time}`,startDate:"Pradžios data",timeZoneName:"laiko juosta",weekday:"savaitės diena",year:"metai"};var Cse={};Cse={calendar:"Kalendārs",day:"diena",dayPeriod:"priekšpusdienā/pēcpusdienā",endDate:"Beigu datums",era:"ēra",hour:"stundas",minute:"minūtes",month:"mēnesis",second:"sekundes",selectedDateDescription:e=>`Atlasītais datums: ${e.date}`,selectedRangeDescription:e=>`Atlasītais diapazons: no ${e.startDate} līdz ${e.endDate}`,selectedTimeDescription:e=>`Atlasītais laiks: ${e.time}`,startDate:"Sākuma datums",timeZoneName:"laika josla",weekday:"nedēļas diena",year:"gads"};var wse={};wse={calendar:"Kalender",day:"dag",dayPeriod:"a.m./p.m.",endDate:"Sluttdato",era:"tidsalder",hour:"time",minute:"minutt",month:"måned",second:"sekund",selectedDateDescription:e=>`Valgt dato: ${e.date}`,selectedRangeDescription:e=>`Valgt område: ${e.startDate} til ${e.endDate}`,selectedTimeDescription:e=>`Valgt tid: ${e.time}`,startDate:"Startdato",timeZoneName:"tidssone",weekday:"ukedag",year:"år"};var Rse={};Rse={calendar:"Kalender",day:"dag",dayPeriod:"a.m./p.m.",endDate:"Einddatum",era:"tijdperk",hour:"uur",minute:"minuut",month:"maand",second:"seconde",selectedDateDescription:e=>`Geselecteerde datum: ${e.date}`,selectedRangeDescription:e=>`Geselecteerd bereik: ${e.startDate} tot ${e.endDate}`,selectedTimeDescription:e=>`Geselecteerde tijd: ${e.time}`,startDate:"Startdatum",timeZoneName:"tijdzone",weekday:"dag van de week",year:"jaar"};var Ase={};Ase={calendar:"Kalendarz",day:"dzień",dayPeriod:"rano / po południu / wieczorem",endDate:"Data końcowa",era:"era",hour:"godzina",minute:"minuta",month:"miesiąc",second:"sekunda",selectedDateDescription:e=>`Wybrana data: ${e.date}`,selectedRangeDescription:e=>`Wybrany zakres: ${e.startDate} do ${e.endDate}`,selectedTimeDescription:e=>`Wybrany czas: ${e.time}`,startDate:"Data początkowa",timeZoneName:"strefa czasowa",weekday:"dzień tygodnia",year:"rok"};var Tse={};Tse={calendar:"Calendário",day:"dia",dayPeriod:"AM/PM",endDate:"Data final",era:"era",hour:"hora",minute:"minuto",month:"mês",second:"segundo",selectedDateDescription:e=>`Data selecionada: ${e.date}`,selectedRangeDescription:e=>`Intervalo selecionado: ${e.startDate} a ${e.endDate}`,selectedTimeDescription:e=>`Hora selecionada: ${e.time}`,startDate:"Data inicial",timeZoneName:"fuso horário",weekday:"dia da semana",year:"ano"};var kse={};kse={calendar:"Calendário",day:"dia",dayPeriod:"am/pm",endDate:"Data de Término",era:"era",hour:"hora",minute:"minuto",month:"mês",second:"segundo",selectedDateDescription:e=>`Data selecionada: ${e.date}`,selectedRangeDescription:e=>`Intervalo selecionado: ${e.startDate} a ${e.endDate}`,selectedTimeDescription:e=>`Hora selecionada: ${e.time}`,startDate:"Data de Início",timeZoneName:"fuso horário",weekday:"dia da semana",year:"ano"};var Pse={};Pse={calendar:"Calendar",day:"zi",dayPeriod:"a.m/p.m.",endDate:"Dată final",era:"eră",hour:"oră",minute:"minut",month:"lună",second:"secundă",selectedDateDescription:e=>`Dată selectată: ${e.date}`,selectedRangeDescription:e=>`Interval selectat: de la ${e.startDate} până la ${e.endDate}`,selectedTimeDescription:e=>`Ora selectată: ${e.time}`,startDate:"Dată început",timeZoneName:"fus orar",weekday:"ziua din săptămână",year:"an"};var Mse={};Mse={calendar:"Календарь",day:"день",dayPeriod:"AM/PM",endDate:"Дата окончания",era:"эра",hour:"час",minute:"минута",month:"месяц",second:"секунда",selectedDateDescription:e=>`Выбранная дата: ${e.date}`,selectedRangeDescription:e=>`Выбранный диапазон: с ${e.startDate} по ${e.endDate}`,selectedTimeDescription:e=>`Выбранное время: ${e.time}`,startDate:"Дата начала",timeZoneName:"часовой пояс",weekday:"день недели",year:"год"};var Fse={};Fse={calendar:"Kalendár",day:"deň",dayPeriod:"AM/PM",endDate:"Dátum ukončenia",era:"letopočet",hour:"hodina",minute:"minúta",month:"mesiac",second:"sekunda",selectedDateDescription:e=>`Vybratý dátum: ${e.date}`,selectedRangeDescription:e=>`Vybratý rozsah: od ${e.startDate} do ${e.endDate}`,selectedTimeDescription:e=>`Vybratý čas: ${e.time}`,startDate:"Dátum začatia",timeZoneName:"časové pásmo",weekday:"deň týždňa",year:"rok"};var Nse={};Nse={calendar:"Koledar",day:"dan",dayPeriod:"dop/pop",endDate:"Datum konca",era:"doba",hour:"ura",minute:"minuta",month:"mesec",second:"sekunda",selectedDateDescription:e=>`Izbrani datum: ${e.date}`,selectedRangeDescription:e=>`Izbrano območje: ${e.startDate} do ${e.endDate}`,selectedTimeDescription:e=>`Izbrani čas: ${e.time}`,startDate:"Datum začetka",timeZoneName:"časovni pas",weekday:"dan v tednu",year:"leto"};var Ise={};Ise={calendar:"Kalendar",day:"дан",dayPeriod:"пре подне/по подне",endDate:"Datum završetka",era:"ера",hour:"сат",minute:"минут",month:"месец",second:"секунд",selectedDateDescription:e=>`Izabrani datum: ${e.date}`,selectedRangeDescription:e=>`Izabrani opseg: od ${e.startDate} do ${e.endDate}`,selectedTimeDescription:e=>`Izabrano vreme: ${e.time}`,startDate:"Datum početka",timeZoneName:"временска зона",weekday:"дан у недељи",year:"година"};var Lse={};Lse={calendar:"Kalender",day:"dag",dayPeriod:"fm/em",endDate:"Slutdatum",era:"era",hour:"timme",minute:"minut",month:"månad",second:"sekund",selectedDateDescription:e=>`Valt datum: ${e.date}`,selectedRangeDescription:e=>`Valt intervall: ${e.startDate} till ${e.endDate}`,selectedTimeDescription:e=>`Vald tid: ${e.time}`,startDate:"Startdatum",timeZoneName:"tidszon",weekday:"veckodag",year:"år"};var Bse={};Bse={calendar:"Takvim",day:"gün",dayPeriod:"ÖÖ/ÖS",endDate:"Bitiş Tarihi",era:"çağ",hour:"saat",minute:"dakika",month:"ay",second:"saniye",selectedDateDescription:e=>`Seçilen Tarih: ${e.date}`,selectedRangeDescription:e=>`Seçilen Aralık: ${e.startDate} - ${e.endDate}`,selectedTimeDescription:e=>`Seçilen Zaman: ${e.time}`,startDate:"Başlangıç Tarihi",timeZoneName:"saat dilimi",weekday:"haftanın günü",year:"yıl"};var Qse={};Qse={calendar:"Календар",day:"день",dayPeriod:"дп/пп",endDate:"Дата завершення",era:"ера",hour:"година",minute:"хвилина",month:"місяць",second:"секунда",selectedDateDescription:e=>`Вибрана дата: ${e.date}`,selectedRangeDescription:e=>`Вибраний діапазон: ${e.startDate} — ${e.endDate}`,selectedTimeDescription:e=>`Вибраний час: ${e.time}`,startDate:"Дата початку",timeZoneName:"часовий пояс",weekday:"день тижня",year:"рік"};var zse={};zse={calendar:"日历",day:"日",dayPeriod:"上午/下午",endDate:"结束日期",era:"纪元",hour:"小时",minute:"分钟",month:"月",second:"秒",selectedDateDescription:e=>`选定的日期：${e.date}`,selectedRangeDescription:e=>`选定的范围：${e.startDate} 至 ${e.endDate}`,selectedTimeDescription:e=>`选定的时间：${e.time}`,startDate:"开始日期",timeZoneName:"时区",weekday:"工作日",year:"年"};var qse={};qse={calendar:"日曆",day:"日",dayPeriod:"上午/下午",endDate:"結束日期",era:"纪元",hour:"小时",minute:"分钟",month:"月",second:"秒",selectedDateDescription:e=>`選定的日期：${e.date}`,selectedRangeDescription:e=>`選定的範圍：${e.startDate} 至 ${e.endDate}`,selectedTimeDescription:e=>`選定的時間：${e.time}`,startDate:"開始日期",timeZoneName:"时区",weekday:"工作日",year:"年"};var UN={};UN={"ar-AE":sse,"bg-BG":cse,"cs-CZ":fse,"da-DK":dse,"de-DE":hse,"el-GR":pse,"en-US":mse,"es-ES":gse,"et-EE":vse,"fi-FI":yse,"fr-FR":bse,"he-IL":Ose,"hr-HR":xse,"hu-HU":Sse,"it-IT":_se,"ja-JP":Ese,"ko-KR":Dse,"lt-LT":$se,"lv-LV":Cse,"nb-NO":wse,"nl-NL":Rse,"pl-PL":Ase,"pt-BR":Tse,"pt-PT":kse,"ro-RO":Pse,"ru-RU":Mse,"sk-SK":Fse,"sl-SI":Nse,"sr-SP":Ise,"sv-SE":Lse,"tr-TR":Bse,"uk-UA":Qse,"zh-CN":zse,"zh-TW":qse};function K$e(e,t,n){let{direction:r}=Hi(),i=P.useMemo(()=>wN(t),[t]),a=o=>{if(o.currentTarget.contains(o.target)&&(o.altKey&&(o.key==="ArrowDown"||o.key==="ArrowUp")&&"setOpen"in e&&(o.preventDefault(),o.stopPropagation(),e.setOpen(!0)),!n))switch(o.key){case"ArrowLeft":if(o.preventDefault(),o.stopPropagation(),r==="rtl"){if(t.current){let s=o.target,c=Mj(t.current,s.getBoundingClientRect().left,-1);c&&c.focus()}}else i.focusPrevious();break;case"ArrowRight":if(o.preventDefault(),o.stopPropagation(),r==="rtl"){if(t.current){let s=o.target,c=Mj(t.current,s.getBoundingClientRect().left,1);c&&c.focus()}}else i.focusNext();break}},u=()=>{var o;if(!t.current)return;let s=(o=window.event)===null||o===void 0?void 0:o.target,c=Cl(t.current,{tabbable:!0});if(s&&(c.currentNode=s,s=c.previousNode()),!s){let d;do d=c.lastChild(),d&&(s=d);while(d)}for(;s!=null&&s.hasAttribute("data-placeholder");){let d=c.previousNode();if(d&&d.hasAttribute("data-placeholder"))s=d;else break}s&&s.focus()},{pressProps:l}=up({preventFocusOnPress:!0,allowTextSelectionOnPress:!0,onPressStart(o){o.pointerType==="mouse"&&u()},onPress(o){(o.pointerType==="touch"||o.pointerType==="pen")&&u()}});return Et(l,{onKeyDown:a})}function Mj(e,t,n){let r=Cl(e,{tabbable:!0}),i=r.nextNode(),a=null,u=1/0;for(;i;){let o=i.getBoundingClientRect().left-t,s=Math.abs(o);Math.sign(o)===n&&s<u&&(a=i,u=s),i=r.nextNode()}return a}function W$e(e){return e&&e.__esModule?e.default:e}const Vse=new WeakMap,ck="__role_"+Date.now(),J$e="__focusManager_"+Date.now();function jN(e,t,n){var r;let{isInvalid:i,validationErrors:a,validationDetails:u}=t.displayValidation,{labelProps:l,fieldProps:o,descriptionProps:s,errorMessageProps:c}=dS({...e,labelElementType:"span",isInvalid:i,errorMessage:e.errorMessage||a}),d=P.useRef(null),{focusWithinProps:h}=B0({...e,onFocusWithin(j){var V;d.current=t.value,(V=e.onFocus)===null||V===void 0||V.call(e,j)},onBlurWithin:j=>{var V;t.confirmPlaceholder(),t.value!==d.current&&t.commitValidation(),(V=e.onBlur)===null||V===void 0||V.call(e,j)},onFocusWithinChange:e.onFocusChange}),m=Fo(W$e(UN),"@react-aria/datepicker"),y=t.maxGranularity==="hour"?"selectedTimeDescription":"selectedDateDescription",v=t.maxGranularity==="hour"?"time":"date",_=t.value?m.format(y,{[v]:t.formatValue({month:"long"})}):"",S=NC(_),E=e[ck]==="presentation"?o["aria-describedby"]:[S["aria-describedby"],o["aria-describedby"]].filter(Boolean).join(" ")||void 0,C=e[J$e],T=P.useMemo(()=>C||wN(n),[C,n]),R=K$e(t,n,e[ck]==="presentation");Vse.set(t,{ariaLabel:e["aria-label"],ariaLabelledBy:[l.id,e["aria-labelledby"]].filter(Boolean).join(" ")||void 0,ariaDescribedBy:E,focusManager:T});let $=P.useRef(e.autoFocus),k;e[ck]==="presentation"?k={role:"presentation"}:k=Et(o,{role:"group","aria-disabled":e.isDisabled||void 0,"aria-describedby":E}),P.useEffect(()=>{$.current&&T.focusFirst(),$.current=!1},[T]),my(e.inputRef,t.defaultValue,t.setValue),pS({...e,focus(){T.focusFirst()}},t,e.inputRef);let F={type:"hidden",name:e.name,form:e.form,value:((r=t.value)===null||r===void 0?void 0:r.toString())||"",disabled:e.isDisabled};e.validationBehavior==="native"&&(F.type="text",F.hidden=!0,F.required=e.isRequired,F.onChange=()=>{});let L=Gt(e);return{labelProps:{...l,onClick:()=>{T.focusFirst()}},fieldProps:Et(L,k,R,h,{onKeyDown(j){e.onKeyDown&&e.onKeyDown(j)},onKeyUp(j){e.onKeyUp&&e.onKeyUp(j)},style:{unicodeBidi:"isolate"}}),inputProps:F,descriptionProps:s,errorMessageProps:c,isInvalid:i,validationErrors:a,validationDetails:u}}function eCe(e,t,n){var r;let i=jN(e,t,n);return i.inputProps.value=((r=t.timeValue)===null||r===void 0?void 0:r.toString())||"",i}function tCe(e){return e&&e.__esModule?e.default:e}function nCe(){let{locale:e}=Hi(),t=Vte(tCe(UN),"@react-aria/datepicker");return P.useMemo(()=>{try{return new Intl.DisplayNames(e,{type:"dateTimeField"})}catch{return new rCe(e,t)}},[e,t])}class rCe{of(t){return this.dictionary.getStringForLocale(t,this.locale)}constructor(t,n){this.locale=t,this.dictionary=n}}function iCe(e,t,n){let r=P.useRef(""),{locale:i,direction:a}=Hi(),u=nCe(),{ariaLabel:l,ariaLabelledBy:o,ariaDescribedBy:s,focusManager:c}=Vse.get(t),d=e.isPlaceholder?"":e.text,h=P.useMemo(()=>t.dateFormatter.resolvedOptions(),[t.dateFormatter]),m=B_({month:"long",timeZone:h.timeZone}),y=B_({hour:"numeric",hour12:h.hour12,timeZone:h.timeZone});if(e.type==="month"&&!e.isPlaceholder){let M=m.format(t.dateValue);d=M!==d?`${d} – ${M}`:M}else e.type==="hour"&&!e.isPlaceholder&&(d=y.format(t.dateValue));let{spinButtonProps:v}=VN({value:e.value,textValue:d,minValue:e.minValue,maxValue:e.maxValue,isDisabled:t.isDisabled,isReadOnly:t.isReadOnly||!e.isEditable,isRequired:t.isRequired,onIncrement:()=>{r.current="",t.increment(e.type)},onDecrement:()=>{r.current="",t.decrement(e.type)},onIncrementPage:()=>{r.current="",t.incrementPage(e.type)},onDecrementPage:()=>{r.current="",t.decrementPage(e.type)},onIncrementToMax:()=>{r.current="",e.maxValue!==void 0&&t.setSegment(e.type,e.maxValue)},onDecrementToMin:()=>{r.current="",e.minValue!==void 0&&t.setSegment(e.type,e.minValue)}}),_=P.useMemo(()=>new xN(i,{maximumFractionDigits:0}),[i]),S=()=>{if(e.text===e.placeholder&&c.focusPrevious(),_.isValidPartialNumber(e.text)&&!t.isReadOnly&&!e.isPlaceholder){let M=e.text.slice(0,-1),K=_.parse(M);M=K===0?"":M,M.length===0||K===0?t.clearSegment(e.type):t.setSegment(e.type,K),r.current=M}else e.type==="dayPeriod"&&t.clearSegment(e.type)},E=M=>{if(M.key==="a"&&(sg()?M.metaKey:M.ctrlKey)&&M.preventDefault(),!(M.ctrlKey||M.metaKey||M.shiftKey||M.altKey))switch(M.key){case"Backspace":case"Delete":M.preventDefault(),M.stopPropagation(),S();break}},{startsWith:C}=xne({sensitivity:"base"}),T=B_({hour:"numeric",hour12:!0}),R=P.useMemo(()=>{let M=new Date;return M.setHours(0),T.formatToParts(M).find(K=>K.type==="dayPeriod").value},[T]),$=P.useMemo(()=>{let M=new Date;return M.setHours(12),T.formatToParts(M).find(K=>K.type==="dayPeriod").value},[T]),k=B_({year:"numeric",era:"narrow",timeZone:"UTC"}),F=P.useMemo(()=>{if(e.type!=="era")return[];let M=sc(new ju(1,1,1),t.calendar),K=t.calendar.getEras().map(B=>{let ne=M.set({year:1,month:1,day:1,era:B}).toDate("UTC"),ie=k.formatToParts(ne).find(de=>de.type==="era").value;return{era:B,formatted:ie}}),X=aCe(K.map(B=>B.formatted));if(X)for(let B of K)B.formatted=B.formatted.slice(X);return K},[k,t.calendar,e.type]),L=M=>{if(t.isDisabled||t.isReadOnly)return;let K=r.current+M;switch(e.type){case"dayPeriod":if(C(R,M))t.setSegment("dayPeriod",0);else if(C($,M))t.setSegment("dayPeriod",12);else break;c.focusNext();break;case"era":{let X=F.find(B=>C(B.formatted,M));X&&(t.setSegment("era",X.era),c.focusNext());break}case"day":case"hour":case"minute":case"second":case"month":case"year":{if(!_.isValidPartialNumber(K))return;let X=_.parse(K),B=X,ne=e.minValue===0;if(e.type==="hour"&&t.dateFormatter.resolvedOptions().hour12){switch(t.dateFormatter.resolvedOptions().hourCycle){case"h11":X>11&&(B=_.parse(M));break;case"h12":ne=!1,X>12&&(B=_.parse(M));break}e.value!==void 0&&e.value>=12&&X>1&&(X+=12)}else e.maxValue!==void 0&&X>e.maxValue&&(B=_.parse(M));if(isNaN(X))return;let oe=B!==0||ne;oe&&t.setSegment(e.type,B),e.maxValue!==void 0&&(+(X+"0")>e.maxValue||K.length>=String(e.maxValue).length)?(r.current="",oe&&c.focusNext()):r.current=K;break}}},j=()=>{r.current="",n.current&&Vm(n.current,{containingElement:g0(n.current)});let M=window.getSelection();M==null||M.collapse(n.current)},V=P.useRef(typeof document<"u"?document:null);Xd(V,"selectionchange",()=>{var M;let K=window.getSelection();K!=null&&K.anchorNode&&(!((M=n.current)===null||M===void 0)&&M.contains(K==null?void 0:K.anchorNode))&&K.collapse(n.current)});let q=P.useRef("");Xd(n,"beforeinput",M=>{if(n.current)switch(M.preventDefault(),M.inputType){case"deleteContentBackward":case"deleteContentForward":_.isValidPartialNumber(e.text)&&!t.isReadOnly&&S();break;case"insertCompositionText":q.current=n.current.textContent,n.current.textContent=n.current.textContent;break;default:M.data!=null&&L(M.data);break}}),Xd(n,"input",M=>{let{inputType:K,data:X}=M;switch(K){case"insertCompositionText":n.current&&(n.current.textContent=q.current),X!=null&&(C(R,X)||C($,X))&&L(X);break}}),qr(()=>{let M=n.current;return()=>{document.activeElement===M&&(c.focusPrevious()||c.focusNext())}},[n,c]);let N=Db()||e.type==="timeZoneName"?{role:"textbox","aria-valuemax":null,"aria-valuemin":null,"aria-valuetext":null,"aria-valuenow":null}:{},U=P.useMemo(()=>t.segments.find(M=>M.isEditable),[t.segments]);e!==U&&!t.isInvalid&&(s=void 0);let W=pi(),G=!t.isDisabled&&!t.isReadOnly&&e.isEditable,J=e.type==="literal"?"":u.of(e.type),te=Yv({"aria-label":`${J}${l?`, ${l}`:""}${o?", ":""}`,"aria-labelledby":o});if(e.type==="literal")return{segmentProps:{"aria-hidden":!0}};let H={caretColor:"transparent"};if(a==="rtl"){H.unicodeBidi="embed";let M=h[e.type];(M==="numeric"||M==="2-digit")&&(H.direction="ltr")}return{segmentProps:Et(v,te,{id:W,...N,"aria-invalid":t.isInvalid?"true":void 0,"aria-describedby":s,"aria-readonly":t.isReadOnly||!e.isEditable?"true":void 0,"data-placeholder":e.isPlaceholder||void 0,contentEditable:G,suppressContentEditableWarning:G,spellCheck:G?"false":void 0,autoCorrect:G?"off":void 0,[parseInt(ye.version,10)>=17?"enterKeyHint":"enterkeyhint"]:G?"next":void 0,inputMode:t.isDisabled||e.type==="dayPeriod"||e.type==="era"||!G?void 0:"numeric",tabIndex:t.isDisabled?void 0:0,onKeyDown:E,onFocus:j,style:H,onPointerDown(M){M.stopPropagation()},onMouseDown(M){M.stopPropagation()}})}}function aCe(e){e.sort();let t=e[0],n=e[e.length-1];for(let r=0;r<t.length;r++)if(t[r]!==n[r])return r;return 0}function uCe(e,t){let{role:n="dialog"}=e,r=C0();r=e["aria-label"]?void 0:r;let i=P.useRef(!1);return P.useEffect(()=>{if(t.current&&!t.current.contains(document.activeElement)){ac(t.current);let a=setTimeout(()=>{(document.activeElement===t.current||document.activeElement===document.body)&&(i.current=!0,t.current&&(t.current.blur(),ac(t.current)),i.current=!1)},500);return()=>{clearTimeout(a)}}},[t]),Dre(),{dialogProps:{...Gt(e,{labelable:!0}),role:n,tabIndex:-1,"aria-labelledby":e["aria-labelledby"]||r,onBlur:a=>{i.current&&a.stopPropagation()}},titleProps:{id:r}}}function lCe(e,t,n){let{isDisabled:r}=e,i=pi(),a=pi(),u=hp(),l=P.useRef(null),o=P.useCallback(()=>{l.current=requestAnimationFrame(()=>{n.current&&n.current.setAttribute("hidden","until-found")}),Vf.flushSync(()=>{t.toggle()})},[n,t]);Xd(n,"beforematch",o);let s=P.useRef(null);return qr(()=>{if(l.current&&cancelAnimationFrame(l.current),n.current&&!r&&!u){let c=n.current;s.current==null||typeof c.getAnimations!="function"?t.isExpanded?(c.removeAttribute("hidden"),c.style.setProperty("--disclosure-panel-width","auto"),c.style.setProperty("--disclosure-panel-height","auto")):(c.setAttribute("hidden","until-found"),c.style.setProperty("--disclosure-panel-width","0px"),c.style.setProperty("--disclosure-panel-height","0px")):t.isExpanded!==s.current&&(t.isExpanded?(c.removeAttribute("hidden"),c.style.setProperty("--disclosure-panel-width",c.scrollWidth+"px"),c.style.setProperty("--disclosure-panel-height",c.scrollHeight+"px"),Promise.all(c.getAnimations().map(d=>d.finished)).then(()=>{c.style.setProperty("--disclosure-panel-width","auto"),c.style.setProperty("--disclosure-panel-height","auto")}).catch(()=>{})):(c.style.setProperty("--disclosure-panel-width",c.scrollWidth+"px"),c.style.setProperty("--disclosure-panel-height",c.scrollHeight+"px"),window.getComputedStyle(c).height,c.style.setProperty("--disclosure-panel-width","0px"),c.style.setProperty("--disclosure-panel-height","0px"),Promise.all(c.getAnimations().map(d=>d.finished)).then(()=>c.setAttribute("hidden","until-found")).catch(()=>{}))),s.current=t.isExpanded}},[r,n,t.isExpanded,u]),P.useEffect(()=>()=>{l.current&&cancelAnimationFrame(l.current)},[]),{buttonProps:{id:i,"aria-expanded":t.isExpanded,"aria-controls":a,onPress:c=>{!r&&c.pointerType!=="keyboard"&&t.toggle()},isDisabled:r,onPressStart(c){c.pointerType==="keyboard"&&!r&&t.toggle()}},panelProps:{id:a,role:"group","aria-labelledby":i,"aria-hidden":!t.isExpanded,hidden:u||r?r||!t.isExpanded:void 0}}}const ZN=new WeakMap;function Fj(e,t){var n;let{id:r}=(n=ZN.get(e))!==null&&n!==void 0?n:{};if(!r)throw new Error("Unknown list");return`${r}-${oCe(t)}`}function oCe(e){return typeof e=="string"?e.replace(/\s*/g,""):""+e}var Use={};Use={deselectedItem:e=>`${e.item} غير المحدد`,longPressToSelect:"اضغط مطولًا للدخول إلى وضع التحديد.",select:"تحديد",selectedAll:"جميع العناصر المحددة.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"لم يتم تحديد عناصر",one:()=>`${t.number(e.count)} عنصر محدد`,other:()=>`${t.number(e.count)} عنصر محدد`})}.`,selectedItem:e=>`${e.item} المحدد`};var jse={};jse={deselectedItem:e=>`${e.item} не е избран.`,longPressToSelect:"Натиснете и задръжте за да влезете в избирателен режим.",select:"Изберете",selectedAll:"Всички елементи са избрани.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Няма избрани елементи",one:()=>`${t.number(e.count)} избран елемент`,other:()=>`${t.number(e.count)} избрани елементи`})}.`,selectedItem:e=>`${e.item} избран.`};var Zse={};Zse={deselectedItem:e=>`Položka ${e.item} není vybrána.`,longPressToSelect:"Dlouhým stisknutím přejdete do režimu výběru.",select:"Vybrat",selectedAll:"Vybrány všechny položky.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Nevybrány žádné položky",one:()=>`Vybrána ${t.number(e.count)} položka`,other:()=>`Vybráno ${t.number(e.count)} položek`})}.`,selectedItem:e=>`Vybrána položka ${e.item}.`};var Hse={};Hse={deselectedItem:e=>`${e.item} ikke valgt.`,longPressToSelect:"Lav et langt tryk for at aktivere valgtilstand.",select:"Vælg",selectedAll:"Alle elementer valgt.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Ingen elementer valgt",one:()=>`${t.number(e.count)} element valgt`,other:()=>`${t.number(e.count)} elementer valgt`})}.`,selectedItem:e=>`${e.item} valgt.`};var Xse={};Xse={deselectedItem:e=>`${e.item} nicht ausgewählt.`,longPressToSelect:"Gedrückt halten, um Auswahlmodus zu öffnen.",select:"Auswählen",selectedAll:"Alle Elemente ausgewählt.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Keine Elemente ausgewählt",one:()=>`${t.number(e.count)} Element ausgewählt`,other:()=>`${t.number(e.count)} Elemente ausgewählt`})}.`,selectedItem:e=>`${e.item} ausgewählt.`};var Yse={};Yse={deselectedItem:e=>`Δεν επιλέχθηκε το στοιχείο ${e.item}.`,longPressToSelect:"Πατήστε παρατεταμένα για να μπείτε σε λειτουργία επιλογής.",select:"Επιλογή",selectedAll:"Επιλέχθηκαν όλα τα στοιχεία.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Δεν επιλέχθηκαν στοιχεία",one:()=>`Επιλέχθηκε ${t.number(e.count)} στοιχείο`,other:()=>`Επιλέχθηκαν ${t.number(e.count)} στοιχεία`})}.`,selectedItem:e=>`Επιλέχθηκε το στοιχείο ${e.item}.`};var Gse={};Gse={deselectedItem:e=>`${e.item} not selected.`,select:"Select",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"No items selected",one:()=>`${t.number(e.count)} item selected`,other:()=>`${t.number(e.count)} items selected`})}.`,selectedAll:"All items selected.",selectedItem:e=>`${e.item} selected.`,longPressToSelect:"Long press to enter selection mode."};var Kse={};Kse={deselectedItem:e=>`${e.item} no seleccionado.`,longPressToSelect:"Mantenga pulsado para abrir el modo de selección.",select:"Seleccionar",selectedAll:"Todos los elementos seleccionados.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Ningún elemento seleccionado",one:()=>`${t.number(e.count)} elemento seleccionado`,other:()=>`${t.number(e.count)} elementos seleccionados`})}.`,selectedItem:e=>`${e.item} seleccionado.`};var Wse={};Wse={deselectedItem:e=>`${e.item} pole valitud.`,longPressToSelect:"Valikurežiimi sisenemiseks vajutage pikalt.",select:"Vali",selectedAll:"Kõik üksused valitud.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Üksusi pole valitud",one:()=>`${t.number(e.count)} üksus valitud`,other:()=>`${t.number(e.count)} üksust valitud`})}.`,selectedItem:e=>`${e.item} valitud.`};var Jse={};Jse={deselectedItem:e=>`Kohdetta ${e.item} ei valittu.`,longPressToSelect:"Siirry valintatilaan painamalla pitkään.",select:"Valitse",selectedAll:"Kaikki kohteet valittu.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Ei yhtään kohdetta valittu",one:()=>`${t.number(e.count)} kohde valittu`,other:()=>`${t.number(e.count)} kohdetta valittu`})}.`,selectedItem:e=>`${e.item} valittu.`};var ece={};ece={deselectedItem:e=>`${e.item} non sélectionné.`,longPressToSelect:"Appuyez de manière prolongée pour passer en mode de sélection.",select:"Sélectionner",selectedAll:"Tous les éléments sélectionnés.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Aucun élément sélectionné",one:()=>`${t.number(e.count)} élément sélectionné`,other:()=>`${t.number(e.count)} éléments sélectionnés`})}.`,selectedItem:e=>`${e.item} sélectionné.`};var tce={};tce={deselectedItem:e=>`${e.item} לא נבחר.`,longPressToSelect:"הקשה ארוכה לכניסה למצב בחירה.",select:"בחר",selectedAll:"כל הפריטים נבחרו.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"לא נבחרו פריטים",one:()=>`פריט ${t.number(e.count)} נבחר`,other:()=>`${t.number(e.count)} פריטים נבחרו`})}.`,selectedItem:e=>`${e.item} נבחר.`};var nce={};nce={deselectedItem:e=>`Stavka ${e.item} nije odabrana.`,longPressToSelect:"Dugo pritisnite za ulazak u način odabira.",select:"Odaberite",selectedAll:"Odabrane su sve stavke.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Nije odabrana nijedna stavka",one:()=>`Odabrana je ${t.number(e.count)} stavka`,other:()=>`Odabrano je ${t.number(e.count)} stavki`})}.`,selectedItem:e=>`Stavka ${e.item} je odabrana.`};var rce={};rce={deselectedItem:e=>`${e.item} nincs kijelölve.`,longPressToSelect:"Nyomja hosszan a kijelöléshez.",select:"Kijelölés",selectedAll:"Az összes elem kijelölve.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Egy elem sincs kijelölve",one:()=>`${t.number(e.count)} elem kijelölve`,other:()=>`${t.number(e.count)} elem kijelölve`})}.`,selectedItem:e=>`${e.item} kijelölve.`};var ice={};ice={deselectedItem:e=>`${e.item} non selezionato.`,longPressToSelect:"Premi a lungo per passare alla modalità di selezione.",select:"Seleziona",selectedAll:"Tutti gli elementi selezionati.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Nessun elemento selezionato",one:()=>`${t.number(e.count)} elemento selezionato`,other:()=>`${t.number(e.count)} elementi selezionati`})}.`,selectedItem:e=>`${e.item} selezionato.`};var ace={};ace={deselectedItem:e=>`${e.item} が選択されていません。`,longPressToSelect:"長押しして選択モードを開きます。",select:"選択",selectedAll:"すべての項目を選択しました。",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"項目が選択されていません",one:()=>`${t.number(e.count)} 項目を選択しました`,other:()=>`${t.number(e.count)} 項目を選択しました`})}。`,selectedItem:e=>`${e.item} を選択しました。`};var uce={};uce={deselectedItem:e=>`${e.item}이(가) 선택되지 않았습니다.`,longPressToSelect:"선택 모드로 들어가려면 길게 누르십시오.",select:"선택",selectedAll:"모든 항목이 선택되었습니다.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"선택된 항목이 없습니다",one:()=>`${t.number(e.count)}개 항목이 선택되었습니다`,other:()=>`${t.number(e.count)}개 항목이 선택되었습니다`})}.`,selectedItem:e=>`${e.item}이(가) 선택되었습니다.`};var lce={};lce={deselectedItem:e=>`${e.item} nepasirinkta.`,longPressToSelect:"Norėdami įjungti pasirinkimo režimą, paspauskite ir palaikykite.",select:"Pasirinkti",selectedAll:"Pasirinkti visi elementai.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Nepasirinktas nė vienas elementas",one:()=>`Pasirinktas ${t.number(e.count)} elementas`,other:()=>`Pasirinkta elementų: ${t.number(e.count)}`})}.`,selectedItem:e=>`Pasirinkta: ${e.item}.`};var oce={};oce={deselectedItem:e=>`Vienums ${e.item} nav atlasīts.`,longPressToSelect:"Ilgi turiet nospiestu. lai ieslēgtu atlases režīmu.",select:"Atlasīt",selectedAll:"Atlasīti visi vienumi.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Nav atlasīts neviens vienums",one:()=>`Atlasīto vienumu skaits: ${t.number(e.count)}`,other:()=>`Atlasīto vienumu skaits: ${t.number(e.count)}`})}.`,selectedItem:e=>`Atlasīts vienums ${e.item}.`};var sce={};sce={deselectedItem:e=>`${e.item} er ikke valgt.`,longPressToSelect:"Bruk et langt trykk for å gå inn i valgmodus.",select:"Velg",selectedAll:"Alle elementer er valgt.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Ingen elementer er valgt",one:()=>`${t.number(e.count)} element er valgt`,other:()=>`${t.number(e.count)} elementer er valgt`})}.`,selectedItem:e=>`${e.item} er valgt.`};var cce={};cce={deselectedItem:e=>`${e.item} niet geselecteerd.`,longPressToSelect:"Druk lang om de selectiemodus te openen.",select:"Selecteren",selectedAll:"Alle items geselecteerd.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Geen items geselecteerd",one:()=>`${t.number(e.count)} item geselecteerd`,other:()=>`${t.number(e.count)} items geselecteerd`})}.`,selectedItem:e=>`${e.item} geselecteerd.`};var fce={};fce={deselectedItem:e=>`Nie zaznaczono ${e.item}.`,longPressToSelect:"Naciśnij i przytrzymaj, aby wejść do trybu wyboru.",select:"Zaznacz",selectedAll:"Wszystkie zaznaczone elementy.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Nie zaznaczono żadnych elementów",one:()=>`${t.number(e.count)} zaznaczony element`,other:()=>`${t.number(e.count)} zaznaczonych elementów`})}.`,selectedItem:e=>`Zaznaczono ${e.item}.`};var dce={};dce={deselectedItem:e=>`${e.item} não selecionado.`,longPressToSelect:"Mantenha pressionado para entrar no modo de seleção.",select:"Selecionar",selectedAll:"Todos os itens selecionados.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Nenhum item selecionado",one:()=>`${t.number(e.count)} item selecionado`,other:()=>`${t.number(e.count)} itens selecionados`})}.`,selectedItem:e=>`${e.item} selecionado.`};var hce={};hce={deselectedItem:e=>`${e.item} não selecionado.`,longPressToSelect:"Prima continuamente para entrar no modo de seleção.",select:"Selecionar",selectedAll:"Todos os itens selecionados.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Nenhum item selecionado",one:()=>`${t.number(e.count)} item selecionado`,other:()=>`${t.number(e.count)} itens selecionados`})}.`,selectedItem:e=>`${e.item} selecionado.`};var pce={};pce={deselectedItem:e=>`${e.item} neselectat.`,longPressToSelect:"Apăsați lung pentru a intra în modul de selectare.",select:"Selectare",selectedAll:"Toate elementele selectate.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Niciun element selectat",one:()=>`${t.number(e.count)} element selectat`,other:()=>`${t.number(e.count)} elemente selectate`})}.`,selectedItem:e=>`${e.item} selectat.`};var mce={};mce={deselectedItem:e=>`${e.item} не выбрано.`,longPressToSelect:"Нажмите и удерживайте для входа в режим выбора.",select:"Выбрать",selectedAll:"Выбраны все элементы.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Нет выбранных элементов",one:()=>`${t.number(e.count)} элемент выбран`,other:()=>`${t.number(e.count)} элементов выбрано`})}.`,selectedItem:e=>`${e.item} выбрано.`};var gce={};gce={deselectedItem:e=>`Nevybraté položky: ${e.item}.`,longPressToSelect:"Dlhším stlačením prejdite do režimu výberu.",select:"Vybrať",selectedAll:"Všetky vybraté položky.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Žiadne vybraté položky",one:()=>`${t.number(e.count)} vybratá položka`,other:()=>`Počet vybratých položiek:${t.number(e.count)}`})}.`,selectedItem:e=>`Vybraté položky: ${e.item}.`};var vce={};vce={deselectedItem:e=>`Element ${e.item} ni izbran.`,longPressToSelect:"Za izbirni način pritisnite in dlje časa držite.",select:"Izberite",selectedAll:"Vsi elementi so izbrani.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Noben element ni izbran",one:()=>`${t.number(e.count)} element je izbran`,other:()=>`${t.number(e.count)} elementov je izbranih`})}.`,selectedItem:e=>`Element ${e.item} je izbran.`};var yce={};yce={deselectedItem:e=>`${e.item} nije izabrano.`,longPressToSelect:"Dugo pritisnite za ulazak u režim biranja.",select:"Izaberite",selectedAll:"Izabrane su sve stavke.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Nije izabrana nijedna stavka",one:()=>`Izabrana je ${t.number(e.count)} stavka`,other:()=>`Izabrano je ${t.number(e.count)} stavki`})}.`,selectedItem:e=>`${e.item} je izabrano.`};var bce={};bce={deselectedItem:e=>`${e.item} ej markerat.`,longPressToSelect:"Tryck länge när du vill öppna väljarläge.",select:"Markera",selectedAll:"Alla markerade objekt.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Inga markerade objekt",one:()=>`${t.number(e.count)} markerat objekt`,other:()=>`${t.number(e.count)} markerade objekt`})}.`,selectedItem:e=>`${e.item} markerat.`};var Oce={};Oce={deselectedItem:e=>`${e.item} seçilmedi.`,longPressToSelect:"Seçim moduna girmek için uzun basın.",select:"Seç",selectedAll:"Tüm ögeler seçildi.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Hiçbir öge seçilmedi",one:()=>`${t.number(e.count)} öge seçildi`,other:()=>`${t.number(e.count)} öge seçildi`})}.`,selectedItem:e=>`${e.item} seçildi.`};var xce={};xce={deselectedItem:e=>`${e.item} не вибрано.`,longPressToSelect:"Виконайте довге натиснення, щоб перейти в режим вибору.",select:"Вибрати",selectedAll:"Усі елементи вибрано.",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"Жодних елементів не вибрано",one:()=>`${t.number(e.count)} елемент вибрано`,other:()=>`Вибрано елементів: ${t.number(e.count)}`})}.`,selectedItem:e=>`${e.item} вибрано.`};var Sce={};Sce={deselectedItem:e=>`未选择 ${e.item}。`,longPressToSelect:"长按以进入选择模式。",select:"选择",selectedAll:"已选择所有项目。",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"未选择项目",one:()=>`已选择 ${t.number(e.count)} 个项目`,other:()=>`已选择 ${t.number(e.count)} 个项目`})}。`,selectedItem:e=>`已选择 ${e.item}。`};var _ce={};_ce={deselectedItem:e=>`未選取「${e.item}」。`,longPressToSelect:"長按以進入選擇模式。",select:"選取",selectedAll:"已選取所有項目。",selectedCount:(e,t)=>`${t.plural(e.count,{"=0":"未選取任何項目",one:()=>`已選取 ${t.number(e.count)} 個項目`,other:()=>`已選取 ${t.number(e.count)} 個項目`})}。`,selectedItem:e=>`已選取「${e.item}」。`};var HN={};HN={"ar-AE":Use,"bg-BG":jse,"cs-CZ":Zse,"da-DK":Hse,"de-DE":Xse,"el-GR":Yse,"en-US":Gse,"es-ES":Kse,"et-EE":Wse,"fi-FI":Jse,"fr-FR":ece,"he-IL":tce,"hr-HR":nce,"hu-HU":rce,"it-IT":ice,"ja-JP":ace,"ko-KR":uce,"lt-LT":lce,"lv-LV":oce,"nb-NO":sce,"nl-NL":cce,"pl-PL":fce,"pt-BR":dce,"pt-PT":hce,"ro-RO":pce,"ru-RU":mce,"sk-SK":gce,"sl-SI":vce,"sr-SP":yce,"sv-SE":bce,"tr-TR":Oce,"uk-UA":xce,"zh-CN":Sce,"zh-TW":_ce};function sCe(e){return e&&e.__esModule?e.default:e}function cCe(e,t){let{getRowText:n=l=>{var o,s,c,d;return(d=(o=(s=t.collection).getTextValue)===null||o===void 0?void 0:o.call(s,l))!==null&&d!==void 0?d:(c=t.collection.getItem(l))===null||c===void 0?void 0:c.textValue}}=e,r=Fo(sCe(HN),"@react-aria/grid"),i=t.selectionManager.rawSelection,a=P.useRef(i),u=oi(()=>{var l;if(!t.selectionManager.isFocused||i===a.current){a.current=i;return}let o=Nj(i,a.current),s=Nj(a.current,i),c=t.selectionManager.selectionBehavior==="replace",d=[];if(t.selectionManager.selectedKeys.size===1&&c){let h=t.selectionManager.selectedKeys.keys().next().value;if(h!=null&&t.collection.getItem(h)){let m=n(h);m&&d.push(r.format("selectedItem",{item:m}))}}else if(o.size===1&&s.size===0){let h=o.keys().next().value;if(h!=null){let m=n(h);m&&d.push(r.format("selectedItem",{item:m}))}}else if(s.size===1&&o.size===0){let h=s.keys().next().value;if(h!=null&&t.collection.getItem(h)){let m=n(h);m&&d.push(r.format("deselectedItem",{item:m}))}}t.selectionManager.selectionMode==="multiple"&&(d.length===0||i==="all"||i.size>1||a.current==="all"||((l=a.current)===null||l===void 0?void 0:l.size)>1)&&d.push(i==="all"?r.format("selectedAll"):r.format("selectedCount",{count:i.size})),d.length>0&&j1(d.join(" ")),a.current=i});Yee(()=>{if(t.selectionManager.isFocused)u();else{let l=requestAnimationFrame(u);return()=>cancelAnimationFrame(l)}},[i,t.selectionManager.isFocused])}function Nj(e,t){let n=new Set;if(e==="all"||t==="all")return n;for(let r of e.keys())t.has(r)||n.add(r);return n}function fCe(e){return e&&e.__esModule?e.default:e}function dCe(e){let t=Fo(fCe(HN),"@react-aria/grid"),n=DN(),r=(n==="pointer"||n==="virtual"||n==null)&&typeof window<"u"&&"ontouchstart"in window,i=P.useMemo(()=>{let u=e.selectionManager.selectionMode,l=e.selectionManager.selectionBehavior,o;return r&&(o=t.format("longPressToSelect")),l==="replace"&&u!=="none"&&e.hasItemActions?o:void 0},[e.selectionManager.selectionMode,e.selectionManager.selectionBehavior,e.hasItemActions,t,r]);return NC(i)}function hCe(e,t,n){let{isVirtualized:r,keyboardDelegate:i,layoutDelegate:a,onAction:u,disallowTypeAhead:l,linkBehavior:o="action",keyboardNavigationBehavior:s="arrow",escapeKeyBehavior:c="clearSelection",shouldSelectOnPressUp:d}=e;!e["aria-label"]&&!e["aria-labelledby"]&&console.warn("An aria-label or aria-labelledby prop is required for accessibility.");let{listProps:h}=FN({selectionManager:t.selectionManager,collection:t.collection,disabledKeys:t.disabledKeys,ref:n,keyboardDelegate:i,layoutDelegate:a,isVirtualized:r,selectOnFocus:t.selectionManager.selectionBehavior==="replace",shouldFocusWrap:e.shouldFocusWrap,linkBehavior:o,disallowTypeAhead:l,autoFocus:e.autoFocus,escapeKeyBehavior:c}),m=pi(e.id);ZN.set(t,{id:m,onAction:u,linkBehavior:o,keyboardNavigationBehavior:s,shouldSelectOnPressUp:d});let y=dCe({selectionManager:t.selectionManager,hasItemActions:!!u}),v=Lne(n,{isDisabled:t.collection.size!==0}),_=Gt(e,{labelable:!0}),S=Et(_,{role:"grid",id:m,"aria-multiselectable":t.selectionManager.selectionMode==="multiple"?"true":void 0},t.collection.size===0?{tabIndex:v?-1:0}:h,y);return r&&(S["aria-rowcount"]=t.collection.size,S["aria-colcount"]=1),cCe({},t),{gridProps:S}}const Ij={expand:{ltr:"ArrowRight",rtl:"ArrowLeft"},collapse:{ltr:"ArrowLeft",rtl:"ArrowRight"}};function pCe(e,t,n){var r,i;let{node:a,isVirtualized:u}=e,{direction:l}=Hi(),{onAction:o,linkBehavior:s,keyboardNavigationBehavior:c,shouldSelectOnPressUp:d}=ZN.get(t),h=C0(),m=P.useRef(null),y=()=>{var W;n.current!==null&&(m.current!=null&&a.key!==m.current||!(!((W=n.current)===null||W===void 0)&&W.contains(document.activeElement)))&&ac(n.current)},v={},_=e.hasChildItems,S=t.selectionManager.isLink(a.key);if(a!=null&&"expandedKeys"in t){var E,C;let W=(E=(C=t.collection).getChildren)===null||E===void 0?void 0:E.call(C,a.key);_=_||[...W??[]].length>1,o==null&&!S&&t.selectionManager.selectionMode==="none"&&_&&(o=()=>t.toggleKey(a.key));let G=_?t.expandedKeys.has(a.key):void 0,J=1;if(a.level>0&&(a==null?void 0:a.parentKey)!=null){let te=t.collection.getItem(a.parentKey);if(te){var T,R;J=[...(T=(R=t.collection).getChildren)===null||T===void 0?void 0:T.call(R,te.key)].filter(M=>M.type==="item").length}}else J=[...t.collection].filter(te=>te.level===0&&te.type==="item").length;v={"aria-expanded":G,"aria-level":a.level+1,"aria-posinset":(a==null?void 0:a.index)+1,"aria-setsize":J}}let{itemProps:$,...k}=jC({selectionManager:t.selectionManager,key:a.key,ref:n,isVirtualized:u,shouldSelectOnPressUp:e.shouldSelectOnPressUp||d,onAction:o||!((r=a.props)===null||r===void 0)&&r.onAction?rh((i=a.props)===null||i===void 0?void 0:i.onAction,o?()=>o(a.key):void 0):void 0,focus:y,linkBehavior:s}),F=W=>{if(!W.currentTarget.contains(W.target)||!n.current||!document.activeElement)return;let G=Cl(n.current);if(G.currentNode=document.activeElement,"expandedKeys"in t&&document.activeElement===n.current){if(W.key===Ij.expand[l]&&t.selectionManager.focusedKey===a.key&&_&&!t.expandedKeys.has(a.key)){t.toggleKey(a.key),W.stopPropagation();return}else if(W.key===Ij.collapse[l]&&t.selectionManager.focusedKey===a.key&&_&&t.expandedKeys.has(a.key)){t.toggleKey(a.key),W.stopPropagation();return}}switch(W.key){case"ArrowLeft":if(c==="arrow"){let te=l==="rtl"?G.nextNode():G.previousNode();if(te)W.preventDefault(),W.stopPropagation(),ac(te),Vm(te,{containingElement:g0(n.current)});else if(W.preventDefault(),W.stopPropagation(),l==="rtl")ac(n.current),Vm(n.current,{containingElement:g0(n.current)});else{G.currentNode=n.current;let H=Lj(G);H&&(ac(H),Vm(H,{containingElement:g0(n.current)}))}}break;case"ArrowRight":if(c==="arrow"){let te=l==="rtl"?G.previousNode():G.nextNode();if(te)W.preventDefault(),W.stopPropagation(),ac(te),Vm(te,{containingElement:g0(n.current)});else if(W.preventDefault(),W.stopPropagation(),l==="ltr")ac(n.current),Vm(n.current,{containingElement:g0(n.current)});else{G.currentNode=n.current;let H=Lj(G);H&&(ac(H),Vm(H,{containingElement:g0(n.current)}))}}break;case"ArrowUp":case"ArrowDown":if(!W.altKey&&n.current.contains(W.target)){var J;W.stopPropagation(),W.preventDefault(),(J=n.current.parentElement)===null||J===void 0||J.dispatchEvent(new KeyboardEvent(W.nativeEvent.type,W.nativeEvent))}break}},L=W=>{if(m.current=a.key,W.target!==n.current){Jv()||t.selectionManager.setFocusedKey(a.key);return}},j=W=>{if(!(!W.currentTarget.contains(W.target)||!n.current||!document.activeElement))switch(W.key){case"Tab":if(c==="tab"){let G=Cl(n.current,{tabbable:!0});G.currentNode=document.activeElement,(W.shiftKey?G.previousNode():G.nextNode())&&W.stopPropagation()}}},V=Hee(a.props),q=k.hasAction?V:{},N=Et($,q,{role:"row",onKeyDownCapture:F,onKeyDown:j,onFocus:L,"aria-label":a.textValue||void 0,"aria-selected":t.selectionManager.canSelectItem(a.key)?t.selectionManager.isSelected(a.key):void 0,"aria-disabled":t.selectionManager.isDisabled(a.key)||void 0,"aria-labelledby":h&&a.textValue?`${Fj(t,a.key)} ${h}`:void 0,id:Fj(t,a.key)});if(u){let{collection:W}=t,G=[...W];N["aria-rowindex"]=G.find(J=>J.type==="section")?[...W.getKeys()].filter(J=>{var te;return((te=W.getItem(J))===null||te===void 0?void 0:te.type)!=="section"}).findIndex(J=>J===a.key)+1:a.index+1}let U={role:"gridcell","aria-colindex":1};return{rowProps:{...Et(N,v)},gridCellProps:U,descriptionProps:{id:h},...k}}function Lj(e){let t=null,n=null;do n=e.lastChild(),n&&(t=n);while(n);return t}const Ece=1,fk=Symbol.for("react-aria-landmark-manager");function mCe(e){return document.addEventListener("react-aria-landmark-manager-change",e),()=>document.removeEventListener("react-aria-landmark-manager-change",e)}function Bj(){if(typeof document>"u")return null;let e=document[fk];return e&&e.version>=Ece?e:(document[fk]=new vCe,document.dispatchEvent(new CustomEvent("react-aria-landmark-manager-change")),document[fk])}function gCe(){return LN.useSyncExternalStore(mCe,Bj,Bj)}class vCe{setupIfNeeded(){this.isListening||(document.addEventListener("keydown",this.f6Handler,{capture:!0}),document.addEventListener("focusin",this.focusinHandler,{capture:!0}),document.addEventListener("focusout",this.focusoutHandler,{capture:!0}),this.isListening=!0)}teardownIfNeeded(){!this.isListening||this.landmarks.length>0||this.refCount>0||(document.removeEventListener("keydown",this.f6Handler,{capture:!0}),document.removeEventListener("focusin",this.focusinHandler,{capture:!0}),document.removeEventListener("focusout",this.focusoutHandler,{capture:!0}),this.isListening=!1)}focusLandmark(t,n){var r,i;(i=this.landmarks.find(a=>a.ref.current===t))===null||i===void 0||(r=i.focus)===null||r===void 0||r.call(i,n)}getLandmarksByRole(t){return new Set(this.landmarks.filter(n=>n.role===t))}getLandmarkByRole(t){return this.landmarks.find(n=>n.role===t)}addLandmark(t){if(this.setupIfNeeded(),this.landmarks.find(i=>i.ref===t.ref)||!t.ref.current)return;if(this.landmarks.filter(i=>i.role==="main").length>1,this.landmarks.length===0){this.landmarks=[t],this.checkLabels(t.role);return}let n=0,r=this.landmarks.length-1;for(;n<=r;){let i=Math.floor((n+r)/2),a=t.ref.current.compareDocumentPosition(this.landmarks[i].ref.current);!!(a&Node.DOCUMENT_POSITION_PRECEDING||a&Node.DOCUMENT_POSITION_CONTAINS)?n=i+1:r=i-1}this.landmarks.splice(n,0,t),this.checkLabels(t.role)}updateLandmark(t){let n=this.landmarks.findIndex(r=>r.ref===t.ref);n>=0&&(this.landmarks[n]={...this.landmarks[n],...t},this.checkLabels(this.landmarks[n].role))}removeLandmark(t){this.landmarks=this.landmarks.filter(n=>n.ref!==t),this.teardownIfNeeded()}checkLabels(t){let n=this.getLandmarksByRole(t);n.size>1&&[...n].filter(r=>!r.label)}closestLandmark(t){let n=new Map(this.landmarks.map(i=>[i.ref.current,i])),r=t;for(;r&&!n.has(r)&&r!==document.body&&r.parentElement;)r=r.parentElement;return n.get(r)}getNextLandmark(t,{backward:n}){var r;let i=this.closestLandmark(t),a=n?this.landmarks.length-1:0;i&&(a=this.landmarks.indexOf(i)+(n?-1:1));let u=()=>{if(a<0){if(!t.dispatchEvent(new CustomEvent("react-aria-landmark-navigation",{detail:{direction:"backward"},bubbles:!0,cancelable:!0})))return!0;a=this.landmarks.length-1}else if(a>=this.landmarks.length){if(!t.dispatchEvent(new CustomEvent("react-aria-landmark-navigation",{detail:{direction:"forward"},bubbles:!0,cancelable:!0})))return!0;a=0}return a<0||a>=this.landmarks.length};if(u())return;let l=a;for(;!((r=this.landmarks[a].ref.current)===null||r===void 0)&&r.closest("[aria-hidden=true]");){if(a+=n?-1:1,u())return;if(a===l)break}return this.landmarks[a]}f6Handler(t){t.key==="F6"&&(t.altKey?this.focusMain():this.navigate(t.target,t.shiftKey))&&(t.preventDefault(),t.stopPropagation())}focusMain(){let t=this.getLandmarkByRole("main");return t&&t.ref.current&&document.contains(t.ref.current)?(this.focusLandmark(t.ref.current,"forward"),!0):!1}navigate(t,n){let r=this.getNextLandmark(t,{backward:n});if(!r)return!1;if(r.lastFocused){let i=r.lastFocused;if(document.body.contains(i))return i.focus(),!0}return r.ref.current&&document.contains(r.ref.current)?(this.focusLandmark(r.ref.current,n?"backward":"forward"),!0):!1}focusinHandler(t){let n=this.closestLandmark(t.target);n&&n.ref.current!==t.target&&this.updateLandmark({ref:n.ref,lastFocused:t.target});let r=t.relatedTarget;if(r){let i=this.closestLandmark(r);i&&i.ref.current===r&&i.blur()}}focusoutHandler(t){let n=t.target,r=t.relatedTarget;if(!r||r===document){let i=this.closestLandmark(n);i&&i.ref.current===n&&i.blur()}}createLandmarkController(){let t=this;return t.refCount++,t.setupIfNeeded(),{navigate(n,r){let i=(r==null?void 0:r.from)||document.activeElement;return t.navigate(i,n==="backward")},focusNext(n){let r=(n==null?void 0:n.from)||document.activeElement;return t.navigate(r,!1)},focusPrevious(n){let r=(n==null?void 0:n.from)||document.activeElement;return t.navigate(r,!0)},focusMain(){return t.focusMain()},dispose(){t&&(t.refCount--,t.teardownIfNeeded(),t=null)}}}registerLandmark(t){return this.landmarks.find(n=>n.ref===t.ref)?this.updateLandmark(t):this.addLandmark(t),()=>this.removeLandmark(t.ref)}constructor(){this.landmarks=[],this.isListening=!1,this.refCount=0,this.version=Ece,this.f6Handler=this.f6Handler.bind(this),this.focusinHandler=this.focusinHandler.bind(this),this.focusoutHandler=this.focusoutHandler.bind(this)}}function yCe(e,t){const{role:n,"aria-label":r,"aria-labelledby":i,focus:a}=e;let u=gCe(),l=r||i,[o,s]=P.useState(!1),c=P.useCallback(()=>{s(!0)},[s]),d=P.useCallback(()=>{s(!1)},[s]);return qr(()=>{if(u)return u.registerLandmark({ref:t,label:l,role:n,focus:a||c,blur:d})},[u,l,t,n,a,c,d]),P.useEffect(()=>{var h;o&&((h=t.current)===null||h===void 0||h.focus())},[o,t]),{landmarkProps:{role:n,tabIndex:o?-1:void 0,"aria-label":r,"aria-labelledby":i}}}function bCe(e){let{value:t=0,minValue:n=0,maxValue:r=100,valueLabel:i,isIndeterminate:a,formatOptions:u={style:"percent"}}=e,l=Gt(e,{labelable:!0}),{labelProps:o,fieldProps:s}=fS({...e,labelElementType:"span"});t=ro(t,n,r);let c=(t-n)/(r-n),d=HD(u);if(!a&&!i){let h=u.style==="percent"?c:t;i=d.format(h)}return{progressBarProps:Et(l,{...s,"aria-valuenow":a?void 0:t,"aria-valuemin":n,"aria-valuemax":r,"aria-valuetext":a?void 0:i,role:"progressbar"}),labelProps:o}}const Dce=new WeakMap;function OCe(e,t,n){let{value:r,children:i,"aria-label":a,"aria-labelledby":u,onPressStart:l,onPressEnd:o,onPressChange:s,onPress:c,onPressUp:d,onClick:h}=e;const m=e.isDisabled||t.isDisabled;let y=t.selectedValue===r,v=N=>{N.stopPropagation(),t.setSelectedValue(r)},{pressProps:_,isPressed:S}=up({onPressStart:l,onPressEnd:o,onPressChange:s,onPress:c,onPressUp:d,onClick:h,isDisabled:m}),{pressProps:E,isPressed:C}=up({onPressStart:l,onPressEnd:o,onPressChange:s,onPressUp:d,onClick:h,isDisabled:m,onPress(N){var U;c==null||c(N),t.setSelectedValue(r),(U=n.current)===null||U===void 0||U.focus()}}),{focusableProps:T}=L0(Et(e,{onFocus:()=>t.setLastFocusedValue(r)}),n),R=Et(_,T),$=Gt(e,{labelable:!0}),k=-1;t.selectedValue!=null?t.selectedValue===r&&(k=0):(t.lastFocusedValue===r||t.lastFocusedValue==null)&&(k=0),m&&(k=void 0);let{name:F,form:L,descriptionId:j,errorMessageId:V,validationBehavior:q}=Dce.get(t);return my(n,t.defaultSelectedValue,t.setSelectedValue),pS({validationBehavior:q},t,n),{labelProps:Et(E,P.useMemo(()=>({onClick:N=>N.preventDefault(),onMouseDown:N=>N.preventDefault()}),[])),inputProps:Et($,{...R,type:"radio",name:F,form:L,tabIndex:k,disabled:m,required:t.isRequired&&q==="native",checked:y,value:r,onChange:v,"aria-describedby":[e["aria-describedby"],t.isInvalid?V:null,j].filter(Boolean).join(" ")||void 0}),isDisabled:m,isSelected:y,isPressed:S||C}}function xCe(e,t){let{name:n,form:r,isReadOnly:i,isRequired:a,isDisabled:u,orientation:l="vertical",validationBehavior:o="aria"}=e,{direction:s}=Hi(),{isInvalid:c,validationErrors:d,validationDetails:h}=t.displayValidation,{labelProps:m,fieldProps:y,descriptionProps:v,errorMessageProps:_}=dS({...e,labelElementType:"span",isInvalid:t.isInvalid,errorMessage:e.errorMessage||d}),S=Gt(e,{labelable:!0}),{focusWithinProps:E}=B0({onBlurWithin(R){var $;($=e.onBlur)===null||$===void 0||$.call(e,R),t.selectedValue||t.setLastFocusedValue(null)},onFocusWithin:e.onFocus,onFocusWithinChange:e.onFocusChange}),C=R=>{let $;switch(R.key){case"ArrowRight":s==="rtl"&&l!=="vertical"?$="prev":$="next";break;case"ArrowLeft":s==="rtl"&&l!=="vertical"?$="next":$="prev";break;case"ArrowDown":$="next";break;case"ArrowUp":$="prev";break;default:return}R.preventDefault();let k=Cl(R.currentTarget,{from:R.target,accept:L=>L instanceof af(L).HTMLInputElement&&L.type==="radio"}),F;$==="next"?(F=k.nextNode(),F||(k.currentNode=R.currentTarget,F=k.firstChild())):(F=k.previousNode(),F||(k.currentNode=R.currentTarget,F=k.lastChild())),F&&(F.focus(),t.setSelectedValue(F.value))},T=pi(n);return Dce.set(t,{name:T,form:r,descriptionId:v.id,errorMessageId:_.id,validationBehavior:o}),{radioGroupProps:Et(S,{role:"radiogroup",onKeyDown:C,"aria-invalid":t.isInvalid||void 0,"aria-errormessage":e["aria-errormessage"],"aria-readonly":i||void 0,"aria-required":a||void 0,"aria-disabled":u||void 0,"aria-orientation":l,...y,...E}),labelProps:m,descriptionProps:v,errorMessageProps:_,isInvalid:c,validationErrors:d,validationDetails:h}}const XN=new WeakMap;function SCe(e,t,n){let{keyboardDelegate:r,isDisabled:i,isRequired:a,name:u,form:l,validationBehavior:o="aria"}=e,s=zC({usage:"search",sensitivity:"base"}),c=P.useMemo(()=>r||new hS(t.collection,t.disabledKeys,n,s),[r,t.collection,t.disabledKeys,s,n]),{menuTriggerProps:d,menuProps:h}=IN({isDisabled:i,type:"listbox"},t,n),m=L=>{if(t.selectionManager.selectionMode!=="multiple")switch(L.key){case"ArrowLeft":{var j,V;L.preventDefault();let U=t.selectedKey!=null?(j=c.getKeyAbove)===null||j===void 0?void 0:j.call(c,t.selectedKey):(V=c.getFirstKey)===null||V===void 0?void 0:V.call(c);U&&t.setSelectedKey(U);break}case"ArrowRight":{var q,N;L.preventDefault();let U=t.selectedKey!=null?(q=c.getKeyBelow)===null||q===void 0?void 0:q.call(c,t.selectedKey):(N=c.getFirstKey)===null||N===void 0?void 0:N.call(c);U&&t.setSelectedKey(U);break}}},{typeSelectProps:y}=wre({keyboardDelegate:c,selectionManager:t.selectionManager,onTypeSelect(L){t.setSelectedKey(L)}}),{isInvalid:v,validationErrors:_,validationDetails:S}=t.displayValidation,{labelProps:E,fieldProps:C,descriptionProps:T,errorMessageProps:R}=dS({...e,labelElementType:"span",isInvalid:v,errorMessage:e.errorMessage||_});y.onKeyDown=y.onKeyDownCapture,delete y.onKeyDownCapture,t.selectionManager.selectionMode==="multiple"&&(y={});let $=Gt(e,{labelable:!0}),k=Et(y,d,C),F=pi();return XN.set(t,{isDisabled:i,isRequired:a,name:u,form:l,validationBehavior:o}),{labelProps:{...E,onClick:()=>{if(!e.isDisabled){var L;(L=n.current)===null||L===void 0||L.focus(),EN("keyboard")}}},triggerProps:Et($,{...k,isDisabled:i,onKeyDown:rh(k.onKeyDown,m,e.onKeyDown),onKeyUp:e.onKeyUp,"aria-labelledby":[F,k["aria-labelledby"],k["aria-label"]&&!k["aria-labelledby"]?k.id:null].filter(Boolean).join(" "),onFocus(L){t.isFocused||(e.onFocus&&e.onFocus(L),e.onFocusChange&&e.onFocusChange(!0),t.setFocused(!0))},onBlur(L){t.isOpen||(e.onBlur&&e.onBlur(L),e.onFocusChange&&e.onFocusChange(!1),t.setFocused(!1))}}),valueProps:{id:F},menuProps:{...h,autoFocus:t.focusStrategy||!0,shouldSelectOnPressUp:!0,shouldFocusOnHover:!0,disallowEmptySelection:!0,linkBehavior:"selection",onBlur:L=>{L.currentTarget.contains(L.relatedTarget)||(e.onBlur&&e.onBlur(L),e.onFocusChange&&e.onFocusChange(!1),t.setFocused(!1))},"aria-labelledby":[C["aria-labelledby"],k["aria-label"]&&!C["aria-labelledby"]?k.id:null].filter(Boolean).join(" ")},descriptionProps:T,errorMessageProps:R,isInvalid:v,validationErrors:_,validationDetails:S,hiddenSelectProps:{isDisabled:i,name:u,label:e.label,state:t,triggerRef:n,form:l}}}function _Ce(e,t,n){let r=XN.get(t)||{},{autoComplete:i,name:a=r.name,form:u=r.form,isDisabled:l=r.isDisabled}=e,{validationBehavior:o,isRequired:s}=r,{visuallyHiddenProps:c}=kN({style:{position:"fixed",top:0,left:0}});my(e.selectRef,t.defaultValue,t.setValue),pS({validationBehavior:o,focus:()=>{var y;return(y=n.current)===null||y===void 0?void 0:y.focus()}},t,e.selectRef);let d=t.setValue,h=P.useCallback(y=>{y.target.multiple?d(Array.from(y.target.selectedOptions,v=>v.value)):d(y.currentTarget.value)},[d]);var m;return{containerProps:{...c,"aria-hidden":!0,"data-react-aria-prevent-focus":!0,"data-a11y-ignore":"aria-hidden-focus"},inputProps:{style:{display:"none"}},selectProps:{tabIndex:-1,autoComplete:i,disabled:l,multiple:t.selectionManager.selectionMode==="multiple",required:o==="native"&&s,name:a,form:u,value:(m=t.value)!==null&&m!==void 0?m:"",onChange:h,onInput:h}}}function ECe(e){let{state:t,triggerRef:n,label:r,name:i,form:a,isDisabled:u}=e,l=P.useRef(null),o=P.useRef(null),{containerProps:s,selectProps:c}=_Ce({...e,selectRef:t.collection.size<=300?l:o},t,n);if(t.collection.size<=300)return ye.createElement("div",{...s,"data-testid":"hidden-select-container"},ye.createElement("label",null,r,ye.createElement("select",{...c,ref:l},ye.createElement("option",null),[...t.collection.getKeys()].map(d=>{let h=t.collection.getItem(d);if(h&&h.type==="item")return ye.createElement("option",{key:h.key,value:h.key},h.textValue)}))));if(i){let d=XN.get(t)||{},{validationBehavior:h}=d,m=Array.isArray(t.value)?t.value:[t.value];m.length===0&&(m=[null]);let y=m.map((v,_)=>{let S={type:"hidden",autoComplete:c.autoComplete,name:i,form:a,disabled:u,value:v??""};return h==="native"?ye.createElement("input",{key:_,...S,ref:_===0?o:null,style:{display:"none"},type:"text",required:_===0?c.required:!1,onChange:()=>{}}):ye.createElement("input",{key:_,...S,ref:_===0?o:null})});return ye.createElement(ye.Fragment,null,y)}return null}function DCe(e){let t=Gt(e,{labelable:!0}),n;return e.orientation==="vertical"&&(n="vertical"),e.elementType!=="hr"?{separatorProps:{...t,role:"separator","aria-orientation":n}}:{separatorProps:t}}function $Ce(e,t,n){let{labelProps:r,inputProps:i,isSelected:a,isPressed:u,isDisabled:l,isReadOnly:o}=Due(e,t,n);return{labelProps:r,inputProps:{...i,role:"switch",checked:a},isSelected:a,isPressed:u,isDisabled:l,isReadOnly:o}}const $ce=new WeakMap;function t$(e,t,n){return e?(typeof t=="string"&&(t=t.replace(/\s+/g,"")),`${$ce.get(e)}-${n}-${t}`):""}function CCe(e,t,n){let{key:r,isDisabled:i,shouldSelectOnPressUp:a}=e,{selectionManager:u,selectedKey:l}=t,o=r===l,s=i||t.isDisabled||t.selectionManager.isDisabled(r),{itemProps:c,isPressed:d}=jC({selectionManager:u,key:r,ref:n,isDisabled:s,shouldSelectOnPressUp:a,linkBehavior:"selection"}),h=t$(t,r,"tab"),m=t$(t,r,"tabpanel"),{tabIndex:y}=c,v=t.collection.getItem(r),_=Gt(v==null?void 0:v.props,{labelable:!0});delete _.id;let S=lN(v==null?void 0:v.props),{focusableProps:E}=L0({isDisabled:s},n);return{tabProps:Et(_,E,S,c,{id:h,"aria-selected":o,"aria-disabled":s||void 0,"aria-controls":o?m:void 0,tabIndex:s?void 0:y,role:"tab"}),isSelected:o,isDisabled:s,isPressed:d}}function wCe(e,t,n){let r=Lne(n)?void 0:0;var i;const a=t$(t,(i=e.id)!==null&&i!==void 0?i:t==null?void 0:t.selectedKey,"tabpanel"),u=Yv({...e,id:a,"aria-labelledby":t$(t,t==null?void 0:t.selectedKey,"tab")});return{tabPanelProps:Et(u,{tabIndex:r,role:"tabpanel","aria-describedby":e["aria-describedby"],"aria-details":e["aria-details"]})}}class RCe{getKeyLeftOf(t){return this.flipDirection?this.getNextKey(t):this.getPreviousKey(t)}getKeyRightOf(t){return this.flipDirection?this.getPreviousKey(t):this.getNextKey(t)}isDisabled(t){var n,r;return this.disabledKeys.has(t)||!!(!((r=this.collection.getItem(t))===null||r===void 0||(n=r.props)===null||n===void 0)&&n.isDisabled)}getFirstKey(){let t=this.collection.getFirstKey();return t!=null&&this.isDisabled(t)&&(t=this.getNextKey(t)),t}getLastKey(){let t=this.collection.getLastKey();return t!=null&&this.isDisabled(t)&&(t=this.getPreviousKey(t)),t}getKeyAbove(t){return this.tabDirection?null:this.getPreviousKey(t)}getKeyBelow(t){return this.tabDirection?null:this.getNextKey(t)}getNextKey(t){let n=t;do n=this.collection.getKeyAfter(n),n==null&&(n=this.collection.getFirstKey());while(n!=null&&this.isDisabled(n));return n}getPreviousKey(t){let n=t;do n=this.collection.getKeyBefore(n),n==null&&(n=this.collection.getLastKey());while(n!=null&&this.isDisabled(n));return n}constructor(t,n,r,i=new Set){this.collection=t,this.flipDirection=n==="rtl"&&r==="horizontal",this.disabledKeys=i,this.tabDirection=r==="horizontal"}}function ACe(e,t,n){let{orientation:r="horizontal",keyboardActivation:i="automatic"}=e,{collection:a,selectionManager:u,disabledKeys:l}=t,{direction:o}=Hi(),s=P.useMemo(()=>new RCe(a,o,r,l),[a,l,r,o]),{collectionProps:c}=MN({ref:n,selectionManager:u,keyboardDelegate:s,selectOnFocus:i==="automatic",disallowEmptySelection:!0,scrollRef:n,linkBehavior:"selection"}),d=pi();$ce.set(t,d);let h=Yv({...e,id:d});return{tabListProps:{...Et(c,h),role:"tablist","aria-orientation":r,tabIndex:void 0}}}const Cce=new WeakMap;function TCe(e,t,n){let{direction:r}=Hi(),i=e.keyboardDelegate||new hS({collection:t.collection,ref:n,orientation:"horizontal",direction:r,disabledKeys:t.disabledKeys,disabledBehavior:t.selectionManager.disabledBehavior}),{labelProps:a,fieldProps:u,descriptionProps:l,errorMessageProps:o}=dS({...e,labelElementType:"span"}),{gridProps:s}=hCe({...e,...u,keyboardDelegate:i,shouldFocusWrap:!0,linkBehavior:"override",keyboardNavigationBehavior:"tab"},t,n),[c,d]=P.useState(!1),{focusWithinProps:h}=B0({onFocusWithinChange:d}),m=Gt(e),y=P.useRef(t.collection.size);return P.useEffect(()=>{n.current&&y.current>0&&t.collection.size===0&&c&&n.current.focus(),y.current=t.collection.size},[t.collection.size,c,n]),Cce.set(t,{onRemove:e.onRemove}),{gridProps:Et(s,m,{role:t.collection.size?"grid":"group","aria-atomic":!1,"aria-relevant":"additions","aria-live":c?"polite":"off",...h,...u}),labelProps:a,descriptionProps:l,errorMessageProps:o}}var wce={};wce={removeButtonLabel:"إزالة",removeDescription:"اضغط على مفتاح DELETE لإزالة علامة."};var Rce={};Rce={removeButtonLabel:"Премахване",removeDescription:"Натиснете Delete, за да премахнете маркера."};var Ace={};Ace={removeButtonLabel:"Odebrat",removeDescription:"Stisknutím klávesy Delete odeberete značku."};var Tce={};Tce={removeButtonLabel:"Fjern",removeDescription:"Tryk på Slet for at fjerne tag."};var kce={};kce={removeButtonLabel:"Entfernen",removeDescription:"Auf „Löschen“ drücken, um das Tag zu entfernen."};var Pce={};Pce={removeButtonLabel:"Κατάργηση",removeDescription:"Πατήστε Διαγραφή για να καταργήσετε την ετικέτα."};var Mce={};Mce={removeDescription:"Press Delete to remove tag.",removeButtonLabel:"Remove"};var Fce={};Fce={removeButtonLabel:"Quitar",removeDescription:"Pulse Eliminar para quitar la etiqueta."};var Nce={};Nce={removeButtonLabel:"Eemalda",removeDescription:"Sildi eemaldamiseks vajutage kustutusklahvi Delete."};var Ice={};Ice={removeButtonLabel:"Poista",removeDescription:"Poista tunniste painamalla Poista-painiketta."};var Lce={};Lce={removeButtonLabel:"Supprimer",removeDescription:"Appuyez sur Supprimer pour supprimer l’étiquette."};var Bce={};Bce={removeButtonLabel:"הסר",removeDescription:"לחץ על מחק כדי להסיר תג."};var Qce={};Qce={removeButtonLabel:"Ukloni",removeDescription:"Pritisnite Delete za uklanjanje oznake."};var zce={};zce={removeButtonLabel:"Eltávolítás",removeDescription:"Nyomja meg a Delete billentyűt a címke eltávolításához."};var qce={};qce={removeButtonLabel:"Rimuovi",removeDescription:"Premi Elimina per rimuovere il tag."};var Vce={};Vce={removeButtonLabel:"削除",removeDescription:"タグを削除するには、Delete キーを押します。"};var Uce={};Uce={removeButtonLabel:"제거",removeDescription:"태그를 제거하려면 Delete 키를 누르십시오."};var jce={};jce={removeButtonLabel:"Pašalinti",removeDescription:"Norėdami pašalinti žymą, paspauskite „Delete“ klavišą."};var Zce={};Zce={removeButtonLabel:"Noņemt",removeDescription:"Nospiediet Delete [Dzēst], lai noņemtu tagu."};var Hce={};Hce={removeButtonLabel:"Fjern",removeDescription:"Trykk på Slett for å fjerne taggen."};var Xce={};Xce={removeButtonLabel:"Verwijderen",removeDescription:"Druk op Verwijderen om de tag te verwijderen."};var Yce={};Yce={removeButtonLabel:"Usuń",removeDescription:"Naciśnij Usuń, aby usunąć znacznik."};var Gce={};Gce={removeButtonLabel:"Remover",removeDescription:"Pressione Delete para remover a tag."};var Kce={};Kce={removeButtonLabel:"Eliminar",removeDescription:"Prima Delete para eliminar a tag."};var Wce={};Wce={removeButtonLabel:"Îndepărtaţi",removeDescription:"Apăsați pe Delete (Ștergere) pentru a elimina eticheta."};var Jce={};Jce={removeButtonLabel:"Удалить",removeDescription:"Нажмите DELETE, чтобы удалить тег."};var efe={};efe={removeButtonLabel:"Odstrániť",removeDescription:"Ak chcete odstrániť značku, stlačte kláves Delete."};var tfe={};tfe={removeButtonLabel:"Odstrani",removeDescription:"Pritisnite Delete, da odstranite oznako."};var nfe={};nfe={removeButtonLabel:"Ukloni",removeDescription:"Pritisnite Obriši da biste uklonili oznaku."};var rfe={};rfe={removeButtonLabel:"Ta bort",removeDescription:"Tryck på Radera för att ta bort taggen."};var ife={};ife={removeButtonLabel:"Kaldır",removeDescription:"Etiketi kaldırmak için Sil tuşuna basın."};var afe={};afe={removeButtonLabel:"Вилучити",removeDescription:"Натисніть Delete, щоб вилучити тег."};var ufe={};ufe={removeButtonLabel:"删除",removeDescription:"按下“删除”以删除标记。"};var lfe={};lfe={removeButtonLabel:"移除",removeDescription:"按 Delete 鍵以移除標記。"};var ofe={};ofe={"ar-AE":wce,"bg-BG":Rce,"cs-CZ":Ace,"da-DK":Tce,"de-DE":kce,"el-GR":Pce,"en-US":Mce,"es-ES":Fce,"et-EE":Nce,"fi-FI":Ice,"fr-FR":Lce,"he-IL":Bce,"hr-HR":Qce,"hu-HU":zce,"it-IT":qce,"ja-JP":Vce,"ko-KR":Uce,"lt-LT":jce,"lv-LV":Zce,"nb-NO":Hce,"nl-NL":Xce,"pl-PL":Yce,"pt-BR":Gce,"pt-PT":Kce,"ro-RO":Wce,"ru-RU":Jce,"sk-SK":efe,"sl-SI":tfe,"sr-SP":nfe,"sv-SE":rfe,"tr-TR":ife,"uk-UA":afe,"zh-CN":ufe,"zh-TW":lfe};function kCe(e){return e&&e.__esModule?e.default:e}function PCe(e,t,n){let{item:r}=e,i=Fo(kCe(ofe),"@react-aria/tag"),a=pi(),{onRemove:u}=Cce.get(t)||{},{rowProps:l,gridCellProps:o,...s}=pCe({node:r},t,n),{descriptionProps:c,...d}=s,h=t.disabledKeys.has(r.key)||r.props.isDisabled,m=k=>{if(k.key==="Delete"||k.key==="Backspace"){if(h)return;k.preventDefault(),t.selectionManager.isSelected(r.key)?u==null||u(new Set(t.selectionManager.selectedKeys)):u==null||u(new Set([r.key]))}},y=DN();y==="virtual"&&typeof window<"u"&&"ontouchstart"in window&&(y="pointer");let v=u&&(y==="keyboard"||y==="virtual")?i.format("removeDescription"):"",_=NC(v),S=r.key===t.selectionManager.focusedKey,E=t.selectionManager.focusedKey!=null,C=-1;!h&&(S||!E)&&(C=0);let T=Gt(r.props),R=Hee(r.props),{focusableProps:$}=L0({isDisabled:h},n);return{removeButtonProps:{"aria-label":i.format("removeButtonLabel"),"aria-labelledby":`${a} ${l.id}`,isDisabled:h,id:a,onPress:()=>u?u(new Set([r.key])):null},rowProps:Et($,l,T,R,{tabIndex:C,onKeyDown:u?m:void 0,"aria-describedby":_["aria-describedby"]}),gridCellProps:Et(o,{"aria-errormessage":e["aria-errormessage"],"aria-label":e["aria-label"]}),...d,allowsRemoving:!!u}}var sfe={};sfe={close:"إغلاق",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} إشعار`,other:()=>`${t.number(e.count)} إشعارات`})}.`};var cfe={};cfe={close:"Затвори",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} известие`,other:()=>`${t.number(e.count)} известия`})}.`};var ffe={};ffe={close:"Zavřít",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} oznámení`,other:()=>`${t.number(e.count)} oznámení`})}.`};var dfe={};dfe={close:"Luk",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} besked`,other:()=>`${t.number(e.count)} beskeder`})}.`};var hfe={};hfe={close:"Schließen",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} Benachrichtigung`,other:()=>`${t.number(e.count)} Benachrichtigungen`})}.`};var pfe={};pfe={close:"Κλείσιμο",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} ειδοποίηση`,other:()=>`${t.number(e.count)} ειδοποιήσεις`})}.`};var mfe={};mfe={close:"Close",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} notification`,other:()=>`${t.number(e.count)} notifications`})}.`};var gfe={};gfe={close:"Cerrar",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} notificación`,other:()=>`${t.number(e.count)} notificaciones`})}.`};var vfe={};vfe={close:"Sule",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} teatis`,other:()=>`${t.number(e.count)} teatist`})}.`};var yfe={};yfe={close:"Sulje",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} ilmoitus`,other:()=>`${t.number(e.count)} ilmoitusta`})}.`};var bfe={};bfe={close:"Fermer",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} notification`,other:()=>`${t.number(e.count)} notifications`})}.`};var Ofe={};Ofe={close:"סגור",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} התראה`,other:()=>`${t.number(e.count)} התראות`})}.`};var xfe={};xfe={close:"Zatvori",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} obavijest`,other:()=>`${t.number(e.count)} obavijesti`})}.`};var Sfe={};Sfe={close:"Bezárás",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} értesítés`,other:()=>`${t.number(e.count)} értesítés`})}.`};var _fe={};_fe={close:"Chiudi",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} notifica`,other:()=>`${t.number(e.count)} notifiche`})}.`};var Efe={};Efe={close:"閉じる",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} 個の通知`,other:()=>`${t.number(e.count)} 個の通知`})}。`};var Dfe={};Dfe={close:"닫기",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)}개 알림`,other:()=>`${t.number(e.count)}개 알림`})}.`};var $fe={};$fe={close:"Uždaryti",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} pranešimas`,other:()=>`${t.number(e.count)} pranešimai`})}.`};var Cfe={};Cfe={close:"Aizvērt",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} paziņojums`,other:()=>`${t.number(e.count)} paziņojumi`})}.`};var wfe={};wfe={close:"Lukk",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} varsling`,other:()=>`${t.number(e.count)} varsler`})}.`};var Rfe={};Rfe={close:"Sluiten",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} melding`,other:()=>`${t.number(e.count)} meldingen`})}.`};var Afe={};Afe={close:"Zamknij",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} powiadomienie`,few:()=>`${t.number(e.count)} powiadomienia`,many:()=>`${t.number(e.count)} powiadomień`,other:()=>`${t.number(e.count)} powiadomienia`})}.`};var Tfe={};Tfe={close:"Fechar",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} notificação`,other:()=>`${t.number(e.count)} notificações`})}.`};var kfe={};kfe={close:"Fechar",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} notificação`,other:()=>`${t.number(e.count)} notificações`})}.`};var Pfe={};Pfe={close:"Închideţi",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} notificare`,other:()=>`${t.number(e.count)} notificări`})}.`};var Mfe={};Mfe={close:"Закрыть",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} уведомление`,other:()=>`${t.number(e.count)} уведомления`})}.`};var Ffe={};Ffe={close:"Zatvoriť",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} oznámenie`,few:()=>`${t.number(e.count)} oznámenia`,other:()=>`${t.number(e.count)} oznámení`})}.`};var Nfe={};Nfe={close:"Zapri",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} obvestilo`,two:()=>`${t.number(e.count)} obvestili`,few:()=>`${t.number(e.count)} obvestila`,other:()=>`${t.number(e.count)} obvestil`})}.`};var Ife={};Ife={close:"Zatvori",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} obaveštenje`,other:()=>`${t.number(e.count)} obaveštenja`})}.`};var Lfe={};Lfe={close:"Stäng",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} meddelande`,other:()=>`${t.number(e.count)} meddelanden`})}.`};var Bfe={};Bfe={close:"Kapat",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} bildirim`,other:()=>`${t.number(e.count)} bildirim`})}.`};var Qfe={};Qfe={close:"Закрити",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} сповіщення`,other:()=>`${t.number(e.count)} сповіщення`})}.`};var zfe={};zfe={close:"关闭",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} 个通知`,other:()=>`${t.number(e.count)} 个通知`})}。`};var qfe={};qfe={close:"關閉",notifications:(e,t)=>`${t.plural(e.count,{one:()=>`${t.number(e.count)} 個通知`,other:()=>`${t.number(e.count)} 個通知`})}。`};var YN={};YN={"ar-AE":sfe,"bg-BG":cfe,"cs-CZ":ffe,"da-DK":dfe,"de-DE":hfe,"el-GR":pfe,"en-US":mfe,"es-ES":gfe,"et-EE":vfe,"fi-FI":yfe,"fr-FR":bfe,"he-IL":Ofe,"hr-HR":xfe,"hu-HU":Sfe,"it-IT":_fe,"ja-JP":Efe,"ko-KR":Dfe,"lt-LT":$fe,"lv-LV":Cfe,"nb-NO":wfe,"nl-NL":Rfe,"pl-PL":Afe,"pt-BR":Tfe,"pt-PT":kfe,"ro-RO":Pfe,"ru-RU":Mfe,"sk-SK":Ffe,"sl-SI":Nfe,"sr-SP":Ife,"sv-SE":Lfe,"tr-TR":Bfe,"uk-UA":Qfe,"zh-CN":zfe,"zh-TW":qfe};function MCe(e){return e&&e.__esModule?e.default:e}function FCe(e,t,n){let{key:r,timer:i,timeout:a}=e.toast;P.useEffect(()=>{if(!(i==null||a==null))return i.reset(a),()=>{i.pause()}},[i,a]);let u=pi(),l=C0(),o=Fo(MCe(YN),"@react-aria/toast"),[s,c]=P.useState(!1);return P.useEffect(()=>{c(!0)},[]),{toastProps:{...Gt(e,{labelable:!0}),role:"alertdialog","aria-modal":"false","aria-labelledby":e["aria-labelledby"]||u,"aria-describedby":e["aria-describedby"]||l,tabIndex:0},contentProps:{role:"alert","aria-atomic":"true","aria-hidden":s?void 0:"true"},titleProps:{id:u},descriptionProps:{id:l},closeButtonProps:{"aria-label":o.format("close"),onPress:()=>t.close(r)}}}function NCe(e){return e&&e.__esModule?e.default:e}function ICe(e,t,n){let r=Fo(NCe(YN),"@react-aria/toast"),{landmarkProps:i}=yCe({role:"region","aria-label":e["aria-label"]||r.format("notifications",{count:t.visibleToasts.length})},n),a=P.useRef(!1),u=P.useRef(!1),l=oi(()=>{a.current||u.current?t.pauseAll():t.resumeAll()}),{hoverProps:o}=Cu({onHoverStart:()=>{a.current=!0,l()},onHoverEnd:()=>{a.current=!1,l()}}),s=P.useRef([]),c=P.useRef(t.visibleToasts),d=P.useRef(null);qr(()=>{if(d.current===-1||t.visibleToasts.length===0||!n.current){s.current=[],c.current=t.visibleToasts;return}if(s.current=[...n.current.querySelectorAll('[role="alertdialog"]')],c.current.length===t.visibleToasts.length&&t.visibleToasts.every((S,E)=>S.key===c.current[E].key)){c.current=t.visibleToasts;return}let y=c.current.map((S,E)=>({...S,i:E,isRemoved:!t.visibleToasts.some(C=>S.key===C.key)})),v=y.findIndex(S=>S.i===d.current&&S.isRemoved);if(v>-1){var _;if(rg()==="pointer"&&(!((_=h.current)===null||_===void 0)&&_.isConnected))_u(h.current);else{let S=0,E,C;for(;S<=v;)y[S].isRemoved||(C=Math.max(0,S-1)),S++;for(;S<y.length;){if(!y[S].isRemoved){E=S-1;break}S++}C===void 0&&E===void 0&&(C=0),C>=0&&C<s.current.length?_u(s.current[C]):E>=0&&E<s.current.length&&_u(s.current[E])}}c.current=t.visibleToasts},[t.visibleToasts,n,l]);let h=P.useRef(null),{focusWithinProps:m}=B0({onFocusWithin:y=>{u.current=!0,h.current=y.relatedTarget,l()},onBlurWithin:()=>{u.current=!1,h.current=null,l()}});return P.useEffect(()=>{var y;t.visibleToasts.length===0&&(!((y=h.current)===null||y===void 0)&&y.isConnected)&&(rg()==="pointer"?_u(h.current):h.current.focus(),h.current=null)},[n,t.visibleToasts.length]),P.useEffect(()=>()=>{var y;!((y=h.current)===null||y===void 0)&&y.isConnected&&(rg()==="pointer"?_u(h.current):h.current.focus(),h.current=null)},[n]),{regionProps:Et(i,o,m,{tabIndex:-1,"data-react-aria-top-layer":!0,onFocus:y=>{let v=y.target.closest('[role="alertdialog"]');d.current=s.current.findIndex(_=>_===v)},onBlur:()=>{d.current=-1}})}}function LCe(e,t){let n=Gt(e,{labelable:!0}),{hoverProps:r}=Cu({onHoverStart:()=>t==null?void 0:t.open(!0),onHoverEnd:()=>t==null?void 0:t.close()});return{tooltipProps:Et(n,r,{role:"tooltip"})}}function BCe(e,t,n){let{isDisabled:r,trigger:i}=e,a=pi(),u=P.useRef(!1),l=P.useRef(!1),o=()=>{(u.current||l.current)&&t.open(l.current)},s=S=>{!u.current&&!l.current&&t.close(S)};P.useEffect(()=>{let S=E=>{n&&n.current&&E.key==="Escape"&&(E.stopPropagation(),t.close(!0))};if(t.isOpen)return document.addEventListener("keydown",S,!0),()=>{document.removeEventListener("keydown",S,!0)}},[n,t]);let c=()=>{i!=="focus"&&(rg()==="pointer"?u.current=!0:u.current=!1,o())},d=()=>{i!=="focus"&&(l.current=!1,u.current=!1,s())},h=()=>{l.current=!1,u.current=!1,s(!0)},m=()=>{Jv()&&(l.current=!0,o())},y=()=>{l.current=!1,u.current=!1,s(!0)},{hoverProps:v}=Cu({isDisabled:r,onHoverStart:c,onHoverEnd:d}),{focusableProps:_}=L0({isDisabled:r,onFocus:m,onBlur:y},n);return{triggerProps:{"aria-describedby":t.isOpen?a:void 0,...Et(_,v,{onPointerDown:h,onKeyDown:h}),tabIndex:void 0},tooltipProps:{id:a}}}const QCe=P.createContext(null),Z9=P.createContext(null),Mrt=P.forwardRef(function(t,n){[t,n]=In(t,n,Z9);let{CollectionRoot:r}=P.useContext(pp),{navProps:i}=O$e(t),a=Gt(t,{global:!0});return ye.createElement(Cb,{content:ye.createElement(mS,t)},u=>{var l;return ye.createElement("ol",{ref:n,...Et(a,i),slot:t.slot||void 0,style:t.style,className:(l=t.className)!==null&&l!==void 0?l:"react-aria-Breadcrumbs"},ye.createElement(Z9.Provider,{value:t},ye.createElement(r,{collection:u})))})});class Vfe extends gy{}Vfe.type="item";const Frt=wb(Vfe,function(t,n,r){let i=r.nextKey==null,{isDisabled:a,onAction:u}=vs(Z9),l={"aria-current":i?"page":null,isDisabled:a||i,onPress:()=>u==null?void 0:u(r.key)},o=wn({...r.props,children:r.rendered,values:{isDisabled:a||i,isCurrent:i},defaultClassName:"react-aria-Breadcrumb"}),s=Gt(t,{global:!0});return delete s.id,ye.createElement("li",{...s,...o,ref:n,"data-disabled":a||i||void 0,"data-current":i||void 0},ye.createElement(QCe.Provider,{value:l},o.children))}),bs=P.createContext({}),Nrt=$b(function(t,n){[t,n]=In(t,n,bs);let{elementType:r="label",...i}=t;return ye.createElement(r,{className:"react-aria-Label",...i,ref:n})}),Ufe=P.createContext(null),Irt=P.forwardRef(function(t,n){[t,n]=In(t,n,Ufe);let{value:r=0,minValue:i=0,maxValue:a=100,isIndeterminate:u=!1}=t;r=ro(r,i,a);let[l,o]=ys(!t["aria-label"]&&!t["aria-labelledby"]),{progressBarProps:s,labelProps:c}=bCe({...t,label:o}),d=u?void 0:(r-i)/(a-i)*100,h=wn({...t,defaultClassName:"react-aria-ProgressBar",values:{percentage:d,valueText:s["aria-valuetext"],isIndeterminate:u}}),m=Gt(t,{global:!0});return ye.createElement("div",{...Et(m,h,s),ref:n,slot:t.slot||void 0},ye.createElement(bs.Provider,{value:{...c,ref:l,elementType:"span"}},h.children))}),ih=P.createContext({}),Lrt=$b(function(t,n){[t,n]=In(t,n,ih);let r=t,{isPending:i}=r,{buttonProps:a,isPressed:u}=Sue(t,n);a=zCe(a,i);let{focusProps:l,isFocused:o,isFocusVisible:s}=Hu(t),{hoverProps:c,isHovered:d}=Cu({...t,isDisabled:t.isDisabled||i}),h={isHovered:d,isPressed:(r.isPressed||u)&&!i,isFocused:o,isFocusVisible:s,isDisabled:t.isDisabled||!1,isPending:i??!1},m=wn({...t,values:h,defaultClassName:"react-aria-Button"}),y=pi(a.id),v=pi(),_=a["aria-labelledby"];i&&(_?_=`${_} ${v}`:a["aria-label"]&&(_=`${y} ${v}`));let S=P.useRef(i);P.useEffect(()=>{let C={"aria-labelledby":_||y};(!S.current&&o&&i||S.current&&o&&!i)&&j1(C,"assertive"),S.current=i},[i,o,_,y]);let E=Gt(t,{global:!0});return delete E.onClick,ye.createElement("button",{...Et(E,m,a,l,c),type:a.type==="submit"&&i?"button":a.type,id:y,ref:n,"aria-labelledby":_,slot:t.slot||void 0,"aria-disabled":i?"true":a["aria-disabled"],"data-disabled":t.isDisabled||void 0,"data-pressed":h.isPressed||void 0,"data-hovered":d||void 0,"data-focused":o||void 0,"data-pending":i||void 0,"data-focus-visible":s||void 0},ye.createElement(Ufe.Provider,{value:{id:v}},m.children))});function zCe(e,t){if(t){for(const n in e)n.startsWith("on")&&!(n.includes("Focus")||n.includes("Blur"))&&(e[n]=void 0);e.href=void 0,e.target=void 0}return e}const No=P.createContext({}),qCe=P.forwardRef(function(t,n){[t,n]=In(t,n,No);let{elementType:r="span",...i}=t;return ye.createElement(r,{className:"react-aria-Text",...i,ref:n})});class H9{*[Symbol.iterator](){yield*this.iterable}get size(){return this._size}getKeys(){return this.keyMap.keys()}getKeyBefore(t){let n=this.keyMap.get(t);var r;return n&&(r=n.prevKey)!==null&&r!==void 0?r:null}getKeyAfter(t){let n=this.keyMap.get(t);var r;return n&&(r=n.nextKey)!==null&&r!==void 0?r:null}getFirstKey(){return this.firstKey}getLastKey(){return this.lastKey}getItem(t){var n;return(n=this.keyMap.get(t))!==null&&n!==void 0?n:null}at(t){const n=[...this.getKeys()];return this.getItem(n[t])}getChildren(t){let n=this.keyMap.get(t);return(n==null?void 0:n.childNodes)||[]}constructor(t){this.keyMap=new Map,this.firstKey=null,this.lastKey=null,this.iterable=t;let n=l=>{if(this.keyMap.set(l.key,l),l.childNodes&&l.type==="section")for(let o of l.childNodes)n(o)};for(let l of t)n(l);let r=null,i=0,a=0;for(let[l,o]of this.keyMap)r?(r.nextKey=l,o.prevKey=r.key):(this.firstKey=l,o.prevKey=void 0),o.type==="item"&&(o.index=i++),(o.type==="section"||o.type==="item")&&a++,r=o,r.nextKey=void 0;this._size=a;var u;this.lastKey=(u=r==null?void 0:r.key)!==null&&u!==void 0?u:null}}class Yh extends Set{constructor(t,n,r){super(t),t instanceof Yh?(this.anchorKey=n??t.anchorKey,this.currentKey=r??t.currentKey):(this.anchorKey=n??null,this.currentKey=r??null)}}function VCe(e,t){if(e.size!==t.size)return!1;for(let n of e)if(!t.has(n))return!1;return!0}function GN(e){let{selectionMode:t="none",disallowEmptySelection:n=!1,allowDuplicateSelectionEvents:r,selectionBehavior:i="toggle",disabledBehavior:a="all"}=e,u=P.useRef(!1),[,l]=P.useState(!1),o=P.useRef(null),s=P.useRef(null),[,c]=P.useState(null),d=P.useMemo(()=>Qj(e.selectedKeys),[e.selectedKeys]),h=P.useMemo(()=>Qj(e.defaultSelectedKeys,new Yh),[e.defaultSelectedKeys]),[m,y]=Zu(d,h,e.onSelectionChange),v=P.useMemo(()=>e.disabledKeys?new Set(e.disabledKeys):new Set,[e.disabledKeys]),[_,S]=P.useState(i);i==="replace"&&_==="toggle"&&typeof m=="object"&&m.size===0&&S("replace");let E=P.useRef(i);return P.useEffect(()=>{i!==E.current&&(S(i),E.current=i)},[i]),{selectionMode:t,disallowEmptySelection:n,selectionBehavior:_,setSelectionBehavior:S,get isFocused(){return u.current},setFocused(C){u.current=C,l(C)},get focusedKey(){return o.current},get childFocusStrategy(){return s.current},setFocusedKey(C,T="first"){o.current=C,s.current=T,c(C)},selectedKeys:m,setSelectedKeys(C){(r||!VCe(C,m))&&y(C)},disabledKeys:v,disabledBehavior:a}}function Qj(e,t){return e?e==="all"?"all":new Yh(e):t}class gS{get selectionMode(){return this.state.selectionMode}get disallowEmptySelection(){return this.state.disallowEmptySelection}get selectionBehavior(){return this.state.selectionBehavior}setSelectionBehavior(t){this.state.setSelectionBehavior(t)}get isFocused(){return this.state.isFocused}setFocused(t){this.state.setFocused(t)}get focusedKey(){return this.state.focusedKey}get childFocusStrategy(){return this.state.childFocusStrategy}setFocusedKey(t,n){(t==null||this.collection.getItem(t))&&this.state.setFocusedKey(t,n)}get selectedKeys(){return this.state.selectedKeys==="all"?new Set(this.getSelectAllKeys()):this.state.selectedKeys}get rawSelection(){return this.state.selectedKeys}isSelected(t){if(this.state.selectionMode==="none")return!1;let n=this.getKey(t);return n==null?!1:this.state.selectedKeys==="all"?this.canSelectItem(n):this.state.selectedKeys.has(n)}get isEmpty(){return this.state.selectedKeys!=="all"&&this.state.selectedKeys.size===0}get isSelectAll(){if(this.isEmpty)return!1;if(this.state.selectedKeys==="all")return!0;if(this._isSelectAll!=null)return this._isSelectAll;let t=this.getSelectAllKeys(),n=this.state.selectedKeys;return this._isSelectAll=t.every(r=>n.has(r)),this._isSelectAll}get firstSelectedKey(){let t=null;for(let r of this.state.selectedKeys){let i=this.collection.getItem(r);(!t||i&&ik(this.collection,i,t)<0)&&(t=i)}var n;return(n=t==null?void 0:t.key)!==null&&n!==void 0?n:null}get lastSelectedKey(){let t=null;for(let r of this.state.selectedKeys){let i=this.collection.getItem(r);(!t||i&&ik(this.collection,i,t)>0)&&(t=i)}var n;return(n=t==null?void 0:t.key)!==null&&n!==void 0?n:null}get disabledKeys(){return this.state.disabledKeys}get disabledBehavior(){return this.state.disabledBehavior}extendSelection(t){if(this.selectionMode==="none")return;if(this.selectionMode==="single"){this.replaceSelection(t);return}let n=this.getKey(t);if(n==null)return;let r;if(this.state.selectedKeys==="all")r=new Yh([n],n,n);else{let u=this.state.selectedKeys;var i;let l=(i=u.anchorKey)!==null&&i!==void 0?i:n;r=new Yh(u,l,n);var a;for(let o of this.getKeyRange(l,(a=u.currentKey)!==null&&a!==void 0?a:n))r.delete(o);for(let o of this.getKeyRange(n,l))this.canSelectItem(o)&&r.add(o)}this.state.setSelectedKeys(r)}getKeyRange(t,n){let r=this.collection.getItem(t),i=this.collection.getItem(n);return r&&i?ik(this.collection,r,i)<=0?this.getKeyRangeInternal(t,n):this.getKeyRangeInternal(n,t):[]}getKeyRangeInternal(t,n){var r;if(!((r=this.layoutDelegate)===null||r===void 0)&&r.getKeyRange)return this.layoutDelegate.getKeyRange(t,n);let i=[],a=t;for(;a!=null;){let u=this.collection.getItem(a);if(u&&(u.type==="item"||u.type==="cell"&&this.allowsCellSelection)&&i.push(a),a===n)return i;a=this.collection.getKeyAfter(a)}return[]}getKey(t){let n=this.collection.getItem(t);if(!n||n.type==="cell"&&this.allowsCellSelection)return t;for(;n&&n.type!=="item"&&n.parentKey!=null;)n=this.collection.getItem(n.parentKey);return!n||n.type!=="item"?null:n.key}toggleSelection(t){if(this.selectionMode==="none")return;if(this.selectionMode==="single"&&!this.isSelected(t)){this.replaceSelection(t);return}let n=this.getKey(t);if(n==null)return;let r=new Yh(this.state.selectedKeys==="all"?this.getSelectAllKeys():this.state.selectedKeys);r.has(n)?r.delete(n):this.canSelectItem(n)&&(r.add(n),r.anchorKey=n,r.currentKey=n),!(this.disallowEmptySelection&&r.size===0)&&this.state.setSelectedKeys(r)}replaceSelection(t){if(this.selectionMode==="none")return;let n=this.getKey(t);if(n==null)return;let r=this.canSelectItem(n)?new Yh([n],n,n):new Yh;this.state.setSelectedKeys(r)}setSelectedKeys(t){if(this.selectionMode==="none")return;let n=new Yh;for(let r of t){let i=this.getKey(r);if(i!=null&&(n.add(i),this.selectionMode==="single"))break}this.state.setSelectedKeys(n)}getSelectAllKeys(){let t=[],n=r=>{for(;r!=null;){if(this.canSelectItem(r)){var i;let u=this.collection.getItem(r);(u==null?void 0:u.type)==="item"&&t.push(r);var a;u!=null&&u.hasChildNodes&&(this.allowsCellSelection||u.type!=="item")&&n((a=(i=PDe(ZC(u,this.collection)))===null||i===void 0?void 0:i.key)!==null&&a!==void 0?a:null)}r=this.collection.getKeyAfter(r)}};return n(this.collection.getFirstKey()),t}selectAll(){!this.isSelectAll&&this.selectionMode==="multiple"&&this.state.setSelectedKeys("all")}clearSelection(){!this.disallowEmptySelection&&(this.state.selectedKeys==="all"||this.state.selectedKeys.size>0)&&this.state.setSelectedKeys(new Yh)}toggleSelectAll(){this.isSelectAll?this.clearSelection():this.selectAll()}select(t,n){this.selectionMode!=="none"&&(this.selectionMode==="single"?this.isSelected(t)&&!this.disallowEmptySelection?this.toggleSelection(t):this.replaceSelection(t):this.selectionBehavior==="toggle"||n&&(n.pointerType==="touch"||n.pointerType==="virtual")?this.toggleSelection(t):this.replaceSelection(t))}isSelectionEqual(t){if(t===this.state.selectedKeys)return!0;let n=this.selectedKeys;if(t.size!==n.size)return!1;for(let r of t)if(!n.has(r))return!1;for(let r of n)if(!t.has(r))return!1;return!0}canSelectItem(t){var n;if(this.state.selectionMode==="none"||this.state.disabledKeys.has(t))return!1;let r=this.collection.getItem(t);return!(!r||!(r==null||(n=r.props)===null||n===void 0)&&n.isDisabled||r.type==="cell"&&!this.allowsCellSelection)}isDisabled(t){var n,r;return this.state.disabledBehavior==="all"&&(this.state.disabledKeys.has(t)||!!(!((r=this.collection.getItem(t))===null||r===void 0||(n=r.props)===null||n===void 0)&&n.isDisabled))}isLink(t){var n,r;return!!(!((r=this.collection.getItem(t))===null||r===void 0||(n=r.props)===null||n===void 0)&&n.href)}getItemProps(t){var n;return(n=this.collection.getItem(t))===null||n===void 0?void 0:n.props}withCollection(t){return new gS(t,this.state,{allowsCellSelection:this.allowsCellSelection,layoutDelegate:this.layoutDelegate||void 0})}constructor(t,n,r){this.collection=t,this.state=n;var i;this.allowsCellSelection=(i=r==null?void 0:r.allowsCellSelection)!==null&&i!==void 0?i:!1,this._isSelectAll=null,this.layoutDelegate=(r==null?void 0:r.layoutDelegate)||null}}function GC(e){let{filter:t,layoutDelegate:n}=e,r=GN(e),i=P.useMemo(()=>e.disabledKeys?new Set(e.disabledKeys):new Set,[e.disabledKeys]),a=P.useCallback(s=>t?new H9(t(s)):new H9(s),[t]),u=P.useMemo(()=>({suppressTextValueWarning:e.suppressTextValueWarning}),[e.suppressTextValueWarning]),l=Rre(e,a,u),o=P.useMemo(()=>new gS(l,r,{layoutDelegate:n}),[l,r,n]);return Zfe(l,o),{collection:l,disabledKeys:i,selectionManager:o}}function jfe(e,t){let n=P.useMemo(()=>t?e.collection.filter(t):e.collection,[e.collection,t]),r=e.selectionManager.withCollection(n);return Zfe(n,r),{collection:n,selectionManager:r,disabledKeys:e.disabledKeys}}function Zfe(e,t){const n=P.useRef(null);P.useEffect(()=>{if(t.focusedKey!=null&&!e.getItem(t.focusedKey)&&n.current){const c=n.current.getItem(t.focusedKey),d=[...n.current.getKeys()].map(S=>{const E=n.current.getItem(S);return(E==null?void 0:E.type)==="item"?E:null}).filter(S=>S!==null),h=[...e.getKeys()].map(S=>{const E=e.getItem(S);return(E==null?void 0:E.type)==="item"?E:null}).filter(S=>S!==null);var r,i;const m=((r=d==null?void 0:d.length)!==null&&r!==void 0?r:0)-((i=h==null?void 0:h.length)!==null&&i!==void 0?i:0);var a,u,l;let y=Math.min(m>1?Math.max(((a=c==null?void 0:c.index)!==null&&a!==void 0?a:0)-m+1,0):(u=c==null?void 0:c.index)!==null&&u!==void 0?u:0,((l=h==null?void 0:h.length)!==null&&l!==void 0?l:0)-1),v=null,_=!1;for(;y>=0;){if(!t.isDisabled(h[y].key)){v=h[y];break}if(y<h.length-1&&!_)y++;else{_=!0;var o,s;y>((o=c==null?void 0:c.index)!==null&&o!==void 0?o:0)&&(y=(s=c==null?void 0:c.index)!==null&&s!==void 0?s:0),y--}}t.setFocusedKey(v?v.key:null)}n.current=e},[e,t])}function Hfe(e){var t;let[n,r]=Zu(e.selectedKey,(t=e.defaultSelectedKey)!==null&&t!==void 0?t:null,e.onSelectionChange),i=P.useMemo(()=>n!=null?[n]:[],[n]),{collection:a,disabledKeys:u,selectionManager:l}=GC({...e,selectionMode:"single",disallowEmptySelection:!0,allowDuplicateSelectionEvents:!0,selectedKeys:i,onSelectionChange:s=>{if(s==="all")return;var c;let d=(c=s.values().next().value)!==null&&c!==void 0?c:null;d===n&&e.onSelectionChange&&e.onSelectionChange(d),r(d)}}),o=n!=null?a.getItem(n):null;return{collection:a,disabledKeys:u,selectionManager:l,selectedKey:n,setSelectedKey:r,selectedItem:o}}function H3(e){let[t,n]=Zu(e.isOpen,e.defaultOpen||!1,e.onOpenChange);const r=P.useCallback(()=>{n(!0)},[n]),i=P.useCallback(()=>{n(!1)},[n]),a=P.useCallback(()=>{n(!t)},[n,t]);return{isOpen:t,setOpen:n,open:r,close:i,toggle:a}}function UCe(e){var t;let{defaultFilter:n,menuTrigger:r="input",allowsEmptyCollection:i=!1,allowsCustomValue:a,shouldCloseOnBlur:u=!0}=e,[l,o]=P.useState(!1),[s,c]=P.useState(!1),[d,h]=P.useState(null),m=$e=>{e.onSelectionChange&&e.onSelectionChange($e),$e===S&&(B(),M())};var y;let{collection:v,selectionManager:_,selectedKey:S,setSelectedKey:E,selectedItem:C,disabledKeys:T}=Hfe({...e,onSelectionChange:m,items:(y=e.items)!==null&&y!==void 0?y:e.defaultItems}),[R,$]=Zu(e.inputValue,zj(e.defaultInputValue,S,v)||"",e.onInputChange),[k]=P.useState(S),[F]=P.useState(R),L=v,j=P.useMemo(()=>e.items!=null||!n?v:jCe(v,R,n),[v,R,n,e.items]),[V,q]=P.useState(j),N=P.useRef("focus"),W=H3({...e,onOpenChange:$e=>{e.onOpenChange&&e.onOpenChange($e,$e?N.current:void 0),_.setFocused($e),$e||_.setFocusedKey(null)},isOpen:void 0,defaultOpen:void 0}),G=($e=null,Ae)=>{let Ue=Ae==="manual"||Ae==="focus"&&r==="focus";(i||j.size>0||Ue&&L.size>0||e.items)&&(Ue&&!W.isOpen&&e.items===void 0&&o(!0),N.current=Ae,h($e),W.open())},J=($e=null,Ae)=>{let Ue=Ae==="manual"||Ae==="focus"&&r==="focus";!(i||j.size>0||Ue&&L.size>0||e.items)&&!W.isOpen||(Ue&&!W.isOpen&&e.items===void 0&&o(!0),W.isOpen||(N.current=Ae),H($e))},te=P.useCallback(()=>{q(l?L:j)},[l,L,j]),H=P.useCallback(($e=null)=>{W.isOpen&&te(),h($e),W.toggle()},[W,te]),M=P.useCallback(()=>{W.isOpen&&(te(),W.close())},[W,te]),[K,X]=P.useState(R),B=()=>{var $e,Ae;let Ue=S!=null&&(Ae=($e=v.getItem(S))===null||$e===void 0?void 0:$e.textValue)!==null&&Ae!==void 0?Ae:"";X(Ue),$(Ue)};var ne,oe;let ie=P.useRef((oe=(ne=e.selectedKey)!==null&&ne!==void 0?ne:e.defaultSelectedKey)!==null&&oe!==void 0?oe:null);var de;let be=P.useRef(S!=null&&(de=(t=v.getItem(S))===null||t===void 0?void 0:t.textValue)!==null&&de!==void 0?de:"");P.useEffect(()=>{var $e;s&&(j.size>0||i)&&!W.isOpen&&R!==K&&r!=="manual"&&G(null,"input"),!l&&!i&&W.isOpen&&j.size===0&&M(),S!=null&&S!==ie.current&&M(),R!==K&&(_.setFocusedKey(null),o(!1),R===""&&(e.inputValue===void 0||e.selectedKey===void 0)&&E(null)),S!==ie.current&&(e.inputValue===void 0||e.selectedKey===void 0)?B():K!==R&&X(R);var Ae;let Ue=S!=null&&(Ae=($e=v.getItem(S))===null||$e===void 0?void 0:$e.textValue)!==null&&Ae!==void 0?Ae:"";!s&&S!=null&&e.inputValue===void 0&&S===ie.current&&be.current!==Ue&&(X(Ue),$(Ue)),ie.current=S,be.current=Ue});let ve=bg({...e,value:P.useMemo(()=>({inputValue:R,selectedKey:S}),[R,S])}),pe=()=>{a&&S==null?_e():se()},_e=()=>{ie.current=null,E(null),M()},se=()=>{if(e.selectedKey!==void 0&&e.inputValue!==void 0){var $e,Ae;($e=e.onSelectionChange)===null||$e===void 0||$e.call(e,S);var Ue;let Ze=S!=null&&(Ue=(Ae=v.getItem(S))===null||Ae===void 0?void 0:Ae.textValue)!==null&&Ue!==void 0?Ue:"";X(Ze),M()}else B(),M()};const me=()=>{if(a){var $e,Ae;const Ue=S!=null&&(Ae=($e=v.getItem(S))===null||$e===void 0?void 0:$e.textValue)!==null&&Ae!==void 0?Ae:"";R===Ue?se():_e()}else se()};let ge=()=>{W.isOpen&&_.focusedKey!=null?S===_.focusedKey?se():E(_.focusedKey):me()},we=P.useRef(R),Ne=$e=>{$e?(we.current=R,r==="focus"&&!e.isReadOnly&&G(null,"focus")):(u&&me(),R!==we.current&&ve.commitValidation()),c($e)},Re=P.useMemo(()=>W.isOpen?l?L:j:V,[W.isOpen,L,j,l,V]);var et;let tt=(et=e.defaultSelectedKey)!==null&&et!==void 0?et:k;var Oe;return{...ve,...W,focusStrategy:d,toggle:J,open:G,close:me,selectionManager:_,selectedKey:S,defaultSelectedKey:tt,setSelectedKey:E,disabledKeys:T,isFocused:s,setFocused:Ne,selectedItem:C,collection:Re,inputValue:R,defaultInputValue:(Oe=zj(e.defaultInputValue,tt,v))!==null&&Oe!==void 0?Oe:F,setInputValue:$,commit:ge,revert:pe}}function jCe(e,t,n){return new H9(Xfe(e,e,t,n))}function Xfe(e,t,n,r){let i=[];for(let a of t)if(a.type==="section"&&a.hasChildNodes){let u=Xfe(e,ZC(a,e),n,r);[...u].some(l=>l.type==="item")&&i.push({...a,childNodes:u})}else a.type==="item"&&r(a.textValue,n)?i.push({...a}):a.type!=="item"&&i.push({...a});return i}function zj(e,t,n){if(e==null){var r,i;if(t!=null)return(i=(r=n.getItem(t))===null||r===void 0?void 0:r.textValue)!==null&&i!==void 0?i:""}return e}var Yfe={};Yfe={rangeOverflow:e=>`يجب أن تكون القيمة ${e.maxValue} أو قبل ذلك.`,rangeReversed:"تاريخ البدء يجب أن يكون قبل تاريخ الانتهاء.",rangeUnderflow:e=>`يجب أن تكون القيمة ${e.minValue} أو بعد ذلك.`,unavailableDate:"البيانات المحددة غير متاحة."};var Gfe={};Gfe={rangeOverflow:e=>`Стойността трябва да е ${e.maxValue} или по-ранна.`,rangeReversed:"Началната дата трябва да е преди крайната.",rangeUnderflow:e=>`Стойността трябва да е ${e.minValue} или по-късно.`,unavailableDate:"Избраната дата не е налична."};var Kfe={};Kfe={rangeOverflow:e=>`Hodnota musí být ${e.maxValue} nebo dřívější.`,rangeReversed:"Datum zahájení musí předcházet datu ukončení.",rangeUnderflow:e=>`Hodnota musí být ${e.minValue} nebo pozdější.`,unavailableDate:"Vybrané datum není k dispozici."};var Wfe={};Wfe={rangeOverflow:e=>`Værdien skal være ${e.maxValue} eller tidligere.`,rangeReversed:"Startdatoen skal være før slutdatoen.",rangeUnderflow:e=>`Værdien skal være ${e.minValue} eller nyere.`,unavailableDate:"Den valgte dato er ikke tilgængelig."};var Jfe={};Jfe={rangeOverflow:e=>`Der Wert muss ${e.maxValue} oder früher sein.`,rangeReversed:"Das Startdatum muss vor dem Enddatum liegen.",rangeUnderflow:e=>`Der Wert muss ${e.minValue} oder später sein.`,unavailableDate:"Das ausgewählte Datum ist nicht verfügbar."};var ede={};ede={rangeOverflow:e=>`Η τιμή πρέπει να είναι ${e.maxValue} ή παλαιότερη.`,rangeReversed:"Η ημερομηνία έναρξης πρέπει να είναι πριν από την ημερομηνία λήξης.",rangeUnderflow:e=>`Η τιμή πρέπει να είναι ${e.minValue} ή μεταγενέστερη.`,unavailableDate:"Η επιλεγμένη ημερομηνία δεν είναι διαθέσιμη."};var tde={};tde={rangeUnderflow:e=>`Value must be ${e.minValue} or later.`,rangeOverflow:e=>`Value must be ${e.maxValue} or earlier.`,rangeReversed:"Start date must be before end date.",unavailableDate:"Selected date unavailable."};var nde={};nde={rangeOverflow:e=>`El valor debe ser ${e.maxValue} o anterior.`,rangeReversed:"La fecha de inicio debe ser anterior a la fecha de finalización.",rangeUnderflow:e=>`El valor debe ser ${e.minValue} o posterior.`,unavailableDate:"Fecha seleccionada no disponible."};var rde={};rde={rangeOverflow:e=>`Väärtus peab olema ${e.maxValue} või varasem.`,rangeReversed:"Alguskuupäev peab olema enne lõppkuupäeva.",rangeUnderflow:e=>`Väärtus peab olema ${e.minValue} või hilisem.`,unavailableDate:"Valitud kuupäev pole saadaval."};var ide={};ide={rangeOverflow:e=>`Arvon on oltava ${e.maxValue} tai sitä aikaisempi.`,rangeReversed:"Aloituspäivän on oltava ennen lopetuspäivää.",rangeUnderflow:e=>`Arvon on oltava ${e.minValue} tai sitä myöhäisempi.`,unavailableDate:"Valittu päivämäärä ei ole käytettävissä."};var ade={};ade={rangeOverflow:e=>`La valeur doit être ${e.maxValue} ou antérieure.`,rangeReversed:"La date de début doit être antérieure à la date de fin.",rangeUnderflow:e=>`La valeur doit être ${e.minValue} ou ultérieure.`,unavailableDate:"La date sélectionnée n’est pas disponible."};var ude={};ude={rangeOverflow:e=>`הערך חייב להיות ${e.maxValue} או מוקדם יותר.`,rangeReversed:"תאריך ההתחלה חייב להיות לפני תאריך הסיום.",rangeUnderflow:e=>`הערך חייב להיות ${e.minValue} או מאוחר יותר.`,unavailableDate:"התאריך הנבחר אינו זמין."};var lde={};lde={rangeOverflow:e=>`Vrijednost mora biti ${e.maxValue} ili ranije.`,rangeReversed:"Datum početka mora biti prije datuma završetka.",rangeUnderflow:e=>`Vrijednost mora biti ${e.minValue} ili kasnije.`,unavailableDate:"Odabrani datum nije dostupan."};var ode={};ode={rangeOverflow:e=>`Az értéknek ${e.maxValue} vagy korábbinak kell lennie.`,rangeReversed:"A kezdő dátumnak a befejező dátumnál korábbinak kell lennie.",rangeUnderflow:e=>`Az értéknek ${e.minValue} vagy későbbinek kell lennie.`,unavailableDate:"A kiválasztott dátum nem érhető el."};var sde={};sde={rangeOverflow:e=>`Il valore deve essere ${e.maxValue} o precedente.`,rangeReversed:"La data di inizio deve essere antecedente alla data di fine.",rangeUnderflow:e=>`Il valore deve essere ${e.minValue} o successivo.`,unavailableDate:"Data selezionata non disponibile."};var cde={};cde={rangeOverflow:e=>`値は ${e.maxValue} 以下にする必要があります。`,rangeReversed:"開始日は終了日より前にする必要があります。",rangeUnderflow:e=>`値は ${e.minValue} 以上にする必要があります。`,unavailableDate:"選択した日付は使用できません。"};var fde={};fde={rangeOverflow:e=>`값은 ${e.maxValue} 이전이어야 합니다.`,rangeReversed:"시작일은 종료일 이전이어야 합니다.",rangeUnderflow:e=>`값은 ${e.minValue} 이상이어야 합니다.`,unavailableDate:"선택한 날짜를 사용할 수 없습니다."};var dde={};dde={rangeOverflow:e=>`Reikšmė turi būti ${e.maxValue} arba ankstesnė.`,rangeReversed:"Pradžios data turi būti ankstesnė nei pabaigos data.",rangeUnderflow:e=>`Reikšmė turi būti ${e.minValue} arba naujesnė.`,unavailableDate:"Pasirinkta data nepasiekiama."};var hde={};hde={rangeOverflow:e=>`Vērtībai ir jābūt ${e.maxValue} vai agrākai.`,rangeReversed:"Sākuma datumam ir jābūt pirms beigu datuma.",rangeUnderflow:e=>`Vērtībai ir jābūt ${e.minValue} vai vēlākai.`,unavailableDate:"Atlasītais datums nav pieejams."};var pde={};pde={rangeOverflow:e=>`Verdien må være ${e.maxValue} eller tidligere.`,rangeReversed:"Startdatoen må være før sluttdatoen.",rangeUnderflow:e=>`Verdien må være ${e.minValue} eller senere.`,unavailableDate:"Valgt dato utilgjengelig."};var mde={};mde={rangeOverflow:e=>`Waarde moet ${e.maxValue} of eerder zijn.`,rangeReversed:"De startdatum moet voor de einddatum liggen.",rangeUnderflow:e=>`Waarde moet ${e.minValue} of later zijn.`,unavailableDate:"Geselecteerde datum niet beschikbaar."};var gde={};gde={rangeOverflow:e=>`Wartość musi mieć wartość ${e.maxValue} lub wcześniejszą.`,rangeReversed:"Data rozpoczęcia musi być wcześniejsza niż data zakończenia.",rangeUnderflow:e=>`Wartość musi mieć wartość ${e.minValue} lub późniejszą.`,unavailableDate:"Wybrana data jest niedostępna."};var vde={};vde={rangeOverflow:e=>`O valor deve ser ${e.maxValue} ou anterior.`,rangeReversed:"A data inicial deve ser anterior à data final.",rangeUnderflow:e=>`O valor deve ser ${e.minValue} ou posterior.`,unavailableDate:"Data selecionada indisponível."};var yde={};yde={rangeOverflow:e=>`O valor tem de ser ${e.maxValue} ou anterior.`,rangeReversed:"A data de início deve ser anterior à data de fim.",rangeUnderflow:e=>`O valor tem de ser ${e.minValue} ou posterior.`,unavailableDate:"Data selecionada indisponível."};var bde={};bde={rangeOverflow:e=>`Valoarea trebuie să fie ${e.maxValue} sau anterioară.`,rangeReversed:"Data de început trebuie să fie anterioară datei de sfârșit.",rangeUnderflow:e=>`Valoarea trebuie să fie ${e.minValue} sau ulterioară.`,unavailableDate:"Data selectată nu este disponibilă."};var Ode={};Ode={rangeOverflow:e=>`Значение должно быть не позже ${e.maxValue}.`,rangeReversed:"Дата начала должна предшествовать дате окончания.",rangeUnderflow:e=>`Значение должно быть не раньше ${e.minValue}.`,unavailableDate:"Выбранная дата недоступна."};var xde={};xde={rangeOverflow:e=>`Hodnota musí byť ${e.maxValue} alebo skoršia.`,rangeReversed:"Dátum začiatku musí byť skorší ako dátum konca.",rangeUnderflow:e=>`Hodnota musí byť ${e.minValue} alebo neskoršia.`,unavailableDate:"Vybratý dátum je nedostupný."};var Sde={};Sde={rangeOverflow:e=>`Vrednost mora biti ${e.maxValue} ali starejša.`,rangeReversed:"Začetni datum mora biti pred končnim datumom.",rangeUnderflow:e=>`Vrednost mora biti ${e.minValue} ali novejša.`,unavailableDate:"Izbrani datum ni na voljo."};var _de={};_de={rangeOverflow:e=>`Vrednost mora da bude ${e.maxValue} ili starija.`,rangeReversed:"Datum početka mora biti pre datuma završetka.",rangeUnderflow:e=>`Vrednost mora da bude ${e.minValue} ili novija.`,unavailableDate:"Izabrani datum nije dostupan."};var Ede={};Ede={rangeOverflow:e=>`Värdet måste vara ${e.maxValue} eller tidigare.`,rangeReversed:"Startdatumet måste vara före slutdatumet.",rangeUnderflow:e=>`Värdet måste vara ${e.minValue} eller senare.`,unavailableDate:"Det valda datumet är inte tillgängligt."};var Dde={};Dde={rangeOverflow:e=>`Değer, ${e.maxValue} veya öncesi olmalıdır.`,rangeReversed:"Başlangıç tarihi bitiş tarihinden önce olmalıdır.",rangeUnderflow:e=>`Değer, ${e.minValue} veya sonrası olmalıdır.`,unavailableDate:"Seçilen tarih kullanılamıyor."};var $de={};$de={rangeOverflow:e=>`Значення має бути не пізніше ${e.maxValue}.`,rangeReversed:"Дата початку має передувати даті завершення.",rangeUnderflow:e=>`Значення має бути не раніше ${e.minValue}.`,unavailableDate:"Вибрана дата недоступна."};var Cde={};Cde={rangeOverflow:e=>`值必须是 ${e.maxValue} 或更早日期。`,rangeReversed:"开始日期必须早于结束日期。",rangeUnderflow:e=>`值必须是 ${e.minValue} 或更晚日期。`,unavailableDate:"所选日期不可用。"};var wde={};wde={rangeOverflow:e=>`值必須是 ${e.maxValue} 或更早。`,rangeReversed:"開始日期必須在結束日期之前。",rangeUnderflow:e=>`值必須是 ${e.minValue} 或更晚。`,unavailableDate:"所選日期無法使用。"};var Rde={};Rde={"ar-AE":Yfe,"bg-BG":Gfe,"cs-CZ":Kfe,"da-DK":Wfe,"de-DE":Jfe,"el-GR":ede,"en-US":tde,"es-ES":nde,"et-EE":rde,"fi-FI":ide,"fr-FR":ade,"he-IL":ude,"hr-HR":lde,"hu-HU":ode,"it-IT":sde,"ja-JP":cde,"ko-KR":fde,"lt-LT":dde,"lv-LV":hde,"nb-NO":pde,"nl-NL":mde,"pl-PL":gde,"pt-BR":vde,"pt-PT":yde,"ro-RO":bde,"ru-RU":Ode,"sk-SK":xde,"sl-SI":Sde,"sr-SP":_de,"sv-SE":Ede,"tr-TR":Dde,"uk-UA":$de,"zh-CN":Cde,"zh-TW":wde};function ZCe(e){return e&&e.__esModule?e.default:e}const HCe=new tp(ZCe(Rde));function XCe(){let e=typeof navigator<"u"&&(navigator.language||navigator.userLanguage)||"en-US";try{Intl.DateTimeFormat.supportedLocalesOf([e])}catch{e="en-US"}return e}function YCe(e,t,n,r,i){let a=e!=null&&n!=null&&e.compare(n)>0,u=e!=null&&t!=null&&e.compare(t)<0,l=e!=null&&(r==null?void 0:r(e))||!1,o=a||u||l,s=[];if(o){let c=XCe(),d=tp.getGlobalDictionaryForPackage("@react-stately/datepicker")||HCe,h=new dN(c,d),m=new VO(c,KE({},i)),y=m.resolvedOptions().timeZone;u&&t!=null&&s.push(h.format("rangeUnderflow",{minValue:m.format(t.toDate(y))})),a&&n!=null&&s.push(h.format("rangeOverflow",{maxValue:m.format(n.toDate(y))})),l&&s.push(h.format("unavailableDate"))}return{isInvalid:o,validationErrors:s,validationDetails:{badInput:l,customError:!1,patternMismatch:!1,rangeOverflow:a,rangeUnderflow:u,stepMismatch:!1,tooLong:!1,tooShort:!1,typeMismatch:!1,valueMissing:!1,valid:!o}}}const GCe={year:"numeric",month:"numeric",day:"numeric",hour:"numeric",minute:"2-digit",second:"2-digit"},KCe={year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit"};function KE(e,t){e={...t.shouldForceLeadingZeros?KCe:GCe,...e};let r=t.granularity||"minute",i=Object.keys(e);var a;let u=i.indexOf((a=t.maxGranularity)!==null&&a!==void 0?a:"year");u<0&&(u=0);let l=i.indexOf(r);if(l<0&&(l=2),u>l)throw new Error("maxGranularity must be greater than granularity");let o=i.slice(u,l+1).reduce((c,d)=>(c[d]=e[d],c),{});return t.hourCycle!=null&&(o.hour12=t.hourCycle===12),o.timeZone=t.timeZone||"UTC",(r==="hour"||r==="minute"||r==="second")&&t.timeZone&&!t.hideTimeZone&&(o.timeZoneName="short"),t.showEra&&u===0&&(o.era="short"),o}function Ade(e,t){if(e===null)return null;if(e)return sc(e,t)}function K4(e,t,n,r){if(e)return Ade(e,n);let i=sc(Zte(r??oS()).set({hour:0,minute:0,second:0,millisecond:0}),n);return t==="year"||t==="month"||t==="day"?Wte(i):r?i:Kv(i)}function WCe(e,t){let n=e&&"timeZone"in e?e.timeZone:void 0,r=e&&"minute"in e?"minute":"day";if(e&&t&&!(t in e))throw new Error("Invalid granularity "+t+" for value "+e.toString());let[i,a]=P.useState([r,n]);e&&(i[0]!==r||i[1]!==n)&&a([r,n]),t||(t=e?r:i[0]);let u=e?n:i[1];return[t,u]}const JCe=new tp({ach:{year:"mwaka",month:"dwe",day:"nino"},af:{year:"jjjj",month:"mm",day:"dd"},am:{year:"ዓዓዓዓ",month:"ሚሜ",day:"ቀቀ"},an:{year:"aaaa",month:"mm",day:"dd"},ar:{year:"سنة",month:"شهر",day:"يوم"},ast:{year:"aaaa",month:"mm",day:"dd"},az:{year:"iiii",month:"aa",day:"gg"},be:{year:"гггг",month:"мм",day:"дд"},bg:{year:"гггг",month:"мм",day:"дд"},bn:{year:"yyyy",month:"মিমি",day:"dd"},br:{year:"bbbb",month:"mm",day:"dd"},bs:{year:"gggg",month:"mm",day:"dd"},ca:{year:"aaaa",month:"mm",day:"dd"},cak:{year:"jjjj",month:"ii",day:"q'q'"},ckb:{year:"ساڵ",month:"مانگ",day:"ڕۆژ"},cs:{year:"rrrr",month:"mm",day:"dd"},cy:{year:"bbbb",month:"mm",day:"dd"},da:{year:"åååå",month:"mm",day:"dd"},de:{year:"jjjj",month:"mm",day:"tt"},dsb:{year:"llll",month:"mm",day:"źź"},el:{year:"εεεε",month:"μμ",day:"ηη"},en:{year:"yyyy",month:"mm",day:"dd"},eo:{year:"jjjj",month:"mm",day:"tt"},es:{year:"aaaa",month:"mm",day:"dd"},et:{year:"aaaa",month:"kk",day:"pp"},eu:{year:"uuuu",month:"hh",day:"ee"},fa:{year:"سال",month:"ماه",day:"روز"},ff:{year:"hhhh",month:"ll",day:"ññ"},fi:{year:"vvvv",month:"kk",day:"pp"},fr:{year:"aaaa",month:"mm",day:"jj"},fy:{year:"jjjj",month:"mm",day:"dd"},ga:{year:"bbbb",month:"mm",day:"ll"},gd:{year:"bbbb",month:"mm",day:"ll"},gl:{year:"aaaa",month:"mm",day:"dd"},he:{year:"שנה",month:"חודש",day:"יום"},hr:{year:"gggg",month:"mm",day:"dd"},hsb:{year:"llll",month:"mm",day:"dd"},hu:{year:"éééé",month:"hh",day:"nn"},ia:{year:"aaaa",month:"mm",day:"dd"},id:{year:"tttt",month:"bb",day:"hh"},it:{year:"aaaa",month:"mm",day:"gg"},ja:{year:"年",month:"月",day:"日"},ka:{year:"წწწწ",month:"თთ",day:"რრ"},kk:{year:"жжжж",month:"аа",day:"кк"},kn:{year:"ವವವವ",month:"ಮಿಮೀ",day:"ದಿದಿ"},ko:{year:"연도",month:"월",day:"일"},lb:{year:"jjjj",month:"mm",day:"dd"},lo:{year:"ປປປປ",month:"ດດ",day:"ວວ"},lt:{year:"mmmm",month:"mm",day:"dd"},lv:{year:"gggg",month:"mm",day:"dd"},meh:{year:"aaaa",month:"mm",day:"dd"},ml:{year:"വർഷം",month:"മാസം",day:"തീയതി"},ms:{year:"tttt",month:"mm",day:"hh"},nb:{year:"åååå",month:"mm",day:"dd"},nl:{year:"jjjj",month:"mm",day:"dd"},nn:{year:"åååå",month:"mm",day:"dd"},no:{year:"åååå",month:"mm",day:"dd"},oc:{year:"aaaa",month:"mm",day:"jj"},pl:{year:"rrrr",month:"mm",day:"dd"},pt:{year:"aaaa",month:"mm",day:"dd"},rm:{year:"oooo",month:"mm",day:"dd"},ro:{year:"aaaa",month:"ll",day:"zz"},ru:{year:"гггг",month:"мм",day:"дд"},sc:{year:"aaaa",month:"mm",day:"dd"},scn:{year:"aaaa",month:"mm",day:"jj"},sk:{year:"rrrr",month:"mm",day:"dd"},sl:{year:"llll",month:"mm",day:"dd"},sr:{year:"гггг",month:"мм",day:"дд"},sv:{year:"åååå",month:"mm",day:"dd"},szl:{year:"rrrr",month:"mm",day:"dd"},tg:{year:"сссс",month:"мм",day:"рр"},th:{year:"ปปปป",month:"ดด",day:"วว"},tr:{year:"yyyy",month:"aa",day:"gg"},uk:{year:"рррр",month:"мм",day:"дд"},"zh-CN":{year:"年",month:"月",day:"日"},"zh-TW":{year:"年",month:"月",day:"日"}},"en");function ewe(e,t,n){return e==="era"||e==="dayPeriod"?t:e==="year"||e==="month"||e==="day"?JCe.getStringForLocale(e,n):"––"}const WE={year:!0,month:!0,day:!0,hour:!0,minute:!0,second:!0,dayPeriod:!0,era:!0},qj={year:5,month:2,day:7,hour:2,minute:15,second:15},Tde={dayperiod:"dayPeriod",relatedYear:"year",yearName:"literal",unknown:"literal"};function KN(e){let{locale:t,createCalendar:n,hideTimeZone:r,isDisabled:i=!1,isReadOnly:a=!1,isRequired:u=!1,minValue:l,maxValue:o,isDateUnavailable:s}=e,c=e.value||e.defaultValue||e.placeholderValue||null,[d,h]=WCe(c,e.granularity),m=h||"UTC";if(c&&!(d in c))throw new Error("Invalid granularity "+d+" for value "+c.toString());let y=P.useMemo(()=>new VO(t),[t]),v=P.useMemo(()=>n(y.resolvedOptions().calendar),[n,y]);var _;let[S,E]=Zu(e.value,(_=e.defaultValue)!==null&&_!==void 0?_:null,e.onChange),[C]=P.useState(S),T=P.useMemo(()=>{var pe;return(pe=Ade(S,v))!==null&&pe!==void 0?pe:null},[S,v]),[R,$]=P.useState(()=>K4(e.placeholderValue,d,v,h)),k=T||R,F=v.identifier==="gregory"&&k.era==="BC",L=P.useMemo(()=>{var pe;return{granularity:d,maxGranularity:(pe=e.maxGranularity)!==null&&pe!==void 0?pe:"year",timeZone:h,hideTimeZone:r,hourCycle:e.hourCycle,showEra:F,shouldForceLeadingZeros:e.shouldForceLeadingZeros}},[e.maxGranularity,d,e.hourCycle,e.shouldForceLeadingZeros,h,r,F]),j=P.useMemo(()=>KE({},L),[L]),V=P.useMemo(()=>new VO(t,j),[t,j]),q=P.useMemo(()=>V.resolvedOptions(),[V]),N=P.useMemo(()=>V.formatToParts(new Date).filter(pe=>WE[pe.type]).reduce((pe,_e)=>(pe[Tde[_e.type]||_e.type]=!0,pe),{}),[V]),[U,W]=P.useState(()=>e.value||e.defaultValue?{...N}:{}),G=P.useRef(null),J=P.useRef(v);P.useEffect(()=>{jte(v,J.current)||(J.current=v,$(pe=>Object.keys(U).length>0?sc(pe,v):K4(e.placeholderValue,d,v,h)))},[v,d,U,h,e.placeholderValue]),S&&Object.keys(U).length<Object.keys(N).length&&(U={...N},W(U)),S==null&&Object.keys(U).length===Object.keys(N).length&&(U={},W(U),$(K4(e.placeholderValue,d,v,h)));let te=T&&Object.keys(U).length>=Object.keys(N).length?T:R,H=pe=>{if(e.isDisabled||e.isReadOnly)return;let _e=Object.keys(U),se=Object.keys(N);pe==null?(E(null),$(K4(e.placeholderValue,d,v,h)),W({})):_e.length===0&&G.current==null||_e.length>=se.length||_e.length===se.length-1&&N.dayPeriod&&!U.dayPeriod&&G.current!=="dayPeriod"?(_e.length===0&&(U={...N},W(U)),pe=sc(pe,(c==null?void 0:c.calendar)||new Hf),E(pe)):$(pe),G.current=null},M=P.useMemo(()=>te.toDate(m),[te,m]),K=P.useMemo(()=>twe(M,U,V,q,te,v,t,d),[M,U,V,q,te,v,t,d]);N.era&&U.year&&!U.era?(U.era=!0,W({...U})):!N.era&&U.era&&(delete U.era,W({...U}));let X=pe=>{U[pe]=!0,pe==="year"&&N.era&&(U.era=!0),W({...U})},B=(pe,_e)=>{if(U[pe])H(nwe(te,pe,_e,q));else{X(pe);let se=Object.keys(U),me=Object.keys(N);(se.length>=me.length||se.length===me.length-1&&N.dayPeriod&&!U.dayPeriod)&&H(te)}},ne=P.useMemo(()=>YCe(S,l,o,s,L),[S,l,o,s,L]),oe=bg({...e,value:S,builtinValidation:ne}),ie=oe.displayValidation.isInvalid,de=e.validationState||(ie?"invalid":null);var be,ve;return{...oe,value:T,defaultValue:(be=e.defaultValue)!==null&&be!==void 0?be:C,dateValue:M,calendar:v,setValue:H,segments:K,dateFormatter:V,validationState:de,isInvalid:ie,granularity:d,maxGranularity:(ve=e.maxGranularity)!==null&&ve!==void 0?ve:"year",isDisabled:i,isReadOnly:a,isRequired:u,increment(pe){B(pe,1)},decrement(pe){B(pe,-1)},incrementPage(pe){B(pe,qj[pe]||1)},decrementPage(pe){B(pe,-(qj[pe]||1))},setSegment(pe,_e){X(pe),H(rwe(te,pe,_e,q))},confirmPlaceholder(){if(e.isDisabled||e.isReadOnly)return;let pe=Object.keys(U),_e=Object.keys(N);pe.length===_e.length-1&&N.dayPeriod&&!U.dayPeriod&&(U={...N},W(U),H(te.copy()))},clearSegment(pe){delete U[pe],G.current=pe,W({...U});let _e=K4(e.placeholderValue,d,v,h),se=te;if(pe==="dayPeriod"&&"hour"in te&&"hour"in _e){let me=te.hour>=12,ge=_e.hour>=12;me&&!ge?se=te.set({hour:te.hour-12}):!me&&ge&&(se=te.set({hour:te.hour+12}))}else pe==="hour"&&"hour"in te&&te.hour>=12&&U.dayPeriod?se=te.set({hour:_e.hour+12}):pe in te&&(se=te.set({[pe]:_e[pe]}));E(null),H(se)},formatValue(pe){if(!T)return"";let _e=KE(pe,L);return new VO(t,_e).format(M)},getDateFormatter(pe,_e){let se={...L,..._e},me=KE({},se);return new VO(pe,me)}}}function twe(e,t,n,r,i,a,u,l){let o=["hour","minute","second"],s=n.formatToParts(e),c=[];for(let d of s){let h=Tde[d.type]||d.type,m=WE[h];h==="era"&&a.getEras().length===1&&(m=!1);let y=WE[h]&&!t[h],v=WE[h]?ewe(h,d.value,u):null,_={type:h,text:y?v:d.value,...j_(i,h,r),isPlaceholder:y,placeholder:v,isEditable:m};h==="hour"?(c.push({type:"literal",text:"⁦",...j_(i,"literal",r),isPlaceholder:!1,placeholder:"",isEditable:!1}),c.push(_),h===l&&c.push({type:"literal",text:"⁩",...j_(i,"literal",r),isPlaceholder:!1,placeholder:"",isEditable:!1})):o.includes(h)&&h===l?(c.push(_),c.push({type:"literal",text:"⁩",...j_(i,"literal",r),isPlaceholder:!1,placeholder:"",isEditable:!1})):c.push(_)}return c}function j_(e,t,n){switch(t){case"era":{let r=e.calendar.getEras();return{value:r.indexOf(e.era),minValue:0,maxValue:r.length-1}}case"year":return{value:e.year,minValue:1,maxValue:e.calendar.getYearsInEra(e)};case"month":return{value:e.month,minValue:I_e(e),maxValue:e.calendar.getMonthsInYear(e)};case"day":return{value:e.day,minValue:L_e(e),maxValue:e.calendar.getDaysInMonth(e)}}if("hour"in e)switch(t){case"dayPeriod":return{value:e.hour>=12?12:0,minValue:0,maxValue:12};case"hour":if(n.hour12){let r=e.hour>=12;return{value:e.hour,minValue:r?12:0,maxValue:r?23:11}}return{value:e.hour,minValue:0,maxValue:23};case"minute":return{value:e.minute,minValue:0,maxValue:59};case"second":return{value:e.second,minValue:0,maxValue:59}}return{}}function nwe(e,t,n,r){switch(t){case"era":case"year":case"month":case"day":return e.cycle(t,n,{round:t==="year"})}if("hour"in e)switch(t){case"dayPeriod":{let i=e.hour,a=i>=12;return e.set({hour:a?i-12:i+12})}case"hour":case"minute":case"second":return e.cycle(t,n,{round:t!=="hour",hourCycle:r.hour12?12:24})}throw new Error("Unknown segment: "+t)}function rwe(e,t,n,r){switch(t){case"day":case"month":case"year":case"era":return e.set({[t]:n})}if("hour"in e&&typeof n=="number")switch(t){case"dayPeriod":{let i=e.hour,a=i>=12;return n>=12===a?e:e.set({hour:a?i-12:i+12})}case"hour":if(r.hour12){let a=e.hour>=12;!a&&n===12&&(n=0),a&&n<12&&(n+=12)}case"minute":case"second":return e.set({[t]:n})}throw new Error("Unknown segment: "+t)}function iwe(e){let{placeholderValue:t=new QC,minValue:n,maxValue:r,defaultValue:i,granularity:a,validate:u}=e,[l,o]=Zu(e.value,i??null,e.onChange),s=l||t,c=s&&"day"in s?s:void 0,d=i&&"timeZone"in i?i.timeZone:void 0,h=P.useMemo(()=>{let T=s&&"timeZone"in s?s.timeZone:void 0;return(T||d)&&t?Jte(OO(t),T||d):OO(t)},[t,s,d]),m=P.useMemo(()=>OO(n,c),[n,c]),y=P.useMemo(()=>OO(r,c),[r,c]),v=P.useMemo(()=>l&&"day"in l?NU(l):l,[l]),_=P.useMemo(()=>l==null?null:OO(l),[l]),S=P.useMemo(()=>i==null?null:OO(i),[i]);return{...KN({...e,value:_,defaultValue:S,minValue:m,maxValue:y,onChange:T=>{o(c||d?T:T&&NU(T))},granularity:a||"minute",maxGranularity:"hour",placeholderValue:h??void 0,createCalendar:()=>new Hf,validate:P.useCallback(()=>u==null?void 0:u(l),[u,l])}),timeValue:v}}function OO(e,t=N_e(oS())){return e?"day"in e?e:Kv(t,e):null}function awe(e){let[t,n]=Zu(e.isExpanded,e.defaultExpanded||!1,e.onExpandedChange);const r=P.useCallback(()=>{n(!0)},[n]),i=P.useCallback(()=>{n(!1)},[n]),a=P.useCallback(()=>{n(!t)},[n,t]);return{isExpanded:t,setExpanded:n,expand:r,collapse:i,toggle:a}}function uwe(e){let{allowsMultipleExpanded:t=!1,isDisabled:n=!1}=e,[r,i]=Zu(P.useMemo(()=>e.expandedKeys?new Set(e.expandedKeys):void 0,[e.expandedKeys]),P.useMemo(()=>e.defaultExpandedKeys?new Set(e.defaultExpandedKeys):new Set,[e.defaultExpandedKeys]),e.onExpandedChange);return P.useEffect(()=>{if(!t&&r.size>1){let a=r.values().next().value;a!=null&&i(new Set([a]))}}),{allowsMultipleExpanded:t,isDisabled:n,expandedKeys:r,setExpandedKeys:i,toggleKey(a){let u;t?(u=new Set(r),u.has(a)?u.delete(a):u.add(a)):u=new Set(r.has(a)?[]:[a]),i(u)}}}function WN(e){let t=H3(e),[n,r]=P.useState(null),[i,a]=P.useState([]),u=()=>{a([]),t.close()};return{focusStrategy:n,...t,open(s=null){r(s),t.open()},toggle(s=null){r(s),t.toggle()},close(){u()},expandedKeysStack:i,openSubmenu:(s,c)=>{a(d=>c>d.length?d:[...d.slice(0,c),s])},closeSubmenu:(s,c)=>{a(d=>d[c]===s?d.slice(0,c):d)}}}function lwe(e,t){let{triggerKey:n}=e,{expandedKeysStack:r,openSubmenu:i,closeSubmenu:a,close:u}=t,[l]=P.useState(r==null?void 0:r.length),o=P.useMemo(()=>r[l]===n,[r,n,l]),[s,c]=P.useState(null),d=P.useCallback(y=>{c(y??null),i(n,l)},[i,l,n]),h=P.useCallback(()=>{c(null),a(n,l)},[a,l,n]),m=P.useCallback(y=>{c(y??null),o?h():d(y)},[h,d,o]);return P.useMemo(()=>({focusStrategy:s,isOpen:o,open:d,close:h,closeAll:u,submenuLevel:l,setOpen:()=>{},toggle:m}),[o,d,h,u,s,m,l])}let owe=Math.round(Math.random()*1e10),swe=0;function cwe(e){let t=P.useMemo(()=>e.name||`radio-group-${owe}-${++swe}`,[e.name]);var n;let[r,i]=Zu(e.value,(n=e.defaultValue)!==null&&n!==void 0?n:null,e.onChange),[a]=P.useState(r),[u,l]=P.useState(null),o=bg({...e,value:r}),s=h=>{!e.isReadOnly&&!e.isDisabled&&(i(h),o.commitValidation())},c=o.displayValidation.isInvalid;var d;return{...o,name:t,selectedValue:r,defaultSelectedValue:e.value!==void 0?a:(d=e.defaultValue)!==null&&d!==void 0?d:null,setSelectedValue:s,lastFocusedValue:u,setLastFocusedValue:l,isDisabled:e.isDisabled||!1,isReadOnly:e.isReadOnly||!1,isRequired:e.isRequired||!1,validationState:e.validationState||(c?"invalid":null),isInvalid:c}}function fwe(e){let[t,n]=Zu(Vj(e.value),Vj(e.defaultValue)||"",e.onChange);return{value:t,setValue:n}}function Vj(e){if(e!=null)return e.toString()}function dwe(e){let{selectionMode:t="single"}=e,n=H3(e),[r,i]=P.useState(null),a=P.useMemo(()=>{var T;return e.defaultValue!==void 0?e.defaultValue:t==="single"?(T=e.defaultSelectedKey)!==null&&T!==void 0?T:null:[]},[e.defaultValue,e.defaultSelectedKey,t]),u=P.useMemo(()=>e.value!==void 0?e.value:t==="single"?e.selectedKey:void 0,[e.value,e.selectedKey,t]),[l,o]=Zu(u,a,e.onChange),s=t==="single"&&Array.isArray(l)?l[0]:l,c=T=>{if(t==="single"){var R,$;let k=Array.isArray(T)?($=T[0])!==null&&$!==void 0?$:null:T;o(k),k!==s&&((R=e.onSelectionChange)===null||R===void 0||R.call(e,k))}else{let k=[];Array.isArray(T)?k=T:T!=null&&(k=[T]),o(k)}},d=GC({...e,selectionMode:t,disallowEmptySelection:t==="single",allowDuplicateSelectionEvents:!0,selectedKeys:P.useMemo(()=>hwe(s),[s]),onSelectionChange:T=>{if(T!=="all"){if(t==="single"){var R;let $=(R=T.values().next().value)!==null&&R!==void 0?R:null;c($),n.close()}else c([...T]);y.commitValidation()}}}),h=d.selectionManager.firstSelectedKey,m=P.useMemo(()=>[...d.selectionManager.selectedKeys].map(T=>d.collection.getItem(T)).filter(T=>T!=null),[d.selectionManager.selectedKeys,d.collection]),y=bg({...e,value:Array.isArray(s)&&s.length===0?null:s}),[v,_]=P.useState(!1),[S]=P.useState(s);var E,C;return{...y,...d,...n,value:s,defaultValue:a??S,setValue:c,selectedKey:h,setSelectedKey:c,selectedItem:(E=m[0])!==null&&E!==void 0?E:null,selectedItems:m,defaultSelectedKey:(C=e.defaultSelectedKey)!==null&&C!==void 0?C:e.selectionMode==="single"?S:null,focusStrategy:r,open(T=null){d.collection.size!==0&&(i(T),n.open())},toggle(T=null){d.collection.size!==0&&(i(T),n.toggle())},isFocused:v,setFocused:_}}function hwe(e){if(e!==void 0)return e===null?[]:Array.isArray(e)?e:[e]}function pwe(e){var t,n;let r=Hfe({...e,onSelectionChange:e.onSelectionChange?o=>{var s;o!=null&&((s=e.onSelectionChange)===null||s===void 0||s.call(e,o))}:void 0,suppressTextValueWarning:!0,defaultSelectedKey:(n=(t=e.defaultSelectedKey)!==null&&t!==void 0?t:Uj(e.collection,e.disabledKeys?new Set(e.disabledKeys):new Set))!==null&&n!==void 0?n:void 0}),{selectionManager:i,collection:a,selectedKey:u}=r,l=P.useRef(u);return P.useEffect(()=>{let o=u;e.selectedKey==null&&(i.isEmpty||o==null||!a.getItem(o))&&(o=Uj(a,r.disabledKeys),o!=null&&i.setSelectedKeys([o])),(o!=null&&i.focusedKey==null||!i.isFocused&&o!==l.current)&&i.setFocusedKey(o),l.current=o}),{...r,isDisabled:e.isDisabled||!1}}function Uj(e,t){let n=null;if(e){var r,i,a,u;for(n=e.getFirstKey();n!=null&&(t.has(n)||!((i=e.getItem(n))===null||i===void 0||(r=i.props)===null||r===void 0)&&r.isDisabled)&&n!==e.getLastKey();)n=e.getKeyAfter(n);n!=null&&(t.has(n)||!((u=e.getItem(n))===null||u===void 0||(a=u.props)===null||a===void 0)&&a.isDisabled)&&n===e.getLastKey()&&(n=e.getFirstKey())}return n}function mwe(e){let t=P.useCallback(i=>e.subscribe(i),[e]),n=P.useCallback(()=>e.visibleToasts,[e]);return{visibleToasts:LN.useSyncExternalStore(t,n,n),add:(i,a)=>e.add(i,a),close:i=>e.close(i),pauseAll:()=>e.pauseAll(),resumeAll:()=>e.resumeAll()}}class Brt{runWithWrapUpdate(t,n){this.wrapUpdate?this.wrapUpdate(t,n):t()}subscribe(t){return this.subscriptions.add(t),()=>this.subscriptions.delete(t)}add(t,n={}){let r="_"+Math.random().toString(36).slice(2),i={...n,content:t,key:r,timer:n.timeout?new gwe(()=>this.close(r),n.timeout):void 0};return this.queue.unshift(i),this.updateVisibleToasts("add"),r}close(t){let n=this.queue.findIndex(a=>a.key===t);if(n>=0){var r,i;(r=(i=this.queue[n]).onClose)===null||r===void 0||r.call(i),this.queue.splice(n,1)}this.updateVisibleToasts("remove")}updateVisibleToasts(t){this.visibleToasts=this.queue.slice(0,this.maxVisibleToasts),this.runWithWrapUpdate(()=>{for(let n of this.subscriptions)n()},t)}pauseAll(){for(let t of this.visibleToasts)t.timer&&t.timer.pause()}resumeAll(){for(let t of this.visibleToasts)t.timer&&t.timer.resume()}clear(){this.queue=[],this.updateVisibleToasts("clear")}constructor(t){this.queue=[],this.subscriptions=new Set,this.visibleToasts=[];var n;this.maxVisibleToasts=(n=t==null?void 0:t.maxVisibleToasts)!==null&&n!==void 0?n:1/0,this.wrapUpdate=t==null?void 0:t.wrapUpdate}}class gwe{reset(t){this.remaining=t,this.resume()}pause(){this.timerId!=null&&(clearTimeout(this.timerId),this.timerId=null,this.remaining-=Date.now()-this.startTime)}resume(){this.remaining<=0||(this.startTime=Date.now(),this.timerId=setTimeout(()=>{this.timerId=null,this.remaining=0,this.callback()},this.remaining))}constructor(t,n){this.startTime=null,this.remaining=n,this.callback=t}}const vwe=1500,jj=500;let g1={},ywe=0,W4=!1,Am=null,v1=null;function kde(e={}){let{delay:t=vwe,closeDelay:n=jj}=e,{isOpen:r,open:i,close:a}=H3(e),u=P.useMemo(()=>`${++ywe}`,[]),l=P.useRef(null),o=P.useRef(a),s=()=>{g1[u]=h},c=()=>{for(let y in g1)y!==u&&(g1[y](!0),delete g1[y])},d=()=>{l.current&&clearTimeout(l.current),l.current=null,c(),s(),W4=!0,i(),Am&&(clearTimeout(Am),Am=null),v1&&(clearTimeout(v1),v1=null)},h=y=>{y||n<=0?(l.current&&clearTimeout(l.current),l.current=null,o.current()):l.current||(l.current=setTimeout(()=>{l.current=null,o.current()},n)),Am&&(clearTimeout(Am),Am=null),W4&&(v1&&clearTimeout(v1),v1=setTimeout(()=>{delete g1[u],v1=null,W4=!1},Math.max(jj,n)))},m=()=>{c(),s(),!r&&!Am&&!W4?Am=setTimeout(()=>{Am=null,W4=!0,d()},t):r||d()};return P.useEffect(()=>{o.current=a},[a]),P.useEffect(()=>()=>{l.current&&clearTimeout(l.current),g1[u]&&delete g1[u]},[u]),{isOpen:r,open:y=>{!y&&t>0&&!l.current?m():d()},close:h}}class bwe{*[Symbol.iterator](){yield*this.iterable}get size(){return this.keyMap.size}getKeys(){return this.keyMap.keys()}getKeyBefore(t){let n=this.keyMap.get(t);var r;return n&&(r=n.prevKey)!==null&&r!==void 0?r:null}getKeyAfter(t){let n=this.keyMap.get(t);var r;return n&&(r=n.nextKey)!==null&&r!==void 0?r:null}getFirstKey(){return this.firstKey}getLastKey(){return this.lastKey}getItem(t){var n;return(n=this.keyMap.get(t))!==null&&n!==void 0?n:null}at(t){const n=[...this.getKeys()];return this.getItem(n[t])}constructor(t,{expandedKeys:n}={}){this.keyMap=new Map,this.firstKey=null,this.lastKey=null,this.iterable=t,n=n||new Set;let r=l=>{if(this.keyMap.set(l.key,l),l.childNodes&&(l.type==="section"||n.has(l.key)))for(let o of l.childNodes)r(o)};for(let l of t)r(l);let i=null,a=0;for(let[l,o]of this.keyMap)i?(i.nextKey=l,o.prevKey=i.key):(this.firstKey=l,o.prevKey=void 0),o.type==="item"&&(o.index=a++),i=o,i.nextKey=void 0;var u;this.lastKey=(u=i==null?void 0:i.key)!==null&&u!==void 0?u:null}}function Owe(e){let{onExpandedChange:t}=e,[n,r]=Zu(e.expandedKeys?new Set(e.expandedKeys):void 0,e.defaultExpandedKeys?new Set(e.defaultExpandedKeys):new Set,t),i=GN(e),a=P.useMemo(()=>e.disabledKeys?new Set(e.disabledKeys):new Set,[e.disabledKeys]),u=Rre(e,P.useCallback(o=>new bwe(o,{expandedKeys:n}),[n]),null);return P.useEffect(()=>{i.focusedKey!=null&&!u.getItem(i.focusedKey)&&i.setFocusedKey(null)},[u,i.focusedKey]),{collection:u,expandedKeys:n,disabledKeys:a,toggleKey:o=>{r(xwe(n,o))},setExpandedKeys:r,selectionManager:new gS(u,i)}}function xwe(e,t){let n=new Set(e);return n.has(t)?n.delete(t):n.add(t),n}const mp=P.createContext(null),Qrt=P.forwardRef(function(t,n){let r=P.useContext(mp);return r!=null&&r.isInvalid?ye.createElement(Swe,{...t,ref:n}):null}),Swe=P.forwardRef((e,t)=>{let n=P.useContext(mp),r=Gt(e,{global:!0}),i=wn({...e,defaultClassName:"react-aria-FieldError",defaultChildren:n.validationErrors.length===0?void 0:n.validationErrors.join(" "),values:n});return i.children==null?null:ye.createElement(qCe,{slot:"errorMessage",...r,...i,ref:t})}),lp=P.createContext(null),zrt=P.forwardRef(function(t,n){[t,n]=In(t,n,lp);let{validationErrors:r,validationBehavior:i="native",children:a,className:u,...l}=t;return ye.createElement("form",{noValidate:i!=="native",...l,ref:n,className:u||"react-aria-Form"},ye.createElement(lp.Provider,{value:{...t,validationBehavior:i}},ye.createElement(kre.Provider,{value:r??{}},a)))}),_we=P.createContext(null),qrt=P.forwardRef(function(t,n){let{inputRef:r=null,...i}=t;[t,n]=In(i,n,mSe);let{validationBehavior:a}=vs(lp)||{};var u,l;let o=(l=(u=t.validationBehavior)!==null&&u!==void 0?u:a)!==null&&l!==void 0?l:"native",s=P.useContext(_we),c=$u(P.useMemo(()=>vg(r,t.inputRef!==void 0?t.inputRef:null),[r,t.inputRef])),{labelProps:d,inputProps:h,isSelected:m,isDisabled:y,isReadOnly:v,isPressed:_,isInvalid:S}=s?D$e({...dc(t),value:t.value,children:typeof t.children=="function"?!0:t.children},s,c):$ue({...dc(t),children:typeof t.children=="function"?!0:t.children,validationBehavior:o},YC(t),c),{isFocused:E,isFocusVisible:C,focusProps:T}=Hu(),R=y||v,{hoverProps:$,isHovered:k}=Cu({...t,isDisabled:R}),F=wn({...t,defaultClassName:"react-aria-Checkbox",values:{isSelected:m,isIndeterminate:t.isIndeterminate||!1,isPressed:_,isHovered:k,isFocused:E,isFocusVisible:C,isDisabled:y,isReadOnly:v,isInvalid:S,isRequired:t.isRequired||!1}}),L=Gt(t,{global:!0});return delete L.id,delete L.onClick,ye.createElement("label",{...Et(L,d,$,F),ref:n,slot:t.slot||void 0,"data-selected":m||void 0,"data-indeterminate":t.isIndeterminate||void 0,"data-pressed":_||void 0,"data-hovered":k||void 0,"data-focused":E||void 0,"data-focus-visible":C||void 0,"data-disabled":y||void 0,"data-readonly":v||void 0,"data-invalid":S||void 0,"data-required":t.isRequired||void 0},ye.createElement(cS,{elementType:"span"},ye.createElement("input",{...Et(h,T),ref:c})),F.children)}),Q0=P.createContext({}),Ewe=P.forwardRef(function(t,n){[t,n]=In(t,n,Q0);let{isDisabled:r,isInvalid:i,isReadOnly:a,onHoverStart:u,onHoverChange:l,onHoverEnd:o,...s}=t,{hoverProps:c,isHovered:d}=Cu({onHoverStart:u,onHoverChange:l,onHoverEnd:o,isDisabled:r}),{isFocused:h,isFocusVisible:m,focusProps:y}=Hu({within:!0});r??(r=!!t["aria-disabled"]&&t["aria-disabled"]!=="false"),i??(i=!!t["aria-invalid"]&&t["aria-invalid"]!=="false");let v=wn({...t,values:{isHovered:d,isFocusWithin:h,isFocusVisible:m,isDisabled:r,isInvalid:i},defaultClassName:"react-aria-Group"});var _,S;return ye.createElement("div",{...Et(s,y,c),...v,ref:n,role:(_=t.role)!==null&&_!==void 0?_:"group",slot:(S=t.slot)!==null&&S!==void 0?S:void 0,"data-focus-within":h||void 0,"data-hovered":d||void 0,"data-focus-visible":m||void 0,"data-disabled":r||void 0,"data-invalid":i||void 0,"data-readonly":a||void 0},v.children)}),z0=P.createContext({});let Dwe=e=>{let{onHoverStart:t,onHoverChange:n,onHoverEnd:r,...i}=e;return i};const $we=$b(function(t,n){[t,n]=In(t,n,z0);let{hoverProps:r,isHovered:i}=Cu(t),{isFocused:a,isFocusVisible:u,focusProps:l}=Hu({isTextInput:!0,autoFocus:t.autoFocus}),o=!!t["aria-invalid"]&&t["aria-invalid"]!=="false",s=wn({...t,values:{isHovered:i,isFocused:a,isFocusVisible:u,isDisabled:t.disabled||!1,isInvalid:o},defaultClassName:"react-aria-Input"});return ye.createElement("input",{...Et(Dwe(t),l,r),...s,ref:n,"data-focused":a||void 0,"data-disabled":t.disabled||void 0,"data-hovered":i||void 0,"data-focus-visible":u||void 0,"data-invalid":o||void 0})}),Cwe=P.createContext(null),Vrt=P.forwardRef(function(t,n){return[t,n]=In(t,n,gSe),t.channel?ye.createElement(wwe,{...t,channel:t.channel,forwardedRef:n}):ye.createElement(Rwe,{...t,forwardedRef:n})});function wwe(e){let{locale:t}=Hi(),n=z$e({...e,locale:t}),r=P.useRef(null),[i,a]=ys(!e["aria-label"]&&!e["aria-labelledby"]);var u;let{labelProps:l,inputProps:o,descriptionProps:s,errorMessageProps:c,...d}=G$e({...dc(e),label:a,validationBehavior:(u=e.validationBehavior)!==null&&u!==void 0?u:"native"},n,r);return ye.createElement(ye.Fragment,null,Pde(e,n,e.forwardedRef,o,r,l,i,s,c,d),e.name&&ye.createElement("input",{type:"hidden",name:e.name,form:e.form,value:isNaN(n.numberValue)?"":n.numberValue}))}function Rwe(e){var t;let n=Q$e({...e,validationBehavior:(t=e.validationBehavior)!==null&&t!==void 0?t:"native"}),r=P.useRef(null),[i,a]=ys(!e["aria-label"]&&!e["aria-labelledby"]);var u;let{labelProps:l,inputProps:o,descriptionProps:s,errorMessageProps:c,...d}=Z$e({...dc(e),label:a,validationBehavior:(u=e.validationBehavior)!==null&&u!==void 0?u:"native"},n,r);return Pde(e,n,e.forwardedRef,o,r,l,i,s,c,d)}function Pde(e,t,n,r,i,a,u,l,o,s){let c=wn({...e,values:{state:t,channel:e.channel||"hex",isDisabled:e.isDisabled||!1,isInvalid:s.isInvalid||!1},defaultClassName:"react-aria-ColorField"}),d=Gt(e,{global:!0});return delete d.id,ye.createElement(ki,{values:[[Cwe,t],[z0,{...r,ref:i}],[bs,{...a,ref:u}],[Q0,{role:"presentation",isInvalid:s.isInvalid,isDisabled:e.isDisabled||!1}],[No,{slots:{description:l,errorMessage:o}}],[mp,s]]},ye.createElement("div",{...d,...c,ref:n,slot:e.slot||void 0,"data-channel":e.channel||"hex","data-disabled":e.isDisabled||void 0,"data-invalid":s.isInvalid||void 0}))}const Mde=P.createContext(null),Urt=P.forwardRef(function(t,n){[t,n]=In(t,n,Mde);let{colorSwatchProps:r,color:i}=X$e(t),a=wn({...t,defaultClassName:"react-aria-ColorSwatch",defaultStyle:r.style,values:{color:i}}),u=Gt(t,{global:!0});return ye.createElement("div",{...Et(u,r,a),slot:t.slot||void 0,ref:n})});var Fde={};Fde={colorSwatchPicker:"تغييرات الألوان",dropzoneLabel:"DropZone",selectPlaceholder:"حدد عنصرًا",tableResizer:"أداة تغيير الحجم"};var Nde={};Nde={colorSwatchPicker:"Цветови мостри",dropzoneLabel:"DropZone",selectPlaceholder:"Изберете предмет",tableResizer:"Преоразмерител"};var Ide={};Ide={colorSwatchPicker:"Vzorky barev",dropzoneLabel:"Místo pro přetažení",selectPlaceholder:"Vyberte položku",tableResizer:"Změna velikosti"};var Lde={};Lde={colorSwatchPicker:"Farveprøver",dropzoneLabel:"DropZone",selectPlaceholder:"Vælg et element",tableResizer:"Størrelsesændring"};var Bde={};Bde={colorSwatchPicker:"Farbfelder",dropzoneLabel:"Ablegebereich",selectPlaceholder:"Element wählen",tableResizer:"Größenanpassung"};var Qde={};Qde={colorSwatchPicker:"Χρωματικά δείγματα",dropzoneLabel:"DropZone",selectPlaceholder:"Επιλέξτε ένα αντικείμενο",tableResizer:"Αλλαγή μεγέθους"};var zde={};zde={selectPlaceholder:"Select an item",tableResizer:"Resizer",dropzoneLabel:"DropZone",colorSwatchPicker:"Color swatches"};var qde={};qde={colorSwatchPicker:"Muestras de colores",dropzoneLabel:"DropZone",selectPlaceholder:"Seleccionar un artículo",tableResizer:"Cambiador de tamaño"};var Vde={};Vde={colorSwatchPicker:"Värvinäidised",dropzoneLabel:"DropZone",selectPlaceholder:"Valige üksus",tableResizer:"Suuruse muutja"};var Ude={};Ude={colorSwatchPicker:"Värimallit",dropzoneLabel:"DropZone",selectPlaceholder:"Valitse kohde",tableResizer:"Koon muuttaja"};var jde={};jde={colorSwatchPicker:"Échantillons de couleurs",dropzoneLabel:"DropZone",selectPlaceholder:"Sélectionner un élément",tableResizer:"Redimensionneur"};var Zde={};Zde={colorSwatchPicker:"דוגמיות צבע",dropzoneLabel:"DropZone",selectPlaceholder:"בחר פריט",tableResizer:"שינוי גודל"};var Hde={};Hde={colorSwatchPicker:"Uzorci boja",dropzoneLabel:"Zona spuštanja",selectPlaceholder:"Odaberite stavku",tableResizer:"Promjena veličine"};var Xde={};Xde={colorSwatchPicker:"Színtárak",dropzoneLabel:"DropZone",selectPlaceholder:"Válasszon ki egy elemet",tableResizer:"Átméretező"};var Yde={};Yde={colorSwatchPicker:"Campioni di colore",dropzoneLabel:"Zona di rilascio",selectPlaceholder:"Seleziona un elemento",tableResizer:"Ridimensionamento"};var Gde={};Gde={colorSwatchPicker:"カラースウォッチ",dropzoneLabel:"ドロップゾーン",selectPlaceholder:"項目を選択",tableResizer:"サイズ変更ツール"};var Kde={};Kde={colorSwatchPicker:"색상 견본",dropzoneLabel:"드롭 영역",selectPlaceholder:"항목 선택",tableResizer:"크기 조정기"};var Wde={};Wde={colorSwatchPicker:"Spalvų pavyzdžiai",dropzoneLabel:"„DropZone“",selectPlaceholder:"Pasirinkite elementą",tableResizer:"Dydžio keitiklis"};var Jde={};Jde={colorSwatchPicker:"Krāsu paraugi",dropzoneLabel:"DropZone",selectPlaceholder:"Izvēlēties vienumu",tableResizer:"Izmēra mainītājs"};var ehe={};ehe={colorSwatchPicker:"Fargekart",dropzoneLabel:"Droppsone",selectPlaceholder:"Velg et element",tableResizer:"Størrelsesendrer"};var the={};the={colorSwatchPicker:"kleurstalen",dropzoneLabel:"DropZone",selectPlaceholder:"Selecteer een item",tableResizer:"Resizer"};var nhe={};nhe={colorSwatchPicker:"Próbki kolorów",dropzoneLabel:"Strefa upuszczania",selectPlaceholder:"Wybierz element",tableResizer:"Zmiana rozmiaru"};var rhe={};rhe={colorSwatchPicker:"Amostras de cores",dropzoneLabel:"DropZone",selectPlaceholder:"Selecione um item",tableResizer:"Redimensionador"};var ihe={};ihe={colorSwatchPicker:"Amostras de cores",dropzoneLabel:"DropZone",selectPlaceholder:"Selecione um item",tableResizer:"Redimensionador"};var ahe={};ahe={colorSwatchPicker:"Specimene de culoare",dropzoneLabel:"Zonă de plasare",selectPlaceholder:"Selectați un element",tableResizer:"Instrument de redimensionare"};var uhe={};uhe={colorSwatchPicker:"Цветовые образцы",dropzoneLabel:"DropZone",selectPlaceholder:"Выберите элемент",tableResizer:"Средство изменения размера"};var lhe={};lhe={colorSwatchPicker:"Vzorkovníky farieb",dropzoneLabel:"DropZone",selectPlaceholder:"Vyberte položku",tableResizer:"Nástroj na zmenu veľkosti"};var ohe={};ohe={colorSwatchPicker:"Barvne palete",dropzoneLabel:"DropZone",selectPlaceholder:"Izberite element",tableResizer:"Spreminjanje velikosti"};var she={};she={colorSwatchPicker:"Uzorci boje",dropzoneLabel:"DropZone",selectPlaceholder:"Izaberite stavku",tableResizer:"Promena veličine"};var che={};che={colorSwatchPicker:"Färgrutor",dropzoneLabel:"DropZone",selectPlaceholder:"Välj en artikel",tableResizer:"Storleksändrare"};var fhe={};fhe={colorSwatchPicker:"Renk örnekleri",dropzoneLabel:"Bırakma Bölgesi",selectPlaceholder:"Bir öğe seçin",tableResizer:"Yeniden boyutlandırıcı"};var dhe={};dhe={colorSwatchPicker:"Зразки кольорів",dropzoneLabel:"DropZone",selectPlaceholder:"Виберіть елемент",tableResizer:"Засіб змінення розміру"};var hhe={};hhe={colorSwatchPicker:"颜色色板",dropzoneLabel:"放置区域",selectPlaceholder:"选择一个项目",tableResizer:"尺寸调整器"};var phe={};phe={colorSwatchPicker:"色票",dropzoneLabel:"放置區",selectPlaceholder:"選取項目",tableResizer:"大小調整器"};var JN={};JN={"ar-AE":Fde,"bg-BG":Nde,"cs-CZ":Ide,"da-DK":Lde,"de-DE":Bde,"el-GR":Qde,"en-US":zde,"es-ES":qde,"et-EE":Vde,"fi-FI":Ude,"fr-FR":jde,"he-IL":Zde,"hr-HR":Hde,"hu-HU":Xde,"it-IT":Yde,"ja-JP":Gde,"ko-KR":Kde,"lt-LT":Wde,"lv-LV":Jde,"nb-NO":ehe,"nl-NL":the,"pl-PL":nhe,"pt-BR":rhe,"pt-PT":ihe,"ro-RO":ahe,"ru-RU":uhe,"sk-SK":lhe,"sl-SI":ohe,"sr-SP":she,"sv-SE":che,"tr-TR":fhe,"uk-UA":dhe,"zh-CN":hhe,"zh-TW":phe};const KC=P.createContext({}),mhe=P.createContext(null),Awe=P.forwardRef(function(t,n){let{render:r}=P.useContext(mhe);return ye.createElement(ye.Fragment,null,r(t,n))});function ghe(e,t){var n;let r=e==null?void 0:e.renderDropIndicator,i=e==null||(n=e.isVirtualDragging)===null||n===void 0?void 0:n.call(e),a=P.useCallback(u=>{if(i||t!=null&&t.isDropTarget(u))return r?r(u):ye.createElement(Awe,{target:u})},[t==null?void 0:t.target,i,r]);return e!=null&&e.useDropIndicator?a:void 0}function Twe(e,t,n){var r,i;let a=e.focusedKey,u=null;if(!(t==null||(r=t.isVirtualDragging)===null||r===void 0)&&r.call(t)&&(n==null||(i=n.target)===null||i===void 0?void 0:i.type)==="item"&&(u=n.target.key,n.target.dropPosition==="after")){let d=n.collection.getKeyAfter(u),h=null;if(d!=null){var l,o;let m=(o=(l=n.collection.getItem(u))===null||l===void 0?void 0:l.level)!==null&&o!==void 0?o:0;for(;d;){let y=n.collection.getItem(d);if(!y)break;if(y.type!=="item"){d=n.collection.getKeyAfter(d);continue}var s;if(((s=y.level)!==null&&s!==void 0?s:0)<=m)break;h=d,d=n.collection.getKeyAfter(d)}}var c;u=(c=d??h)!==null&&c!==void 0?c:u}return P.useMemo(()=>new Set([a,u].filter(d=>d!=null)),[a,u])}const vhe=P.createContext({}),kwe=P.createContext(null);function X3(e){let t=P.useRef({});return ye.createElement(kwe.Provider,{value:t},e.children)}const Y3=P.createContext({isSelected:!1}),eI=P.createContext({});class yhe extends gy{filter(t,n){let r=n.getItem(this.prevKey);if(r&&r.type!=="separator"){let i=this.clone();return n.addDescendants(i,t),i}return null}}yhe.type="separator";const jrt=wb(yhe,function(t,n){[t,n]=In(t,n,eI);let{elementType:r,orientation:i,style:a,className:u,slot:l,...o}=t,s=r||"hr";s==="hr"&&i==="vertical"&&(s="div");let{separatorProps:c}=DCe({...o,elementType:r,orientation:i}),d=Gt(t,{global:!0});return ye.createElement(s,{...Et(d,c),style:a,className:u??"react-aria-Separator",ref:n,slot:l||void 0})}),vS=P.createContext(null),ah=P.createContext(null),Pwe=P.forwardRef(function(t,n){[t,n]=In(t,n,vS);let r=P.useContext(ah);return r?ye.createElement(bhe,{state:r,props:t,listBoxRef:n}):ye.createElement(Cb,{content:ye.createElement(mS,t)},i=>ye.createElement(Mwe,{props:t,listBoxRef:n,collection:i}))});function Mwe({props:e,listBoxRef:t,collection:n}){e={...e,collection:n,children:null,items:null};let{layoutDelegate:r}=P.useContext(pp),i=GC({...e,layoutDelegate:r});return ye.createElement(bhe,{state:i,props:e,listBoxRef:t})}function bhe({state:e,props:t,listBoxRef:n}){[t,n]=In(t,n,dx);let{dragAndDropHooks:r,layout:i="stack",orientation:a="vertical",filter:u}=t,l=jfe(e,u),{collection:o,selectionManager:s}=l,c=!!(r!=null&&r.useDraggableCollectionState),d=!!(r!=null&&r.useDroppableCollectionState),{direction:h}=Hi(),{disabledBehavior:m,disabledKeys:y}=s,v=zC({usage:"search",sensitivity:"base"}),{isVirtualized:_,layoutDelegate:S,dropTargetDelegate:E,CollectionRoot:C}=P.useContext(pp),T=P.useMemo(()=>t.keyboardDelegate||new hS({collection:o,collator:v,ref:n,disabledKeys:y,disabledBehavior:m,layout:i,orientation:a,direction:h,layoutDelegate:S}),[o,v,n,m,y,a,h,t.keyboardDelegate,i,S]),{listBoxProps:R}=ADe({...t,shouldSelectOnPressUp:c||t.shouldSelectOnPressUp,keyboardDelegate:T,isVirtualized:_},l,n);P.useRef(c),P.useRef(d),P.useEffect(()=>{},[c,d]);let $,k,F,L=!1,j=null,V=P.useRef(null);if(c&&r){$=r.useDraggableCollectionState({collection:o,selectionManager:s,preview:r.renderDragPreview?V:void 0}),r.useDraggableCollection({},$,n);let M=r.DragPreview;j=r.renderDragPreview?ye.createElement(M,{ref:V},r.renderDragPreview):null}if(d&&r){k=r.useDroppableCollectionState({collection:o,selectionManager:s});let M=r.dropTargetDelegate||E||new r.ListDropTargetDelegate(o,n,{orientation:a,layout:i,direction:h});F=r.useDroppableCollection({keyboardDelegate:T,dropTargetDelegate:M},k,n),L=k.isDropTarget({type:"root"})}let{focusProps:q,isFocused:N,isFocusVisible:U}=Hu(),W=l.collection.size===0,G={isDropTarget:L,isEmpty:W,isFocused:N,isFocusVisible:U,layout:t.layout||"stack",state:l},J=wn({className:t.className,style:t.style,defaultClassName:"react-aria-ListBox",values:G}),te=null;W&&t.renderEmptyState&&(te=ye.createElement("div",{role:"option",style:{display:"contents"}},t.renderEmptyState(G)));let H=Gt(t,{global:!0});return ye.createElement(CN,null,ye.createElement("div",{...Et(H,J,R,q,F==null?void 0:F.collectionProps),ref:n,slot:t.slot||void 0,onScroll:t.onScroll,"data-drop-target":L||void 0,"data-empty":W||void 0,"data-focused":N||void 0,"data-focus-visible":U||void 0,"data-layout":t.layout||"stack","data-orientation":t.orientation||"vertical"},ye.createElement(ki,{values:[[vS,t],[ah,l],[KC,{dragAndDropHooks:r,dragState:$,dropState:k}],[eI,{elementType:"div"}],[mhe,{render:Iwe}],[Qae,{name:"ListBoxSection",render:Fwe}]]},ye.createElement(X3,null,ye.createElement(C,{collection:o,scrollRef:n,persistedKeys:Twe(s,r,k),renderDropIndicator:ghe(r,k)}))),te,j))}function Fwe(e,t,n,r="react-aria-ListBoxSection"){let i=P.useContext(ah),{dragAndDropHooks:a,dropState:u}=P.useContext(KC),{CollectionBranch:l}=P.useContext(pp),[o,s]=ys();var c;let{headingProps:d,groupProps:h}=NDe({heading:s,"aria-label":(c=e["aria-label"])!==null&&c!==void 0?c:void 0}),m=wn({defaultClassName:r,className:e.className,style:e.style,values:{}}),y=Gt(e,{global:!0});return delete y.id,ye.createElement("section",{...Et(y,m,h),ref:t},ye.createElement(vhe.Provider,{value:{...d,ref:o}},ye.createElement(l,{collection:i.collection,parent:n,renderDropIndicator:ghe(a,u)})))}const Nwe=wb(XC,function(t,n,r){let i=$u(n),a=P.useContext(ah),{dragAndDropHooks:u,dragState:l,dropState:o}=P.useContext(KC),{optionProps:s,labelProps:c,descriptionProps:d,...h}=FDe({key:r.key,"aria-label":t==null?void 0:t["aria-label"]},a,i),{hoverProps:m,isHovered:y}=Cu({isDisabled:!h.allowsSelection&&!h.hasAction,onHoverStart:r.props.onHoverStart,onHoverChange:r.props.onHoverChange,onHoverEnd:r.props.onHoverEnd}),v=null;l&&u&&(v=u.useDraggableItem({key:r.key},l));let _=null;o&&u&&(_=u.useDroppableItem({target:{type:"item",key:r.key,dropPosition:"on"}},o,i));let S=l&&l.isDragging(r.key),E=wn({...t,id:void 0,children:t.children,defaultClassName:"react-aria-ListBoxItem",values:{...h,isHovered:y,selectionMode:a.selectionManager.selectionMode,selectionBehavior:a.selectionManager.selectionBehavior,allowsDragging:!!l,isDragging:S,isDropTarget:_==null?void 0:_.isDropTarget}});P.useEffect(()=>{r.textValue},[r.textValue]);let C=t.href?"a":"div",T=Gt(t,{global:!0});return delete T.id,delete T.onClick,ye.createElement(C,{...Et(T,E,s,m,v==null?void 0:v.dragProps,_==null?void 0:_.dropProps),ref:i,"data-allows-dragging":!!l||void 0,"data-selected":h.isSelected||void 0,"data-disabled":h.isDisabled||void 0,"data-hovered":y||void 0,"data-focused":h.isFocused||void 0,"data-focus-visible":h.isFocusVisible||void 0,"data-pressed":h.isPressed||void 0,"data-dragging":S||void 0,"data-drop-target":(_==null?void 0:_.isDropTarget)||void 0,"data-selection-mode":a.selectionManager.selectionMode==="none"?void 0:a.selectionManager.selectionMode},ye.createElement(ki,{values:[[No,{slots:{[Gv]:c,label:c,description:d}}],[Y3,{isSelected:h.isSelected}]]},E.children))});function Iwe(e,t){t=$u(t);let{dragAndDropHooks:n,dropState:r}=P.useContext(KC),{dropIndicatorProps:i,isHidden:a,isDropTarget:u}=n.useDropIndicator(e,r,t);return a?null:ye.createElement(Bwe,{...e,dropIndicatorProps:i,isDropTarget:u,ref:t})}function Lwe(e,t){let{dropIndicatorProps:n,isDropTarget:r,...i}=e,a=wn({...i,defaultClassName:"react-aria-DropIndicator",values:{isDropTarget:r}});return ye.createElement("div",{...n,...a,role:"option",ref:t,"data-drop-target":r||void 0})}const Bwe=P.forwardRef(Lwe);wb(Pae,function(t,n,r){let i=P.useContext(ah),{isLoading:a,onLoadMore:u,scrollOffset:l,...o}=t,s=P.useRef(null),c=P.useMemo(()=>({onLoadMore:u,collection:i==null?void 0:i.collection,sentinelRef:s,scrollOffset:l}),[u,l,i==null?void 0:i.collection]);r_e(c,s);let d=wn({...o,id:void 0,children:r.rendered,defaultClassName:"react-aria-ListBoxLoadingIndicator",values:null}),h={tabIndex:-1};return ye.createElement(ye.Fragment,null,ye.createElement("div",{style:{position:"relative",width:0,height:0},inert:v9(!0)},ye.createElement("div",{"data-testid":"loadMoreSentinel",ref:s,style:{position:"absolute",height:1,width:1}})),a&&d.children&&ye.createElement("div",{...Et(Gt(t,{global:!0}),h),...d,role:"option",ref:n},d.children))});function Qwe(e){return e&&e.__esModule?e.default:e}const zwe=P.createContext(null),Ohe=P.createContext(null),Zrt=P.forwardRef(function(t,n){[t,n]=In(t,n,zwe);let r=q$e(t),i=P.useMemo(()=>new Map,[]),a=Fo(Qwe(JN),"react-aria-components");return ye.createElement(Pwe,{...Gt(t,{labelable:!0}),ref:n,className:t.className||"react-aria-ColorSwatchPicker",style:t.style,"aria-label":t["aria-label"]||(t["aria-labelledby"]?void 0:a.format("colorSwatchPicker")),layout:t.layout||"grid",selectionMode:"single",selectedKeys:[r.color.toString("hexa")],onSelectionChange:u=>{u!=="all"&&r.setColor(i.get([...u][0]))},disallowEmptySelection:!0},ye.createElement(Ohe.Provider,{value:i},t.children))}),Hrt=P.forwardRef(function(t,n){let r=t.color||"#0000",i=P.useMemo(()=>typeof r=="string"?vy(r):r,[r]),{locale:a}=Hi(),u=P.useContext(Ohe);P.useEffect(()=>{let o=i.toString("hexa");return u.set(o,i),()=>{u.delete(o)}},[i,u]);let l=o=>typeof o=="function"?s=>o({...s,color:i}):o;return ye.createElement(Nwe,{...t,ref:n,id:i.toString("hexa"),textValue:i.getColorName(a),className:l(t.className||"react-aria-ColorSwatchPickerItem"),style:l(t.style)},c_e(l(t.children),o=>ye.createElement(Mde.Provider,{value:{color:i}},o)))}),qwe=P.createContext(null),WC=P.createContext(null),tI=P.createContext(null),xhe=P.createContext(null),Xrt=P.forwardRef(function(t,n){[t,n]=In(t,n,qwe);let r=P.useRef(null),i=HD(t.formatOptions),a=I$e({...t,numberFormatter:i}),[u,l]=ys(!t["aria-label"]&&!t["aria-labelledby"]),{groupProps:o,trackProps:s,labelProps:c,outputProps:d}=V$e({...t,label:l},a,r),h=wn({...t,values:{orientation:a.orientation,isDisabled:a.isDisabled,state:a},defaultClassName:"react-aria-Slider"}),m=Gt(t,{global:!0});return delete m.id,ye.createElement(ki,{values:[[WC,a],[tI,{...s,ref:r}],[xhe,d],[bs,{...c,ref:u}]]},ye.createElement("div",{...Et(m,h,o),ref:n,slot:t.slot||void 0,"data-orientation":a.orientation,"data-disabled":a.isDisabled||void 0}))}),Yrt=P.forwardRef(function(t,n){[t,n]=In(t,n,xhe);let{children:r,style:i,className:a,...u}=t,l=P.useContext(WC),o=wn({className:a,style:i,children:r,defaultChildren:l.getThumbValueLabel(0),defaultClassName:"react-aria-SliderOutput",values:{orientation:l.orientation,isDisabled:l.isDisabled,state:l}});return ye.createElement("output",{...u,...o,ref:n,"data-orientation":l.orientation||void 0,"data-disabled":l.isDisabled||void 0})}),Grt=P.forwardRef(function(t,n){[t,n]=In(t,n,tI);let r=P.useContext(WC),{onHoverStart:i,onHoverEnd:a,onHoverChange:u,...l}=t,{hoverProps:o,isHovered:s}=Cu({onHoverStart:i,onHoverEnd:a,onHoverChange:u}),c=wn({...t,defaultClassName:"react-aria-SliderTrack",values:{orientation:r.orientation,isDisabled:r.isDisabled,isHovered:s,state:r}});return ye.createElement("div",{...Et(l,o),...c,ref:n,"data-hovered":s||void 0,"data-orientation":r.orientation||void 0,"data-disabled":r.isDisabled||void 0})}),Krt=P.forwardRef(function(t,n){let{inputRef:r=null}=t,i=P.useContext(WC),{ref:a}=vs(tI),{index:u=0}=t,l=P.useRef(null),o=r||l,[s,c]=ys(!t["aria-label"]&&!t["aria-labelledby"]),{thumbProps:d,inputProps:h,labelProps:m,isDragging:y,isFocused:v,isDisabled:_}=U$e({...t,index:u,trackRef:a,inputRef:o,label:c},i),{focusProps:S,isFocusVisible:E}=Hu(),{hoverProps:C,isHovered:T}=Cu(t),R=wn({...t,defaultClassName:"react-aria-SliderThumb",values:{state:i,isHovered:T,isDragging:y,isFocused:v,isFocusVisible:E,isDisabled:_}}),$=Gt(t,{global:!0});return delete $.id,ye.createElement("div",{...Et($,d,C),...R,ref:n,style:{...d.style,...R.style},"data-hovered":T||void 0,"data-dragging":y||void 0,"data-focused":v||void 0,"data-focus-visible":E||void 0,"data-disabled":_||void 0},ye.createElement(cS,null,ye.createElement("input",{ref:o,...Et(h,S)})),ye.createElement(ki,{values:[[bs,{...m,ref:s}]]},R.children))}),nI=P.createContext({placement:"bottom"}),Wrt=P.forwardRef(function(t,n){[t,n]=In(t,n,nI);let r=t.placement,i={position:"absolute",transform:r==="top"||r==="bottom"?"translateX(-50%)":"translateY(-50%)"};r!=null&&(i[r]="100%");let a=wn({...t,defaultClassName:"react-aria-OverlayArrow",values:{placement:r}});a.style&&Object.keys(a.style).forEach(l=>a.style[l]===void 0&&delete a.style[l]);let u=Gt(t);return ye.createElement("div",{...u,...a,style:{...i,...a.style},ref:n,"data-placement":r})}),G3=P.createContext(null),Zj=P.createContext(null),Jrt=P.forwardRef(function(t,n){[t,n]=In(t,n,G3);let r=P.useContext(q0),i=H3(t),a=t.isOpen!=null||t.defaultOpen!=null||!r?i:r,u=QD(n,a.isOpen)||t.isExiting||!1,l=c$e(),{direction:o}=Hi();if(l){let s=t.children;return typeof s=="function"&&(s=s({trigger:t.trigger||null,placement:"bottom",isEntering:!1,isExiting:!1,defaultChildren:null})),ye.createElement(ye.Fragment,null,s)}return a&&!a.isOpen&&!u?null:ye.createElement(Vwe,{...t,triggerRef:t.triggerRef,state:a,popoverRef:n,isExiting:u,dir:o})});function Vwe({state:e,isExiting:t,UNSTABLE_portalContainer:n,clearContexts:r,...i}){let a=P.useRef(null),u=P.useRef(null),l=P.useContext(Zj),o=l&&i.trigger==="SubmenuTrigger";var s;let{popoverProps:c,underlayProps:d,arrowProps:h,placement:m,triggerAnchorPoint:y}=_De({...i,offset:(s=i.offset)!==null&&s!==void 0?s:8,arrowRef:a,groupRef:o?l:u},e),v=i.popoverRef,_=IC(v,!!m)||i.isEntering||!1,S=wn({...i,defaultClassName:"react-aria-Popover",values:{trigger:i.trigger||null,placement:m,isEntering:_,isExiting:t}}),E=!i.isNonModal||i.trigger==="SubmenuTrigger",[C,T]=P.useState(!1);qr(()=>{v.current&&T(E&&!v.current.querySelector("[role=dialog]"))},[v,E]),P.useEffect(()=>{C&&i.trigger!=="SubmenuTrigger"&&v.current&&!v.current.contains(document.activeElement)&&ac(v.current)},[C,v,i.trigger]);let R=P.useMemo(()=>{let L=S.children;if(r)for(let j of r)L=ye.createElement(j.Provider,{value:null},L);return L},[S.children,r]),$={...c.style,"--trigger-anchor-point":y?`${y.x}px ${y.y}px`:void 0,...S.style},k=ye.createElement("div",{...Et(Gt(i,{global:!0}),c),...S,role:C?"dialog":void 0,tabIndex:C?-1:void 0,"aria-label":i["aria-label"],"aria-labelledby":i["aria-labelledby"],ref:v,slot:i.slot||void 0,style:$,dir:i.dir,"data-trigger":i.trigger,"data-placement":m,"data-entering":_||void 0,"data-exiting":t||void 0},!i.isNonModal&&ye.createElement(B9,{onDismiss:e.close}),ye.createElement(nI.Provider,{value:{...h,placement:m,ref:a}},R),ye.createElement(B9,{onDismiss:e.close}));if(!o)return ye.createElement(Q9,{...i,shouldContainFocus:C,isExiting:t,portalContainer:n},!i.isNonModal&&e.isOpen&&ye.createElement("div",{"data-testid":"underlay",...d,style:{position:"fixed",inset:0}}),ye.createElement("div",{ref:u,style:{display:"contents"}},ye.createElement(Zj.Provider,{value:u},k)));var F;return ye.createElement(Q9,{...i,shouldContainFocus:C,isExiting:t,portalContainer:(F=n??(l==null?void 0:l.current))!==null&&F!==void 0?F:void 0},k)}const Uwe=P.createContext({}),rI=P.createContext(null),JC=P.createContext(null),bx=P.createContext(null),n$=P.createContext(null);function eit(e){let t=WN(e),n=P.useRef(null),{menuTriggerProps:r,menuProps:i}=IN({...e,type:"menu"},t,n),[a,u]=P.useState(null),l=P.useCallback(()=>{n.current&&u(n.current.offsetWidth+"px")},[n]);ab({ref:n,onResize:l});let o=P.useRef(null);return ye.createElement(ki,{values:[[rI,{...i,ref:o}],[q0,t],[bx,t],[G3,{trigger:"MenuTrigger",triggerRef:n,scrollRef:o,placement:"bottom start",style:{"--trigger-width":a},"aria-labelledby":i["aria-labelledby"]}]]},ye.createElement(kne,{...r,ref:n,isPressed:t.isOpen},e.children))}const She=P.createContext(null);class _he extends gy{filter(t,n,r){let i=t.getItem(this.firstChildKey);if(i&&r(i.textValue,this)){let a=this.clone();return n.addDescendants(a,t),a}return null}}_he.type="submenutrigger";const tit=g$e(_he,(e,t,n)=>{let{CollectionBranch:r}=P.useContext(pp),i=P.useContext(JC),a=P.useContext(bx),u=lwe({triggerKey:n.key},a),l=P.useRef(null),o=$u(t),{parentMenuRef:s,shouldUseVirtualFocus:c}=P.useContext(She),{submenuTriggerProps:d,submenuProps:h,popoverProps:m}=ZDe({parentMenuRef:s,submenuRef:l,delay:e.delay,shouldUseVirtualFocus:c},u,o);return ye.createElement(ki,{values:[[r$,{...d,onAction:void 0,ref:o}],[rI,{ref:l,...h}],[q0,u],[G3,{trigger:"SubmenuTrigger",triggerRef:o,placement:"end top","aria-labelledby":h["aria-labelledby"],...m}]]},ye.createElement(r,{collection:i.collection,parent:n}),e.children[1])},e=>e.children[0]),nit=P.forwardRef(function(t,n){return[t,n]=In(t,n,rI),ye.createElement(Cb,{content:ye.createElement(mS,t)},r=>ye.createElement(jwe,{props:t,collection:r,menuRef:n}))});function jwe({props:e,collection:t,menuRef:n}){[e,n]=In(e,n,dx);let{filter:r,...i}=e,a=P.useMemo(()=>r?t.filter(r):t,[t,r]),u=Owe({...e,collection:a,children:void 0}),l=P.useContext(bx),{isVirtualized:o,CollectionRoot:s}=P.useContext(pp),{menuProps:c}=QDe({...e,isVirtualized:o,onClose:e.onClose||(l==null?void 0:l.close)},u,n),d=wn({defaultClassName:"react-aria-Menu",className:e.className,style:e.style,values:{isEmpty:u.collection.size===0}}),h=null;u.collection.size===0&&e.renderEmptyState&&(h=ye.createElement("div",{role:"menuitem",style:{display:"contents"}},e.renderEmptyState()));let m=Gt(e,{global:!0});return ye.createElement(CN,null,ye.createElement("div",{...Et(m,d,c),ref:n,slot:e.slot||void 0,"data-empty":u.collection.size===0||void 0,onScroll:e.onScroll},ye.createElement(ki,{values:[[JC,u],[eI,{elementType:"div"}],[Qae,{name:"MenuSection",render:Hwe}],[She,{parentMenuRef:n,shouldUseVirtualFocus:i==null?void 0:i.shouldUseVirtualFocus}],[r$,null],[dx,null],[PC,null],[n$,u.selectionManager],[bx,l??WN({})]]},ye.createElement(X3,null,ye.createElement(s,{collection:u.collection,persistedKeys:QN(u.selectionManager.focusedKey),scrollRef:n}))),h))}class Zwe extends gS{get focusedKey(){return this.parent.focusedKey}get isFocused(){return this.parent.isFocused}setFocusedKey(t,n){return this.parent.setFocusedKey(t,n)}setFocused(t){this.parent.setFocused(t)}get childFocusStrategy(){return this.parent.childFocusStrategy}constructor(t,n){super(t.collection,n),this.parent=t}}function Hwe(e,t,n,r="react-aria-MenuSection"){var i,a;let u=P.useContext(JC),{CollectionBranch:l}=P.useContext(pp),[o,s]=ys();var c;let{headingProps:d,groupProps:h}=qDe({heading:s,"aria-label":(c=n.props["aria-label"])!==null&&c!==void 0?c:void 0}),m=wn({defaultClassName:r,className:(i=n.props)===null||i===void 0?void 0:i.className,style:(a=n.props)===null||a===void 0?void 0:a.style,values:{}}),y=P.useContext(n$),v=GN(e),_=e.selectionMode!=null?new Zwe(y,v):y,S=Gt(e,{global:!0});return delete S.id,ye.createElement("section",{...Et(S,m,h),ref:t},ye.createElement(ki,{values:[[vhe,{...d,ref:o}],[n$,_]]},ye.createElement(l,{collection:u.collection,parent:n})))}const r$=P.createContext(null),rit=wb(XC,function(t,n,r){var i;[t,n]=In(t,n,r$);let a=(i=vs(r$))===null||i===void 0?void 0:i.id,u=P.useContext(JC),l=$u(n),o=P.useContext(n$),{menuItemProps:s,labelProps:c,descriptionProps:d,keyboardShortcutProps:h,...m}=zDe({...t,id:a,key:r.key,selectionManager:o},u,l),{hoverProps:y,isHovered:v}=Cu({isDisabled:m.isDisabled}),_=wn({...t,id:void 0,children:r.rendered,defaultClassName:"react-aria-MenuItem",values:{...m,isHovered:v,isFocusVisible:m.isFocusVisible,selectionMode:o.selectionMode,selectionBehavior:o.selectionBehavior,hasSubmenu:!!t["aria-haspopup"],isOpen:t["aria-expanded"]==="true"}}),S=t.href?"a":"div",E=Gt(t,{global:!0});return delete E.id,delete E.onClick,ye.createElement(S,{...Et(E,_,s,y),ref:l,"data-disabled":m.isDisabled||void 0,"data-hovered":v||void 0,"data-focused":m.isFocused||void 0,"data-focus-visible":m.isFocusVisible||void 0,"data-pressed":m.isPressed||void 0,"data-selected":m.isSelected||void 0,"data-selection-mode":o.selectionMode==="none"?void 0:o.selectionMode,"data-has-submenu":!!t["aria-haspopup"]||void 0,"data-open":t["aria-expanded"]==="true"||void 0},ye.createElement(ki,{values:[[No,{slots:{[Gv]:c,label:c,description:d}}],[Uwe,h],[Y3,{isSelected:m.isSelected}]]},_.children))}),Ehe=P.createContext(null),q0=P.createContext(null);function iit(e){let t=WN(e),n=P.useRef(null),{triggerProps:r,overlayProps:i}=zne({type:"dialog"},t,n),[a,u]=P.useState(null),l=P.useCallback(()=>{n.current&&u(n.current.offsetWidth+"px")},[n]);return ab({ref:n,onResize:l}),r.id=pi(),i["aria-labelledby"]=r.id,ye.createElement(ki,{values:[[q0,t],[bx,t],[Ehe,i],[G3,{trigger:"DialogTrigger",triggerRef:n,"aria-labelledby":i["aria-labelledby"],style:{"--trigger-width":a}}]]},ye.createElement(kne,{...r,ref:n,isPressed:t.isOpen},e.children))}const ait=P.forwardRef(function(t,n){let r=t["aria-labelledby"];[t,n]=In(t,n,Ehe);let{dialogProps:i,titleProps:a}=uCe({...t,"aria-labelledby":r},n),u=P.useContext(q0);!i["aria-label"]&&!i["aria-labelledby"]&&t["aria-labelledby"]&&(i["aria-labelledby"]=t["aria-labelledby"]);let l=wn({defaultClassName:"react-aria-Dialog",className:t.className,style:t.style,children:t.children,values:{close:(u==null?void 0:u.close)||(()=>{})}}),o=Gt(t,{global:!0});return ye.createElement("section",{...Et(o,l,i),ref:n,slot:t.slot||void 0},ye.createElement(ki,{values:[[zee,{slots:{[Gv]:{},title:{...a,level:2}}}],[ih,{slots:{[Gv]:{},close:{onPress:()=>u==null?void 0:u.close()}}}]]},l.children))}),Xwe=P.createContext(null),Ywe=P.createContext(null),uit=P.forwardRef(function(t,n){[t,n]=In(t,n,Xwe);let{children:r,isDisabled:i=!1,isInvalid:a=!1,isRequired:u=!1}=t,l=P.useMemo(()=>{var o;return ye.createElement(vS.Provider,{value:{items:(o=t.items)!==null&&o!==void 0?o:t.defaultItems}},typeof r=="function"?r({isOpen:!1,isDisabled:i,isInvalid:a,isRequired:u,defaultChildren:null}):r)},[r,i,a,u,t.items,t.defaultItems]);return ye.createElement(Cb,{content:l},o=>ye.createElement(Kwe,{props:t,collection:o,comboBoxRef:n}))}),Gwe=[bs,ih,z0,Q0,No];function Kwe({props:e,collection:t,comboBoxRef:n}){let{name:r,formValue:i="key",allowsCustomValue:a}=e;a&&(i="text");let{validationBehavior:u}=vs(lp)||{};var l,o;let s=(o=(l=e.validationBehavior)!==null&&l!==void 0?l:u)!==null&&o!==void 0?o:"native",{contains:c}=xne({sensitivity:"base"}),d=UCe({defaultFilter:e.defaultFilter||c,...e,items:e.items,children:void 0,collection:t,validationBehavior:s}),h=P.useRef(null),m=P.useRef(null),y=P.useRef(null),v=P.useRef(null),[_,S]=ys(!e["aria-label"]&&!e["aria-labelledby"]),{buttonProps:E,inputProps:C,listBoxProps:T,labelProps:R,descriptionProps:$,errorMessageProps:k,...F}=KDe({...dc(e),label:S,inputRef:m,buttonRef:h,listBoxRef:y,popoverRef:v,name:i==="text"?r:void 0,validationBehavior:s},d),[L,j]=P.useState(null),V=P.useCallback(()=>{if(m.current){var G;let J=(G=h.current)===null||G===void 0?void 0:G.getBoundingClientRect(),te=m.current.getBoundingClientRect(),H=J?Math.min(J.left,te.left):te.left,M=J?Math.max(J.right,te.right):te.right;j(M-H+"px")}},[h,m,j]);ab({ref:m,onResize:V});let q=P.useMemo(()=>({isOpen:d.isOpen,isDisabled:e.isDisabled||!1,isInvalid:F.isInvalid||!1,isRequired:e.isRequired||!1}),[d.isOpen,e.isDisabled,F.isInvalid,e.isRequired]),N=wn({...e,values:q,defaultClassName:"react-aria-ComboBox"}),U=Gt(e,{global:!0});delete U.id;var W;return ye.createElement(ki,{values:[[Ywe,d],[bs,{...R,ref:_}],[ih,{...E,ref:h,isPressed:d.isOpen}],[z0,{...C,ref:m}],[q0,d],[G3,{ref:v,triggerRef:m,scrollRef:y,placement:"bottom start",isNonModal:!0,trigger:"ComboBox",style:{"--trigger-width":L},clearContexts:Gwe}],[vS,{...T,ref:y}],[ah,d],[No,{slots:{description:$,errorMessage:k}}],[Q0,{isInvalid:F.isInvalid,isDisabled:e.isDisabled||!1}],[mp,F]]},ye.createElement("div",{...U,...N,ref:n,slot:e.slot||void 0,"data-focused":d.isFocused||void 0,"data-open":d.isOpen||void 0,"data-disabled":e.isDisabled||void 0,"data-invalid":F.isInvalid||void 0,"data-required":e.isRequired||void 0}),r&&i==="key"&&ye.createElement("input",{type:"hidden",name:r,form:e.form,value:(W=d.selectedKey)!==null&&W!==void 0?W:""}))}const Wwe=["day","month","year"],Jwe={hour:1,minute:2,second:3};function e5e(e,t){let{autoComplete:n,isDisabled:r,name:i}=e,{visuallyHiddenProps:a}=kN({style:{position:"fixed",top:0,left:0}}),u=60;t.granularity==="second"?u=1:t.granularity==="hour"&&(u=3600);let l=t.value==null?"":t.value.toString(),o=t.granularity==="day"?"date":"datetime-local",s=["hour","minute","second"],c=0;return s.includes(t.granularity)&&(c=Jwe[t.granularity],s=s.slice(0,c)),{containerProps:{...a,"aria-hidden":!0,"data-react-aria-prevent-focus":!0,"data-a11y-ignore":"aria-hidden-focus"},inputProps:{tabIndex:-1,autoComplete:n,disabled:r,type:o,form:"",name:i,step:u,value:l,onChange:d=>{let h=d.target.value.toString();if(h)try{let m=W_e(h);if(t.granularity==="day"&&(m=K_e(h)),"setSegment"in t)for(let y in m)Wwe.includes(y)&&t.setSegment(y,m[y]),s.includes(y)&&t.setSegment(y,m[y]);t.setValue(m)}catch{}}}}}function t5e(e){let{state:t}=e,{containerProps:n,inputProps:r}=e5e({...e},t);return ye.createElement("div",{...n,"data-testid":"hidden-dateinput-container"},ye.createElement("input",r))}const Dhe=P.createContext(null),n5e=P.createContext(null),yS=P.createContext(null),ew=P.createContext(null),lit=P.forwardRef(function(t,n){[t,n]=In(t,n,Dhe);let{validationBehavior:r}=vs(lp)||{};var i,a;let u=(a=(i=t.validationBehavior)!==null&&i!==void 0?i:r)!==null&&a!==void 0?a:"native",{locale:l}=Hi(),o=KN({...t,locale:l,createCalendar:yne,validationBehavior:u}),s=P.useRef(null),[c,d]=ys(!t["aria-label"]&&!t["aria-labelledby"]),h=P.useRef(null),{labelProps:m,fieldProps:y,inputProps:v,descriptionProps:_,errorMessageProps:S,...E}=jN({...dc(t),label:d,inputRef:h,validationBehavior:u},o,s),C=wn({...dc(t),values:{state:o,isInvalid:o.isInvalid,isDisabled:o.isDisabled,isReadOnly:o.isReadOnly},defaultClassName:"react-aria-DateField"}),T=Gt(t,{global:!0});return delete T.id,ye.createElement(ki,{values:[[yS,o],[Q0,{...y,ref:s,isInvalid:o.isInvalid,isDisabled:o.isDisabled}],[z0,{...v,ref:h}],[bs,{...m,ref:c,elementType:"span"}],[No,{slots:{description:_,errorMessage:S}}],[mp,E]]},ye.createElement("div",{...T,...C,ref:n,slot:t.slot||void 0,"data-invalid":o.isInvalid||void 0,"data-disabled":o.isDisabled||void 0,"data-readonly":o.isReadOnly||void 0}),ye.createElement(t5e,{autoComplete:t.autoComplete,name:t.name,isDisabled:t.isDisabled,state:o}))}),oit=P.forwardRef(function(t,n){[t,n]=In(t,n,n5e);let{validationBehavior:r}=vs(lp)||{};var i,a;let u=(a=(i=t.validationBehavior)!==null&&i!==void 0?i:r)!==null&&a!==void 0?a:"native",{locale:l}=Hi(),o=iwe({...t,locale:l,validationBehavior:u}),s=P.useRef(null),[c,d]=ys(!t["aria-label"]&&!t["aria-labelledby"]),h=P.useRef(null),{labelProps:m,fieldProps:y,inputProps:v,descriptionProps:_,errorMessageProps:S,...E}=eCe({...dc(t),label:d,inputRef:h,validationBehavior:u},o,s),C=wn({...t,values:{state:o,isInvalid:o.isInvalid,isDisabled:o.isDisabled,isReadOnly:o.isReadOnly},defaultClassName:"react-aria-TimeField"}),T=Gt(t,{global:!0});return delete T.id,ye.createElement(ki,{values:[[ew,o],[Q0,{...y,ref:s,isInvalid:o.isInvalid,isDisabled:o.isDisabled}],[z0,{...v,ref:h}],[bs,{...m,ref:c,elementType:"span"}],[No,{slots:{description:_,errorMessage:S}}],[mp,E]]},ye.createElement("div",{...T,...C,ref:n,slot:t.slot||void 0,"data-invalid":o.isInvalid||void 0,"data-disabled":o.isDisabled||void 0,"data-readonly":o.isReadOnly||void 0}))}),sit=P.forwardRef(function(t,n){let r=P.useContext(yS),i=P.useContext(ew);return r||i?ye.createElement($he,{...t,ref:n}):ye.createElement(r5e,{...t,ref:n})}),r5e=P.forwardRef((e,t)=>{let[n,r]=In({slot:e.slot},t,Dhe),{locale:i}=Hi(),a=KN({...n,locale:i,createCalendar:yne}),u=P.useRef(null),{fieldProps:l,inputProps:o}=jN({...n,inputRef:u},a,r);return ye.createElement(ki,{values:[[yS,a],[z0,{...o,ref:u}],[Q0,{...l,ref:r,isInvalid:a.isInvalid,isDisabled:a.isDisabled}]]},ye.createElement($he,e))}),$he=P.forwardRef((e,t)=>{let{className:n,children:r}=e,i=P.useContext(yS),a=P.useContext(ew),u=i??a;return ye.createElement(ye.Fragment,null,ye.createElement(Ewe,{...e,ref:t,slot:e.slot||void 0,className:n??"react-aria-DateInput",isReadOnly:u.isReadOnly,isInvalid:u.isInvalid,isDisabled:u.isDisabled},u.segments.map((l,o)=>P.cloneElement(r(l),{key:o}))),ye.createElement($we,null))}),cit=P.forwardRef(function({segment:t,...n},r){let i=P.useContext(yS),a=P.useContext(ew),u=i??a,l=$u(r),{segmentProps:o}=iCe(t,u,l),{focusProps:s,isFocused:c,isFocusVisible:d}=Hu(),{hoverProps:h,isHovered:m}=Cu({...n,isDisabled:u.isDisabled||t.type==="literal"}),y=wn({...n,values:{...t,isReadOnly:u.isReadOnly,isInvalid:u.isInvalid,isDisabled:u.isDisabled,isHovered:m,isFocused:c,isFocusVisible:d},defaultChildren:t.text,defaultClassName:"react-aria-DateSegment"});return ye.createElement("span",{...Et(Gt(n,{global:!0}),o,s,h),...y,style:o.style,ref:l,"data-placeholder":t.isPlaceholder||void 0,"data-invalid":u.isInvalid||void 0,"data-readonly":u.isReadOnly||void 0,"data-disabled":u.isDisabled||void 0,"data-type":t.type,"data-hovered":m||void 0,"data-focused":c||void 0,"data-focus-visible":d||void 0})}),Che=P.createContext(null),fit=P.forwardRef(function(t,n){let r=uwe(t),i=wn({...t,defaultClassName:"react-aria-DisclosureGroup",values:{isDisabled:r.isDisabled,state:r}}),a=Gt(t,{global:!0});return ye.createElement("div",{...a,...i,ref:n,"data-disabled":t.isDisabled||void 0},ye.createElement(Che.Provider,{value:r},i.children))}),i5e=P.createContext(null),a5e=P.createContext(null),whe=P.createContext(null),dit=P.forwardRef(function(t,n){[t,n]=In(t,n,i5e);let r=P.useContext(Che),{id:i,...a}=t,u=pi();i||(i=u);let l=r?r.expandedKeys.has(i):t.isExpanded,o=awe({...t,isExpanded:l,onExpandedChange(S){var E;r&&r.toggleKey(i),(E=t.onExpandedChange)===null||E===void 0||E.call(t,S)}}),s=ye.useRef(null),c=t.isDisabled||(r==null?void 0:r.isDisabled)||!1,{buttonProps:d,panelProps:h}=lCe({...t,isExpanded:l,isDisabled:c},o,s),{isFocusVisible:m,focusProps:y}=Hu({within:!0}),v=wn({...t,id:void 0,defaultClassName:"react-aria-Disclosure",values:{isExpanded:o.isExpanded,isDisabled:c,isFocusVisibleWithin:m,state:o}}),_=Gt(a,{global:!0});return ye.createElement(ki,{values:[[ih,{slots:{[Gv]:{},trigger:d}}],[whe,{panelProps:h,panelRef:s}],[a5e,o]]},ye.createElement("div",{...Et(_,v,y),ref:n,"data-expanded":o.isExpanded||void 0,"data-disabled":c||void 0,"data-focus-visible-within":m||void 0},v.children))}),hit=P.forwardRef(function(t,n){let{role:r="group"}=t,{panelProps:i,panelRef:a}=P.useContext(whe),{isFocusVisible:u,focusProps:l}=Hu({within:!0}),o=wn({...t,defaultClassName:"react-aria-DisclosurePanel",values:{isFocusVisibleWithin:u}}),s=Gt(t,{global:!0});return ye.createElement("div",{...Et(s,o,i,l),ref:vg(n,a),role:r,"data-focus-visible-within":u||void 0},ye.createElement(ki,{values:[[ih,null]]},t.children))}),pit=P.forwardRef(function(t,n){[t,n]=In(t,n,zee);let{children:r,level:i=3,className:a,...u}=t,l=`h${i}`;return ye.createElement(l,{...u,ref:n,className:a??"react-aria-Heading"},r)}),u5e=P.createContext(null),iI=P.createContext(null),mit=P.forwardRef(function(t,n){if(P.useContext(iI))return ye.createElement(Hj,{...t,modalRef:n},t.children);let{isDismissable:i,isKeyboardDismissDisabled:a,isOpen:u,defaultOpen:l,onOpenChange:o,children:s,isEntering:c,isExiting:d,UNSTABLE_portalContainer:h,shouldCloseOnInteractOutside:m,...y}=t;return ye.createElement(o5e,{isDismissable:i,isKeyboardDismissDisabled:a,isOpen:u,defaultOpen:l,onOpenChange:o,isEntering:c,isExiting:d,UNSTABLE_portalContainer:h,shouldCloseOnInteractOutside:m},ye.createElement(Hj,{...y,modalRef:n},s))});function l5e(e,t){[e,t]=In(e,t,u5e);let n=P.useContext(q0),r=H3(e),i=e.isOpen!=null||e.defaultOpen!=null||!n?r:n,a=$u(t),u=P.useRef(null),l=QD(a,i.isOpen),o=QD(u,i.isOpen),s=l||o||e.isExiting||!1,c=hp();return!i.isOpen&&!s||c?null:ye.createElement(s5e,{...e,state:i,isExiting:s,overlayRef:a,modalRef:u})}const o5e=P.forwardRef(l5e);function s5e({UNSTABLE_portalContainer:e,...t}){let n=t.modalRef,{state:r}=t,{modalProps:i,underlayProps:a}=EDe(t,r,n),u=IC(t.overlayRef)||t.isEntering||!1,l=wn({...t,defaultClassName:"react-aria-ModalOverlay",values:{isEntering:u,isExiting:t.isExiting,state:r}}),o=JSe(),s;if(typeof document<"u"){let d=ub(document.body)?document.body:document.scrollingElement||document.documentElement,h=d.getBoundingClientRect().height%1;s=d.scrollHeight-h}let c={...l.style,"--visual-viewport-height":o.height+"px","--page-height":s!==void 0?s+"px":void 0};return ye.createElement(Q9,{isExiting:t.isExiting,portalContainer:e},ye.createElement("div",{...Et(Gt(t,{global:!0}),a),...l,style:c,ref:t.overlayRef,"data-entering":u||void 0,"data-exiting":t.isExiting||void 0},ye.createElement(ki,{values:[[iI,{modalProps:i,modalRef:n,isExiting:t.isExiting,isDismissable:t.isDismissable}],[q0,r]]},l.children)))}function Hj(e){let{modalProps:t,modalRef:n,isExiting:r,isDismissable:i}=P.useContext(iI),a=P.useContext(q0),u=P.useMemo(()=>vg(e.modalRef,n),[e.modalRef,n]),l=$u(u),o=IC(l),s=wn({...e,defaultClassName:"react-aria-Modal",values:{isEntering:o,isExiting:r,state:a}});return ye.createElement("div",{...Et(Gt(e,{global:!0}),t),...s,ref:l,"data-entering":o||void 0,"data-exiting":r||void 0},i&&ye.createElement(B9,{onDismiss:a.close}),s.children)}const c5e=P.createContext(null),f5e=P.createContext(null),git=P.forwardRef(function(t,n){[t,n]=In(t,n,c5e);let{validationBehavior:r}=vs(lp)||{};var i,a;let u=(a=(i=t.validationBehavior)!==null&&i!==void 0?i:r)!==null&&a!==void 0?a:"native",{locale:l}=Hi(),o=jle({...t,locale:l,validationBehavior:u}),s=P.useRef(null),[c,d]=ys(!t["aria-label"]&&!t["aria-labelledby"]),{labelProps:h,groupProps:m,inputProps:y,incrementButtonProps:v,decrementButtonProps:_,descriptionProps:S,errorMessageProps:E,...C}=ose({...dc(t),label:d,validationBehavior:u},o,s),T=wn({...t,values:{state:o,isDisabled:t.isDisabled||!1,isInvalid:C.isInvalid||!1,isRequired:t.isRequired||!1},defaultClassName:"react-aria-NumberField"}),R=Gt(t,{global:!0});return delete R.id,ye.createElement(ki,{values:[[f5e,o],[Q0,m],[z0,{...y,ref:s}],[bs,{...h,ref:c}],[ih,{slots:{increment:v,decrement:_}}],[No,{slots:{description:S,errorMessage:E}}],[mp,C]]},ye.createElement("div",{...R,...T,ref:n,slot:t.slot||void 0,"data-disabled":t.isDisabled||void 0,"data-required":t.isRequired||void 0,"data-invalid":C.isInvalid||void 0}),t.name&&ye.createElement("input",{type:"hidden",name:t.name,form:t.form,value:isNaN(o.numberValue)?"":o.numberValue,disabled:t.isDisabled||void 0}))}),d5e=P.createContext(null),h5e=P.createContext(null),Rhe=P.createContext(null),vit=P.forwardRef(function(t,n){[t,n]=In(t,n,d5e);let{validationBehavior:r}=vs(lp)||{};var i,a;let u=(a=(i=t.validationBehavior)!==null&&i!==void 0?i:r)!==null&&a!==void 0?a:"native",l=cwe({...t,validationBehavior:u}),[o,s]=ys(!t["aria-label"]&&!t["aria-labelledby"]),{radioGroupProps:c,labelProps:d,descriptionProps:h,errorMessageProps:m,...y}=xCe({...t,label:s,validationBehavior:u},l),v=wn({...t,values:{orientation:t.orientation||"vertical",isDisabled:l.isDisabled,isReadOnly:l.isReadOnly,isRequired:l.isRequired,isInvalid:l.isInvalid,state:l},defaultClassName:"react-aria-RadioGroup"}),_=Gt(t,{global:!0});return ye.createElement("div",{...Et(_,v,c),ref:n,slot:t.slot||void 0,"data-orientation":t.orientation||"vertical","data-invalid":l.isInvalid||void 0,"data-disabled":l.isDisabled||void 0,"data-readonly":l.isReadOnly||void 0,"data-required":l.isRequired||void 0},ye.createElement(ki,{values:[[Rhe,l],[bs,{...d,ref:o,elementType:"span"}],[No,{slots:{description:h,errorMessage:m}}],[mp,y]]},ye.createElement(X3,null,v.children)))}),yit=P.forwardRef(function(t,n){let{inputRef:r=null,...i}=t;[t,n]=In(i,n,h5e);let a=ye.useContext(Rhe),u=$u(P.useMemo(()=>vg(r,t.inputRef!==void 0?t.inputRef:null),[r,t.inputRef])),{labelProps:l,inputProps:o,isSelected:s,isDisabled:c,isPressed:d}=OCe({...dc(t),children:typeof t.children=="function"?!0:t.children},a,u),{isFocused:h,isFocusVisible:m,focusProps:y}=Hu(),v=c||a.isReadOnly,{hoverProps:_,isHovered:S}=Cu({...t,isDisabled:v}),E=wn({...t,defaultClassName:"react-aria-Radio",values:{isSelected:s,isPressed:d,isHovered:S,isFocused:h,isFocusVisible:m,isDisabled:c,isReadOnly:a.isReadOnly,isInvalid:a.isInvalid,isRequired:a.isRequired}}),C=Gt(t,{global:!0});return delete C.id,delete C.onClick,ye.createElement("label",{...Et(C,l,_,E),ref:n,"data-selected":s||void 0,"data-pressed":d||void 0,"data-hovered":S||void 0,"data-focused":h||void 0,"data-focus-visible":m||void 0,"data-disabled":c||void 0,"data-readonly":a.isReadOnly||void 0,"data-invalid":a.isInvalid||void 0,"data-required":a.isRequired||void 0},ye.createElement(cS,{elementType:"span"},ye.createElement("input",{...Et(o,y),ref:u})),ye.createElement(Y3.Provider,{value:{isSelected:s}},E.children))}),p5e=P.createContext(null),bit=$b(function(t,n){[t,n]=In(t,n,p5e);let{validationBehavior:r}=vs(lp)||{};var i,a;let u=(a=(i=t.validationBehavior)!==null&&i!==void 0?i:r)!==null&&a!==void 0?a:"native",l=P.useRef(null);[t,l]=In(t,l,PC);let[o,s]=ys(!t["aria-label"]&&!t["aria-labelledby"]),c=fwe({...t,validationBehavior:u}),{labelProps:d,inputProps:h,clearButtonProps:m,descriptionProps:y,errorMessageProps:v,..._}=JDe({...dc(t),label:s,validationBehavior:u},c,l),S=wn({...t,values:{isEmpty:c.value==="",isDisabled:t.isDisabled||!1,isInvalid:_.isInvalid||!1,state:c},defaultClassName:"react-aria-SearchField"}),E=Gt(t,{global:!0});return delete E.id,ye.createElement("div",{...E,...S,ref:n,slot:t.slot||void 0,"data-empty":c.value===""||void 0,"data-disabled":t.isDisabled||void 0,"data-invalid":_.isInvalid||void 0},ye.createElement(ki,{values:[[bs,{...d,ref:o}],[z0,{...h,ref:l}],[ih,m],[No,{slots:{description:y,errorMessage:v}}],[Q0,{isInvalid:_.isInvalid,isDisabled:t.isDisabled||!1}],[mp,_]]},S.children))});function m5e(e){return e&&e.__esModule?e.default:e}const aI=P.createContext(null),Ahe=P.createContext(null),Oit=P.forwardRef(function(t,n){[t,n]=In(t,n,aI);let{children:r,isDisabled:i=!1,isInvalid:a=!1,isRequired:u=!1}=t,l=P.useMemo(()=>typeof r=="function"?r({isOpen:!1,isDisabled:i,isInvalid:a,isRequired:u,isFocused:!1,isFocusVisible:!1,defaultChildren:null}):r,[r,i,a,u]);return ye.createElement(Cb,{content:l},o=>ye.createElement(v5e,{props:t,collection:o,selectRef:n}))}),g5e=[bs,ih,No];function v5e({props:e,selectRef:t,collection:n}){let{validationBehavior:r}=vs(lp)||{};var i,a;let u=(a=(i=e.validationBehavior)!==null&&i!==void 0?i:r)!==null&&a!==void 0?a:"native",l=dwe({...e,collection:n,children:void 0,validationBehavior:u}),{isFocusVisible:o,focusProps:s}=Hu({within:!0}),c=P.useRef(null),[d,h]=ys(!e["aria-label"]&&!e["aria-labelledby"]),{labelProps:m,triggerProps:y,valueProps:v,menuProps:_,descriptionProps:S,errorMessageProps:E,hiddenSelectProps:C,...T}=SCe({...dc(e),label:h,validationBehavior:u},l,c),[R,$]=P.useState(null),k=P.useCallback(()=>{c.current&&$(c.current.offsetWidth+"px")},[c]);ab({ref:c,onResize:k});let F=P.useMemo(()=>({isOpen:l.isOpen,isFocused:l.isFocused,isFocusVisible:o,isDisabled:e.isDisabled||!1,isInvalid:T.isInvalid||!1,isRequired:e.isRequired||!1}),[l.isOpen,l.isFocused,o,e.isDisabled,T.isInvalid,e.isRequired]),L=wn({...e,values:F,defaultClassName:"react-aria-Select"}),j=Gt(e,{global:!0});delete j.id;let V=P.useRef(null);return ye.createElement(ki,{values:[[aI,e],[Ahe,l],[The,v],[bs,{...m,ref:d,elementType:"span"}],[ih,{...y,ref:c,isPressed:l.isOpen,autoFocus:e.autoFocus}],[q0,l],[G3,{trigger:"Select",triggerRef:c,scrollRef:V,placement:"bottom start",style:{"--trigger-width":R},"aria-labelledby":_["aria-labelledby"],clearContexts:g5e}],[vS,{..._,ref:V}],[ah,l],[No,{slots:{description:S,errorMessage:E}}],[mp,T]]},ye.createElement("div",{...Et(j,L,s),ref:t,slot:e.slot||void 0,"data-focused":l.isFocused||void 0,"data-focus-visible":o||void 0,"data-open":l.isOpen||void 0,"data-disabled":e.isDisabled||void 0,"data-invalid":T.isInvalid||void 0,"data-required":e.isRequired||void 0},L.children,ye.createElement(ECe,{...C,autoComplete:e.autoComplete})))}const The=P.createContext(null),xit=$b(function(t,n){var r;[t,n]=In(t,n,The);let i=P.useContext(Ahe),{placeholder:a}=vs(aI),u=i.selectedItems.map(S=>{var E;let C=(E=S.props)===null||E===void 0?void 0:E.children;return typeof C=="function"&&(C=C({isHovered:!1,isPressed:!1,isSelected:!1,isFocused:!1,isFocusVisible:!1,isDisabled:!1,selectionMode:"single",selectionBehavior:"toggle"})),C}),l=M_e(),o=P.useMemo(()=>i.selectedItems.map(S=>S==null?void 0:S.textValue),[i.selectedItems]),s=i.selectionManager.selectionMode,c=P.useMemo(()=>{var S;return s==="single"?(S=o[0])!==null&&S!==void 0?S:"":l.format(o)},[s,l,o]),d=P.useMemo(()=>{if(s==="single")return u[0];let S=l.formatToParts(o);if(S.length===0)return null;let E=0;return S.map(C=>C.type==="element"?ye.createElement(P.Fragment,{key:E},u[E++]):C.value)},[s,l,o,u]),h=Fo(m5e(JN),"react-aria-components");var m,y;let v=wn({...t,defaultChildren:(m=d??a)!==null&&m!==void 0?m:h.format("selectPlaceholder"),defaultClassName:"react-aria-SelectValue",values:{selectedItem:(y=(r=i.selectedItems[0])===null||r===void 0?void 0:r.value)!==null&&y!==void 0?y:null,selectedItems:P.useMemo(()=>i.selectedItems.map(S=>{var E;return(E=S.value)!==null&&E!==void 0?E:null}),[i.selectedItems]),selectedText:c,isPlaceholder:i.selectedItems.length===0,state:i}}),_=Gt(t,{global:!0});return ye.createElement("span",{ref:n,..._,...v,"data-placeholder":i.selectedItems.length===0||void 0},ye.createElement(No.Provider,{value:void 0},v.children))}),y5e=P.createContext(null),Sit=P.forwardRef(function(t,n){let{inputRef:r=null,...i}=t;[t,n]=In(i,n,y5e);let a=$u(vg(r,t.inputRef!==void 0?t.inputRef:null)),u=YC(t),{labelProps:l,inputProps:o,isSelected:s,isDisabled:c,isReadOnly:d,isPressed:h}=$Ce({...dc(t),children:typeof t.children=="function"?!0:t.children},u,a),{isFocused:m,isFocusVisible:y,focusProps:v}=Hu(),_=t.isDisabled||t.isReadOnly,{hoverProps:S,isHovered:E}=Cu({...t,isDisabled:_}),C=wn({...t,defaultClassName:"react-aria-Switch",values:{isSelected:s,isPressed:h,isHovered:E,isFocused:m,isFocusVisible:y,isDisabled:c,isReadOnly:d,state:u}}),T=Gt(t,{global:!0});return delete T.id,delete T.onClick,ye.createElement("label",{...Et(T,l,S,C),ref:n,slot:t.slot||void 0,"data-selected":s||void 0,"data-pressed":h||void 0,"data-hovered":E||void 0,"data-focused":m||void 0,"data-focus-visible":y||void 0,"data-disabled":c||void 0,"data-readonly":d||void 0},ye.createElement(cS,{elementType:"span"},ye.createElement("input",{...Et(o,v),ref:a})),C.children)}),tw=P.createContext(null),R3=P.createContext(null),_it=P.forwardRef(function(t,n){[t,n]=In(t,n,tw);let{children:r,orientation:i="horizontal"}=t;return r=P.useMemo(()=>typeof r=="function"?r({orientation:i,defaultChildren:null}):r,[r,i]),ye.createElement(Cb,{content:r},a=>ye.createElement(b5e,{props:t,collection:a,tabsRef:n}))});function b5e({props:e,tabsRef:t,collection:n}){let{orientation:r="horizontal"}=e,i=pwe({...e,collection:n,children:void 0}),{focusProps:a,isFocused:u,isFocusVisible:l}=Hu({within:!0}),o=P.useMemo(()=>({orientation:r,isFocusWithin:u,isFocusVisible:l}),[r,u,l]),s=wn({...e,defaultClassName:"react-aria-Tabs",values:o}),c=Gt(e,{global:!0});return ye.createElement("div",{...Et(c,s,a),ref:t,slot:e.slot||void 0,"data-focused":u||void 0,"data-orientation":r,"data-focus-visible":l||void 0,"data-disabled":i.isDisabled||void 0},ye.createElement(ki,{values:[[tw,e],[R3,i]]},s.children))}const Eit=P.forwardRef(function(t,n){return P.useContext(R3)?ye.createElement(O5e,{props:t,forwardedRef:n}):ye.createElement(mS,t)});function O5e({props:e,forwardedRef:t}){let n=P.useContext(R3),{CollectionRoot:r}=P.useContext(pp),{orientation:i="horizontal",keyboardActivation:a="automatic"}=vs(tw),u=$u(t),{tabListProps:l}=ACe({...e,orientation:i,keyboardActivation:a},n,u),o=wn({...e,children:null,defaultClassName:"react-aria-TabList",values:{orientation:i,state:n}}),s=Gt(e,{global:!0});return delete s.id,ye.createElement("div",{...Et(s,o,l),ref:u,"data-orientation":i||void 0},ye.createElement(X3,null,ye.createElement(r,{collection:n.collection,persistedKeys:QN(n.selectionManager.focusedKey)})))}class khe extends gy{}khe.type="item";const Dit=wb(khe,(e,t,n)=>{let r=P.useContext(R3),i=$u(t),{tabProps:a,isSelected:u,isDisabled:l,isPressed:o}=CCe({key:n.key,...e},r,i),{focusProps:s,isFocused:c,isFocusVisible:d}=Hu(),{hoverProps:h,isHovered:m}=Cu({isDisabled:l,onHoverStart:e.onHoverStart,onHoverEnd:e.onHoverEnd,onHoverChange:e.onHoverChange}),y=wn({...e,id:void 0,children:n.rendered,defaultClassName:"react-aria-Tab",values:{isSelected:u,isDisabled:l,isFocused:c,isFocusVisible:d,isPressed:o,isHovered:m}}),v=n.props.href?"a":"div",_=Gt(e,{global:!0});return delete _.id,delete _.onClick,ye.createElement(v,{...Et(_,y,a,s,h),ref:i,"data-selected":u||void 0,"data-disabled":l||void 0,"data-focused":c||void 0,"data-focus-visible":d||void 0,"data-pressed":o||void 0,"data-hovered":m||void 0},ye.createElement(Y3.Provider,{value:{isSelected:u}},y.children))}),$it=$b(function(t,n){const r=P.useContext(R3);let i=$u(n),{id:a,...u}=t,{tabPanelProps:l}=wCe(t,r,i),{focusProps:o,isFocused:s,isFocusVisible:c}=Hu(),d=r.selectedKey===t.id,h=wn({...t,defaultClassName:"react-aria-TabPanel",values:{isFocused:s,isFocusVisible:c,isInert:v9(!d),state:r}});if(!d&&!t.shouldForceMount)return null;let m=Gt(u,{global:!0});delete m.id;let y=d?Et(m,l,o,h):h;return ye.createElement("div",{...y,ref:i,"data-focused":s||void 0,"data-focus-visible":c||void 0,inert:v9(!d||t.inert),"data-inert":d?void 0:"true"},ye.createElement(ki,{values:[[tw,null],[R3,null]]},ye.createElement(pp.Provider,{value:BN},h.children)))}),x5e=P.createContext(null),Phe=P.createContext(null),Cit=P.forwardRef(function(t,n){return[t,n]=In(t,n,x5e),ye.createElement(ah.Provider,{value:null},ye.createElement(Cb,{content:t.children},r=>ye.createElement(S5e,{props:t,forwardedRef:n,collection:r})))});function S5e({props:e,forwardedRef:t,collection:n}){let r=P.useRef(null),{id:i,...a}=e;[a,r]=In(a,r,dx);let{filter:u,shouldUseVirtualFocus:l,...o}=a,[s,c]=ys(!e["aria-label"]&&!e["aria-labelledby"]),d=GC({...o,children:void 0,collection:n}),h=jfe(d,u),m=Gt(a,{global:!0}),y=Object.fromEntries(Object.entries(m).map(([T,R])=>[T,T==="id"?R:void 0])),{gridProps:v,labelProps:_,descriptionProps:S,errorMessageProps:E}=TCe({...o,...y,label:c},h,r);var C;return ye.createElement("div",{...m,id:i,ref:t,slot:e.slot||void 0,className:(C=e.className)!==null&&C!==void 0?C:"react-aria-TagGroup",style:e.style},ye.createElement(ki,{values:[[bs,{..._,elementType:"span",ref:s}],[Phe,{...v,ref:r}],[ah,h],[No,{slots:{description:S,errorMessage:E}}]]},e.children))}const wit=P.forwardRef(function(t,n){return P.useContext(ah)?ye.createElement(_5e,{props:t,forwardedRef:n}):ye.createElement(mS,t)});function _5e({props:e,forwardedRef:t}){let n=P.useContext(ah),{CollectionRoot:r}=P.useContext(pp),[i,a]=In({},t,Phe),{focusProps:u,isFocused:l,isFocusVisible:o}=Hu(),s={isEmpty:n.collection.size===0,isFocused:l,isFocusVisible:o,state:n},c=wn({className:e.className,style:e.style,defaultClassName:"react-aria-TagList",values:s}),d=QN(n.selectionManager.focusedKey),h=Gt(e,{global:!0});return ye.createElement("div",{...Et(h,c,i,u),ref:a,"data-empty":n.collection.size===0||void 0,"data-focused":l||void 0,"data-focus-visible":o||void 0},ye.createElement(X3,null,n.collection.size===0&&e.renderEmptyState?e.renderEmptyState(s):ye.createElement(r,{collection:n.collection,persistedKeys:d})))}const Rit=wb(XC,(e,t,n)=>{let r=P.useContext(ah),i=$u(t),{focusProps:a,isFocusVisible:u}=Hu({within:!1}),{rowProps:l,gridCellProps:o,removeButtonProps:s,...c}=PCe({item:n},r,i),{hoverProps:d,isHovered:h}=Cu({isDisabled:!c.allowsSelection,onHoverStart:n.props.onHoverStart,onHoverChange:n.props.onHoverChange,onHoverEnd:n.props.onHoverEnd}),m=wn({...e,id:void 0,children:n.rendered,defaultClassName:"react-aria-Tag",values:{...c,isFocusVisible:u,isHovered:h,selectionMode:r.selectionManager.selectionMode,selectionBehavior:r.selectionManager.selectionBehavior}});P.useEffect(()=>{n.textValue},[n.textValue]);let y=Gt(e,{global:!0});return delete y.id,delete y.onClick,ye.createElement("div",{ref:i,...Et(y,m,l,a,d),"data-selected":c.isSelected||void 0,"data-disabled":c.isDisabled||void 0,"data-hovered":h||void 0,"data-focused":c.isFocused||void 0,"data-focus-visible":u||void 0,"data-pressed":c.isPressed||void 0,"data-allows-removing":c.allowsRemoving||void 0,"data-selection-mode":r.selectionManager.selectionMode==="none"?void 0:r.selectionManager.selectionMode},ye.createElement("div",{...o,style:{display:"contents"}},ye.createElement(ki,{values:[[ih,{slots:{remove:s}}],[pp,BN],[Y3,{isSelected:c.isSelected}]]},m.children)))}),Mhe=P.createContext({});let E5e=e=>{let{onHoverStart:t,onHoverChange:n,onHoverEnd:r,...i}=e;return i};const Ait=P.forwardRef(function(t,n){[t,n]=In(t,n,Mhe);let{hoverProps:r,isHovered:i}=Cu(t),{isFocused:a,isFocusVisible:u,focusProps:l}=Hu({isTextInput:!0,autoFocus:t.autoFocus}),o=!!t["aria-invalid"]&&t["aria-invalid"]!=="false",s=wn({...t,values:{isHovered:i,isFocused:a,isFocusVisible:u,isDisabled:t.disabled||!1,isInvalid:o},defaultClassName:"react-aria-TextArea"});return ye.createElement("textarea",{...Et(E5e(t),l,r),...s,ref:n,"data-focused":a||void 0,"data-disabled":t.disabled||void 0,"data-hovered":i||void 0,"data-focus-visible":u||void 0,"data-invalid":o||void 0})}),D5e=P.createContext(null),Tit=$b(function(t,n){[t,n]=In(t,n,D5e);let{validationBehavior:r}=vs(lp)||{};var i,a;let u=(a=(i=t.validationBehavior)!==null&&i!==void 0?i:r)!==null&&a!==void 0?a:"native",l=P.useRef(null);[t,l]=In(t,l,PC);let[o,s]=ys(!t["aria-label"]&&!t["aria-labelledby"]),[c,d]=P.useState("input"),{labelProps:h,inputProps:m,descriptionProps:y,errorMessageProps:v,..._}=HC({...dc(t),inputElementType:c,label:s,validationBehavior:u},l),S=P.useCallback(T=>{l.current=T,T&&d(T instanceof HTMLTextAreaElement?"textarea":"input")},[l]),E=wn({...t,values:{isDisabled:t.isDisabled||!1,isInvalid:_.isInvalid,isReadOnly:t.isReadOnly||!1,isRequired:t.isRequired||!1},defaultClassName:"react-aria-TextField"}),C=Gt(t,{global:!0});return delete C.id,ye.createElement("div",{...C,...E,ref:n,slot:t.slot||void 0,"data-disabled":t.isDisabled||void 0,"data-invalid":_.isInvalid||void 0,"data-readonly":t.isReadOnly||void 0,"data-required":t.isRequired||void 0},ye.createElement(ki,{values:[[bs,{...h,ref:o}],[z0,{...m,ref:S}],[Mhe,{...m,ref:S}],[Q0,{role:"presentation",isInvalid:_.isInvalid,isDisabled:t.isDisabled||!1}],[No,{slots:{description:y,errorMessage:v}}],[mp,_]]},E.children))}),uI=P.createContext(null),kit=P.forwardRef(function(t,n){let r=hp(),i=mwe(t.queue),a=$u(n),{regionProps:u}=ICe(t,i,a),{focusProps:l,isFocused:o,isFocusVisible:s}=Hu(),{hoverProps:c,isHovered:d}=Cu({}),h=wn({...t,children:void 0,defaultClassName:"react-aria-ToastRegion",values:{visibleToasts:i.visibleToasts,isHovered:d,isFocused:o,isFocusVisible:s}}),{direction:m}=Hi(),y,{getContainer:v}=TN();r||(y=document.body,v&&(y=v()));let _=Gt(t,{global:!0}),S=ye.createElement(uI.Provider,{value:i},ye.createElement("div",{...Et(_,h,u,l,c),dir:m,ref:a,"data-hovered":d||void 0,"data-focused":o||void 0,"data-focus-visible":s||void 0},typeof t.children=="function"?ye.createElement($5e,{...t,className:void 0,style:{display:"contents"}},t.children):t.children));return i.visibleToasts.length>0&&y?Vf.createPortal(S,y):null}),$5e=P.forwardRef(function(t,n){let r=P.useContext(uI),{hoverProps:i,isHovered:a}=Cu({}),u=wn({...t,children:void 0,defaultClassName:"react-aria-ToastList",values:{visibleToasts:r.visibleToasts,isFocused:!1,isFocusVisible:!1,isHovered:a}});return ye.createElement("ol",{...i,...u,ref:n},r.visibleToasts.map(l=>ye.createElement("li",{key:l.key,style:{display:"contents"}},t.children({toast:l}))))}),Pit=P.forwardRef(function(t,n){let r=P.useContext(uI),i=$u(n),{toastProps:a,contentProps:u,titleProps:l,descriptionProps:o,closeButtonProps:s}=FCe(t,r,i),{focusProps:c,isFocused:d,isFocusVisible:h}=Hu(),m=wn({...t,defaultClassName:"react-aria-Toast",values:{toast:t.toast,isFocused:d,isFocusVisible:h}}),y=Gt(t,{global:!0});return ye.createElement("div",{...Et(y,m,a,c),ref:i,"data-focused":d||void 0,"data-focus-visible":h||void 0},ye.createElement(ki,{values:[[Fhe,u],[No,{slots:{[Gv]:{},title:l,description:o}}],[ih,{slots:{[Gv]:{},close:s}}]]},m.children))}),Fhe=P.createContext({}),Mit=P.forwardRef(function(t,n){return[t,n]=In(t,n,Fhe),ye.createElement("div",{className:"react-aria-ToastContent",...t,ref:n},t.children)}),C5e=P.createContext({}),Nhe=P.createContext(null),Fit=P.forwardRef(function(t,n){[t,n]=In(t,n,C5e);let r=E$e(t),{groupProps:i}=x$e(t,r,n),a=wn({...t,values:{isDisabled:r.isDisabled,state:r},defaultClassName:"react-aria-ToggleButtonGroup"}),u=Gt(t,{global:!0});return ye.createElement("div",{...Et(u,a,i),ref:n,slot:t.slot||void 0,"data-orientation":t.orientation||"horizontal","data-disabled":t.isDisabled||void 0},ye.createElement(Nhe.Provider,{value:r},ye.createElement(X3,null,a.children)))}),w5e=P.createContext({}),Nit=P.forwardRef(function(t,n){[t,n]=In(t,n,w5e);let r=P.useContext(Nhe),i=YC(r&&t.id!=null?{isSelected:r.selectedKeys.has(t.id),onChange(_){r.setSelected(t.id,_)}}:t),{buttonProps:a,isPressed:u,isSelected:l,isDisabled:o}=r&&t.id!=null?S$e({...t,id:t.id},r,n):_ue({...t,id:t.id!=null?String(t.id):void 0},i,n),{focusProps:s,isFocused:c,isFocusVisible:d}=Hu(t),{hoverProps:h,isHovered:m}=Cu(t),y=wn({...t,id:void 0,values:{isHovered:m,isPressed:u,isFocused:c,isSelected:i.isSelected,isFocusVisible:d,isDisabled:o,state:i},defaultClassName:"react-aria-ToggleButton"}),v=Gt(t,{global:!0});return delete v.id,delete v.onClick,ye.createElement("button",{...Et(v,y,a,s,h),ref:n,slot:t.slot||void 0,"data-focused":c||void 0,"data-disabled":o||void 0,"data-pressed":u||void 0,"data-selected":l||void 0,"data-hovered":m||void 0,"data-focus-visible":d||void 0},ye.createElement(Y3.Provider,{value:{isSelected:l}},y.children))}),R5e=P.createContext({}),Iit=P.forwardRef(function(t,n){[t,n]=In(t,n,R5e);let{toolbarProps:r}=Eue(t,n),i=wn({...t,values:{orientation:t.orientation||"horizontal"},defaultClassName:"react-aria-Toolbar"}),a=Gt(t,{global:!0});return delete a.id,ye.createElement("div",{...Et(a,i,r),ref:n,slot:t.slot||void 0,"data-orientation":t.orientation||"horizontal"},i.children)}),lI=P.createContext(null),Ihe=P.createContext(null);function Lit(e){let t=kde(e),n=P.useRef(null),{triggerProps:r,tooltipProps:i}=BCe(e,t,n);return ye.createElement(ki,{values:[[lI,t],[Ihe,{...i,triggerRef:n}]]},ye.createElement(JEe,{...r,ref:n},e.children))}const Bit=P.forwardRef(function({UNSTABLE_portalContainer:t,...n},r){[n,r]=In(n,r,Ihe);let i=P.useContext(lI),a=kde(n),u=n.isOpen!=null||n.defaultOpen!=null||!i?a:i,l=QD(r,u.isOpen)||n.isExiting||!1;return!u.isOpen&&!l?null:ye.createElement(bDe,{portalContainer:t},ye.createElement(A5e,{...n,tooltipRef:r,isExiting:l}))});function A5e(e){let t=P.useContext(lI),n=P.useRef(null),{overlayProps:r,arrowProps:i,placement:a,triggerAnchorPoint:u}=Sne({placement:e.placement||"top",targetRef:e.triggerRef,overlayRef:e.tooltipRef,arrowRef:n,offset:e.offset,crossOffset:e.crossOffset,isOpen:t.isOpen,arrowBoundaryOffset:e.arrowBoundaryOffset,shouldFlip:e.shouldFlip,containerPadding:e.containerPadding,onClose:()=>t.close(!0)}),l=IC(e.tooltipRef,!!a)||e.isEntering||!1,o=wn({...e,defaultClassName:"react-aria-Tooltip",values:{placement:a,isEntering:l,isExiting:e.isExiting,state:t}});e=Et(e,r);let{tooltipProps:s}=LCe(e,t),c=Gt(e,{global:!0});return ye.createElement("div",{...Et(c,o,s),ref:e.tooltipRef,style:{...r.style,"--trigger-anchor-point":u?`${u.x}px ${u.y}px`:void 0,...o.style},"data-placement":a??void 0,"data-entering":l||void 0,"data-exiting":e.isExiting||void 0},ye.createElement(nI.Provider,{value:{...i,placement:a,ref:n}},o.children))}/**
 * react-router v7.8.0
 *
 * Copyright (c) Remix Software Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE.md file in the root directory of this source tree.
 *
 * @license MIT
 */var Lhe=e=>{throw TypeError(e)},T5e=(e,t,n)=>t.has(e)||Lhe("Cannot "+n),dk=(e,t,n)=>(T5e(e,t,"read from private field"),n?n.call(e):t.get(e)),k5e=(e,t,n)=>t.has(e)?Lhe("Cannot add the same private member more than once"):t instanceof WeakSet?t.add(e):t.set(e,n),Xj="popstate";function P5e(e={}){function t(r,i){let{pathname:a,search:u,hash:l}=r.location;return Ox("",{pathname:a,search:u,hash:l},i.state&&i.state.usr||null,i.state&&i.state.key||"default")}function n(r,i){return typeof i=="string"?i:ey(i)}return F5e(t,n,null,e)}function pr(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}function Eu(e,t){if(!e){typeof console<"u"&&console.warn(t);try{throw new Error(t)}catch{}}}function M5e(){return Math.random().toString(36).substring(2,10)}function Yj(e,t){return{usr:e.state,key:e.key,idx:t}}function Ox(e,t,n=null,r){return{pathname:typeof e=="string"?e:e.pathname,search:"",hash:"",...typeof t=="string"?yy(t):t,state:n,key:t&&t.key||r||M5e()}}function ey({pathname:e="/",search:t="",hash:n=""}){return t&&t!=="?"&&(e+=t.charAt(0)==="?"?t:"?"+t),n&&n!=="#"&&(e+=n.charAt(0)==="#"?n:"#"+n),e}function yy(e){let t={};if(e){let n=e.indexOf("#");n>=0&&(t.hash=e.substring(n),e=e.substring(0,n));let r=e.indexOf("?");r>=0&&(t.search=e.substring(r),e=e.substring(0,r)),e&&(t.pathname=e)}return t}function F5e(e,t,n,r={}){let{window:i=document.defaultView,v5Compat:a=!1}=r,u=i.history,l="POP",o=null,s=c();s==null&&(s=0,u.replaceState({...u.state,idx:s},""));function c(){return(u.state||{idx:null}).idx}function d(){l="POP";let _=c(),S=_==null?null:_-s;s=_,o&&o({action:l,location:v.location,delta:S})}function h(_,S){l="PUSH";let E=Ox(v.location,_,S);s=c()+1;let C=Yj(E,s),T=v.createHref(E);try{u.pushState(C,"",T)}catch(R){if(R instanceof DOMException&&R.name==="DataCloneError")throw R;i.location.assign(T)}a&&o&&o({action:l,location:v.location,delta:1})}function m(_,S){l="REPLACE";let E=Ox(v.location,_,S);s=c();let C=Yj(E,s),T=v.createHref(E);u.replaceState(C,"",T),a&&o&&o({action:l,location:v.location,delta:0})}function y(_){return Bhe(_)}let v={get action(){return l},get location(){return e(i,u)},listen(_){if(o)throw new Error("A history only accepts one active listener");return i.addEventListener(Xj,d),o=_,()=>{i.removeEventListener(Xj,d),o=null}},createHref(_){return t(i,_)},createURL:y,encodeLocation(_){let S=y(_);return{pathname:S.pathname,search:S.search,hash:S.hash}},push:h,replace:m,go(_){return u.go(_)}};return v}function Bhe(e,t=!1){let n="http://localhost";typeof window<"u"&&(n=window.location.origin!=="null"?window.location.origin:window.location.href),pr(n,"No window.location.(origin|href) available to create URL");let r=typeof e=="string"?e:ey(e);return r=r.replace(/ $/,"%20"),!t&&r.startsWith("//")&&(r=n+r),new URL(r,n)}var F2,Gj=class{constructor(e){if(k5e(this,F2,new Map),e)for(let[t,n]of e)this.set(t,n)}get(e){if(dk(this,F2).has(e))return dk(this,F2).get(e);if(e.defaultValue!==void 0)return e.defaultValue;throw new Error("No value found for context")}set(e,t){dk(this,F2).set(e,t)}};F2=new WeakMap;var N5e=new Set(["lazy","caseSensitive","path","id","index","children"]);function I5e(e){return N5e.has(e)}var L5e=new Set(["lazy","caseSensitive","path","id","index","unstable_middleware","children"]);function B5e(e){return L5e.has(e)}function Q5e(e){return e.index===!0}function xx(e,t,n=[],r={},i=!1){return e.map((a,u)=>{let l=[...n,String(u)],o=typeof a.id=="string"?a.id:l.join("-");if(pr(a.index!==!0||!a.children,"Cannot specify children on an index route"),pr(i||!r[o],`Found a route id collision on id "${o}".  Route id's must be globally unique within Data Router usages`),Q5e(a)){let s={...a,...t(a),id:o};return r[o]=s,s}else{let s={...a,...t(a),id:o,children:void 0};return r[o]=s,a.children&&(s.children=xx(a.children,t,l,r,i)),s}})}function Rv(e,t,n="/"){return JE(e,t,n,!1)}function JE(e,t,n,r){let i=typeof t=="string"?yy(t):t,a=cf(i.pathname||"/",n);if(a==null)return null;let u=zhe(e);z5e(u);let l=null;for(let o=0;l==null&&o<u.length;++o){let s=W5e(a);l=G5e(u[o],s,r)}return l}function Qhe(e,t){let{route:n,pathname:r,params:i}=e;return{id:n.id,pathname:r,params:i,data:t[n.id],loaderData:t[n.id],handle:n.handle}}function zhe(e,t=[],n=[],r=""){let i=(a,u,l)=>{let o={relativePath:l===void 0?a.path||"":l,caseSensitive:a.caseSensitive===!0,childrenIndex:u,route:a};o.relativePath.startsWith("/")&&(pr(o.relativePath.startsWith(r),`Absolute route path "${o.relativePath}" nested under path "${r}" is not valid. An absolute child route path must start with the combined path of all its parent routes.`),o.relativePath=o.relativePath.slice(r.length));let s=w0([r,o.relativePath]),c=n.concat(o);a.children&&a.children.length>0&&(pr(a.index!==!0,`Index routes must not have child routes. Please remove all child routes from route path "${s}".`),zhe(a.children,t,c,s)),!(a.path==null&&!a.index)&&t.push({path:s,score:X5e(s,a.index),routesMeta:c})};return e.forEach((a,u)=>{var l;if(a.path===""||!((l=a.path)!=null&&l.includes("?")))i(a,u);else for(let o of qhe(a.path))i(a,u,o)}),t}function qhe(e){let t=e.split("/");if(t.length===0)return[];let[n,...r]=t,i=n.endsWith("?"),a=n.replace(/\?$/,"");if(r.length===0)return i?[a,""]:[a];let u=qhe(r.join("/")),l=[];return l.push(...u.map(o=>o===""?a:[a,o].join("/"))),i&&l.push(...u),l.map(o=>e.startsWith("/")&&o===""?"/":o)}function z5e(e){e.sort((t,n)=>t.score!==n.score?n.score-t.score:Y5e(t.routesMeta.map(r=>r.childrenIndex),n.routesMeta.map(r=>r.childrenIndex)))}var q5e=/^:[\w-]+$/,V5e=3,U5e=2,j5e=1,Z5e=10,H5e=-2,Kj=e=>e==="*";function X5e(e,t){let n=e.split("/"),r=n.length;return n.some(Kj)&&(r+=H5e),t&&(r+=U5e),n.filter(i=>!Kj(i)).reduce((i,a)=>i+(q5e.test(a)?V5e:a===""?j5e:Z5e),r)}function Y5e(e,t){return e.length===t.length&&e.slice(0,-1).every((r,i)=>r===t[i])?e[e.length-1]-t[t.length-1]:0}function G5e(e,t,n=!1){let{routesMeta:r}=e,i={},a="/",u=[];for(let l=0;l<r.length;++l){let o=r[l],s=l===r.length-1,c=a==="/"?t:t.slice(a.length)||"/",d=i$({path:o.relativePath,caseSensitive:o.caseSensitive,end:s},c),h=o.route;if(!d&&s&&n&&!r[r.length-1].route.index&&(d=i$({path:o.relativePath,caseSensitive:o.caseSensitive,end:!1},c)),!d)return null;Object.assign(i,d.params),u.push({params:i,pathname:w0([a,d.pathname]),pathnameBase:n6e(w0([a,d.pathnameBase])),route:h}),d.pathnameBase!=="/"&&(a=w0([a,d.pathnameBase]))}return u}function i$(e,t){typeof e=="string"&&(e={path:e,caseSensitive:!1,end:!0});let[n,r]=K5e(e.path,e.caseSensitive,e.end),i=t.match(n);if(!i)return null;let a=i[0],u=a.replace(/(.)\/+$/,"$1"),l=i.slice(1);return{params:r.reduce((s,{paramName:c,isOptional:d},h)=>{if(c==="*"){let y=l[h]||"";u=a.slice(0,a.length-y.length).replace(/(.)\/+$/,"$1")}const m=l[h];return d&&!m?s[c]=void 0:s[c]=(m||"").replace(/%2F/g,"/"),s},{}),pathname:a,pathnameBase:u,pattern:e}}function K5e(e,t=!1,n=!0){Eu(e==="*"||!e.endsWith("*")||e.endsWith("/*"),`Route path "${e}" will be treated as if it were "${e.replace(/\*$/,"/*")}" because the \`*\` character must always follow a \`/\` in the pattern. To get rid of this warning, please change the route path to "${e.replace(/\*$/,"/*")}".`);let r=[],i="^"+e.replace(/\/*\*?$/,"").replace(/^\/*/,"/").replace(/[\\.*+^${}|()[\]]/g,"\\$&").replace(/\/:([\w-]+)(\?)?/g,(u,l,o)=>(r.push({paramName:l,isOptional:o!=null}),o?"/?([^\\/]+)?":"/([^\\/]+)"));return e.endsWith("*")?(r.push({paramName:"*"}),i+=e==="*"||e==="/*"?"(.*)$":"(?:\\/(.+)|\\/*)$"):n?i+="\\/*$":e!==""&&e!=="/"&&(i+="(?:(?=\\/|$))"),[new RegExp(i,t?void 0:"i"),r]}function W5e(e){try{return e.split("/").map(t=>decodeURIComponent(t).replace(/\//g,"%2F")).join("/")}catch(t){return Eu(!1,`The URL path "${e}" could not be decoded because it is a malformed URL segment. This is probably due to a bad percent encoding (${t}).`),e}}function cf(e,t){if(t==="/")return e;if(!e.toLowerCase().startsWith(t.toLowerCase()))return null;let n=t.endsWith("/")?t.length-1:t.length,r=e.charAt(n);return r&&r!=="/"?null:e.slice(n)||"/"}function J5e({basename:e,pathname:t}){return t==="/"?e:w0([e,t])}function e6e(e,t="/"){let{pathname:n,search:r="",hash:i=""}=typeof e=="string"?yy(e):e;return{pathname:n?n.startsWith("/")?n:t6e(n,t):t,search:r6e(r),hash:i6e(i)}}function t6e(e,t){let n=t.replace(/\/+$/,"").split("/");return e.split("/").forEach(i=>{i===".."?n.length>1&&n.pop():i!=="."&&n.push(i)}),n.length>1?n.join("/"):"/"}function hk(e,t,n,r){return`Cannot include a '${e}' character in a manually specified \`to.${t}\` field [${JSON.stringify(r)}].  Please separate it out to the \`to.${n}\` field. Alternatively you may provide the full path as a string in <Link to="..."> and the router will parse it for you.`}function Vhe(e){return e.filter((t,n)=>n===0||t.route.path&&t.route.path.length>0)}function nw(e){let t=Vhe(e);return t.map((n,r)=>r===t.length-1?n.pathname:n.pathnameBase)}function rw(e,t,n,r=!1){let i;typeof e=="string"?i=yy(e):(i={...e},pr(!i.pathname||!i.pathname.includes("?"),hk("?","pathname","search",i)),pr(!i.pathname||!i.pathname.includes("#"),hk("#","pathname","hash",i)),pr(!i.search||!i.search.includes("#"),hk("#","search","hash",i)));let a=e===""||i.pathname==="",u=a?"/":i.pathname,l;if(u==null)l=n;else{let d=t.length-1;if(!r&&u.startsWith("..")){let h=u.split("/");for(;h[0]==="..";)h.shift(),d-=1;i.pathname=h.join("/")}l=d>=0?t[d]:"/"}let o=e6e(i,l),s=u&&u!=="/"&&u.endsWith("/"),c=(a||u===".")&&n.endsWith("/");return!o.pathname.endsWith("/")&&(s||c)&&(o.pathname+="/"),o}var w0=e=>e.join("/").replace(/\/\/+/g,"/"),n6e=e=>e.replace(/\/+$/,"").replace(/^\/*/,"/"),r6e=e=>!e||e==="?"?"":e.startsWith("?")?e:"?"+e,i6e=e=>!e||e==="#"?"":e.startsWith("#")?e:"#"+e,Qit=(e,t=302)=>{let n=t;typeof n=="number"?n={status:n}:typeof n.status>"u"&&(n.status=302);let r=new Headers(n.headers);return r.set("Location",e),new Response(null,{...n,headers:r})},a$=class{constructor(e,t,n,r=!1){this.status=e,this.statusText=t||"",this.internal=r,n instanceof Error?(this.data=n.toString(),this.error=n):this.data=n}};function Sx(e){return e!=null&&typeof e.status=="number"&&typeof e.statusText=="string"&&typeof e.internal=="boolean"&&"data"in e}var Uhe=["POST","PUT","PATCH","DELETE"],a6e=new Set(Uhe),u6e=["GET",...Uhe],l6e=new Set(u6e),o6e=new Set([301,302,303,307,308]),s6e=new Set([307,308]),pk={state:"idle",location:void 0,formMethod:void 0,formAction:void 0,formEncType:void 0,formData:void 0,json:void 0,text:void 0},c6e={state:"idle",data:void 0,formMethod:void 0,formAction:void 0,formEncType:void 0,formData:void 0,json:void 0,text:void 0},IO={state:"unblocked",proceed:void 0,reset:void 0,location:void 0},f6e=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i,oI=e=>f6e.test(e),d6e=e=>({hasErrorBoundary:!!e.hasErrorBoundary}),jhe="remix-router-transitions",Zhe=Symbol("ResetLoaderData");function h6e(e){const t=e.window?e.window:typeof window<"u"?window:void 0,n=typeof t<"u"&&typeof t.document<"u"&&typeof t.document.createElement<"u";pr(e.routes.length>0,"You must provide a non-empty routes array to createRouter");let r=e.hydrationRouteProperties||[],i=e.mapRouteProperties||d6e,a={},u=xx(e.routes,i,void 0,a),l,o=e.basename||"/",s=e.dataStrategy||y6e,c={unstable_middleware:!1,...e.future},d=null,h=new Set,m=null,y=null,v=null,_=e.hydrationData!=null,S=Rv(u,e.history.location,o),E=!1,C=null,T;if(S==null&&!e.patchRoutesOnNavigation){let ke=Qd(404,{pathname:e.history.location.pathname}),{matches:He,route:nt}=sZ(u);T=!0,S=He,C={[nt.id]:ke}}else if(S&&!e.hydrationData&&cr(S,u,e.history.location.pathname).active&&(S=null),S)if(S.some(ke=>ke.route.lazy))T=!1;else if(!S.some(ke=>ke.route.loader))T=!0;else{let ke=e.hydrationData?e.hydrationData.loaderData:null,He=e.hydrationData?e.hydrationData.errors:null;if(He){let nt=S.findIndex(dt=>He[dt.route.id]!==void 0);T=S.slice(0,nt+1).every(dt=>!Y9(dt.route,ke,He))}else T=S.every(nt=>!Y9(nt.route,ke,He))}else{T=!1,S=[];let ke=cr(null,u,e.history.location.pathname);ke.active&&ke.matches&&(E=!0,S=ke.matches)}let R,$={historyAction:e.history.action,location:e.history.location,matches:S,initialized:T,navigation:pk,restoreScrollPosition:e.hydrationData!=null?!1:null,preventScrollReset:!1,revalidation:"idle",loaderData:e.hydrationData&&e.hydrationData.loaderData||{},actionData:e.hydrationData&&e.hydrationData.actionData||null,errors:e.hydrationData&&e.hydrationData.errors||C,fetchers:new Map,blockers:new Map},k="POP",F=!1,L,j=!1,V=new Map,q=null,N=!1,U=!1,W=new Set,G=new Map,J=0,te=-1,H=new Map,M=new Set,K=new Map,X=new Map,B=new Set,ne=new Map,oe,ie=null;function de(){if(d=e.history.listen(({action:ke,location:He,delta:nt})=>{if(oe){oe(),oe=void 0;return}Eu(ne.size===0||nt!=null,"You are trying to use a blocker on a POP navigation to a location that was not created by @remix-run/router. This will fail silently in production. This can happen if you are navigating outside the router via `window.history.pushState`/`window.location.hash` instead of using router navigation APIs.  This can also happen if you are using createHashRouter and the user manually changes the URL.");let dt=Tt({currentLocation:$.location,nextLocation:He,historyAction:ke});if(dt&&nt!=null){let $t=new Promise(Ut=>{oe=Ut});e.history.go(nt*-1),ht(dt,{state:"blocked",location:He,proceed(){ht(dt,{state:"proceeding",proceed:void 0,reset:void 0,location:He}),$t.then(()=>e.history.go(nt))},reset(){let Ut=new Map($.blockers);Ut.set(dt,IO),pe({blockers:Ut})}});return}return ge(ke,He)}),n){R6e(t,V);let ke=()=>A6e(t,V);t.addEventListener("pagehide",ke),q=()=>t.removeEventListener("pagehide",ke)}return $.initialized||ge("POP",$.location,{initialHydration:!0}),R}function be(){d&&d(),q&&q(),h.clear(),L&&L.abort(),$.fetchers.forEach((ke,He)=>Ot(He)),$.blockers.forEach((ke,He)=>Fe(He))}function ve(ke){return h.add(ke),()=>h.delete(ke)}function pe(ke,He={}){ke.matches&&(ke.matches=ke.matches.map($t=>{let Ut=a[$t.route.id],Zt=$t.route;return Zt.element!==Ut.element||Zt.errorElement!==Ut.errorElement||Zt.hydrateFallbackElement!==Ut.hydrateFallbackElement?{...$t,route:Ut}:$t})),$={...$,...ke};let nt=[],dt=[];$.fetchers.forEach(($t,Ut)=>{$t.state==="idle"&&(B.has(Ut)?nt.push(Ut):dt.push(Ut))}),B.forEach($t=>{!$.fetchers.has($t)&&!G.has($t)&&nt.push($t)}),[...h].forEach($t=>$t($,{deletedFetchers:nt,viewTransitionOpts:He.viewTransitionOpts,flushSync:He.flushSync===!0})),nt.forEach($t=>Ot($t)),dt.forEach($t=>$.fetchers.delete($t))}function _e(ke,He,{flushSync:nt}={}){var nn,Rt;let dt=$.actionData!=null&&$.navigation.formMethod!=null&&ef($.navigation.formMethod)&&$.navigation.state==="loading"&&((nn=ke.state)==null?void 0:nn._isRedirect)!==!0,$t;He.actionData?Object.keys(He.actionData).length>0?$t=He.actionData:$t=null:dt?$t=$.actionData:$t=null;let Ut=He.loaderData?lZ($.loaderData,He.loaderData,He.matches||[],He.errors):$.loaderData,Zt=$.blockers;Zt.size>0&&(Zt=new Map(Zt),Zt.forEach((sn,gr)=>Zt.set(gr,IO)));let Lt=N?!1:Zn(ke,He.matches||$.matches),Vt=F===!0||$.navigation.formMethod!=null&&ef($.navigation.formMethod)&&((Rt=ke.state)==null?void 0:Rt._isRedirect)!==!0;l&&(u=l,l=void 0),N||k==="POP"||(k==="PUSH"?e.history.push(ke,ke.state):k==="REPLACE"&&e.history.replace(ke,ke.state));let tn;if(k==="POP"){let sn=V.get($.location.pathname);sn&&sn.has(ke.pathname)?tn={currentLocation:$.location,nextLocation:ke}:V.has(ke.pathname)&&(tn={currentLocation:ke,nextLocation:$.location})}else if(j){let sn=V.get($.location.pathname);sn?sn.add(ke.pathname):(sn=new Set([ke.pathname]),V.set($.location.pathname,sn)),tn={currentLocation:$.location,nextLocation:ke}}pe({...He,actionData:$t,loaderData:Ut,historyAction:k,location:ke,initialized:!0,navigation:pk,revalidation:"idle",restoreScrollPosition:Lt,preventScrollReset:Vt,blockers:Zt},{viewTransitionOpts:tn,flushSync:nt===!0}),k="POP",F=!1,j=!1,N=!1,U=!1,ie==null||ie.resolve(),ie=null}async function se(ke,He){if(typeof ke=="number"){e.history.go(ke);return}let nt=X9($.location,$.matches,o,ke,He==null?void 0:He.fromRouteId,He==null?void 0:He.relative),{path:dt,submission:$t,error:Ut}=Wj(!1,nt,He),Zt=$.location,Lt=Ox($.location,dt,He&&He.state);Lt={...Lt,...e.history.encodeLocation(Lt)};let Vt=He&&He.replace!=null?He.replace:void 0,tn="PUSH";Vt===!0?tn="REPLACE":Vt===!1||$t!=null&&ef($t.formMethod)&&$t.formAction===$.location.pathname+$.location.search&&(tn="REPLACE");let nn=He&&"preventScrollReset"in He?He.preventScrollReset===!0:void 0,Rt=(He&&He.flushSync)===!0,sn=Tt({currentLocation:Zt,nextLocation:Lt,historyAction:tn});if(sn){ht(sn,{state:"blocked",location:Lt,proceed(){ht(sn,{state:"proceeding",proceed:void 0,reset:void 0,location:Lt}),se(ke,He)},reset(){let gr=new Map($.blockers);gr.set(sn,IO),pe({blockers:gr})}});return}await ge(tn,Lt,{submission:$t,pendingError:Ut,preventScrollReset:nn,replace:He&&He.replace,enableViewTransition:He&&He.viewTransition,flushSync:Rt})}function me(){ie||(ie=T6e()),Ye(),pe({revalidation:"loading"});let ke=ie.promise;return $.navigation.state==="submitting"?ke:$.navigation.state==="idle"?(ge($.historyAction,$.location,{startUninterruptedRevalidation:!0}),ke):(ge(k||$.historyAction,$.navigation.location,{overrideNavigation:$.navigation,enableViewTransition:j===!0}),ke)}async function ge(ke,He,nt){L&&L.abort(),L=null,k=ke,N=(nt&&nt.startUninterruptedRevalidation)===!0,ln($.location,$.matches),F=(nt&&nt.preventScrollReset)===!0,j=(nt&&nt.enableViewTransition)===!0;let dt=l||u,$t=nt&&nt.overrideNavigation,Ut=nt!=null&&nt.initialHydration&&$.matches&&$.matches.length>0&&!E?$.matches:Rv(dt,He,o),Zt=(nt&&nt.flushSync)===!0;if(Ut&&$.initialized&&!U&&E6e($.location,He)&&!(nt&&nt.submission&&ef(nt.submission.formMethod))){_e(He,{matches:Ut},{flushSync:Zt});return}let Lt=cr(Ut,dt,He.pathname);if(Lt.active&&Lt.matches&&(Ut=Lt.matches),!Ut){let{error:Da,notFoundMatches:mi,route:Ur}=Qt(He.pathname);_e(He,{matches:mi,loaderData:{},errors:{[Ur.id]:Da}},{flushSync:Zt});return}L=new AbortController;let Vt=LO(e.history,He,L.signal,nt&&nt.submission),tn=e.unstable_getContext?await e.unstable_getContext():new Gj,nn;if(nt&&nt.pendingError)nn=[Av(Ut).route.id,{type:"error",error:nt.pendingError}];else if(nt&&nt.submission&&ef(nt.submission.formMethod)){let Da=await we(Vt,He,nt.submission,Ut,tn,Lt.active,nt&&nt.initialHydration===!0,{replace:nt.replace,flushSync:Zt});if(Da.shortCircuited)return;if(Da.pendingActionResult){let[mi,Ur]=Da.pendingActionResult;if(Bf(Ur)&&Sx(Ur.error)&&Ur.error.status===404){L=null,_e(He,{matches:Da.matches,loaderData:{},errors:{[mi]:Ur.error}});return}}Ut=Da.matches||Ut,nn=Da.pendingActionResult,$t=mk(He,nt.submission),Zt=!1,Lt.active=!1,Vt=LO(e.history,Vt.url,Vt.signal)}let{shortCircuited:Rt,matches:sn,loaderData:gr,errors:Pi}=await Ne(Vt,He,Ut,tn,Lt.active,$t,nt&&nt.submission,nt&&nt.fetcherSubmission,nt&&nt.replace,nt&&nt.initialHydration===!0,Zt,nn);Rt||(L=null,_e(He,{matches:sn||Ut,...oZ(nn),loaderData:gr,errors:Pi}))}async function we(ke,He,nt,dt,$t,Ut,Zt,Lt={}){Ye();let Vt=C6e(He,nt);if(pe({navigation:Vt},{flushSync:Lt.flushSync===!0}),Ut){let Rt=await ur(dt,He.pathname,ke.signal);if(Rt.type==="aborted")return{shortCircuited:!0};if(Rt.type==="error"){let sn=Av(Rt.partialMatches).route.id;return{matches:Rt.partialMatches,pendingActionResult:[sn,{type:"error",error:Rt.error}]}}else if(Rt.matches)dt=Rt.matches;else{let{notFoundMatches:sn,error:gr,route:Pi}=Qt(He.pathname);return{matches:sn,pendingActionResult:[Pi.id,{type:"error",error:gr}]}}}let tn,nn=eD(dt,He);if(!nn.route.action&&!nn.route.lazy)tn={type:"error",error:Qd(405,{method:ke.method,pathname:He.pathname,routeId:nn.route.id})};else{let Rt=s3(i,a,ke,dt,nn,Zt?[]:r,$t),sn=await Ue(ke,Rt,$t,null);if(tn=sn[nn.route.id],!tn){for(let gr of dt)if(sn[gr.route.id]){tn=sn[gr.route.id];break}}if(ke.signal.aborted)return{shortCircuited:!0}}if(I1(tn)){let Rt;return Lt&&Lt.replace!=null?Rt=Lt.replace:Rt=iZ(tn.response.headers.get("Location"),new URL(ke.url),o)===$.location.pathname+$.location.search,await Ae(ke,tn,!0,{submission:nt,replace:Rt}),{shortCircuited:!0}}if(Bf(tn)){let Rt=Av(dt,nn.route.id);return(Lt&&Lt.replace)!==!0&&(k="PUSH"),{matches:dt,pendingActionResult:[Rt.route.id,tn,nn.route.id]}}return{matches:dt,pendingActionResult:[nn.route.id,tn]}}async function Ne(ke,He,nt,dt,$t,Ut,Zt,Lt,Vt,tn,nn,Rt){let sn=Ut||mk(He,Zt),gr=Zt||Lt||fZ(sn),Pi=!N&&!tn;if($t){if(Pi){let gi=Re(Rt);pe({navigation:sn,...gi!==void 0?{actionData:gi}:{}},{flushSync:nn})}let Xn=await ur(nt,He.pathname,ke.signal);if(Xn.type==="aborted")return{shortCircuited:!0};if(Xn.type==="error"){let gi=Av(Xn.partialMatches).route.id;return{matches:Xn.partialMatches,loaderData:{},errors:{[gi]:Xn.error}}}else if(Xn.matches)nt=Xn.matches;else{let{error:gi,notFoundMatches:xs,route:Ss}=Qt(He.pathname);return{matches:xs,loaderData:{},errors:{[Ss.id]:gi}}}}let Da=l||u,{dsMatches:mi,revalidatingFetchers:Ur}=Jj(ke,dt,i,a,e.history,$,nt,gr,He,tn?[]:r,tn===!0,U,W,B,K,M,Da,o,e.patchRoutesOnNavigation!=null,Rt);if(te=++J,!e.dataStrategy&&!mi.some(Xn=>Xn.shouldLoad)&&!mi.some(Xn=>Xn.route.unstable_middleware)&&Ur.length===0){let Xn=zt();return _e(He,{matches:nt,loaderData:{},errors:Rt&&Bf(Rt[1])?{[Rt[0]]:Rt[1].error}:null,...oZ(Rt),...Xn?{fetchers:new Map($.fetchers)}:{}},{flushSync:nn}),{shortCircuited:!0}}if(Pi){let Xn={};if(!$t){Xn.navigation=sn;let gi=Re(Rt);gi!==void 0&&(Xn.actionData=gi)}Ur.length>0&&(Xn.fetchers=et(Ur)),pe(Xn,{flushSync:nn})}Ur.forEach(Xn=>{gt(Xn.key),Xn.controller&&G.set(Xn.key,Xn.controller)});let wu=()=>Ur.forEach(Xn=>gt(Xn.key));L&&L.signal.addEventListener("abort",wu);let{loaderResults:Al,fetcherResults:Hr}=await Ze(mi,Ur,ke,dt);if(ke.signal.aborted)return{shortCircuited:!0};L&&L.signal.removeEventListener("abort",wu),Ur.forEach(Xn=>G.delete(Xn.key));let Pt=Z_(Al);if(Pt)return await Ae(ke,Pt.result,!0,{replace:Vt}),{shortCircuited:!0};if(Pt=Z_(Hr),Pt)return M.add(Pt.key),await Ae(ke,Pt.result,!0,{replace:Vt}),{shortCircuited:!0};let{loaderData:ca,errors:Wi}=uZ($,nt,Al,Rt,Ur,Hr);tn&&$.errors&&(Wi={...$.errors,...Wi});let ti=zt(),Ru=an(te),uo=ti||Ru||Ur.length>0;return{matches:nt,loaderData:ca,errors:Wi,...uo?{fetchers:new Map($.fetchers)}:{}}}function Re(ke){if(ke&&!Bf(ke[1]))return{[ke[0]]:ke[1].data};if($.actionData)return Object.keys($.actionData).length===0?null:$.actionData}function et(ke){return ke.forEach(He=>{let nt=$.fetchers.get(He.key),dt=J4(void 0,nt?nt.data:void 0);$.fetchers.set(He.key,dt)}),new Map($.fetchers)}async function tt(ke,He,nt,dt){gt(ke);let $t=(dt&&dt.flushSync)===!0,Ut=l||u,Zt=X9($.location,$.matches,o,nt,He,dt==null?void 0:dt.relative),Lt=Rv(Ut,Zt,o),Vt=cr(Lt,Ut,Zt);if(Vt.active&&Vt.matches&&(Lt=Vt.matches),!Lt){ze(ke,He,Qd(404,{pathname:Zt}),{flushSync:$t});return}let{path:tn,submission:nn,error:Rt}=Wj(!0,Zt,dt);if(Rt){ze(ke,He,Rt,{flushSync:$t});return}let sn=e.unstable_getContext?await e.unstable_getContext():new Gj,gr=(dt&&dt.preventScrollReset)===!0;if(nn&&ef(nn.formMethod)){await Oe(ke,He,tn,Lt,sn,Vt.active,$t,gr,nn);return}K.set(ke,{routeId:He,path:tn}),await $e(ke,He,tn,Lt,sn,Vt.active,$t,gr,nn)}async function Oe(ke,He,nt,dt,$t,Ut,Zt,Lt,Vt){Ye(),K.delete(ke);let tn=$.fetchers.get(ke);Me(ke,w6e(Vt,tn),{flushSync:Zt});let nn=new AbortController,Rt=LO(e.history,nt,nn.signal,Vt);if(Ut){let ni=await ur(dt,new URL(Rt.url).pathname,Rt.signal,ke);if(ni.type==="aborted")return;if(ni.type==="error"){ze(ke,He,ni.error,{flushSync:Zt});return}else if(ni.matches)dt=ni.matches;else{ze(ke,He,Qd(404,{pathname:nt}),{flushSync:Zt});return}}let sn=eD(dt,nt);if(!sn.route.action&&!sn.route.lazy){let ni=Qd(405,{method:Vt.formMethod,pathname:nt,routeId:He});ze(ke,He,ni,{flushSync:Zt});return}G.set(ke,nn);let gr=J,Pi=s3(i,a,Rt,dt,sn,r,$t),mi=(await Ue(Rt,Pi,$t,ke))[sn.route.id];if(Rt.signal.aborted){G.get(ke)===nn&&G.delete(ke);return}if(B.has(ke)){if(I1(mi)||Bf(mi)){Me(ke,mv(void 0));return}}else{if(I1(mi))if(G.delete(ke),te>gr){Me(ke,mv(void 0));return}else return M.add(ke),Me(ke,J4(Vt)),Ae(Rt,mi,!1,{fetcherSubmission:Vt,preventScrollReset:Lt});if(Bf(mi)){ze(ke,He,mi.error);return}}let Ur=$.navigation.location||$.location,wu=LO(e.history,Ur,nn.signal),Al=l||u,Hr=$.navigation.state!=="idle"?Rv(Al,$.navigation.location,o):$.matches;pr(Hr,"Didn't find any matches after fetcher action");let Pt=++J;H.set(ke,Pt);let ca=J4(Vt,mi.data);$.fetchers.set(ke,ca);let{dsMatches:Wi,revalidatingFetchers:ti}=Jj(wu,$t,i,a,e.history,$,Hr,Vt,Ur,r,!1,U,W,B,K,M,Al,o,e.patchRoutesOnNavigation!=null,[sn.route.id,mi]);ti.filter(ni=>ni.key!==ke).forEach(ni=>{let _s=ni.key,$a=$.fetchers.get(_s),pc=J4(void 0,$a?$a.data:void 0);$.fetchers.set(_s,pc),gt(_s),ni.controller&&G.set(_s,ni.controller)}),pe({fetchers:new Map($.fetchers)});let Ru=()=>ti.forEach(ni=>gt(ni.key));nn.signal.addEventListener("abort",Ru);let{loaderResults:uo,fetcherResults:Xn}=await Ze(Wi,ti,wu,$t);if(nn.signal.aborted)return;if(nn.signal.removeEventListener("abort",Ru),H.delete(ke),G.delete(ke),ti.forEach(ni=>G.delete(ni.key)),$.fetchers.has(ke)){let ni=mv(mi.data);$.fetchers.set(ke,ni)}let gi=Z_(uo);if(gi)return Ae(wu,gi.result,!1,{preventScrollReset:Lt});if(gi=Z_(Xn),gi)return M.add(gi.key),Ae(wu,gi.result,!1,{preventScrollReset:Lt});let{loaderData:xs,errors:Ss}=uZ($,Hr,uo,void 0,ti,Xn);an(Pt),$.navigation.state==="loading"&&Pt>te?(pr(k,"Expected pending action"),L&&L.abort(),_e($.navigation.location,{matches:Hr,loaderData:xs,errors:Ss,fetchers:new Map($.fetchers)})):(pe({errors:Ss,loaderData:lZ($.loaderData,xs,Hr,Ss),fetchers:new Map($.fetchers)}),U=!1)}async function $e(ke,He,nt,dt,$t,Ut,Zt,Lt,Vt){let tn=$.fetchers.get(ke);Me(ke,J4(Vt,tn?tn.data:void 0),{flushSync:Zt});let nn=new AbortController,Rt=LO(e.history,nt,nn.signal);if(Ut){let Ur=await ur(dt,new URL(Rt.url).pathname,Rt.signal,ke);if(Ur.type==="aborted")return;if(Ur.type==="error"){ze(ke,He,Ur.error,{flushSync:Zt});return}else if(Ur.matches)dt=Ur.matches;else{ze(ke,He,Qd(404,{pathname:nt}),{flushSync:Zt});return}}let sn=eD(dt,nt);G.set(ke,nn);let gr=J,Pi=s3(i,a,Rt,dt,sn,r,$t),mi=(await Ue(Rt,Pi,$t,ke))[sn.route.id];if(G.get(ke)===nn&&G.delete(ke),!Rt.signal.aborted){if(B.has(ke)){Me(ke,mv(void 0));return}if(I1(mi))if(te>gr){Me(ke,mv(void 0));return}else{M.add(ke),await Ae(Rt,mi,!1,{preventScrollReset:Lt});return}if(Bf(mi)){ze(ke,He,mi.error);return}Me(ke,mv(mi.data))}}async function Ae(ke,He,nt,{submission:dt,fetcherSubmission:$t,preventScrollReset:Ut,replace:Zt}={}){He.response.headers.has("X-Remix-Revalidate")&&(U=!0);let Lt=He.response.headers.get("Location");pr(Lt,"Expected a Location header on the redirect Response"),Lt=iZ(Lt,new URL(ke.url),o);let Vt=Ox($.location,Lt,{_isRedirect:!0});if(n){let Pi=!1;if(He.response.headers.has("X-Remix-Reload-Document"))Pi=!0;else if(oI(Lt)){const Da=Bhe(Lt,!0);Pi=Da.origin!==t.location.origin||cf(Da.pathname,o)==null}if(Pi){Zt?t.location.replace(Lt):t.location.assign(Lt);return}}L=null;let tn=Zt===!0||He.response.headers.has("X-Remix-Replace")?"REPLACE":"PUSH",{formMethod:nn,formAction:Rt,formEncType:sn}=$.navigation;!dt&&!$t&&nn&&Rt&&sn&&(dt=fZ($.navigation));let gr=dt||$t;if(s6e.has(He.response.status)&&gr&&ef(gr.formMethod))await ge(tn,Vt,{submission:{...gr,formAction:Lt},preventScrollReset:Ut||F,enableViewTransition:nt?j:void 0});else{let Pi=mk(Vt,dt);await ge(tn,Vt,{overrideNavigation:Pi,fetcherSubmission:$t,preventScrollReset:Ut||F,enableViewTransition:nt?j:void 0})}}async function Ue(ke,He,nt,dt){let $t,Ut={};try{$t=await b6e(s,ke,He,dt,nt,!1)}catch(Zt){return He.filter(Lt=>Lt.shouldLoad).forEach(Lt=>{Ut[Lt.route.id]={type:"error",error:Zt}}),Ut}if(ke.signal.aborted)return Ut;for(let[Zt,Lt]of Object.entries($t))if(D6e(Lt)){let Vt=Lt.result;Ut[Zt]={type:"redirect",response:S6e(Vt,ke,Zt,He,o)}}else Ut[Zt]=await x6e(Lt);return Ut}async function Ze(ke,He,nt,dt){let $t=Ue(nt,ke,dt,null),Ut=Promise.all(He.map(async Vt=>{if(Vt.matches&&Vt.match&&Vt.request&&Vt.controller){let nn=(await Ue(Vt.request,Vt.matches,dt,Vt.key))[Vt.match.route.id];return{[Vt.key]:nn}}else return Promise.resolve({[Vt.key]:{type:"error",error:Qd(404,{pathname:Vt.path})}})})),Zt=await $t,Lt=(await Ut).reduce((Vt,tn)=>Object.assign(Vt,tn),{});return{loaderResults:Zt,fetcherResults:Lt}}function Ye(){U=!0,K.forEach((ke,He)=>{G.has(He)&&W.add(He),gt(He)})}function Me(ke,He,nt={}){$.fetchers.set(ke,He),pe({fetchers:new Map($.fetchers)},{flushSync:(nt&&nt.flushSync)===!0})}function ze(ke,He,nt,dt={}){let $t=Av($.matches,He);Ot(ke),pe({errors:{[$t.route.id]:nt},fetchers:new Map($.fetchers)},{flushSync:(dt&&dt.flushSync)===!0})}function st(ke){return X.set(ke,(X.get(ke)||0)+1),B.has(ke)&&B.delete(ke),$.fetchers.get(ke)||c6e}function Ot(ke){let He=$.fetchers.get(ke);G.has(ke)&&!(He&&He.state==="loading"&&H.has(ke))&&gt(ke),K.delete(ke),H.delete(ke),M.delete(ke),B.delete(ke),W.delete(ke),$.fetchers.delete(ke)}function Nt(ke){let He=(X.get(ke)||0)-1;He<=0?(X.delete(ke),B.add(ke)):X.set(ke,He),pe({fetchers:new Map($.fetchers)})}function gt(ke){let He=G.get(ke);He&&(He.abort(),G.delete(ke))}function qt(ke){for(let He of ke){let nt=st(He),dt=mv(nt.data);$.fetchers.set(He,dt)}}function zt(){let ke=[],He=!1;for(let nt of M){let dt=$.fetchers.get(nt);pr(dt,`Expected fetcher: ${nt}`),dt.state==="loading"&&(M.delete(nt),ke.push(nt),He=!0)}return qt(ke),He}function an(ke){let He=[];for(let[nt,dt]of H)if(dt<ke){let $t=$.fetchers.get(nt);pr($t,`Expected fetcher: ${nt}`),$t.state==="loading"&&(gt(nt),H.delete(nt),He.push(nt))}return qt(He),He.length>0}function rn(ke,He){let nt=$.blockers.get(ke)||IO;return ne.get(ke)!==He&&ne.set(ke,He),nt}function Fe(ke){$.blockers.delete(ke),ne.delete(ke)}function ht(ke,He){let nt=$.blockers.get(ke)||IO;pr(nt.state==="unblocked"&&He.state==="blocked"||nt.state==="blocked"&&He.state==="blocked"||nt.state==="blocked"&&He.state==="proceeding"||nt.state==="blocked"&&He.state==="unblocked"||nt.state==="proceeding"&&He.state==="unblocked",`Invalid blocker state transition: ${nt.state} -> ${He.state}`);let dt=new Map($.blockers);dt.set(ke,He),pe({blockers:dt})}function Tt({currentLocation:ke,nextLocation:He,historyAction:nt}){if(ne.size===0)return;ne.size>1&&Eu(!1,"A router only supports one blocker at a time");let dt=Array.from(ne.entries()),[$t,Ut]=dt[dt.length-1],Zt=$.blockers.get($t);if(!(Zt&&Zt.state==="proceeding")&&Ut({currentLocation:ke,nextLocation:He,historyAction:nt}))return $t}function Qt(ke){let He=Qd(404,{pathname:ke}),nt=l||u,{matches:dt,route:$t}=sZ(nt);return{notFoundMatches:dt,route:$t,error:He}}function un(ke,He,nt){if(m=ke,v=He,y=nt||null,!_&&$.navigation===pk){_=!0;let dt=Zn($.location,$.matches);dt!=null&&pe({restoreScrollPosition:dt})}return()=>{m=null,v=null,y=null}}function Ln(ke,He){return y&&y(ke,He.map(dt=>Qhe(dt,$.loaderData)))||ke.key}function ln(ke,He){if(m&&v){let nt=Ln(ke,He);m[nt]=v()}}function Zn(ke,He){if(m){let nt=Ln(ke,He),dt=m[nt];if(typeof dt=="number")return dt}return null}function cr(ke,He,nt){if(e.patchRoutesOnNavigation)if(ke){if(Object.keys(ke[0].params).length>0)return{active:!0,matches:JE(He,nt,o,!0)}}else return{active:!0,matches:JE(He,nt,o,!0)||[]};return{active:!1,matches:null}}async function ur(ke,He,nt,dt){if(!e.patchRoutesOnNavigation)return{type:"success",matches:ke};let $t=ke;for(;;){let Ut=l==null,Zt=l||u,Lt=a;try{await e.patchRoutesOnNavigation({signal:nt,path:He,matches:$t,fetcherKey:dt,patch:(nn,Rt)=>{nt.aborted||eZ(nn,Rt,Zt,Lt,i,!1)}})}catch(nn){return{type:"error",error:nn,partialMatches:$t}}finally{Ut&&!nt.aborted&&(u=[...u])}if(nt.aborted)return{type:"aborted"};let Vt=Rv(Zt,He,o);if(Vt)return{type:"success",matches:Vt};let tn=JE(Zt,He,o,!0);if(!tn||$t.length===tn.length&&$t.every((nn,Rt)=>nn.route.id===tn[Rt].route.id))return{type:"success",matches:null};$t=tn}}function Cr(ke){a={},l=xx(ke,i,void 0,a)}function Vr(ke,He,nt=!1){let dt=l==null;eZ(ke,He,l||u,a,i,nt),dt&&(u=[...u],pe({}))}return R={get basename(){return o},get future(){return c},get state(){return $},get routes(){return u},get window(){return t},initialize:de,subscribe:ve,enableScrollRestoration:un,navigate:se,fetch:tt,revalidate:me,createHref:ke=>e.history.createHref(ke),encodeLocation:ke=>e.history.encodeLocation(ke),getFetcher:st,deleteFetcher:Nt,dispose:be,getBlocker:rn,deleteBlocker:Fe,patchRoutes:Vr,_internalFetchControllers:G,_internalSetRoutes:Cr,_internalSetStateDoNotUseOrYouWillBreakYourApp(ke){pe(ke)}},R}function p6e(e){return e!=null&&("formData"in e&&e.formData!=null||"body"in e&&e.body!==void 0)}function X9(e,t,n,r,i,a){let u,l;if(i){u=[];for(let s of t)if(u.push(s),s.route.id===i){l=s;break}}else u=t,l=t[t.length-1];let o=rw(r||".",nw(u),cf(e.pathname,n)||e.pathname,a==="path");if(r==null&&(o.search=e.search,o.hash=e.hash),(r==null||r===""||r===".")&&l){let s=sI(o.search);if(l.route.index&&!s)o.search=o.search?o.search.replace(/^\?/,"?index&"):"?index";else if(!l.route.index&&s){let c=new URLSearchParams(o.search),d=c.getAll("index");c.delete("index"),d.filter(m=>m).forEach(m=>c.append("index",m));let h=c.toString();o.search=h?`?${h}`:""}}return n!=="/"&&(o.pathname=J5e({basename:n,pathname:o.pathname})),ey(o)}function Wj(e,t,n){if(!n||!p6e(n))return{path:t};if(n.formMethod&&!$6e(n.formMethod))return{path:t,error:Qd(405,{method:n.formMethod})};let r=()=>({path:t,error:Qd(400,{type:"invalid-body"})}),a=(n.formMethod||"get").toUpperCase(),u=Jhe(t);if(n.body!==void 0){if(n.formEncType==="text/plain"){if(!ef(a))return r();let d=typeof n.body=="string"?n.body:n.body instanceof FormData||n.body instanceof URLSearchParams?Array.from(n.body.entries()).reduce((h,[m,y])=>`${h}${m}=${y}
`,""):String(n.body);return{path:t,submission:{formMethod:a,formAction:u,formEncType:n.formEncType,formData:void 0,json:void 0,text:d}}}else if(n.formEncType==="application/json"){if(!ef(a))return r();try{let d=typeof n.body=="string"?JSON.parse(n.body):n.body;return{path:t,submission:{formMethod:a,formAction:u,formEncType:n.formEncType,formData:void 0,json:d,text:void 0}}}catch{return r()}}}pr(typeof FormData=="function","FormData is not available in this environment");let l,o;if(n.formData)l=K9(n.formData),o=n.formData;else if(n.body instanceof FormData)l=K9(n.body),o=n.body;else if(n.body instanceof URLSearchParams)l=n.body,o=aZ(l);else if(n.body==null)l=new URLSearchParams,o=new FormData;else try{l=new URLSearchParams(n.body),o=aZ(l)}catch{return r()}let s={formMethod:a,formAction:u,formEncType:n&&n.formEncType||"application/x-www-form-urlencoded",formData:o,json:void 0,text:void 0};if(ef(s.formMethod))return{path:t,submission:s};let c=yy(t);return e&&c.search&&sI(c.search)&&l.append("index",""),c.search=`?${l}`,{path:ey(c),submission:s}}function Jj(e,t,n,r,i,a,u,l,o,s,c,d,h,m,y,v,_,S,E,C){var N;let T=C?Bf(C[1])?C[1].error:C[1].data:void 0,R=i.createURL(a.location),$=i.createURL(o),k;if(c&&a.errors){let U=Object.keys(a.errors)[0];k=u.findIndex(W=>W.route.id===U)}else if(C&&Bf(C[1])){let U=C[0];k=u.findIndex(W=>W.route.id===U)-1}let F=C?C[1].statusCode:void 0,L=F&&F>=400,j={currentUrl:R,currentParams:((N=a.matches[0])==null?void 0:N.params)||{},nextUrl:$,nextParams:u[0].params,...l,actionResult:T,actionStatus:F},V=u.map((U,W)=>{let{route:G}=U,J=null;if(k!=null&&W>k?J=!1:G.lazy?J=!0:G.loader==null?J=!1:c?J=Y9(G,a.loaderData,a.errors):m6e(a.loaderData,a.matches[W],U)&&(J=!0),J!==null)return G9(n,r,e,U,s,t,J);let te=L?!1:d||R.pathname+R.search===$.pathname+$.search||R.search!==$.search||g6e(a.matches[W],U),H={...j,defaultShouldRevalidate:te},M=u$(U,H);return G9(n,r,e,U,s,t,M,H)}),q=[];return y.forEach((U,W)=>{if(c||!u.some(B=>B.route.id===U.routeId)||m.has(W))return;let G=a.fetchers.get(W),J=G&&G.state!=="idle"&&G.data===void 0,te=Rv(_,U.path,S);if(!te){if(E&&J)return;q.push({key:W,routeId:U.routeId,path:U.path,matches:null,match:null,request:null,controller:null});return}if(v.has(W))return;let H=eD(te,U.path),M=new AbortController,K=LO(i,U.path,M.signal),X=null;if(h.has(W))h.delete(W),X=s3(n,r,K,te,H,s,t);else if(J)d&&(X=s3(n,r,K,te,H,s,t));else{let B={...j,defaultShouldRevalidate:L?!1:d};u$(H,B)&&(X=s3(n,r,K,te,H,s,t,B))}X&&q.push({key:W,routeId:U.routeId,path:U.path,matches:X,match:H,request:K,controller:M})}),{dsMatches:V,revalidatingFetchers:q}}function Y9(e,t,n){if(e.lazy)return!0;if(!e.loader)return!1;let r=t!=null&&e.id in t,i=n!=null&&n[e.id]!==void 0;return!r&&i?!1:typeof e.loader=="function"&&e.loader.hydrate===!0?!0:!r&&!i}function m6e(e,t,n){let r=!t||n.route.id!==t.route.id,i=!e.hasOwnProperty(n.route.id);return r||i}function g6e(e,t){let n=e.route.path;return e.pathname!==t.pathname||n!=null&&n.endsWith("*")&&e.params["*"]!==t.params["*"]}function u$(e,t){if(e.route.shouldRevalidate){let n=e.route.shouldRevalidate(t);if(typeof n=="boolean")return n}return t.defaultShouldRevalidate}function eZ(e,t,n,r,i,a){let u;if(e){let s=r[e];pr(s,`No route found to patch children into: routeId = ${e}`),s.children||(s.children=[]),u=s.children}else u=n;let l=[],o=[];if(t.forEach(s=>{let c=u.find(d=>Hhe(s,d));c?o.push({existingRoute:c,newRoute:s}):l.push(s)}),l.length>0){let s=xx(l,i,[e||"_","patch",String((u==null?void 0:u.length)||"0")],r);u.push(...s)}if(a&&o.length>0)for(let s=0;s<o.length;s++){let{existingRoute:c,newRoute:d}=o[s],h=c,[m]=xx([d],i,[],{},!0);Object.assign(h,{element:m.element?m.element:h.element,errorElement:m.errorElement?m.errorElement:h.errorElement,hydrateFallbackElement:m.hydrateFallbackElement?m.hydrateFallbackElement:h.hydrateFallbackElement})}}function Hhe(e,t){return"id"in e&&"id"in t&&e.id===t.id?!0:e.index===t.index&&e.path===t.path&&e.caseSensitive===t.caseSensitive?(!e.children||e.children.length===0)&&(!t.children||t.children.length===0)?!0:e.children.every((n,r)=>{var i;return(i=t.children)==null?void 0:i.some(a=>Hhe(n,a))}):!1}var tZ=new WeakMap,Xhe=({key:e,route:t,manifest:n,mapRouteProperties:r})=>{let i=n[t.id];if(pr(i,"No route found in manifest"),!i.lazy||typeof i.lazy!="object")return;let a=i.lazy[e];if(!a)return;let u=tZ.get(i);u||(u={},tZ.set(i,u));let l=u[e];if(l)return l;let o=(async()=>{let s=I5e(e),d=i[e]!==void 0&&e!=="hasErrorBoundary";if(s)Eu(!s,"Route property "+e+" is not a supported lazy route property. This property will be ignored."),u[e]=Promise.resolve();else if(d)Eu(!1,`Route "${i.id}" has a static property "${e}" defined. The lazy property will be ignored.`);else{let h=await a();h!=null&&(Object.assign(i,{[e]:h}),Object.assign(i,r(i)))}typeof i.lazy=="object"&&(i.lazy[e]=void 0,Object.values(i.lazy).every(h=>h===void 0)&&(i.lazy=void 0))})();return u[e]=o,o},nZ=new WeakMap;function v6e(e,t,n,r,i){let a=n[e.id];if(pr(a,"No route found in manifest"),!e.lazy)return{lazyRoutePromise:void 0,lazyHandlerPromise:void 0};if(typeof e.lazy=="function"){let c=nZ.get(a);if(c)return{lazyRoutePromise:c,lazyHandlerPromise:c};let d=(async()=>{pr(typeof e.lazy=="function","No lazy route function found");let h=await e.lazy(),m={};for(let y in h){let v=h[y];if(v===void 0)continue;let _=B5e(y),E=a[y]!==void 0&&y!=="hasErrorBoundary";_?Eu(!_,"Route property "+y+" is not a supported property to be returned from a lazy route function. This property will be ignored."):E?Eu(!E,`Route "${a.id}" has a static property "${y}" defined but its lazy function is also returning a value for this property. The lazy route property "${y}" will be ignored.`):m[y]=v}Object.assign(a,m),Object.assign(a,{...r(a),lazy:void 0})})();return nZ.set(a,d),d.catch(()=>{}),{lazyRoutePromise:d,lazyHandlerPromise:d}}let u=Object.keys(e.lazy),l=[],o;for(let c of u){if(i&&i.includes(c))continue;let d=Xhe({key:c,route:e,manifest:n,mapRouteProperties:r});d&&(l.push(d),c===t&&(o=d))}let s=l.length>0?Promise.all(l).then(()=>{}):void 0;return s==null||s.catch(()=>{}),o==null||o.catch(()=>{}),{lazyRoutePromise:s,lazyHandlerPromise:o}}async function rZ(e){let t=e.matches.filter(i=>i.shouldLoad),n={};return(await Promise.all(t.map(i=>i.resolve()))).forEach((i,a)=>{n[t[a].route.id]=i}),n}async function y6e(e){if(!e.matches.some(n=>n.route.unstable_middleware))return rZ(e);let t=!1;return Ghe(e,()=>(t=!0,rZ(e)),(n,r)=>Yhe(n,r,e.matches,t))}function Yhe(e,t,n,r){var i;return r?{[t]:{type:"error",result:e}}:{[Av(n,((i=n.find(u=>u.route.id===t||u.route.loader))==null?void 0:i.route.id)||t).route.id]:{type:"error",result:e}}}async function Ghe(e,t,n){let{matches:r,request:i,params:a,context:u}=e,l=r.flatMap(s=>s.route.unstable_middleware?s.route.unstable_middleware.map(c=>[s.route.id,c]):[]),o={};return await Khe({request:i,params:a,context:u},l,t,n,o),o}async function Khe(e,t,n,r,i={},a=0){let{request:u}=e;if(u.signal.aborted)throw u.signal.reason?u.signal.reason:new Error(`Request aborted without an \`AbortSignal.reason\`: ${u.method} ${u.url}`);let l=t[a];if(!l){let h=await n();Object.assign(i,h);return}let[o,s]=l,c=!1,d=async()=>{if(c)throw new Error("You may only call `next()` once per middleware");c=!0;try{let h=await Khe(e,t,n,r,i,a+1);Object.assign(i,h)}catch(h){let m=await r(h,o);Object.assign(i,m)}};try{let h=await s({request:e.request,params:e.params,context:e.context},d);typeof h<"u"&&console.warn("client middlewares are not intended to return values, the value will be ignored",h),c||await d()}catch(h){let m=await r(h,o);Object.assign(i,m)}}function Whe(e,t,n,r,i){let a=Xhe({key:"unstable_middleware",route:r.route,manifest:t,mapRouteProperties:e}),u=v6e(r.route,ef(n.method)?"action":"loader",t,e,i);return{middleware:a,route:u.lazyRoutePromise,handler:u.lazyHandlerPromise}}function G9(e,t,n,r,i,a,u,l=null){let o=!1,s=Whe(e,t,n,r,i);return{...r,_lazyPromises:s,shouldLoad:u,unstable_shouldRevalidateArgs:l,unstable_shouldCallHandler(c){return o=!0,l?typeof c=="boolean"?u$(r,{...l,defaultShouldRevalidate:c}):u$(r,l):u},resolve(c){return o||u||c&&!ef(n.method)&&(r.route.lazy||r.route.loader)?O6e({request:n,match:r,lazyHandlerPromise:s==null?void 0:s.handler,lazyRoutePromise:s==null?void 0:s.route,handlerOverride:c,scopedContext:a}):Promise.resolve({type:"data",result:void 0})}}}function s3(e,t,n,r,i,a,u,l=null){return r.map(o=>o.route.id!==i.route.id?{...o,shouldLoad:!1,unstable_shouldRevalidateArgs:l,unstable_shouldCallHandler:()=>!1,_lazyPromises:Whe(e,t,n,o,a),resolve:()=>Promise.resolve({type:"data",result:void 0})}:G9(e,t,n,o,a,u,!0,l))}async function b6e(e,t,n,r,i,a){n.some(s=>{var c;return(c=s._lazyPromises)==null?void 0:c.middleware})&&await Promise.all(n.map(s=>{var c;return(c=s._lazyPromises)==null?void 0:c.middleware}));let u={request:t,params:n[0].params,context:i,matches:n},o=await e({...u,fetcherKey:r,unstable_runClientMiddleware:s=>{let c=u,d=!1;return Ghe(c,()=>(d=!0,s({...c,fetcherKey:r,unstable_runClientMiddleware:()=>{throw new Error("Cannot call `unstable_runClientMiddleware()` from within an `unstable_runClientMiddleware` handler")}})),(h,m)=>Yhe(h,m,n,d))}});try{await Promise.all(n.flatMap(s=>{var c,d;return[(c=s._lazyPromises)==null?void 0:c.handler,(d=s._lazyPromises)==null?void 0:d.route]}))}catch{}return o}async function O6e({request:e,match:t,lazyHandlerPromise:n,lazyRoutePromise:r,handlerOverride:i,scopedContext:a}){let u,l,o=ef(e.method),s=o?"action":"loader",c=d=>{let h,m=new Promise((_,S)=>h=S);l=()=>h(),e.signal.addEventListener("abort",l);let y=_=>typeof d!="function"?Promise.reject(new Error(`You cannot call the handler for a route which defines a boolean "${s}" [routeId: ${t.route.id}]`)):d({request:e,params:t.params,context:a},..._!==void 0?[_]:[]),v=(async()=>{try{return{type:"data",result:await(i?i(S=>y(S)):y())}}catch(_){return{type:"error",result:_}}})();return Promise.race([v,m])};try{let d=o?t.route.action:t.route.loader;if(n||r)if(d){let h,[m]=await Promise.all([c(d).catch(y=>{h=y}),n,r]);if(h!==void 0)throw h;u=m}else{await n;let h=o?t.route.action:t.route.loader;if(h)[u]=await Promise.all([c(h),r]);else if(s==="action"){let m=new URL(e.url),y=m.pathname+m.search;throw Qd(405,{method:e.method,pathname:y,routeId:t.route.id})}else return{type:"data",result:void 0}}else if(d)u=await c(d);else{let h=new URL(e.url),m=h.pathname+h.search;throw Qd(404,{pathname:m})}}catch(d){return{type:"error",result:d}}finally{l&&e.signal.removeEventListener("abort",l)}return u}async function x6e(e){var r,i,a,u,l,o;let{result:t,type:n}=e;if(epe(t)){let s;try{let c=t.headers.get("Content-Type");c&&/\bapplication\/json\b/.test(c)?t.body==null?s=null:s=await t.json():s=await t.text()}catch(c){return{type:"error",error:c}}return n==="error"?{type:"error",error:new a$(t.status,t.statusText,s),statusCode:t.status,headers:t.headers}:{type:"data",data:s,statusCode:t.status,headers:t.headers}}return n==="error"?cZ(t)?t.data instanceof Error?{type:"error",error:t.data,statusCode:(r=t.init)==null?void 0:r.status,headers:(i=t.init)!=null&&i.headers?new Headers(t.init.headers):void 0}:{type:"error",error:new a$(((a=t.init)==null?void 0:a.status)||500,void 0,t.data),statusCode:Sx(t)?t.status:void 0,headers:(u=t.init)!=null&&u.headers?new Headers(t.init.headers):void 0}:{type:"error",error:t,statusCode:Sx(t)?t.status:void 0}:cZ(t)?{type:"data",data:t.data,statusCode:(l=t.init)==null?void 0:l.status,headers:(o=t.init)!=null&&o.headers?new Headers(t.init.headers):void 0}:{type:"data",data:t}}function S6e(e,t,n,r,i){let a=e.headers.get("Location");if(pr(a,"Redirects returned/thrown from loaders/actions must have a Location header"),!oI(a)){let u=r.slice(0,r.findIndex(l=>l.route.id===n)+1);a=X9(new URL(t.url),u,i,a),e.headers.set("Location",a)}return e}function iZ(e,t,n){if(oI(e)){let r=e,i=r.startsWith("//")?new URL(t.protocol+r):new URL(r),a=cf(i.pathname,n)!=null;if(i.origin===t.origin&&a)return i.pathname+i.search+i.hash}return e}function LO(e,t,n,r){let i=e.createURL(Jhe(t)).toString(),a={signal:n};if(r&&ef(r.formMethod)){let{formMethod:u,formEncType:l}=r;a.method=u.toUpperCase(),l==="application/json"?(a.headers=new Headers({"Content-Type":l}),a.body=JSON.stringify(r.json)):l==="text/plain"?a.body=r.text:l==="application/x-www-form-urlencoded"&&r.formData?a.body=K9(r.formData):a.body=r.formData}return new Request(i,a)}function K9(e){let t=new URLSearchParams;for(let[n,r]of e.entries())t.append(n,typeof r=="string"?r:r.name);return t}function aZ(e){let t=new FormData;for(let[n,r]of e.entries())t.append(n,r);return t}function _6e(e,t,n,r=!1,i=!1){let a={},u=null,l,o=!1,s={},c=n&&Bf(n[1])?n[1].error:void 0;return e.forEach(d=>{if(!(d.route.id in t))return;let h=d.route.id,m=t[h];if(pr(!I1(m),"Cannot handle redirect results in processLoaderData"),Bf(m)){let y=m.error;if(c!==void 0&&(y=c,c=void 0),u=u||{},i)u[h]=y;else{let v=Av(e,h);u[v.route.id]==null&&(u[v.route.id]=y)}r||(a[h]=Zhe),o||(o=!0,l=Sx(m.error)?m.error.status:500),m.headers&&(s[h]=m.headers)}else a[h]=m.data,m.statusCode&&m.statusCode!==200&&!o&&(l=m.statusCode),m.headers&&(s[h]=m.headers)}),c!==void 0&&n&&(u={[n[0]]:c},n[2]&&(a[n[2]]=void 0)),{loaderData:a,errors:u,statusCode:l||200,loaderHeaders:s}}function uZ(e,t,n,r,i,a){let{loaderData:u,errors:l}=_6e(t,n,r);return i.filter(o=>!o.matches||o.matches.some(s=>s.shouldLoad)).forEach(o=>{let{key:s,match:c,controller:d}=o;if(d&&d.signal.aborted)return;let h=a[s];if(pr(h,"Did not find corresponding fetcher result"),Bf(h)){let m=Av(e.matches,c==null?void 0:c.route.id);l&&l[m.route.id]||(l={...l,[m.route.id]:h.error}),e.fetchers.delete(s)}else if(I1(h))pr(!1,"Unhandled fetcher revalidation redirect");else{let m=mv(h.data);e.fetchers.set(s,m)}}),{loaderData:u,errors:l}}function lZ(e,t,n,r){let i=Object.entries(t).filter(([,a])=>a!==Zhe).reduce((a,[u,l])=>(a[u]=l,a),{});for(let a of n){let u=a.route.id;if(!t.hasOwnProperty(u)&&e.hasOwnProperty(u)&&a.route.loader&&(i[u]=e[u]),r&&r.hasOwnProperty(u))break}return i}function oZ(e){return e?Bf(e[1])?{actionData:{}}:{actionData:{[e[0]]:e[1].data}}:{}}function Av(e,t){return(t?e.slice(0,e.findIndex(r=>r.route.id===t)+1):[...e]).reverse().find(r=>r.route.hasErrorBoundary===!0)||e[0]}function sZ(e){let t=e.length===1?e[0]:e.find(n=>n.index||!n.path||n.path==="/")||{id:"__shim-error-route__"};return{matches:[{params:{},pathname:"",pathnameBase:"",route:t}],route:t}}function Qd(e,{pathname:t,routeId:n,method:r,type:i,message:a}={}){let u="Unknown Server Error",l="Unknown @remix-run/router error";return e===400?(u="Bad Request",r&&t&&n?l=`You made a ${r} request to "${t}" but did not provide a \`loader\` for route "${n}", so there is no way to handle the request.`:i==="invalid-body"&&(l="Unable to encode submission body")):e===403?(u="Forbidden",l=`Route "${n}" does not match URL "${t}"`):e===404?(u="Not Found",l=`No route matches URL "${t}"`):e===405&&(u="Method Not Allowed",r&&t&&n?l=`You made a ${r.toUpperCase()} request to "${t}" but did not provide an \`action\` for route "${n}", so there is no way to handle the request.`:r&&(l=`Invalid request method "${r.toUpperCase()}"`)),new a$(e||500,u,new Error(l),!0)}function Z_(e){let t=Object.entries(e);for(let n=t.length-1;n>=0;n--){let[r,i]=t[n];if(I1(i))return{key:r,result:i}}}function Jhe(e){let t=typeof e=="string"?yy(e):e;return ey({...t,hash:""})}function E6e(e,t){return e.pathname!==t.pathname||e.search!==t.search?!1:e.hash===""?t.hash!=="":e.hash===t.hash?!0:t.hash!==""}function D6e(e){return epe(e.result)&&o6e.has(e.result.status)}function Bf(e){return e.type==="error"}function I1(e){return(e&&e.type)==="redirect"}function cZ(e){return typeof e=="object"&&e!=null&&"type"in e&&"data"in e&&"init"in e&&e.type==="DataWithResponseInit"}function epe(e){return e!=null&&typeof e.status=="number"&&typeof e.statusText=="string"&&typeof e.headers=="object"&&typeof e.body<"u"}function $6e(e){return l6e.has(e.toUpperCase())}function ef(e){return a6e.has(e.toUpperCase())}function sI(e){return new URLSearchParams(e).getAll("index").some(t=>t==="")}function eD(e,t){let n=typeof t=="string"?yy(t).search:t.search;if(e[e.length-1].route.index&&sI(n||""))return e[e.length-1];let r=Vhe(e);return r[r.length-1]}function fZ(e){let{formMethod:t,formAction:n,formEncType:r,text:i,formData:a,json:u}=e;if(!(!t||!n||!r)){if(i!=null)return{formMethod:t,formAction:n,formEncType:r,formData:void 0,json:void 0,text:i};if(a!=null)return{formMethod:t,formAction:n,formEncType:r,formData:a,json:void 0,text:void 0};if(u!==void 0)return{formMethod:t,formAction:n,formEncType:r,formData:void 0,json:u,text:void 0}}}function mk(e,t){return t?{state:"loading",location:e,formMethod:t.formMethod,formAction:t.formAction,formEncType:t.formEncType,formData:t.formData,json:t.json,text:t.text}:{state:"loading",location:e,formMethod:void 0,formAction:void 0,formEncType:void 0,formData:void 0,json:void 0,text:void 0}}function C6e(e,t){return{state:"submitting",location:e,formMethod:t.formMethod,formAction:t.formAction,formEncType:t.formEncType,formData:t.formData,json:t.json,text:t.text}}function J4(e,t){return e?{state:"loading",formMethod:e.formMethod,formAction:e.formAction,formEncType:e.formEncType,formData:e.formData,json:e.json,text:e.text,data:t}:{state:"loading",formMethod:void 0,formAction:void 0,formEncType:void 0,formData:void 0,json:void 0,text:void 0,data:t}}function w6e(e,t){return{state:"submitting",formMethod:e.formMethod,formAction:e.formAction,formEncType:e.formEncType,formData:e.formData,json:e.json,text:e.text,data:t?t.data:void 0}}function mv(e){return{state:"idle",formMethod:void 0,formAction:void 0,formEncType:void 0,formData:void 0,json:void 0,text:void 0,data:e}}function R6e(e,t){try{let n=e.sessionStorage.getItem(jhe);if(n){let r=JSON.parse(n);for(let[i,a]of Object.entries(r||{}))a&&Array.isArray(a)&&t.set(i,new Set(a||[]))}}catch{}}function A6e(e,t){if(t.size>0){let n={};for(let[r,i]of t)n[r]=[...i];try{e.sessionStorage.setItem(jhe,JSON.stringify(n))}catch(r){Eu(!1,`Failed to save applied view transitions in sessionStorage (${r}).`)}}}function T6e(){let e,t,n=new Promise((r,i)=>{e=async a=>{r(a);try{await n}catch{}},t=async a=>{i(a);try{await n}catch{}}});return{promise:n,resolve:e,reject:t}}var Rb=P.createContext(null);Rb.displayName="DataRouter";var bS=P.createContext(null);bS.displayName="DataRouterState";P.createContext(!1);var cI=P.createContext({isTransitioning:!1});cI.displayName="ViewTransition";var tpe=P.createContext(new Map);tpe.displayName="Fetchers";var k6e=P.createContext(null);k6e.displayName="Await";var gp=P.createContext(null);gp.displayName="Navigation";var iw=P.createContext(null);iw.displayName="Location";var uh=P.createContext({outlet:null,matches:[],isDataRoute:!1});uh.displayName="Route";var fI=P.createContext(null);fI.displayName="RouteError";function P6e(e,{relative:t}={}){pr(K3(),"useHref() may be used only in the context of a <Router> component.");let{basename:n,navigator:r}=P.useContext(gp),{hash:i,pathname:a,search:u}=OS(e,{relative:t}),l=a;return n!=="/"&&(l=a==="/"?n:w0([n,a])),r.createHref({pathname:l,search:u,hash:i})}function K3(){return P.useContext(iw)!=null}function Og(){return pr(K3(),"useLocation() may be used only in the context of a <Router> component."),P.useContext(iw).location}var npe="You should call navigate() in a React.useEffect(), not when your component is first rendered.";function rpe(e){P.useContext(gp).static||P.useLayoutEffect(e)}function dI(){let{isDataRoute:e}=P.useContext(uh);return e?H6e():M6e()}function M6e(){pr(K3(),"useNavigate() may be used only in the context of a <Router> component.");let e=P.useContext(Rb),{basename:t,navigator:n}=P.useContext(gp),{matches:r}=P.useContext(uh),{pathname:i}=Og(),a=JSON.stringify(nw(r)),u=P.useRef(!1);return rpe(()=>{u.current=!0}),P.useCallback((o,s={})=>{if(Eu(u.current,npe),!u.current)return;if(typeof o=="number"){n.go(o);return}let c=rw(o,JSON.parse(a),i,s.relative==="path");e==null&&t!=="/"&&(c.pathname=c.pathname==="/"?t:w0([t,c.pathname])),(s.replace?n.replace:n.push)(c,s.state,s)},[t,n,a,i,e])}var F6e=P.createContext(null);function N6e(e){let t=P.useContext(uh).outlet;return t&&P.createElement(F6e.Provider,{value:e},t)}function zit(){let{matches:e}=P.useContext(uh),t=e[e.length-1];return t?t.params:{}}function OS(e,{relative:t}={}){let{matches:n}=P.useContext(uh),{pathname:r}=Og(),i=JSON.stringify(nw(n));return P.useMemo(()=>rw(e,JSON.parse(i),r,t==="path"),[e,i,r,t])}function I6e(e,t,n,r){pr(K3(),"useRoutes() may be used only in the context of a <Router> component.");let{navigator:i}=P.useContext(gp),{matches:a}=P.useContext(uh),u=a[a.length-1],l=u?u.params:{},o=u?u.pathname:"/",s=u?u.pathnameBase:"/",c=u&&u.route;{let S=c&&c.path||"";ipe(o,!c||S.endsWith("*")||S.endsWith("*?"),`You rendered descendant <Routes> (or called \`useRoutes()\`) at "${o}" (under <Route path="${S}">) but the parent route path has no trailing "*". This means if you navigate deeper, the parent won't match anymore and therefore the child routes will never render.

Please change the parent <Route path="${S}"> to <Route path="${S==="/"?"*":`${S}/*`}">.`)}let d=Og(),h;h=d;let m=h.pathname||"/",y=m;if(s!=="/"){let S=s.replace(/^\//,"").split("/");y="/"+m.replace(/^\//,"").split("/").slice(S.length).join("/")}let v=Rv(e,{pathname:y});return Eu(c||v!=null,`No routes matched location "${h.pathname}${h.search}${h.hash}" `),Eu(v==null||v[v.length-1].route.element!==void 0||v[v.length-1].route.Component!==void 0||v[v.length-1].route.lazy!==void 0,`Matched leaf route at location "${h.pathname}${h.search}${h.hash}" does not have an element or Component. This means it will render an <Outlet /> with a null value by default resulting in an "empty" page.`),q6e(v&&v.map(S=>Object.assign({},S,{params:Object.assign({},l,S.params),pathname:w0([s,i.encodeLocation?i.encodeLocation(S.pathname).pathname:S.pathname]),pathnameBase:S.pathnameBase==="/"?s:w0([s,i.encodeLocation?i.encodeLocation(S.pathnameBase).pathname:S.pathnameBase])})),a,n,r)}function L6e(){let e=j6e(),t=Sx(e)?`${e.status} ${e.statusText}`:e instanceof Error?e.message:JSON.stringify(e),n=e instanceof Error?e.stack:null,r="rgba(200,200,200, 0.5)",i={padding:"0.5rem",backgroundColor:r},a={padding:"2px 4px",backgroundColor:r},u=null;return console.error("Error handled by React Router default ErrorBoundary:",e),u=P.createElement(P.Fragment,null,P.createElement("p",null,"💿 Hey developer 👋"),P.createElement("p",null,"You can provide a way better UX than this when your app throws errors by providing your own ",P.createElement("code",{style:a},"ErrorBoundary")," or"," ",P.createElement("code",{style:a},"errorElement")," prop on your route.")),P.createElement(P.Fragment,null,P.createElement("h2",null,"Unexpected Application Error!"),P.createElement("h3",{style:{fontStyle:"italic"}},t),n?P.createElement("pre",{style:i},n):null,u)}var B6e=P.createElement(L6e,null),Q6e=class extends P.Component{constructor(e){super(e),this.state={location:e.location,revalidation:e.revalidation,error:e.error}}static getDerivedStateFromError(e){return{error:e}}static getDerivedStateFromProps(e,t){return t.location!==e.location||t.revalidation!=="idle"&&e.revalidation==="idle"?{error:e.error,location:e.location,revalidation:e.revalidation}:{error:e.error!==void 0?e.error:t.error,location:t.location,revalidation:e.revalidation||t.revalidation}}componentDidCatch(e,t){console.error("React Router caught the following error during render",e,t)}render(){return this.state.error!==void 0?P.createElement(uh.Provider,{value:this.props.routeContext},P.createElement(fI.Provider,{value:this.state.error,children:this.props.component})):this.props.children}};function z6e({routeContext:e,match:t,children:n}){let r=P.useContext(Rb);return r&&r.static&&r.staticContext&&(t.route.errorElement||t.route.ErrorBoundary)&&(r.staticContext._deepestRenderedBoundaryId=t.route.id),P.createElement(uh.Provider,{value:e},n)}function q6e(e,t=[],n=null,r=null){if(e==null){if(!n)return null;if(n.errors)e=n.matches;else if(t.length===0&&!n.initialized&&n.matches.length>0)e=n.matches;else return null}let i=e,a=n==null?void 0:n.errors;if(a!=null){let o=i.findIndex(s=>s.route.id&&(a==null?void 0:a[s.route.id])!==void 0);pr(o>=0,`Could not find a matching route for errors on route IDs: ${Object.keys(a).join(",")}`),i=i.slice(0,Math.min(i.length,o+1))}let u=!1,l=-1;if(n)for(let o=0;o<i.length;o++){let s=i[o];if((s.route.HydrateFallback||s.route.hydrateFallbackElement)&&(l=o),s.route.id){let{loaderData:c,errors:d}=n,h=s.route.loader&&!c.hasOwnProperty(s.route.id)&&(!d||d[s.route.id]===void 0);if(s.route.lazy||h){u=!0,l>=0?i=i.slice(0,l+1):i=[i[0]];break}}}return i.reduceRight((o,s,c)=>{let d,h=!1,m=null,y=null;n&&(d=a&&s.route.id?a[s.route.id]:void 0,m=s.route.errorElement||B6e,u&&(l<0&&c===0?(ipe("route-fallback",!1,"No `HydrateFallback` element provided to render during initial hydration"),h=!0,y=null):l===c&&(h=!0,y=s.route.hydrateFallbackElement||null)));let v=t.concat(i.slice(0,c+1)),_=()=>{let S;return d?S=m:h?S=y:s.route.Component?S=P.createElement(s.route.Component,null):s.route.element?S=s.route.element:S=o,P.createElement(z6e,{match:s,routeContext:{outlet:o,matches:v,isDataRoute:n!=null},children:S})};return n&&(s.route.ErrorBoundary||s.route.errorElement||c===0)?P.createElement(Q6e,{location:n.location,revalidation:n.revalidation,component:m,error:d,children:_(),routeContext:{outlet:null,matches:v,isDataRoute:!0}}):_()},null)}function hI(e){return`${e} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function pI(e){let t=P.useContext(Rb);return pr(t,hI(e)),t}function W3(e){let t=P.useContext(bS);return pr(t,hI(e)),t}function V6e(e){let t=P.useContext(uh);return pr(t,hI(e)),t}function aw(e){let t=V6e(e),n=t.matches[t.matches.length-1];return pr(n.route.id,`${e} can only be used on routes that contain a unique "id"`),n.route.id}function U6e(){return aw("useRouteId")}function qit(){let e=pI("useRevalidator"),t=W3("useRevalidator"),n=P.useCallback(async()=>{await e.router.revalidate()},[e.router]);return P.useMemo(()=>({revalidate:n,state:t.revalidation}),[n,t.revalidation])}function Vit(){let{matches:e,loaderData:t}=W3("useMatches");return P.useMemo(()=>e.map(n=>Qhe(n,t)),[e,t])}function Uit(){let e=W3("useLoaderData"),t=aw("useLoaderData");return e.loaderData[t]}function jit(e){return W3("useRouteLoaderData").loaderData[e]}function j6e(){var r;let e=P.useContext(fI),t=W3("useRouteError"),n=aw("useRouteError");return e!==void 0?e:(r=t.errors)==null?void 0:r[n]}var Z6e=0;function Zit(e){let{router:t,basename:n}=pI("useBlocker"),r=W3("useBlocker"),[i,a]=P.useState(""),u=P.useCallback(l=>{if(typeof e!="function")return!!e;if(n==="/")return e(l);let{currentLocation:o,nextLocation:s,historyAction:c}=l;return e({currentLocation:{...o,pathname:cf(o.pathname,n)||o.pathname},nextLocation:{...s,pathname:cf(s.pathname,n)||s.pathname},historyAction:c})},[n,e]);return P.useEffect(()=>{let l=String(++Z6e);return a(l),()=>t.deleteBlocker(l)},[t]),P.useEffect(()=>{i!==""&&t.getBlocker(i,u)},[t,i,u]),i&&r.blockers.has(i)?r.blockers.get(i):IO}function H6e(){let{router:e}=pI("useNavigate"),t=aw("useNavigate"),n=P.useRef(!1);return rpe(()=>{n.current=!0}),P.useCallback(async(i,a={})=>{Eu(n.current,npe),n.current&&(typeof i=="number"?e.navigate(i):await e.navigate(i,{fromRouteId:t,...a}))},[e,t])}var dZ={};function ipe(e,t,n){!t&&!dZ[e]&&(dZ[e]=!0,Eu(!1,n))}var hZ={};function pZ(e,t){!e&&!hZ[t]&&(hZ[t]=!0,console.warn(t))}function X6e(e){let t={hasErrorBoundary:e.hasErrorBoundary||e.ErrorBoundary!=null||e.errorElement!=null};return e.Component&&(e.element&&Eu(!1,"You should not include both `Component` and `element` on your route - `Component` will be used."),Object.assign(t,{element:P.createElement(e.Component),Component:void 0})),e.HydrateFallback&&(e.hydrateFallbackElement&&Eu(!1,"You should not include both `HydrateFallback` and `hydrateFallbackElement` on your route - `HydrateFallback` will be used."),Object.assign(t,{hydrateFallbackElement:P.createElement(e.HydrateFallback),HydrateFallback:void 0})),e.ErrorBoundary&&(e.errorElement&&Eu(!1,"You should not include both `ErrorBoundary` and `errorElement` on your route - `ErrorBoundary` will be used."),Object.assign(t,{errorElement:P.createElement(e.ErrorBoundary),ErrorBoundary:void 0})),t}var Y6e=["HydrateFallback","hydrateFallbackElement"],G6e=class{constructor(){this.status="pending",this.promise=new Promise((e,t)=>{this.resolve=n=>{this.status==="pending"&&(this.status="resolved",e(n))},this.reject=n=>{this.status==="pending"&&(this.status="rejected",t(n))}})}};function K6e({router:e,flushSync:t}){let[n,r]=P.useState(e.state),[i,a]=P.useState(),[u,l]=P.useState({isTransitioning:!1}),[o,s]=P.useState(),[c,d]=P.useState(),[h,m]=P.useState(),y=P.useRef(new Map),v=P.useCallback((C,{deletedFetchers:T,flushSync:R,viewTransitionOpts:$})=>{C.fetchers.forEach((F,L)=>{F.data!==void 0&&y.current.set(L,F.data)}),T.forEach(F=>y.current.delete(F)),pZ(R===!1||t!=null,'You provided the `flushSync` option to a router update, but you are not using the `<RouterProvider>` from `react-router/dom` so `ReactDOM.flushSync()` is unavailable.  Please update your app to `import { RouterProvider } from "react-router/dom"` and ensure you have `react-dom` installed as a dependency to use the `flushSync` option.');let k=e.window!=null&&e.window.document!=null&&typeof e.window.document.startViewTransition=="function";if(pZ($==null||k,"You provided the `viewTransition` option to a router update, but you do not appear to be running in a DOM environment as `window.startViewTransition` is not available."),!$||!k){t&&R?t(()=>r(C)):P.startTransition(()=>r(C));return}if(t&&R){t(()=>{c&&(o&&o.resolve(),c.skipTransition()),l({isTransitioning:!0,flushSync:!0,currentLocation:$.currentLocation,nextLocation:$.nextLocation})});let F=e.window.document.startViewTransition(()=>{t(()=>r(C))});F.finished.finally(()=>{t(()=>{s(void 0),d(void 0),a(void 0),l({isTransitioning:!1})})}),t(()=>d(F));return}c?(o&&o.resolve(),c.skipTransition(),m({state:C,currentLocation:$.currentLocation,nextLocation:$.nextLocation})):(a(C),l({isTransitioning:!0,flushSync:!1,currentLocation:$.currentLocation,nextLocation:$.nextLocation}))},[e.window,t,c,o]);P.useLayoutEffect(()=>e.subscribe(v),[e,v]),P.useEffect(()=>{u.isTransitioning&&!u.flushSync&&s(new G6e)},[u]),P.useEffect(()=>{if(o&&i&&e.window){let C=i,T=o.promise,R=e.window.document.startViewTransition(async()=>{P.startTransition(()=>r(C)),await T});R.finished.finally(()=>{s(void 0),d(void 0),a(void 0),l({isTransitioning:!1})}),d(R)}},[i,o,e.window]),P.useEffect(()=>{o&&i&&n.location.key===i.location.key&&o.resolve()},[o,c,n.location,i]),P.useEffect(()=>{!u.isTransitioning&&h&&(a(h.state),l({isTransitioning:!0,flushSync:!1,currentLocation:h.currentLocation,nextLocation:h.nextLocation}),m(void 0))},[u.isTransitioning,h]);let _=P.useMemo(()=>({createHref:e.createHref,encodeLocation:e.encodeLocation,go:C=>e.navigate(C),push:(C,T,R)=>e.navigate(C,{state:T,preventScrollReset:R==null?void 0:R.preventScrollReset}),replace:(C,T,R)=>e.navigate(C,{replace:!0,state:T,preventScrollReset:R==null?void 0:R.preventScrollReset})}),[e]),S=e.basename||"/",E=P.useMemo(()=>({router:e,navigator:_,static:!1,basename:S}),[e,_,S]);return P.createElement(P.Fragment,null,P.createElement(Rb.Provider,{value:E},P.createElement(bS.Provider,{value:n},P.createElement(tpe.Provider,{value:y.current},P.createElement(cI.Provider,{value:u},P.createElement(tRe,{basename:S,location:n.location,navigationType:n.historyAction,navigator:_},P.createElement(W6e,{routes:e.routes,future:e.future,state:n})))))),null)}var W6e=P.memo(J6e);function J6e({routes:e,future:t,state:n}){return I6e(e,void 0,n,t)}function Hit({to:e,replace:t,state:n,relative:r}){pr(K3(),"<Navigate> may be used only in the context of a <Router> component.");let{static:i}=P.useContext(gp);Eu(!i,"<Navigate> must not be used on the initial render in a <StaticRouter>. This is a no-op, but you should modify your code so the <Navigate> is only ever rendered in response to some user interaction or state change.");let{matches:a}=P.useContext(uh),{pathname:u}=Og(),l=dI(),o=rw(e,nw(a),u,r==="path"),s=JSON.stringify(o);return P.useEffect(()=>{l(JSON.parse(s),{replace:t,state:n,relative:r})},[l,s,r,t,n]),null}function Xit(e){return N6e(e.context)}function eRe(e){pr(!1,"A <Route> is only ever to be used as the child of <Routes> element, never rendered directly. Please wrap your <Route> in a <Routes>.")}function tRe({basename:e="/",children:t=null,location:n,navigationType:r="POP",navigator:i,static:a=!1}){pr(!K3(),"You cannot render a <Router> inside another <Router>. You should never have more than one in your app.");let u=e.replace(/^\/*/,"/"),l=P.useMemo(()=>({basename:u,navigator:i,static:a,future:{}}),[u,i,a]);typeof n=="string"&&(n=yy(n));let{pathname:o="/",search:s="",hash:c="",state:d=null,key:h="default"}=n,m=P.useMemo(()=>{let y=cf(o,u);return y==null?null:{location:{pathname:y,search:s,hash:c,state:d,key:h},navigationType:r}},[u,o,s,c,d,h,r]);return Eu(m!=null,`<Router basename="${u}"> is not able to match the URL "${o}${s}${c}" because it does not start with the basename, so the <Router> won't render anything.`),m==null?null:P.createElement(gp.Provider,{value:l},P.createElement(iw.Provider,{children:t,value:m}))}function W9(e,t=[]){let n=[];return P.Children.forEach(e,(r,i)=>{if(!P.isValidElement(r))return;let a=[...t,i];if(r.type===P.Fragment){n.push.apply(n,W9(r.props.children,a));return}pr(r.type===eRe,`[${typeof r.type=="string"?r.type:r.type.name}] is not a <Route> component. All component children of <Routes> must be a <Route> or <React.Fragment>`),pr(!r.props.index||!r.props.children,"An index route cannot have child routes.");let u={id:r.props.id||a.join("-"),caseSensitive:r.props.caseSensitive,element:r.props.element,Component:r.props.Component,index:r.props.index,path:r.props.path,loader:r.props.loader,action:r.props.action,hydrateFallbackElement:r.props.hydrateFallbackElement,HydrateFallback:r.props.HydrateFallback,errorElement:r.props.errorElement,ErrorBoundary:r.props.ErrorBoundary,hasErrorBoundary:r.props.hasErrorBoundary===!0||r.props.ErrorBoundary!=null||r.props.errorElement!=null,shouldRevalidate:r.props.shouldRevalidate,handle:r.props.handle,lazy:r.props.lazy};r.props.children&&(u.children=W9(r.props.children,a)),n.push(u)}),n}var Yit=W9,tD="get",nD="application/x-www-form-urlencoded";function uw(e){return e!=null&&typeof e.tagName=="string"}function nRe(e){return uw(e)&&e.tagName.toLowerCase()==="button"}function rRe(e){return uw(e)&&e.tagName.toLowerCase()==="form"}function iRe(e){return uw(e)&&e.tagName.toLowerCase()==="input"}function aRe(e){return!!(e.metaKey||e.altKey||e.ctrlKey||e.shiftKey)}function uRe(e,t){return e.button===0&&(!t||t==="_self")&&!aRe(e)}function J9(e=""){return new URLSearchParams(typeof e=="string"||Array.isArray(e)||e instanceof URLSearchParams?e:Object.keys(e).reduce((t,n)=>{let r=e[n];return t.concat(Array.isArray(r)?r.map(i=>[n,i]):[[n,r]])},[]))}function lRe(e,t){let n=J9(e);return t&&t.forEach((r,i)=>{n.has(i)||t.getAll(i).forEach(a=>{n.append(i,a)})}),n}var H_=null;function oRe(){if(H_===null)try{new FormData(document.createElement("form"),0),H_=!1}catch{H_=!0}return H_}var sRe=new Set(["application/x-www-form-urlencoded","multipart/form-data","text/plain"]);function gk(e){return e!=null&&!sRe.has(e)?(Eu(!1,`"${e}" is not a valid \`encType\` for \`<Form>\`/\`<fetcher.Form>\` and will default to "${nD}"`),null):e}function cRe(e,t){let n,r,i,a,u;if(rRe(e)){let l=e.getAttribute("action");r=l?cf(l,t):null,n=e.getAttribute("method")||tD,i=gk(e.getAttribute("enctype"))||nD,a=new FormData(e)}else if(nRe(e)||iRe(e)&&(e.type==="submit"||e.type==="image")){let l=e.form;if(l==null)throw new Error('Cannot submit a <button> or <input type="submit"> without a <form>');let o=e.getAttribute("formaction")||l.getAttribute("action");if(r=o?cf(o,t):null,n=e.getAttribute("formmethod")||l.getAttribute("method")||tD,i=gk(e.getAttribute("formenctype"))||gk(l.getAttribute("enctype"))||nD,a=new FormData(l,e),!oRe()){let{name:s,type:c,value:d}=e;if(c==="image"){let h=s?`${s}.`:"";a.append(`${h}x`,"0"),a.append(`${h}y`,"0")}else s&&a.append(s,d)}}else{if(uw(e))throw new Error('Cannot submit element that is not <form>, <button>, or <input type="submit|image">');n=tD,r=null,i=nD,u=e}return a&&i==="text/plain"&&(u=a,a=void 0),{action:r,method:n.toLowerCase(),encType:i,formData:a,body:u}}Object.getOwnPropertyNames(Object.prototype).sort().join("\0");function mI(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}function fRe(e,t,n){let r=typeof e=="string"?new URL(e,typeof window>"u"?"server://singlefetch/":window.location.origin):e;return r.pathname==="/"?r.pathname=`_root.${n}`:t&&cf(r.pathname,t)==="/"?r.pathname=`${t.replace(/\/$/,"")}/_root.${n}`:r.pathname=`${r.pathname.replace(/\/$/,"")}.${n}`,r}async function dRe(e,t){if(e.id in t)return t[e.id];try{let n=await import(e.module);return t[e.id]=n,n}catch(n){return console.error(`Error loading route module \`${e.module}\`, reloading page...`),console.error(n),window.__reactRouterContext&&window.__reactRouterContext.isSpaMode,window.location.reload(),new Promise(()=>{})}}function hRe(e){return e==null?!1:e.href==null?e.rel==="preload"&&typeof e.imageSrcSet=="string"&&typeof e.imageSizes=="string":typeof e.rel=="string"&&typeof e.href=="string"}async function pRe(e,t,n){let r=await Promise.all(e.map(async i=>{let a=t.routes[i.route.id];if(a){let u=await dRe(a,n);return u.links?u.links():[]}return[]}));return yRe(r.flat(1).filter(hRe).filter(i=>i.rel==="stylesheet"||i.rel==="preload").map(i=>i.rel==="stylesheet"?{...i,rel:"prefetch",as:"style"}:{...i,rel:"prefetch"}))}function mZ(e,t,n,r,i,a){let u=(o,s)=>n[s]?o.route.id!==n[s].route.id:!0,l=(o,s)=>{var c;return n[s].pathname!==o.pathname||((c=n[s].route.path)==null?void 0:c.endsWith("*"))&&n[s].params["*"]!==o.params["*"]};return a==="assets"?t.filter((o,s)=>u(o,s)||l(o,s)):a==="data"?t.filter((o,s)=>{var d;let c=r.routes[o.route.id];if(!c||!c.hasLoader)return!1;if(u(o,s)||l(o,s))return!0;if(o.route.shouldRevalidate){let h=o.route.shouldRevalidate({currentUrl:new URL(i.pathname+i.search+i.hash,window.origin),currentParams:((d=n[0])==null?void 0:d.params)||{},nextUrl:new URL(e,window.origin),nextParams:o.params,defaultShouldRevalidate:!0});if(typeof h=="boolean")return h}return!0}):[]}function mRe(e,t,{includeHydrateFallback:n}={}){return gRe(e.map(r=>{let i=t.routes[r.route.id];if(!i)return[];let a=[i.module];return i.clientActionModule&&(a=a.concat(i.clientActionModule)),i.clientLoaderModule&&(a=a.concat(i.clientLoaderModule)),n&&i.hydrateFallbackModule&&(a=a.concat(i.hydrateFallbackModule)),i.imports&&(a=a.concat(i.imports)),a}).flat(1))}function gRe(e){return[...new Set(e)]}function vRe(e){let t={},n=Object.keys(e).sort();for(let r of n)t[r]=e[r];return t}function yRe(e,t){let n=new Set;return new Set(t),e.reduce((r,i)=>{let a=JSON.stringify(vRe(i));return n.has(a)||(n.add(a),r.push({key:a,link:i})),r},[])}function ape(){let e=P.useContext(Rb);return mI(e,"You must render this element inside a <DataRouterContext.Provider> element"),e}function bRe(){let e=P.useContext(bS);return mI(e,"You must render this element inside a <DataRouterStateContext.Provider> element"),e}var gI=P.createContext(void 0);gI.displayName="FrameworkContext";function upe(){let e=P.useContext(gI);return mI(e,"You must render this element inside a <HydratedRouter> element"),e}function ORe(e,t){let n=P.useContext(gI),[r,i]=P.useState(!1),[a,u]=P.useState(!1),{onFocus:l,onBlur:o,onMouseEnter:s,onMouseLeave:c,onTouchStart:d}=t,h=P.useRef(null);P.useEffect(()=>{if(e==="render"&&u(!0),e==="viewport"){let v=S=>{S.forEach(E=>{u(E.isIntersecting)})},_=new IntersectionObserver(v,{threshold:.5});return h.current&&_.observe(h.current),()=>{_.disconnect()}}},[e]),P.useEffect(()=>{if(r){let v=setTimeout(()=>{u(!0)},100);return()=>{clearTimeout(v)}}},[r]);let m=()=>{i(!0)},y=()=>{i(!1),u(!1)};return n?e!=="intent"?[a,h,{}]:[a,h,{onFocus:e2(l,m),onBlur:e2(o,y),onMouseEnter:e2(s,m),onMouseLeave:e2(c,y),onTouchStart:e2(d,m)}]:[!1,h,{}]}function e2(e,t){return n=>{e&&e(n),n.defaultPrevented||t(n)}}function xRe({page:e,...t}){let{router:n}=ape(),r=P.useMemo(()=>Rv(n.routes,e,n.basename),[n.routes,e,n.basename]);return r?P.createElement(_Re,{page:e,matches:r,...t}):null}function SRe(e){let{manifest:t,routeModules:n}=upe(),[r,i]=P.useState([]);return P.useEffect(()=>{let a=!1;return pRe(e,t,n).then(u=>{a||i(u)}),()=>{a=!0}},[e,t,n]),r}function _Re({page:e,matches:t,...n}){let r=Og(),{manifest:i,routeModules:a}=upe(),{basename:u}=ape(),{loaderData:l,matches:o}=bRe(),s=P.useMemo(()=>mZ(e,t,o,i,r,"data"),[e,t,o,i,r]),c=P.useMemo(()=>mZ(e,t,o,i,r,"assets"),[e,t,o,i,r]),d=P.useMemo(()=>{if(e===r.pathname+r.search+r.hash)return[];let y=new Set,v=!1;if(t.forEach(S=>{var C;let E=i.routes[S.route.id];!E||!E.hasLoader||(!s.some(T=>T.route.id===S.route.id)&&S.route.id in l&&((C=a[S.route.id])!=null&&C.shouldRevalidate)||E.hasClientLoader?v=!0:y.add(S.route.id))}),y.size===0)return[];let _=fRe(e,u,"data");return v&&y.size>0&&_.searchParams.set("_routes",t.filter(S=>y.has(S.route.id)).map(S=>S.route.id).join(",")),[_.pathname+_.search]},[u,l,r,i,s,t,e,a]),h=P.useMemo(()=>mRe(c,i),[c,i]),m=SRe(c);return P.createElement(P.Fragment,null,d.map(y=>P.createElement("link",{key:y,rel:"prefetch",as:"fetch",href:y,...n})),h.map(y=>P.createElement("link",{key:y,rel:"modulepreload",href:y,...n})),m.map(({key:y,link:v})=>P.createElement("link",{key:y,nonce:n.nonce,...v})))}function ERe(...e){return t=>{e.forEach(n=>{typeof n=="function"?n(t):n!=null&&(n.current=t)})}}var lpe=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";try{lpe&&(window.__reactRouterVersion="7.8.0")}catch{}function Git(e,t){return h6e({basename:t==null?void 0:t.basename,unstable_getContext:t==null?void 0:t.unstable_getContext,future:t==null?void 0:t.future,history:P5e({window:t==null?void 0:t.window}),hydrationData:(t==null?void 0:t.hydrationData)||DRe(),routes:e,mapRouteProperties:X6e,hydrationRouteProperties:Y6e,dataStrategy:t==null?void 0:t.dataStrategy,patchRoutesOnNavigation:t==null?void 0:t.patchRoutesOnNavigation,window:t==null?void 0:t.window}).initialize()}function DRe(){let e=window==null?void 0:window.__staticRouterHydrationData;return e&&e.errors&&(e={...e,errors:$Re(e.errors)}),e}function $Re(e){if(!e)return null;let t=Object.entries(e),n={};for(let[r,i]of t)if(i&&i.__type==="RouteErrorResponse")n[r]=new a$(i.status,i.statusText,i.data,i.internal===!0);else if(i&&i.__type==="Error"){if(i.__subType){let a=window[i.__subType];if(typeof a=="function")try{let u=new a(i.message);u.stack="",n[r]=u}catch{}}if(n[r]==null){let a=new Error(i.message);a.stack="",n[r]=a}}else n[r]=i;return n}var ope=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i,spe=P.forwardRef(function({onClick:t,discover:n="render",prefetch:r="none",relative:i,reloadDocument:a,replace:u,state:l,target:o,to:s,preventScrollReset:c,viewTransition:d,...h},m){let{basename:y}=P.useContext(gp),v=typeof s=="string"&&ope.test(s),_,S=!1;if(typeof s=="string"&&v&&(_=s,lpe))try{let L=new URL(window.location.href),j=s.startsWith("//")?new URL(L.protocol+s):new URL(s),V=cf(j.pathname,y);j.origin===L.origin&&V!=null?s=V+j.search+j.hash:S=!0}catch{Eu(!1,`<Link to="${s}"> contains an invalid URL which will probably break when clicked - please update to a valid URL path.`)}let E=P6e(s,{relative:i}),[C,T,R]=ORe(r,h),$=ARe(s,{replace:u,state:l,target:o,preventScrollReset:c,relative:i,viewTransition:d});function k(L){t&&t(L),L.defaultPrevented||$(L)}let F=P.createElement("a",{...h,...R,href:_||E,onClick:S||a?t:k,ref:ERe(m,T),target:o,"data-discover":!v&&n==="render"?"true":void 0});return C&&!v?P.createElement(P.Fragment,null,F,P.createElement(xRe,{page:E})):F});spe.displayName="Link";var CRe=P.forwardRef(function({"aria-current":t="page",caseSensitive:n=!1,className:r="",end:i=!1,style:a,to:u,viewTransition:l,children:o,...s},c){let d=OS(u,{relative:s.relative}),h=Og(),m=P.useContext(bS),{navigator:y,basename:v}=P.useContext(gp),_=m!=null&&FRe(d)&&l===!0,S=y.encodeLocation?y.encodeLocation(d).pathname:d.pathname,E=h.pathname,C=m&&m.navigation&&m.navigation.location?m.navigation.location.pathname:null;n||(E=E.toLowerCase(),C=C?C.toLowerCase():null,S=S.toLowerCase()),C&&v&&(C=cf(C,v)||C);const T=S!=="/"&&S.endsWith("/")?S.length-1:S.length;let R=E===S||!i&&E.startsWith(S)&&E.charAt(T)==="/",$=C!=null&&(C===S||!i&&C.startsWith(S)&&C.charAt(S.length)==="/"),k={isActive:R,isPending:$,isTransitioning:_},F=R?t:void 0,L;typeof r=="function"?L=r(k):L=[r,R?"active":null,$?"pending":null,_?"transitioning":null].filter(Boolean).join(" ");let j=typeof a=="function"?a(k):a;return P.createElement(spe,{...s,"aria-current":F,className:L,ref:c,style:j,to:u,viewTransition:l},typeof o=="function"?o(k):o)});CRe.displayName="NavLink";var wRe=P.forwardRef(({discover:e="render",fetcherKey:t,navigate:n,reloadDocument:r,replace:i,state:a,method:u=tD,action:l,onSubmit:o,relative:s,preventScrollReset:c,viewTransition:d,...h},m)=>{let y=PRe(),v=MRe(l,{relative:s}),_=u.toLowerCase()==="get"?"get":"post",S=typeof l=="string"&&ope.test(l),E=C=>{if(o&&o(C),C.defaultPrevented)return;C.preventDefault();let T=C.nativeEvent.submitter,R=(T==null?void 0:T.getAttribute("formmethod"))||u;y(T||C.currentTarget,{fetcherKey:t,method:R,navigate:n,replace:i,state:a,relative:s,preventScrollReset:c,viewTransition:d})};return P.createElement("form",{ref:m,method:_,action:v,onSubmit:r?o:E,...h,"data-discover":!S&&e==="render"?"true":void 0})});wRe.displayName="Form";function RRe(e){return`${e} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function cpe(e){let t=P.useContext(Rb);return pr(t,RRe(e)),t}function ARe(e,{target:t,replace:n,state:r,preventScrollReset:i,relative:a,viewTransition:u}={}){let l=dI(),o=Og(),s=OS(e,{relative:a});return P.useCallback(c=>{if(uRe(c,t)){c.preventDefault();let d=n!==void 0?n:ey(o)===ey(s);l(e,{replace:d,state:r,preventScrollReset:i,relative:a,viewTransition:u})}},[o,l,s,n,r,t,e,i,a,u])}function Kit(e){Eu(typeof URLSearchParams<"u","You cannot use the `useSearchParams` hook in a browser that does not support the URLSearchParams API. If you need to support Internet Explorer 11, we recommend you load a polyfill such as https://github.com/ungap/url-search-params.");let t=P.useRef(J9(e)),n=P.useRef(!1),r=Og(),i=P.useMemo(()=>lRe(r.search,n.current?null:t.current),[r.search]),a=dI(),u=P.useCallback((l,o)=>{const s=J9(typeof l=="function"?l(new URLSearchParams(i)):l);n.current=!0,a("?"+s,o)},[a,i]);return[i,u]}var TRe=0,kRe=()=>`__${String(++TRe)}__`;function PRe(){let{router:e}=cpe("useSubmit"),{basename:t}=P.useContext(gp),n=U6e();return P.useCallback(async(r,i={})=>{let{action:a,method:u,encType:l,formData:o,body:s}=cRe(r,t);if(i.navigate===!1){let c=i.fetcherKey||kRe();await e.fetch(c,n,i.action||a,{preventScrollReset:i.preventScrollReset,formData:o,body:s,formMethod:i.method||u,formEncType:i.encType||l,flushSync:i.flushSync})}else await e.navigate(i.action||a,{preventScrollReset:i.preventScrollReset,formData:o,body:s,formMethod:i.method||u,formEncType:i.encType||l,replace:i.replace,state:i.state,fromRouteId:n,flushSync:i.flushSync,viewTransition:i.viewTransition})},[e,t,n])}function MRe(e,{relative:t}={}){let{basename:n}=P.useContext(gp),r=P.useContext(uh);pr(r,"useFormAction must be used inside a RouteContext");let[i]=r.matches.slice(-1),a={...OS(e||".",{relative:t})},u=Og();if(e==null){a.search=u.search;let l=new URLSearchParams(a.search),o=l.getAll("index");if(o.some(c=>c==="")){l.delete("index"),o.filter(d=>d).forEach(d=>l.append("index",d));let c=l.toString();a.search=c?`?${c}`:""}}return(!e||e===".")&&i.route.index&&(a.search=a.search?a.search.replace(/^\?/,"?index&"):"?index"),n!=="/"&&(a.pathname=a.pathname==="/"?n:w0([n,a.pathname])),ey(a)}function FRe(e,{relative:t}={}){let n=P.useContext(cI);pr(n!=null,"`useViewTransitionState` must be used within `react-router-dom`'s `RouterProvider`.  Did you accidentally import `RouterProvider` from `react-router`?");let{basename:r}=cpe("useViewTransitionState"),i=OS(e,{relative:t});if(!n.isTransitioning)return!1;let a=cf(n.currentLocation.pathname,r)||n.currentLocation.pathname,u=cf(n.nextLocation.pathname,r)||n.nextLocation.pathname;return i$(i.pathname,u)!=null||i$(i.pathname,a)!=null}var gZ=function(t,n){var r=arguments;if(n==null||!nS.call(n,"css"))return P.createElement.apply(void 0,r);var i=r.length,a=new Array(i);a[0]=FF,a[1]=MF(t,n);for(var u=2;u<i;u++)a[u]=r[u];return P.createElement.apply(null,a)};(function(e){var t;t||(t=e.JSX||(e.JSX={}))})(gZ||(gZ={}));var Wit=yJ(function(e,t){var n=e.styles,r=PF([n],void 0,P.useContext(bJ)),i=P.useRef();return JB(function(){var a=t.key+"-global",u=new t.sheet.constructor({key:a,nonce:t.sheet.nonce,container:t.sheet.container,speedy:t.sheet.isSpeedy}),l=!1,o=document.querySelector('style[data-emotion="'+a+" "+r.name+'"]');return t.sheet.tags.length&&(u.before=t.sheet.tags[0]),o!==null&&(l=!0,o.setAttribute("data-emotion",a),u.hydrate([o])),i.current=[u,l],function(){u.flush()}},[t]),JB(function(){var a=i.current,u=a[0],l=a[1];if(l){a[1]=!1;return}if(r.next!==void 0&&pJ(t,r.next,!0),u.tags.length){var o=u.tags[u.tags.length-1].nextElementSibling;u.before=o,u.flush()}t.insert("",r,u,!1)},[t,r.name]),null});function NRe(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return PF(t)}function Jit(){var e=NRe.apply(void 0,arguments),t="animation-"+e.name;return{name:t,styles:"@keyframes "+t+"{"+e.styles+"}",anim:1,toString:function(){return"_EMO_"+this.name+"_"+this.styles+"_EMO_"}}}var vk,vZ;function IRe(){return vZ||(vZ=1,vk=function(){var e=document.getSelection();if(!e.rangeCount)return function(){};for(var t=document.activeElement,n=[],r=0;r<e.rangeCount;r++)n.push(e.getRangeAt(r));switch(t.tagName.toUpperCase()){case"INPUT":case"TEXTAREA":t.blur();break;default:t=null;break}return e.removeAllRanges(),function(){e.type==="Caret"&&e.removeAllRanges(),e.rangeCount||n.forEach(function(i){e.addRange(i)}),t&&t.focus()}}),vk}var yk,yZ;function LRe(){if(yZ)return yk;yZ=1;var e=IRe(),t={"text/plain":"Text","text/html":"Url",default:"Text"},n="Copy to clipboard: #{key}, Enter";function r(a){var u=(/mac os x/i.test(navigator.userAgent)?"⌘":"Ctrl")+"+C";return a.replace(/#{\s*key\s*}/g,u)}function i(a,u){var l,o,s,c,d,h,m=!1;u||(u={}),l=u.debug||!1;try{s=e(),c=document.createRange(),d=document.getSelection(),h=document.createElement("span"),h.textContent=a,h.ariaHidden="true",h.style.all="unset",h.style.position="fixed",h.style.top=0,h.style.clip="rect(0, 0, 0, 0)",h.style.whiteSpace="pre",h.style.webkitUserSelect="text",h.style.MozUserSelect="text",h.style.msUserSelect="text",h.style.userSelect="text",h.addEventListener("copy",function(v){if(v.stopPropagation(),u.format)if(v.preventDefault(),typeof v.clipboardData>"u"){l&&console.warn("unable to use e.clipboardData"),l&&console.warn("trying IE specific stuff"),window.clipboardData.clearData();var _=t[u.format]||t.default;window.clipboardData.setData(_,a)}else v.clipboardData.clearData(),v.clipboardData.setData(u.format,a);u.onCopy&&(v.preventDefault(),u.onCopy(v.clipboardData))}),document.body.appendChild(h),c.selectNodeContents(h),d.addRange(c);var y=document.execCommand("copy");if(!y)throw new Error("copy command was unsuccessful");m=!0}catch(v){l&&console.error("unable to copy using execCommand: ",v),l&&console.warn("trying IE specific stuff");try{window.clipboardData.setData(u.format||"text",a),u.onCopy&&u.onCopy(window.clipboardData),m=!0}catch(_){l&&console.error("unable to copy using clipboardData: ",_),l&&console.error("falling back to prompt"),o=r("message"in u?u.message:n),window.prompt(o,a)}}finally{d&&(typeof d.removeRange=="function"?d.removeRange(c):d.removeAllRanges()),h&&document.body.removeChild(h),s()}return m}return yk=i,yk}var BRe=LRe();const eat=sa(BRe),fpe=6048e5,QRe=864e5,zRe=6e4,qRe=36e5,X_=43200,bZ=1440,OZ=Symbol.for("constructDateFrom");function op(e,t){return typeof e=="function"?e(t):e&&typeof e=="object"&&OZ in e?e[OZ](t):e instanceof Date?new e.constructor(t):new Date(t)}function Ea(e,t){return op(t||e,e)}function VRe(e,t,n){const r=Ea(e,n==null?void 0:n.in);return isNaN(t)?op(e,NaN):(t&&r.setDate(r.getDate()+t),r)}function URe(e,t,n){return op(e,+Ea(e)+t)}function jRe(e,t,n){return URe(e,t*qRe)}let ZRe={};function J3(){return ZRe}function _x(e,t){var l,o,s,c;const n=J3(),r=(t==null?void 0:t.weekStartsOn)??((o=(l=t==null?void 0:t.locale)==null?void 0:l.options)==null?void 0:o.weekStartsOn)??n.weekStartsOn??((c=(s=n.locale)==null?void 0:s.options)==null?void 0:c.weekStartsOn)??0,i=Ea(e,t==null?void 0:t.in),a=i.getDay(),u=(a<r?7:0)+a-r;return i.setDate(i.getDate()-u),i.setHours(0,0,0,0),i}function l$(e,t){return _x(e,{...t,weekStartsOn:1})}function dpe(e,t){const n=Ea(e,t==null?void 0:t.in),r=n.getFullYear(),i=op(n,0);i.setFullYear(r+1,0,4),i.setHours(0,0,0,0);const a=l$(i),u=op(n,0);u.setFullYear(r,0,4),u.setHours(0,0,0,0);const l=l$(u);return n.getTime()>=a.getTime()?r+1:n.getTime()>=l.getTime()?r:r-1}function o$(e){const t=Ea(e),n=new Date(Date.UTC(t.getFullYear(),t.getMonth(),t.getDate(),t.getHours(),t.getMinutes(),t.getSeconds(),t.getMilliseconds()));return n.setUTCFullYear(t.getFullYear()),+e-+n}function xS(e,...t){const n=op.bind(null,e||t.find(r=>typeof r=="object"));return t.map(n)}function xZ(e,t){const n=Ea(e,t==null?void 0:t.in);return n.setHours(0,0,0,0),n}function hpe(e,t,n){const[r,i]=xS(n==null?void 0:n.in,e,t),a=xZ(r),u=xZ(i),l=+a-o$(a),o=+u-o$(u);return Math.round((l-o)/QRe)}function HRe(e,t){const n=dpe(e,t),r=op(e,0);return r.setFullYear(n,0,4),r.setHours(0,0,0,0),l$(r)}function XRe(e,t,n){const r=Ea(e,n==null?void 0:n.in);return r.setTime(r.getTime()+t*zRe),r}function rD(e,t){const n=+Ea(e)-+Ea(t);return n<0?-1:n>0?1:n}function YRe(e){return e instanceof Date||typeof e=="object"&&Object.prototype.toString.call(e)==="[object Date]"}function GRe(e){return!(!YRe(e)&&typeof e!="number"||isNaN(+Ea(e)))}function KRe(e,t,n){const[r,i]=xS(n==null?void 0:n.in,e,t),a=r.getFullYear()-i.getFullYear(),u=r.getMonth()-i.getMonth();return a*12+u}function ppe(e){return t=>{const r=(e?Math[e]:Math.trunc)(t);return r===0?0:r}}function WRe(e,t){return+Ea(e)-+Ea(t)}function JRe(e,t){const n=Ea(e,t==null?void 0:t.in);return n.setHours(23,59,59,999),n}function eAe(e,t){const n=Ea(e,t==null?void 0:t.in),r=n.getMonth();return n.setFullYear(n.getFullYear(),r+1,0),n.setHours(23,59,59,999),n}function tAe(e,t){const n=Ea(e,t==null?void 0:t.in);return+JRe(n,t)==+eAe(n,t)}function nAe(e,t,n){const[r,i,a]=xS(n==null?void 0:n.in,e,e,t),u=rD(i,a),l=Math.abs(KRe(i,a));if(l<1)return 0;i.getMonth()===1&&i.getDate()>27&&i.setDate(30),i.setMonth(i.getMonth()-u*l);let o=rD(i,a)===-u;tAe(r)&&l===1&&rD(r,a)===1&&(o=!1);const s=u*(l-+o);return s===0?0:s}function rAe(e,t,n){const r=WRe(e,t)/1e3;return ppe(n==null?void 0:n.roundingMethod)(r)}function iAe(e,t){const n=Ea(e,t==null?void 0:t.in);return n.setFullYear(n.getFullYear(),0,1),n.setHours(0,0,0,0),n}function tat(e,t){const n=Ea(e,t==null?void 0:t.in);return n.setMinutes(59,59,999),n}function nat(e,t){const n=Ea(e,t==null?void 0:t.in);return n.setSeconds(59,999),n}const aAe={lessThanXSeconds:{one:"less than a second",other:"less than {{count}} seconds"},xSeconds:{one:"1 second",other:"{{count}} seconds"},halfAMinute:"half a minute",lessThanXMinutes:{one:"less than a minute",other:"less than {{count}} minutes"},xMinutes:{one:"1 minute",other:"{{count}} minutes"},aboutXHours:{one:"about 1 hour",other:"about {{count}} hours"},xHours:{one:"1 hour",other:"{{count}} hours"},xDays:{one:"1 day",other:"{{count}} days"},aboutXWeeks:{one:"about 1 week",other:"about {{count}} weeks"},xWeeks:{one:"1 week",other:"{{count}} weeks"},aboutXMonths:{one:"about 1 month",other:"about {{count}} months"},xMonths:{one:"1 month",other:"{{count}} months"},aboutXYears:{one:"about 1 year",other:"about {{count}} years"},xYears:{one:"1 year",other:"{{count}} years"},overXYears:{one:"over 1 year",other:"over {{count}} years"},almostXYears:{one:"almost 1 year",other:"almost {{count}} years"}},uAe=(e,t,n)=>{let r;const i=aAe[e];return typeof i=="string"?r=i:t===1?r=i.one:r=i.other.replace("{{count}}",t.toString()),n!=null&&n.addSuffix?n.comparison&&n.comparison>0?"in "+r:r+" ago":r};function bk(e){return(t={})=>{const n=t.width?String(t.width):e.defaultWidth;return e.formats[n]||e.formats[e.defaultWidth]}}const lAe={full:"EEEE, MMMM do, y",long:"MMMM do, y",medium:"MMM d, y",short:"MM/dd/yyyy"},oAe={full:"h:mm:ss a zzzz",long:"h:mm:ss a z",medium:"h:mm:ss a",short:"h:mm a"},sAe={full:"{{date}} 'at' {{time}}",long:"{{date}} 'at' {{time}}",medium:"{{date}}, {{time}}",short:"{{date}}, {{time}}"},cAe={date:bk({formats:lAe,defaultWidth:"full"}),time:bk({formats:oAe,defaultWidth:"full"}),dateTime:bk({formats:sAe,defaultWidth:"full"})},fAe={lastWeek:"'last' eeee 'at' p",yesterday:"'yesterday at' p",today:"'today at' p",tomorrow:"'tomorrow at' p",nextWeek:"eeee 'at' p",other:"P"},dAe=(e,t,n,r)=>fAe[e];function t2(e){return(t,n)=>{const r=n!=null&&n.context?String(n.context):"standalone";let i;if(r==="formatting"&&e.formattingValues){const u=e.defaultFormattingWidth||e.defaultWidth,l=n!=null&&n.width?String(n.width):u;i=e.formattingValues[l]||e.formattingValues[u]}else{const u=e.defaultWidth,l=n!=null&&n.width?String(n.width):e.defaultWidth;i=e.values[l]||e.values[u]}const a=e.argumentCallback?e.argumentCallback(t):t;return i[a]}}const hAe={narrow:["B","A"],abbreviated:["BC","AD"],wide:["Before Christ","Anno Domini"]},pAe={narrow:["1","2","3","4"],abbreviated:["Q1","Q2","Q3","Q4"],wide:["1st quarter","2nd quarter","3rd quarter","4th quarter"]},mAe={narrow:["J","F","M","A","M","J","J","A","S","O","N","D"],abbreviated:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],wide:["January","February","March","April","May","June","July","August","September","October","November","December"]},gAe={narrow:["S","M","T","W","T","F","S"],short:["Su","Mo","Tu","We","Th","Fr","Sa"],abbreviated:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],wide:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"]},vAe={narrow:{am:"a",pm:"p",midnight:"mi",noon:"n",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"},abbreviated:{am:"AM",pm:"PM",midnight:"midnight",noon:"noon",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"},wide:{am:"a.m.",pm:"p.m.",midnight:"midnight",noon:"noon",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"}},yAe={narrow:{am:"a",pm:"p",midnight:"mi",noon:"n",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"},abbreviated:{am:"AM",pm:"PM",midnight:"midnight",noon:"noon",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"},wide:{am:"a.m.",pm:"p.m.",midnight:"midnight",noon:"noon",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"}},bAe=(e,t)=>{const n=Number(e),r=n%100;if(r>20||r<10)switch(r%10){case 1:return n+"st";case 2:return n+"nd";case 3:return n+"rd"}return n+"th"},OAe={ordinalNumber:bAe,era:t2({values:hAe,defaultWidth:"wide"}),quarter:t2({values:pAe,defaultWidth:"wide",argumentCallback:e=>e-1}),month:t2({values:mAe,defaultWidth:"wide"}),day:t2({values:gAe,defaultWidth:"wide"}),dayPeriod:t2({values:vAe,defaultWidth:"wide",formattingValues:yAe,defaultFormattingWidth:"wide"})};function n2(e){return(t,n={})=>{const r=n.width,i=r&&e.matchPatterns[r]||e.matchPatterns[e.defaultMatchWidth],a=t.match(i);if(!a)return null;const u=a[0],l=r&&e.parsePatterns[r]||e.parsePatterns[e.defaultParseWidth],o=Array.isArray(l)?SAe(l,d=>d.test(u)):xAe(l,d=>d.test(u));let s;s=e.valueCallback?e.valueCallback(o):o,s=n.valueCallback?n.valueCallback(s):s;const c=t.slice(u.length);return{value:s,rest:c}}}function xAe(e,t){for(const n in e)if(Object.prototype.hasOwnProperty.call(e,n)&&t(e[n]))return n}function SAe(e,t){for(let n=0;n<e.length;n++)if(t(e[n]))return n}function _Ae(e){return(t,n={})=>{const r=t.match(e.matchPattern);if(!r)return null;const i=r[0],a=t.match(e.parsePattern);if(!a)return null;let u=e.valueCallback?e.valueCallback(a[0]):a[0];u=n.valueCallback?n.valueCallback(u):u;const l=t.slice(i.length);return{value:u,rest:l}}}const EAe=/^(\d+)(th|st|nd|rd)?/i,DAe=/\d+/i,$Ae={narrow:/^(b|a)/i,abbreviated:/^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,wide:/^(before christ|before common era|anno domini|common era)/i},CAe={any:[/^b/i,/^(a|c)/i]},wAe={narrow:/^[1234]/i,abbreviated:/^q[1234]/i,wide:/^[1234](th|st|nd|rd)? quarter/i},RAe={any:[/1/i,/2/i,/3/i,/4/i]},AAe={narrow:/^[jfmasond]/i,abbreviated:/^(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)/i,wide:/^(january|february|march|april|may|june|july|august|september|october|november|december)/i},TAe={narrow:[/^j/i,/^f/i,/^m/i,/^a/i,/^m/i,/^j/i,/^j/i,/^a/i,/^s/i,/^o/i,/^n/i,/^d/i],any:[/^ja/i,/^f/i,/^mar/i,/^ap/i,/^may/i,/^jun/i,/^jul/i,/^au/i,/^s/i,/^o/i,/^n/i,/^d/i]},kAe={narrow:/^[smtwf]/i,short:/^(su|mo|tu|we|th|fr|sa)/i,abbreviated:/^(sun|mon|tue|wed|thu|fri|sat)/i,wide:/^(sunday|monday|tuesday|wednesday|thursday|friday|saturday)/i},PAe={narrow:[/^s/i,/^m/i,/^t/i,/^w/i,/^t/i,/^f/i,/^s/i],any:[/^su/i,/^m/i,/^tu/i,/^w/i,/^th/i,/^f/i,/^sa/i]},MAe={narrow:/^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,any:/^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i},FAe={any:{am:/^a/i,pm:/^p/i,midnight:/^mi/i,noon:/^no/i,morning:/morning/i,afternoon:/afternoon/i,evening:/evening/i,night:/night/i}},NAe={ordinalNumber:_Ae({matchPattern:EAe,parsePattern:DAe,valueCallback:e=>parseInt(e,10)}),era:n2({matchPatterns:$Ae,defaultMatchWidth:"wide",parsePatterns:CAe,defaultParseWidth:"any"}),quarter:n2({matchPatterns:wAe,defaultMatchWidth:"wide",parsePatterns:RAe,defaultParseWidth:"any",valueCallback:e=>e+1}),month:n2({matchPatterns:AAe,defaultMatchWidth:"wide",parsePatterns:TAe,defaultParseWidth:"any"}),day:n2({matchPatterns:kAe,defaultMatchWidth:"wide",parsePatterns:PAe,defaultParseWidth:"any"}),dayPeriod:n2({matchPatterns:MAe,defaultMatchWidth:"any",parsePatterns:FAe,defaultParseWidth:"any"})},vI={code:"en-US",formatDistance:uAe,formatLong:cAe,formatRelative:dAe,localize:OAe,match:NAe,options:{weekStartsOn:0,firstWeekContainsDate:1}};function IAe(e,t){const n=Ea(e,t==null?void 0:t.in);return hpe(n,iAe(n))+1}function LAe(e,t){const n=Ea(e,t==null?void 0:t.in),r=+l$(n)-+HRe(n);return Math.round(r/fpe)+1}function mpe(e,t){var c,d,h,m;const n=Ea(e,t==null?void 0:t.in),r=n.getFullYear(),i=J3(),a=(t==null?void 0:t.firstWeekContainsDate)??((d=(c=t==null?void 0:t.locale)==null?void 0:c.options)==null?void 0:d.firstWeekContainsDate)??i.firstWeekContainsDate??((m=(h=i.locale)==null?void 0:h.options)==null?void 0:m.firstWeekContainsDate)??1,u=op((t==null?void 0:t.in)||e,0);u.setFullYear(r+1,0,a),u.setHours(0,0,0,0);const l=_x(u,t),o=op((t==null?void 0:t.in)||e,0);o.setFullYear(r,0,a),o.setHours(0,0,0,0);const s=_x(o,t);return+n>=+l?r+1:+n>=+s?r:r-1}function BAe(e,t){var l,o,s,c;const n=J3(),r=(t==null?void 0:t.firstWeekContainsDate)??((o=(l=t==null?void 0:t.locale)==null?void 0:l.options)==null?void 0:o.firstWeekContainsDate)??n.firstWeekContainsDate??((c=(s=n.locale)==null?void 0:s.options)==null?void 0:c.firstWeekContainsDate)??1,i=mpe(e,t),a=op((t==null?void 0:t.in)||e,0);return a.setFullYear(i,0,r),a.setHours(0,0,0,0),_x(a,t)}function QAe(e,t){const n=Ea(e,t==null?void 0:t.in),r=+_x(n,t)-+BAe(n,t);return Math.round(r/fpe)+1}function ji(e,t){const n=e<0?"-":"",r=Math.abs(e).toString().padStart(t,"0");return n+r}const dv={y(e,t){const n=e.getFullYear(),r=n>0?n:1-n;return ji(t==="yy"?r%100:r,t.length)},M(e,t){const n=e.getMonth();return t==="M"?String(n+1):ji(n+1,2)},d(e,t){return ji(e.getDate(),t.length)},a(e,t){const n=e.getHours()/12>=1?"pm":"am";switch(t){case"a":case"aa":return n.toUpperCase();case"aaa":return n;case"aaaaa":return n[0];case"aaaa":default:return n==="am"?"a.m.":"p.m."}},h(e,t){return ji(e.getHours()%12||12,t.length)},H(e,t){return ji(e.getHours(),t.length)},m(e,t){return ji(e.getMinutes(),t.length)},s(e,t){return ji(e.getSeconds(),t.length)},S(e,t){const n=t.length,r=e.getMilliseconds(),i=Math.trunc(r*Math.pow(10,n-3));return ji(i,t.length)}},xO={midnight:"midnight",noon:"noon",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"},SZ={G:function(e,t,n){const r=e.getFullYear()>0?1:0;switch(t){case"G":case"GG":case"GGG":return n.era(r,{width:"abbreviated"});case"GGGGG":return n.era(r,{width:"narrow"});case"GGGG":default:return n.era(r,{width:"wide"})}},y:function(e,t,n){if(t==="yo"){const r=e.getFullYear(),i=r>0?r:1-r;return n.ordinalNumber(i,{unit:"year"})}return dv.y(e,t)},Y:function(e,t,n,r){const i=mpe(e,r),a=i>0?i:1-i;if(t==="YY"){const u=a%100;return ji(u,2)}return t==="Yo"?n.ordinalNumber(a,{unit:"year"}):ji(a,t.length)},R:function(e,t){const n=dpe(e);return ji(n,t.length)},u:function(e,t){const n=e.getFullYear();return ji(n,t.length)},Q:function(e,t,n){const r=Math.ceil((e.getMonth()+1)/3);switch(t){case"Q":return String(r);case"QQ":return ji(r,2);case"Qo":return n.ordinalNumber(r,{unit:"quarter"});case"QQQ":return n.quarter(r,{width:"abbreviated",context:"formatting"});case"QQQQQ":return n.quarter(r,{width:"narrow",context:"formatting"});case"QQQQ":default:return n.quarter(r,{width:"wide",context:"formatting"})}},q:function(e,t,n){const r=Math.ceil((e.getMonth()+1)/3);switch(t){case"q":return String(r);case"qq":return ji(r,2);case"qo":return n.ordinalNumber(r,{unit:"quarter"});case"qqq":return n.quarter(r,{width:"abbreviated",context:"standalone"});case"qqqqq":return n.quarter(r,{width:"narrow",context:"standalone"});case"qqqq":default:return n.quarter(r,{width:"wide",context:"standalone"})}},M:function(e,t,n){const r=e.getMonth();switch(t){case"M":case"MM":return dv.M(e,t);case"Mo":return n.ordinalNumber(r+1,{unit:"month"});case"MMM":return n.month(r,{width:"abbreviated",context:"formatting"});case"MMMMM":return n.month(r,{width:"narrow",context:"formatting"});case"MMMM":default:return n.month(r,{width:"wide",context:"formatting"})}},L:function(e,t,n){const r=e.getMonth();switch(t){case"L":return String(r+1);case"LL":return ji(r+1,2);case"Lo":return n.ordinalNumber(r+1,{unit:"month"});case"LLL":return n.month(r,{width:"abbreviated",context:"standalone"});case"LLLLL":return n.month(r,{width:"narrow",context:"standalone"});case"LLLL":default:return n.month(r,{width:"wide",context:"standalone"})}},w:function(e,t,n,r){const i=QAe(e,r);return t==="wo"?n.ordinalNumber(i,{unit:"week"}):ji(i,t.length)},I:function(e,t,n){const r=LAe(e);return t==="Io"?n.ordinalNumber(r,{unit:"week"}):ji(r,t.length)},d:function(e,t,n){return t==="do"?n.ordinalNumber(e.getDate(),{unit:"date"}):dv.d(e,t)},D:function(e,t,n){const r=IAe(e);return t==="Do"?n.ordinalNumber(r,{unit:"dayOfYear"}):ji(r,t.length)},E:function(e,t,n){const r=e.getDay();switch(t){case"E":case"EE":case"EEE":return n.day(r,{width:"abbreviated",context:"formatting"});case"EEEEE":return n.day(r,{width:"narrow",context:"formatting"});case"EEEEEE":return n.day(r,{width:"short",context:"formatting"});case"EEEE":default:return n.day(r,{width:"wide",context:"formatting"})}},e:function(e,t,n,r){const i=e.getDay(),a=(i-r.weekStartsOn+8)%7||7;switch(t){case"e":return String(a);case"ee":return ji(a,2);case"eo":return n.ordinalNumber(a,{unit:"day"});case"eee":return n.day(i,{width:"abbreviated",context:"formatting"});case"eeeee":return n.day(i,{width:"narrow",context:"formatting"});case"eeeeee":return n.day(i,{width:"short",context:"formatting"});case"eeee":default:return n.day(i,{width:"wide",context:"formatting"})}},c:function(e,t,n,r){const i=e.getDay(),a=(i-r.weekStartsOn+8)%7||7;switch(t){case"c":return String(a);case"cc":return ji(a,t.length);case"co":return n.ordinalNumber(a,{unit:"day"});case"ccc":return n.day(i,{width:"abbreviated",context:"standalone"});case"ccccc":return n.day(i,{width:"narrow",context:"standalone"});case"cccccc":return n.day(i,{width:"short",context:"standalone"});case"cccc":default:return n.day(i,{width:"wide",context:"standalone"})}},i:function(e,t,n){const r=e.getDay(),i=r===0?7:r;switch(t){case"i":return String(i);case"ii":return ji(i,t.length);case"io":return n.ordinalNumber(i,{unit:"day"});case"iii":return n.day(r,{width:"abbreviated",context:"formatting"});case"iiiii":return n.day(r,{width:"narrow",context:"formatting"});case"iiiiii":return n.day(r,{width:"short",context:"formatting"});case"iiii":default:return n.day(r,{width:"wide",context:"formatting"})}},a:function(e,t,n){const i=e.getHours()/12>=1?"pm":"am";switch(t){case"a":case"aa":return n.dayPeriod(i,{width:"abbreviated",context:"formatting"});case"aaa":return n.dayPeriod(i,{width:"abbreviated",context:"formatting"}).toLowerCase();case"aaaaa":return n.dayPeriod(i,{width:"narrow",context:"formatting"});case"aaaa":default:return n.dayPeriod(i,{width:"wide",context:"formatting"})}},b:function(e,t,n){const r=e.getHours();let i;switch(r===12?i=xO.noon:r===0?i=xO.midnight:i=r/12>=1?"pm":"am",t){case"b":case"bb":return n.dayPeriod(i,{width:"abbreviated",context:"formatting"});case"bbb":return n.dayPeriod(i,{width:"abbreviated",context:"formatting"}).toLowerCase();case"bbbbb":return n.dayPeriod(i,{width:"narrow",context:"formatting"});case"bbbb":default:return n.dayPeriod(i,{width:"wide",context:"formatting"})}},B:function(e,t,n){const r=e.getHours();let i;switch(r>=17?i=xO.evening:r>=12?i=xO.afternoon:r>=4?i=xO.morning:i=xO.night,t){case"B":case"BB":case"BBB":return n.dayPeriod(i,{width:"abbreviated",context:"formatting"});case"BBBBB":return n.dayPeriod(i,{width:"narrow",context:"formatting"});case"BBBB":default:return n.dayPeriod(i,{width:"wide",context:"formatting"})}},h:function(e,t,n){if(t==="ho"){let r=e.getHours()%12;return r===0&&(r=12),n.ordinalNumber(r,{unit:"hour"})}return dv.h(e,t)},H:function(e,t,n){return t==="Ho"?n.ordinalNumber(e.getHours(),{unit:"hour"}):dv.H(e,t)},K:function(e,t,n){const r=e.getHours()%12;return t==="Ko"?n.ordinalNumber(r,{unit:"hour"}):ji(r,t.length)},k:function(e,t,n){let r=e.getHours();return r===0&&(r=24),t==="ko"?n.ordinalNumber(r,{unit:"hour"}):ji(r,t.length)},m:function(e,t,n){return t==="mo"?n.ordinalNumber(e.getMinutes(),{unit:"minute"}):dv.m(e,t)},s:function(e,t,n){return t==="so"?n.ordinalNumber(e.getSeconds(),{unit:"second"}):dv.s(e,t)},S:function(e,t){return dv.S(e,t)},X:function(e,t,n){const r=e.getTimezoneOffset();if(r===0)return"Z";switch(t){case"X":return EZ(r);case"XXXX":case"XX":return D1(r);case"XXXXX":case"XXX":default:return D1(r,":")}},x:function(e,t,n){const r=e.getTimezoneOffset();switch(t){case"x":return EZ(r);case"xxxx":case"xx":return D1(r);case"xxxxx":case"xxx":default:return D1(r,":")}},O:function(e,t,n){const r=e.getTimezoneOffset();switch(t){case"O":case"OO":case"OOO":return"GMT"+_Z(r,":");case"OOOO":default:return"GMT"+D1(r,":")}},z:function(e,t,n){const r=e.getTimezoneOffset();switch(t){case"z":case"zz":case"zzz":return"GMT"+_Z(r,":");case"zzzz":default:return"GMT"+D1(r,":")}},t:function(e,t,n){const r=Math.trunc(+e/1e3);return ji(r,t.length)},T:function(e,t,n){return ji(+e,t.length)}};function _Z(e,t=""){const n=e>0?"-":"+",r=Math.abs(e),i=Math.trunc(r/60),a=r%60;return a===0?n+String(i):n+String(i)+t+ji(a,2)}function EZ(e,t){return e%60===0?(e>0?"-":"+")+ji(Math.abs(e)/60,2):D1(e,t)}function D1(e,t=""){const n=e>0?"-":"+",r=Math.abs(e),i=ji(Math.trunc(r/60),2),a=ji(r%60,2);return n+i+t+a}const DZ=(e,t)=>{switch(e){case"P":return t.date({width:"short"});case"PP":return t.date({width:"medium"});case"PPP":return t.date({width:"long"});case"PPPP":default:return t.date({width:"full"})}},gpe=(e,t)=>{switch(e){case"p":return t.time({width:"short"});case"pp":return t.time({width:"medium"});case"ppp":return t.time({width:"long"});case"pppp":default:return t.time({width:"full"})}},zAe=(e,t)=>{const n=e.match(/(P+)(p+)?/)||[],r=n[1],i=n[2];if(!i)return DZ(e,t);let a;switch(r){case"P":a=t.dateTime({width:"short"});break;case"PP":a=t.dateTime({width:"medium"});break;case"PPP":a=t.dateTime({width:"long"});break;case"PPPP":default:a=t.dateTime({width:"full"});break}return a.replace("{{date}}",DZ(r,t)).replace("{{time}}",gpe(i,t))},qAe={p:gpe,P:zAe},VAe=/^D+$/,UAe=/^Y+$/,jAe=["D","DD","YY","YYYY"];function ZAe(e){return VAe.test(e)}function HAe(e){return UAe.test(e)}function XAe(e,t,n){const r=YAe(e,t,n);if(console.warn(r),jAe.includes(e))throw new RangeError(r)}function YAe(e,t,n){const r=e[0]==="Y"?"years":"days of the month";return`Use \`${e.toLowerCase()}\` instead of \`${e}\` (in \`${t}\`) for formatting ${r} to the input \`${n}\`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md`}const GAe=/[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g,KAe=/P+p+|P+|p+|''|'(''|[^'])+('|$)|./g,WAe=/^'([^]*?)'?$/,JAe=/''/g,eTe=/[a-zA-Z]/;function tTe(e,t,n){var c,d,h,m,y,v,_,S;const r=J3(),i=(n==null?void 0:n.locale)??r.locale??vI,a=(n==null?void 0:n.firstWeekContainsDate)??((d=(c=n==null?void 0:n.locale)==null?void 0:c.options)==null?void 0:d.firstWeekContainsDate)??r.firstWeekContainsDate??((m=(h=r.locale)==null?void 0:h.options)==null?void 0:m.firstWeekContainsDate)??1,u=(n==null?void 0:n.weekStartsOn)??((v=(y=n==null?void 0:n.locale)==null?void 0:y.options)==null?void 0:v.weekStartsOn)??r.weekStartsOn??((S=(_=r.locale)==null?void 0:_.options)==null?void 0:S.weekStartsOn)??0,l=Ea(e,n==null?void 0:n.in);if(!GRe(l))throw new RangeError("Invalid time value");let o=t.match(KAe).map(E=>{const C=E[0];if(C==="p"||C==="P"){const T=qAe[C];return T(E,i.formatLong)}return E}).join("").match(GAe).map(E=>{if(E==="''")return{isToken:!1,value:"'"};const C=E[0];if(C==="'")return{isToken:!1,value:nTe(E)};if(SZ[C])return{isToken:!0,value:E};if(C.match(eTe))throw new RangeError("Format string contains an unescaped latin alphabet character `"+C+"`");return{isToken:!1,value:E}});i.localize.preprocessor&&(o=i.localize.preprocessor(l,o));const s={firstWeekContainsDate:a,weekStartsOn:u,locale:i};return o.map(E=>{if(!E.isToken)return E.value;const C=E.value;(!(n!=null&&n.useAdditionalWeekYearTokens)&&HAe(C)||!(n!=null&&n.useAdditionalDayOfYearTokens)&&ZAe(C))&&XAe(C,t,String(e));const T=SZ[C[0]];return T(l,C,i.localize,s)}).join("")}function nTe(e){const t=e.match(WAe);return t?t[1].replace(JAe,"'"):e}function rat(e,t,n){const r=J3(),i=(n==null?void 0:n.locale)??r.locale??vI,a=2520,u=rD(e,t);if(isNaN(u))throw new RangeError("Invalid time value");const l=Object.assign({},n,{addSuffix:n==null?void 0:n.addSuffix,comparison:u}),[o,s]=xS(n==null?void 0:n.in,...u>0?[t,e]:[e,t]),c=rAe(s,o),d=(o$(s)-o$(o))/1e3,h=Math.round((c-d)/60);let m;if(h<2)return n!=null&&n.includeSeconds?c<5?i.formatDistance("lessThanXSeconds",5,l):c<10?i.formatDistance("lessThanXSeconds",10,l):c<20?i.formatDistance("lessThanXSeconds",20,l):c<40?i.formatDistance("halfAMinute",0,l):c<60?i.formatDistance("lessThanXMinutes",1,l):i.formatDistance("xMinutes",1,l):h===0?i.formatDistance("lessThanXMinutes",1,l):i.formatDistance("xMinutes",h,l);if(h<45)return i.formatDistance("xMinutes",h,l);if(h<90)return i.formatDistance("aboutXHours",1,l);if(h<bZ){const y=Math.round(h/60);return i.formatDistance("aboutXHours",y,l)}else{if(h<a)return i.formatDistance("xDays",1,l);if(h<X_){const y=Math.round(h/bZ);return i.formatDistance("xDays",y,l)}else if(h<X_*2)return m=Math.round(h/X_),i.formatDistance("aboutXMonths",m,l)}if(m=nAe(s,o),m<12){const y=Math.round(h/X_);return i.formatDistance("xMonths",y,l)}else{const y=m%12,v=Math.trunc(m/12);return y<3?i.formatDistance("aboutXYears",v,l):y<9?i.formatDistance("overXYears",v,l):i.formatDistance("almostXYears",v+1,l)}}function iat(e,t,n){var d,h;const[r,i]=xS(n==null?void 0:n.in,e,t),a=J3(),u=a.locale??vI,l=a.weekStartsOn??((h=(d=a.locale)==null?void 0:d.options)==null?void 0:h.weekStartsOn)??0,o=hpe(r,i);if(isNaN(o))throw new RangeError("Invalid time value");let s;o<-6?s="other":o<-1?s="lastWeek":o<0?s="yesterday":o<1?s="today":o<2?s="tomorrow":o<7?s="nextWeek":s="other";const c=u.formatRelative(s,r,i,{locale:u,weekStartsOn:l});return tTe(r,c,{locale:u,weekStartsOn:l})}function aat(e,t){const n=Ea(e,t==null?void 0:t.in);return n.setMinutes(0,0,0),n}function uat(e,t){const n=Ea(e,t==null?void 0:t.in);return n.setSeconds(0,0),n}function lat(e,t,n){return VRe(e,-t,n)}function oat(e,t){const n=(t==null?void 0:t.nearestTo)??1;if(n<1||n>30)return op(e,NaN);const r=Ea(e,t==null?void 0:t.in),i=r.getSeconds()/60,a=r.getMilliseconds()/1e3/60,u=r.getMinutes()+i+a,l=(t==null?void 0:t.roundingMethod)??"round",s=ppe(l)(u/n)*n;return r.setMinutes(s,0,0),r}function sat(e,t,n){return jRe(e,-t)}function cat(e,t,n){return XRe(e,-15,n)}var Ok,$Z;function yI(){if($Z)return Ok;$Z=1;function e(t){var n=typeof t;return t!=null&&(n=="object"||n=="function")}return Ok=e,Ok}var xk,CZ;function rTe(){if(CZ)return xk;CZ=1;var e=typeof Hd=="object"&&Hd&&Hd.Object===Object&&Hd;return xk=e,xk}var Sk,wZ;function vpe(){if(wZ)return Sk;wZ=1;var e=rTe(),t=typeof self=="object"&&self&&self.Object===Object&&self,n=e||t||Function("return this")();return Sk=n,Sk}var _k,RZ;function iTe(){if(RZ)return _k;RZ=1;var e=vpe(),t=function(){return e.Date.now()};return _k=t,_k}var Ek,AZ;function aTe(){if(AZ)return Ek;AZ=1;var e=/\s/;function t(n){for(var r=n.length;r--&&e.test(n.charAt(r)););return r}return Ek=t,Ek}var Dk,TZ;function uTe(){if(TZ)return Dk;TZ=1;var e=aTe(),t=/^\s+/;function n(r){return r&&r.slice(0,e(r)+1).replace(t,"")}return Dk=n,Dk}var $k,kZ;function ype(){if(kZ)return $k;kZ=1;var e=vpe(),t=e.Symbol;return $k=t,$k}var Ck,PZ;function lTe(){if(PZ)return Ck;PZ=1;var e=ype(),t=Object.prototype,n=t.hasOwnProperty,r=t.toString,i=e?e.toStringTag:void 0;function a(u){var l=n.call(u,i),o=u[i];try{u[i]=void 0;var s=!0}catch{}var c=r.call(u);return s&&(l?u[i]=o:delete u[i]),c}return Ck=a,Ck}var wk,MZ;function oTe(){if(MZ)return wk;MZ=1;var e=Object.prototype,t=e.toString;function n(r){return t.call(r)}return wk=n,wk}var Rk,FZ;function sTe(){if(FZ)return Rk;FZ=1;var e=ype(),t=lTe(),n=oTe(),r="[object Null]",i="[object Undefined]",a=e?e.toStringTag:void 0;function u(l){return l==null?l===void 0?i:r:a&&a in Object(l)?t(l):n(l)}return Rk=u,Rk}var Ak,NZ;function cTe(){if(NZ)return Ak;NZ=1;function e(t){return t!=null&&typeof t=="object"}return Ak=e,Ak}var Tk,IZ;function fTe(){if(IZ)return Tk;IZ=1;var e=sTe(),t=cTe(),n="[object Symbol]";function r(i){return typeof i=="symbol"||t(i)&&e(i)==n}return Tk=r,Tk}var kk,LZ;function dTe(){if(LZ)return kk;LZ=1;var e=uTe(),t=yI(),n=fTe(),r=NaN,i=/^[-+]0x[0-9a-f]+$/i,a=/^0b[01]+$/i,u=/^0o[0-7]+$/i,l=parseInt;function o(s){if(typeof s=="number")return s;if(n(s))return r;if(t(s)){var c=typeof s.valueOf=="function"?s.valueOf():s;s=t(c)?c+"":c}if(typeof s!="string")return s===0?s:+s;s=e(s);var d=a.test(s);return d||u.test(s)?l(s.slice(2),d?2:8):i.test(s)?r:+s}return kk=o,kk}var Pk,BZ;function hTe(){if(BZ)return Pk;BZ=1;var e=yI(),t=iTe(),n=dTe(),r="Expected a function",i=Math.max,a=Math.min;function u(l,o,s){var c,d,h,m,y,v,_=0,S=!1,E=!1,C=!0;if(typeof l!="function")throw new TypeError(r);o=n(o)||0,e(s)&&(S=!!s.leading,E="maxWait"in s,h=E?i(n(s.maxWait)||0,o):h,C="trailing"in s?!!s.trailing:C);function T(N){var U=c,W=d;return c=d=void 0,_=N,m=l.apply(W,U),m}function R(N){return _=N,y=setTimeout(F,o),S?T(N):m}function $(N){var U=N-v,W=N-_,G=o-U;return E?a(G,h-W):G}function k(N){var U=N-v,W=N-_;return v===void 0||U>=o||U<0||E&&W>=h}function F(){var N=t();if(k(N))return L(N);y=setTimeout(F,$(N))}function L(N){return y=void 0,C&&c?T(N):(c=d=void 0,m)}function j(){y!==void 0&&clearTimeout(y),_=0,c=v=d=y=void 0}function V(){return y===void 0?m:L(t())}function q(){var N=t(),U=k(N);if(c=arguments,d=this,v=N,U){if(y===void 0)return R(v);if(E)return clearTimeout(y),y=setTimeout(F,o),T(v)}return y===void 0&&(y=setTimeout(F,o)),m}return q.cancel=j,q.flush=V,q}return Pk=u,Pk}var pTe=hTe();const fat=sa(pTe);var SS=e=>e.type==="checkbox",L1=e=>e instanceof Date,rc=e=>e==null;const bpe=e=>typeof e=="object";var Uu=e=>!rc(e)&&!Array.isArray(e)&&bpe(e)&&!L1(e),Ope=e=>Uu(e)&&e.target?SS(e.target)?e.target.checked:e.target.value:e,mTe=e=>e.substring(0,e.search(/\.\d+(\.|$)/))||e,xpe=(e,t)=>e.has(mTe(t)),gTe=e=>{const t=e.constructor&&e.constructor.prototype;return Uu(t)&&t.hasOwnProperty("isPrototypeOf")},bI=typeof window<"u"&&typeof window.HTMLElement<"u"&&typeof document<"u";function Fa(e){let t;const n=Array.isArray(e),r=typeof FileList<"u"?e instanceof FileList:!1;if(e instanceof Date)t=new Date(e);else if(!(bI&&(e instanceof Blob||r))&&(n||Uu(e)))if(t=n?[]:Object.create(Object.getPrototypeOf(e)),!n&&!gTe(e))t=e;else for(const i in e)e.hasOwnProperty(i)&&(t[i]=Fa(e[i]));else return e;return t}var lw=e=>/^\w*$/.test(e),Ia=e=>e===void 0,ow=e=>Array.isArray(e)?e.filter(Boolean):[],OI=e=>ow(e.replace(/["|']|\]/g,"").split(/\.|\[/)),jt=(e,t,n)=>{if(!t||!Uu(e))return n;const r=(lw(t)?[t]:OI(t)).reduce((i,a)=>rc(i)?i:i[a],e);return Ia(r)||r===e?Ia(e[t])?n:e[t]:r},Qf=e=>typeof e=="boolean",Ki=(e,t,n)=>{let r=-1;const i=lw(t)?[t]:OI(t),a=i.length,u=a-1;for(;++r<a;){const l=i[r];let o=n;if(r!==u){const s=e[l];o=Uu(s)||Array.isArray(s)?s:isNaN(+i[r+1])?{}:[]}if(l==="__proto__"||l==="constructor"||l==="prototype")return;e[l]=o,e=e[l]}};const s$={BLUR:"blur",FOCUS_OUT:"focusout",CHANGE:"change"},Zd={onBlur:"onBlur",onChange:"onChange",onSubmit:"onSubmit",onTouched:"onTouched",all:"all"},Tm={max:"max",min:"min",maxLength:"maxLength",minLength:"minLength",pattern:"pattern",required:"required",validate:"validate"},xI=ye.createContext(null);xI.displayName="HookFormContext";const sw=()=>ye.useContext(xI),dat=e=>{const{children:t,...n}=e;return ye.createElement(xI.Provider,{value:n},t)};var Spe=(e,t,n,r=!0)=>{const i={defaultValues:t._defaultValues};for(const a in e)Object.defineProperty(i,a,{get:()=>{const u=a;return t._proxyFormState[u]!==Zd.all&&(t._proxyFormState[u]=!r||Zd.all),n&&(n[u]=!0),e[u]}});return i};const cw=typeof window<"u"?ye.useLayoutEffect:ye.useEffect;function vTe(e){const t=sw(),{control:n=t.control,disabled:r,name:i,exact:a}=e||{},[u,l]=ye.useState(n._formState),o=ye.useRef({isDirty:!1,isLoading:!1,dirtyFields:!1,touchedFields:!1,validatingFields:!1,isValidating:!1,isValid:!1,errors:!1});return cw(()=>n._subscribe({name:i,formState:o.current,exact:a,callback:s=>{!r&&l({...n._formState,...s})}}),[i,r,a]),ye.useEffect(()=>{o.current.isValid&&n._setValid(!0)},[n]),ye.useMemo(()=>Spe(u,n,o.current,!1),[u,n])}var O0=e=>typeof e=="string",_pe=(e,t,n,r,i)=>O0(e)?(r&&t.watch.add(e),jt(n,e,i)):Array.isArray(e)?e.map(a=>(r&&t.watch.add(a),jt(n,a))):(r&&(t.watchAll=!0),n),eM=e=>rc(e)||!bpe(e);function jm(e,t,n=new WeakSet){if(eM(e)||eM(t))return e===t;if(L1(e)&&L1(t))return e.getTime()===t.getTime();const r=Object.keys(e),i=Object.keys(t);if(r.length!==i.length)return!1;if(n.has(e)||n.has(t))return!0;n.add(e),n.add(t);for(const a of r){const u=e[a];if(!i.includes(a))return!1;if(a!=="ref"){const l=t[a];if(L1(u)&&L1(l)||Uu(u)&&Uu(l)||Array.isArray(u)&&Array.isArray(l)?!jm(u,l,n):u!==l)return!1}}return!0}function yTe(e){const t=sw(),{control:n=t.control,name:r,defaultValue:i,disabled:a,exact:u,compute:l}=e||{},o=ye.useRef(i),s=ye.useRef(l),c=ye.useRef(void 0);s.current=l;const d=ye.useMemo(()=>n._getWatch(r,o.current),[n,r]),[h,m]=ye.useState(s.current?s.current(d):d);return cw(()=>n._subscribe({name:r,formState:{values:!0},exact:u,callback:y=>{if(!a){const v=_pe(r,n._names,y.values||n._formValues,!1,o.current);if(s.current){const _=s.current(v);jm(_,c.current)||(m(_),c.current=_)}else m(v)}}}),[n,a,r,u]),ye.useEffect(()=>n._removeUnmounted()),h}function bTe(e){const t=sw(),{name:n,disabled:r,control:i=t.control,shouldUnregister:a,defaultValue:u}=e,l=xpe(i._names.array,n),o=ye.useMemo(()=>jt(i._formValues,n,jt(i._defaultValues,n,u)),[i,n,u]),s=yTe({control:i,name:n,defaultValue:o,exact:!0}),c=vTe({control:i,name:n,exact:!0}),d=ye.useRef(e),h=ye.useRef(i.register(n,{...e.rules,value:s,...Qf(e.disabled)?{disabled:e.disabled}:{}}));d.current=e;const m=ye.useMemo(()=>Object.defineProperties({},{invalid:{enumerable:!0,get:()=>!!jt(c.errors,n)},isDirty:{enumerable:!0,get:()=>!!jt(c.dirtyFields,n)},isTouched:{enumerable:!0,get:()=>!!jt(c.touchedFields,n)},isValidating:{enumerable:!0,get:()=>!!jt(c.validatingFields,n)},error:{enumerable:!0,get:()=>jt(c.errors,n)}}),[c,n]),y=ye.useCallback(E=>h.current.onChange({target:{value:Ope(E),name:n},type:s$.CHANGE}),[n]),v=ye.useCallback(()=>h.current.onBlur({target:{value:jt(i._formValues,n),name:n},type:s$.BLUR}),[n,i._formValues]),_=ye.useCallback(E=>{const C=jt(i._fields,n);C&&E&&(C._f.ref={focus:()=>E.focus&&E.focus(),select:()=>E.select&&E.select(),setCustomValidity:T=>E.setCustomValidity(T),reportValidity:()=>E.reportValidity()})},[i._fields,n]),S=ye.useMemo(()=>({name:n,value:s,...Qf(r)||c.disabled?{disabled:c.disabled||r}:{},onChange:y,onBlur:v,ref:_}),[n,r,c.disabled,y,v,_,s]);return ye.useEffect(()=>{const E=i._options.shouldUnregister||a;i.register(n,{...d.current.rules,...Qf(d.current.disabled)?{disabled:d.current.disabled}:{}});const C=(T,R)=>{const $=jt(i._fields,T);$&&$._f&&($._f.mount=R)};if(C(n,!0),E){const T=Fa(jt(i._options.defaultValues,n));Ki(i._defaultValues,n,T),Ia(jt(i._formValues,n))&&Ki(i._formValues,n,T)}return!l&&i.register(n),()=>{(l?E&&!i._state.action:E)?i.unregister(n):C(n,!1)}},[n,i,l,a]),ye.useEffect(()=>{i._setDisabledField({disabled:r,name:n})},[r,n,i]),ye.useMemo(()=>({field:S,formState:c,fieldState:m}),[S,c,m])}const hat=e=>e.render(bTe(e));var OTe=(e,t,n,r,i)=>t?{...n[e],types:{...n[e]&&n[e].types?n[e].types:{},[r]:i||!0}}:{},uf=e=>Array.isArray(e)?e:[e],QZ=()=>{let e=[];return{get observers(){return e},next:i=>{for(const a of e)a.next&&a.next(i)},subscribe:i=>(e.push(i),{unsubscribe:()=>{e=e.filter(a=>a!==i)}}),unsubscribe:()=>{e=[]}}},nc=e=>Uu(e)&&!Object.keys(e).length,SI=e=>e.type==="file",Kh=e=>typeof e=="function",c$=e=>{if(!bI)return!1;const t=e?e.ownerDocument:0;return e instanceof(t&&t.defaultView?t.defaultView.HTMLElement:HTMLElement)},Epe=e=>e.type==="select-multiple",_I=e=>e.type==="radio",xTe=e=>_I(e)||SS(e),Mk=e=>c$(e)&&e.isConnected;function STe(e,t){const n=t.slice(0,-1).length;let r=0;for(;r<n;)e=Ia(e)?r++:e[t[r++]];return e}function _Te(e){for(const t in e)if(e.hasOwnProperty(t)&&!Ia(e[t]))return!1;return!0}function Qu(e,t){const n=Array.isArray(t)?t:lw(t)?[t]:OI(t),r=n.length===1?e:STe(e,n),i=n.length-1,a=n[i];return r&&delete r[a],i!==0&&(Uu(r)&&nc(r)||Array.isArray(r)&&_Te(r))&&Qu(e,n.slice(0,-1)),e}var Dpe=e=>{for(const t in e)if(Kh(e[t]))return!0;return!1};function f$(e,t={}){const n=Array.isArray(e);if(Uu(e)||n)for(const r in e)Array.isArray(e[r])||Uu(e[r])&&!Dpe(e[r])?(t[r]=Array.isArray(e[r])?[]:{},f$(e[r],t[r])):rc(e[r])||(t[r]=!0);return t}function $pe(e,t,n){const r=Array.isArray(e);if(Uu(e)||r)for(const i in e)Array.isArray(e[i])||Uu(e[i])&&!Dpe(e[i])?Ia(t)||eM(n[i])?n[i]=Array.isArray(e[i])?f$(e[i],[]):{...f$(e[i])}:$pe(e[i],rc(t)?{}:t[i],n[i]):n[i]=!jm(e[i],t[i]);return n}var r2=(e,t)=>$pe(e,t,f$(t));const zZ={value:!1,isValid:!1},qZ={value:!0,isValid:!0};var Cpe=e=>{if(Array.isArray(e)){if(e.length>1){const t=e.filter(n=>n&&n.checked&&!n.disabled).map(n=>n.value);return{value:t,isValid:!!t.length}}return e[0].checked&&!e[0].disabled?e[0].attributes&&!Ia(e[0].attributes.value)?Ia(e[0].value)||e[0].value===""?qZ:{value:e[0].value,isValid:!0}:qZ:zZ}return zZ},wpe=(e,{valueAsNumber:t,valueAsDate:n,setValueAs:r})=>Ia(e)?e:t?e===""?NaN:e&&+e:n&&O0(e)?new Date(e):r?r(e):e;const VZ={isValid:!1,value:null};var Rpe=e=>Array.isArray(e)?e.reduce((t,n)=>n&&n.checked&&!n.disabled?{isValid:!0,value:n.value}:t,VZ):VZ;function UZ(e){const t=e.ref;return SI(t)?t.files:_I(t)?Rpe(e.refs).value:Epe(t)?[...t.selectedOptions].map(({value:n})=>n):SS(t)?Cpe(e.refs).value:wpe(Ia(t.value)?e.ref.value:t.value,e)}var ETe=(e,t,n,r)=>{const i={};for(const a of e){const u=jt(t,a);u&&Ki(i,a,u._f)}return{criteriaMode:n,names:[...e],fields:i,shouldUseNativeValidation:r}},d$=e=>e instanceof RegExp,i2=e=>Ia(e)?e:d$(e)?e.source:Uu(e)?d$(e.value)?e.value.source:e.value:e,jO=e=>({isOnSubmit:!e||e===Zd.onSubmit,isOnBlur:e===Zd.onBlur,isOnChange:e===Zd.onChange,isOnAll:e===Zd.all,isOnTouch:e===Zd.onTouched});const jZ="AsyncFunction";var DTe=e=>!!e&&!!e.validate&&!!(Kh(e.validate)&&e.validate.constructor.name===jZ||Uu(e.validate)&&Object.values(e.validate).find(t=>t.constructor.name===jZ)),$Te=e=>e.mount&&(e.required||e.min||e.max||e.maxLength||e.minLength||e.pattern||e.validate),tM=(e,t,n)=>!n&&(t.watchAll||t.watch.has(e)||[...t.watch].some(r=>e.startsWith(r)&&/^\.\w+/.test(e.slice(r.length))));const c3=(e,t,n,r)=>{for(const i of n||Object.keys(e)){const a=jt(e,i);if(a){const{_f:u,...l}=a;if(u){if(u.refs&&u.refs[0]&&t(u.refs[0],i)&&!r)return!0;if(u.ref&&t(u.ref,u.name)&&!r)return!0;if(c3(l,t))break}else if(Uu(l)&&c3(l,t))break}}};function ZZ(e,t,n){const r=jt(e,n);if(r||lw(n))return{error:r,name:n};const i=n.split(".");for(;i.length;){const a=i.join("."),u=jt(t,a),l=jt(e,a);if(u&&!Array.isArray(u)&&n!==a)return{name:n};if(l&&l.type)return{name:a,error:l};if(l&&l.root&&l.root.type)return{name:`${a}.root`,error:l.root};i.pop()}return{name:n}}var CTe=(e,t,n,r)=>{n(e);const{name:i,...a}=e;return nc(a)||Object.keys(a).length>=Object.keys(t).length||Object.keys(a).find(u=>t[u]===(!r||Zd.all))},wTe=(e,t,n)=>!e||!t||e===t||uf(e).some(r=>r&&(n?r===t:r.startsWith(t)||t.startsWith(r))),RTe=(e,t,n,r,i)=>i.isOnAll?!1:!n&&i.isOnTouch?!(t||e):(n?r.isOnBlur:i.isOnBlur)?!e:(n?r.isOnChange:i.isOnChange)?e:!0,ATe=(e,t)=>!ow(jt(e,t)).length&&Qu(e,t),Ape=(e,t,n)=>{const r=uf(jt(e,n));return Ki(r,"root",t[n]),Ki(e,n,r),e},iD=e=>O0(e);function HZ(e,t,n="validate"){if(iD(e)||Array.isArray(e)&&e.every(iD)||Qf(e)&&!e)return{type:n,message:iD(e)?e:"",ref:t}}var SO=e=>Uu(e)&&!d$(e)?e:{value:e,message:""},nM=async(e,t,n,r,i,a)=>{const{ref:u,refs:l,required:o,maxLength:s,minLength:c,min:d,max:h,pattern:m,validate:y,name:v,valueAsNumber:_,mount:S}=e._f,E=jt(n,v);if(!S||t.has(v))return{};const C=l?l[0]:u,T=q=>{i&&C.reportValidity&&(C.setCustomValidity(Qf(q)?"":q||""),C.reportValidity())},R={},$=_I(u),k=SS(u),F=$||k,L=(_||SI(u))&&Ia(u.value)&&Ia(E)||c$(u)&&u.value===""||E===""||Array.isArray(E)&&!E.length,j=OTe.bind(null,v,r,R),V=(q,N,U,W=Tm.maxLength,G=Tm.minLength)=>{const J=q?N:U;R[v]={type:q?W:G,message:J,ref:u,...j(q?W:G,J)}};if(a?!Array.isArray(E)||!E.length:o&&(!F&&(L||rc(E))||Qf(E)&&!E||k&&!Cpe(l).isValid||$&&!Rpe(l).isValid)){const{value:q,message:N}=iD(o)?{value:!!o,message:o}:SO(o);if(q&&(R[v]={type:Tm.required,message:N,ref:C,...j(Tm.required,N)},!r))return T(N),R}if(!L&&(!rc(d)||!rc(h))){let q,N;const U=SO(h),W=SO(d);if(!rc(E)&&!isNaN(E)){const G=u.valueAsNumber||E&&+E;rc(U.value)||(q=G>U.value),rc(W.value)||(N=G<W.value)}else{const G=u.valueAsDate||new Date(E),J=M=>new Date(new Date().toDateString()+" "+M),te=u.type=="time",H=u.type=="week";O0(U.value)&&E&&(q=te?J(E)>J(U.value):H?E>U.value:G>new Date(U.value)),O0(W.value)&&E&&(N=te?J(E)<J(W.value):H?E<W.value:G<new Date(W.value))}if((q||N)&&(V(!!q,U.message,W.message,Tm.max,Tm.min),!r))return T(R[v].message),R}if((s||c)&&!L&&(O0(E)||a&&Array.isArray(E))){const q=SO(s),N=SO(c),U=!rc(q.value)&&E.length>+q.value,W=!rc(N.value)&&E.length<+N.value;if((U||W)&&(V(U,q.message,N.message),!r))return T(R[v].message),R}if(m&&!L&&O0(E)){const{value:q,message:N}=SO(m);if(d$(q)&&!E.match(q)&&(R[v]={type:Tm.pattern,message:N,ref:u,...j(Tm.pattern,N)},!r))return T(N),R}if(y){if(Kh(y)){const q=await y(E,n),N=HZ(q,C);if(N&&(R[v]={...N,...j(Tm.validate,N.message)},!r))return T(N.message),R}else if(Uu(y)){let q={};for(const N in y){if(!nc(q)&&!r)break;const U=HZ(await y[N](E,n),C,N);U&&(q={...U,...j(N,U.message)},T(U.message),r&&(R[v]=q))}if(!nc(q)&&(R[v]={ref:C,...q},!r))return R}}return T(!0),R};const TTe={mode:Zd.onSubmit,reValidateMode:Zd.onChange,shouldFocusError:!0};function kTe(e={}){let t={...TTe,...e},n={submitCount:0,isDirty:!1,isReady:!1,isLoading:Kh(t.defaultValues),isValidating:!1,isSubmitted:!1,isSubmitting:!1,isSubmitSuccessful:!1,isValid:!1,touchedFields:{},dirtyFields:{},validatingFields:{},errors:t.errors||{},disabled:t.disabled||!1},r={},i=Uu(t.defaultValues)||Uu(t.values)?Fa(t.defaultValues||t.values)||{}:{},a=t.shouldUnregister?{}:Fa(i),u={action:!1,mount:!1,watch:!1},l={mount:new Set,disabled:new Set,unMount:new Set,array:new Set,watch:new Set},o,s=0;const c={isDirty:!1,dirtyFields:!1,validatingFields:!1,touchedFields:!1,isValidating:!1,isValid:!1,errors:!1};let d={...c};const h={array:QZ(),state:QZ()},m=t.criteriaMode===Zd.all,y=Oe=>$e=>{clearTimeout(s),s=setTimeout(Oe,$e)},v=async Oe=>{if(!t.disabled&&(c.isValid||d.isValid||Oe)){const $e=t.resolver?nc((await k()).errors):await L(r,!0);$e!==n.isValid&&h.state.next({isValid:$e})}},_=(Oe,$e)=>{!t.disabled&&(c.isValidating||c.validatingFields||d.isValidating||d.validatingFields)&&((Oe||Array.from(l.mount)).forEach(Ae=>{Ae&&($e?Ki(n.validatingFields,Ae,$e):Qu(n.validatingFields,Ae))}),h.state.next({validatingFields:n.validatingFields,isValidating:!nc(n.validatingFields)}))},S=(Oe,$e=[],Ae,Ue,Ze=!0,Ye=!0)=>{if(Ue&&Ae&&!t.disabled){if(u.action=!0,Ye&&Array.isArray(jt(r,Oe))){const Me=Ae(jt(r,Oe),Ue.argA,Ue.argB);Ze&&Ki(r,Oe,Me)}if(Ye&&Array.isArray(jt(n.errors,Oe))){const Me=Ae(jt(n.errors,Oe),Ue.argA,Ue.argB);Ze&&Ki(n.errors,Oe,Me),ATe(n.errors,Oe)}if((c.touchedFields||d.touchedFields)&&Ye&&Array.isArray(jt(n.touchedFields,Oe))){const Me=Ae(jt(n.touchedFields,Oe),Ue.argA,Ue.argB);Ze&&Ki(n.touchedFields,Oe,Me)}(c.dirtyFields||d.dirtyFields)&&(n.dirtyFields=r2(i,a)),h.state.next({name:Oe,isDirty:V(Oe,$e),dirtyFields:n.dirtyFields,errors:n.errors,isValid:n.isValid})}else Ki(a,Oe,$e)},E=(Oe,$e)=>{Ki(n.errors,Oe,$e),h.state.next({errors:n.errors})},C=Oe=>{n.errors=Oe,h.state.next({errors:n.errors,isValid:!1})},T=(Oe,$e,Ae,Ue)=>{const Ze=jt(r,Oe);if(Ze){const Ye=jt(a,Oe,Ia(Ae)?jt(i,Oe):Ae);Ia(Ye)||Ue&&Ue.defaultChecked||$e?Ki(a,Oe,$e?Ye:UZ(Ze._f)):U(Oe,Ye),u.mount&&v()}},R=(Oe,$e,Ae,Ue,Ze)=>{let Ye=!1,Me=!1;const ze={name:Oe};if(!t.disabled){if(!Ae||Ue){(c.isDirty||d.isDirty)&&(Me=n.isDirty,n.isDirty=ze.isDirty=V(),Ye=Me!==ze.isDirty);const st=jm(jt(i,Oe),$e);Me=!!jt(n.dirtyFields,Oe),st?Qu(n.dirtyFields,Oe):Ki(n.dirtyFields,Oe,!0),ze.dirtyFields=n.dirtyFields,Ye=Ye||(c.dirtyFields||d.dirtyFields)&&Me!==!st}if(Ae){const st=jt(n.touchedFields,Oe);st||(Ki(n.touchedFields,Oe,Ae),ze.touchedFields=n.touchedFields,Ye=Ye||(c.touchedFields||d.touchedFields)&&st!==Ae)}Ye&&Ze&&h.state.next(ze)}return Ye?ze:{}},$=(Oe,$e,Ae,Ue)=>{const Ze=jt(n.errors,Oe),Ye=(c.isValid||d.isValid)&&Qf($e)&&n.isValid!==$e;if(t.delayError&&Ae?(o=y(()=>E(Oe,Ae)),o(t.delayError)):(clearTimeout(s),o=null,Ae?Ki(n.errors,Oe,Ae):Qu(n.errors,Oe)),(Ae?!jm(Ze,Ae):Ze)||!nc(Ue)||Ye){const Me={...Ue,...Ye&&Qf($e)?{isValid:$e}:{},errors:n.errors,name:Oe};n={...n,...Me},h.state.next(Me)}},k=async Oe=>{_(Oe,!0);const $e=await t.resolver(a,t.context,ETe(Oe||l.mount,r,t.criteriaMode,t.shouldUseNativeValidation));return _(Oe),$e},F=async Oe=>{const{errors:$e}=await k(Oe);if(Oe)for(const Ae of Oe){const Ue=jt($e,Ae);Ue?Ki(n.errors,Ae,Ue):Qu(n.errors,Ae)}else n.errors=$e;return $e},L=async(Oe,$e,Ae={valid:!0})=>{for(const Ue in Oe){const Ze=Oe[Ue];if(Ze){const{_f:Ye,...Me}=Ze;if(Ye){const ze=l.array.has(Ye.name),st=Ze._f&&DTe(Ze._f);st&&c.validatingFields&&_([Ue],!0);const Ot=await nM(Ze,l.disabled,a,m,t.shouldUseNativeValidation&&!$e,ze);if(st&&c.validatingFields&&_([Ue]),Ot[Ye.name]&&(Ae.valid=!1,$e))break;!$e&&(jt(Ot,Ye.name)?ze?Ape(n.errors,Ot,Ye.name):Ki(n.errors,Ye.name,Ot[Ye.name]):Qu(n.errors,Ye.name))}!nc(Me)&&await L(Me,$e,Ae)}}return Ae.valid},j=()=>{for(const Oe of l.unMount){const $e=jt(r,Oe);$e&&($e._f.refs?$e._f.refs.every(Ae=>!Mk(Ae)):!Mk($e._f.ref))&&de(Oe)}l.unMount=new Set},V=(Oe,$e)=>!t.disabled&&(Oe&&$e&&Ki(a,Oe,$e),!jm(M(),i)),q=(Oe,$e,Ae)=>_pe(Oe,l,{...u.mount?a:Ia($e)?i:O0(Oe)?{[Oe]:$e}:$e},Ae,$e),N=Oe=>ow(jt(u.mount?a:i,Oe,t.shouldUnregister?jt(i,Oe,[]):[])),U=(Oe,$e,Ae={})=>{const Ue=jt(r,Oe);let Ze=$e;if(Ue){const Ye=Ue._f;Ye&&(!Ye.disabled&&Ki(a,Oe,wpe($e,Ye)),Ze=c$(Ye.ref)&&rc($e)?"":$e,Epe(Ye.ref)?[...Ye.ref.options].forEach(Me=>Me.selected=Ze.includes(Me.value)):Ye.refs?SS(Ye.ref)?Ye.refs.forEach(Me=>{(!Me.defaultChecked||!Me.disabled)&&(Array.isArray(Ze)?Me.checked=!!Ze.find(ze=>ze===Me.value):Me.checked=Ze===Me.value||!!Ze)}):Ye.refs.forEach(Me=>Me.checked=Me.value===Ze):SI(Ye.ref)?Ye.ref.value="":(Ye.ref.value=Ze,Ye.ref.type||h.state.next({name:Oe,values:Fa(a)})))}(Ae.shouldDirty||Ae.shouldTouch)&&R(Oe,Ze,Ae.shouldTouch,Ae.shouldDirty,!0),Ae.shouldValidate&&H(Oe)},W=(Oe,$e,Ae)=>{for(const Ue in $e){if(!$e.hasOwnProperty(Ue))return;const Ze=$e[Ue],Ye=Oe+"."+Ue,Me=jt(r,Ye);(l.array.has(Oe)||Uu(Ze)||Me&&!Me._f)&&!L1(Ze)?W(Ye,Ze,Ae):U(Ye,Ze,Ae)}},G=(Oe,$e,Ae={})=>{const Ue=jt(r,Oe),Ze=l.array.has(Oe),Ye=Fa($e);Ki(a,Oe,Ye),Ze?(h.array.next({name:Oe,values:Fa(a)}),(c.isDirty||c.dirtyFields||d.isDirty||d.dirtyFields)&&Ae.shouldDirty&&h.state.next({name:Oe,dirtyFields:r2(i,a),isDirty:V(Oe,Ye)})):Ue&&!Ue._f&&!rc(Ye)?W(Oe,Ye,Ae):U(Oe,Ye,Ae),tM(Oe,l)&&h.state.next({...n,name:Oe}),h.state.next({name:u.mount?Oe:void 0,values:Fa(a)})},J=async Oe=>{u.mount=!0;const $e=Oe.target;let Ae=$e.name,Ue=!0;const Ze=jt(r,Ae),Ye=st=>{Ue=Number.isNaN(st)||L1(st)&&isNaN(st.getTime())||jm(st,jt(a,Ae,st))},Me=jO(t.mode),ze=jO(t.reValidateMode);if(Ze){let st,Ot;const Nt=$e.type?UZ(Ze._f):Ope(Oe),gt=Oe.type===s$.BLUR||Oe.type===s$.FOCUS_OUT,qt=!$Te(Ze._f)&&!t.resolver&&!jt(n.errors,Ae)&&!Ze._f.deps||RTe(gt,jt(n.touchedFields,Ae),n.isSubmitted,ze,Me),zt=tM(Ae,l,gt);Ki(a,Ae,Nt),gt?(!$e||!$e.readOnly)&&(Ze._f.onBlur&&Ze._f.onBlur(Oe),o&&o(0)):Ze._f.onChange&&Ze._f.onChange(Oe);const an=R(Ae,Nt,gt),rn=!nc(an)||zt;if(!gt&&h.state.next({name:Ae,type:Oe.type,values:Fa(a)}),qt)return(c.isValid||d.isValid)&&(t.mode==="onBlur"?gt&&v():gt||v()),rn&&h.state.next({name:Ae,...zt?{}:an});if(!gt&&zt&&h.state.next({...n}),t.resolver){const{errors:Fe}=await k([Ae]);if(Ye(Nt),Ue){const ht=ZZ(n.errors,r,Ae),Tt=ZZ(Fe,r,ht.name||Ae);st=Tt.error,Ae=Tt.name,Ot=nc(Fe)}}else _([Ae],!0),st=(await nM(Ze,l.disabled,a,m,t.shouldUseNativeValidation))[Ae],_([Ae]),Ye(Nt),Ue&&(st?Ot=!1:(c.isValid||d.isValid)&&(Ot=await L(r,!0)));Ue&&(Ze._f.deps&&H(Ze._f.deps),$(Ae,Ot,st,an))}},te=(Oe,$e)=>{if(jt(n.errors,$e)&&Oe.focus)return Oe.focus(),1},H=async(Oe,$e={})=>{let Ae,Ue;const Ze=uf(Oe);if(t.resolver){const Ye=await F(Ia(Oe)?Oe:Ze);Ae=nc(Ye),Ue=Oe?!Ze.some(Me=>jt(Ye,Me)):Ae}else Oe?(Ue=(await Promise.all(Ze.map(async Ye=>{const Me=jt(r,Ye);return await L(Me&&Me._f?{[Ye]:Me}:Me)}))).every(Boolean),!(!Ue&&!n.isValid)&&v()):Ue=Ae=await L(r);return h.state.next({...!O0(Oe)||(c.isValid||d.isValid)&&Ae!==n.isValid?{}:{name:Oe},...t.resolver||!Oe?{isValid:Ae}:{},errors:n.errors}),$e.shouldFocus&&!Ue&&c3(r,te,Oe?Ze:l.mount),Ue},M=Oe=>{const $e={...u.mount?a:i};return Ia(Oe)?$e:O0(Oe)?jt($e,Oe):Oe.map(Ae=>jt($e,Ae))},K=(Oe,$e)=>({invalid:!!jt(($e||n).errors,Oe),isDirty:!!jt(($e||n).dirtyFields,Oe),error:jt(($e||n).errors,Oe),isValidating:!!jt(n.validatingFields,Oe),isTouched:!!jt(($e||n).touchedFields,Oe)}),X=Oe=>{Oe&&uf(Oe).forEach($e=>Qu(n.errors,$e)),h.state.next({errors:Oe?n.errors:{}})},B=(Oe,$e,Ae)=>{const Ue=(jt(r,Oe,{_f:{}})._f||{}).ref,Ze=jt(n.errors,Oe)||{},{ref:Ye,message:Me,type:ze,...st}=Ze;Ki(n.errors,Oe,{...st,...$e,ref:Ue}),h.state.next({name:Oe,errors:n.errors,isValid:!1}),Ae&&Ae.shouldFocus&&Ue&&Ue.focus&&Ue.focus()},ne=(Oe,$e)=>Kh(Oe)?h.state.subscribe({next:Ae=>"values"in Ae&&Oe(q(void 0,$e),Ae)}):q(Oe,$e,!0),oe=Oe=>h.state.subscribe({next:$e=>{wTe(Oe.name,$e.name,Oe.exact)&&CTe($e,Oe.formState||c,Re,Oe.reRenderRoot)&&Oe.callback({values:{...a},...n,...$e,defaultValues:i})}}).unsubscribe,ie=Oe=>(u.mount=!0,d={...d,...Oe.formState},oe({...Oe,formState:d})),de=(Oe,$e={})=>{for(const Ae of Oe?uf(Oe):l.mount)l.mount.delete(Ae),l.array.delete(Ae),$e.keepValue||(Qu(r,Ae),Qu(a,Ae)),!$e.keepError&&Qu(n.errors,Ae),!$e.keepDirty&&Qu(n.dirtyFields,Ae),!$e.keepTouched&&Qu(n.touchedFields,Ae),!$e.keepIsValidating&&Qu(n.validatingFields,Ae),!t.shouldUnregister&&!$e.keepDefaultValue&&Qu(i,Ae);h.state.next({values:Fa(a)}),h.state.next({...n,...$e.keepDirty?{isDirty:V()}:{}}),!$e.keepIsValid&&v()},be=({disabled:Oe,name:$e})=>{(Qf(Oe)&&u.mount||Oe||l.disabled.has($e))&&(Oe?l.disabled.add($e):l.disabled.delete($e))},ve=(Oe,$e={})=>{let Ae=jt(r,Oe);const Ue=Qf($e.disabled)||Qf(t.disabled);return Ki(r,Oe,{...Ae||{},_f:{...Ae&&Ae._f?Ae._f:{ref:{name:Oe}},name:Oe,mount:!0,...$e}}),l.mount.add(Oe),Ae?be({disabled:Qf($e.disabled)?$e.disabled:t.disabled,name:Oe}):T(Oe,!0,$e.value),{...Ue?{disabled:$e.disabled||t.disabled}:{},...t.progressive?{required:!!$e.required,min:i2($e.min),max:i2($e.max),minLength:i2($e.minLength),maxLength:i2($e.maxLength),pattern:i2($e.pattern)}:{},name:Oe,onChange:J,onBlur:J,ref:Ze=>{if(Ze){ve(Oe,$e),Ae=jt(r,Oe);const Ye=Ia(Ze.value)&&Ze.querySelectorAll&&Ze.querySelectorAll("input,select,textarea")[0]||Ze,Me=xTe(Ye),ze=Ae._f.refs||[];if(Me?ze.find(st=>st===Ye):Ye===Ae._f.ref)return;Ki(r,Oe,{_f:{...Ae._f,...Me?{refs:[...ze.filter(Mk),Ye,...Array.isArray(jt(i,Oe))?[{}]:[]],ref:{type:Ye.type,name:Oe}}:{ref:Ye}}}),T(Oe,!1,void 0,Ye)}else Ae=jt(r,Oe,{}),Ae._f&&(Ae._f.mount=!1),(t.shouldUnregister||$e.shouldUnregister)&&!(xpe(l.array,Oe)&&u.action)&&l.unMount.add(Oe)}}},pe=()=>t.shouldFocusError&&c3(r,te,l.mount),_e=Oe=>{Qf(Oe)&&(h.state.next({disabled:Oe}),c3(r,($e,Ae)=>{const Ue=jt(r,Ae);Ue&&($e.disabled=Ue._f.disabled||Oe,Array.isArray(Ue._f.refs)&&Ue._f.refs.forEach(Ze=>{Ze.disabled=Ue._f.disabled||Oe}))},0,!1))},se=(Oe,$e)=>async Ae=>{let Ue;Ae&&(Ae.preventDefault&&Ae.preventDefault(),Ae.persist&&Ae.persist());let Ze=Fa(a);if(h.state.next({isSubmitting:!0}),t.resolver){const{errors:Ye,values:Me}=await k();n.errors=Ye,Ze=Fa(Me)}else await L(r);if(l.disabled.size)for(const Ye of l.disabled)Qu(Ze,Ye);if(Qu(n.errors,"root"),nc(n.errors)){h.state.next({errors:{}});try{await Oe(Ze,Ae)}catch(Ye){Ue=Ye}}else $e&&await $e({...n.errors},Ae),pe(),setTimeout(pe);if(h.state.next({isSubmitted:!0,isSubmitting:!1,isSubmitSuccessful:nc(n.errors)&&!Ue,submitCount:n.submitCount+1,errors:n.errors}),Ue)throw Ue},me=(Oe,$e={})=>{jt(r,Oe)&&(Ia($e.defaultValue)?G(Oe,Fa(jt(i,Oe))):(G(Oe,$e.defaultValue),Ki(i,Oe,Fa($e.defaultValue))),$e.keepTouched||Qu(n.touchedFields,Oe),$e.keepDirty||(Qu(n.dirtyFields,Oe),n.isDirty=$e.defaultValue?V(Oe,Fa(jt(i,Oe))):V()),$e.keepError||(Qu(n.errors,Oe),c.isValid&&v()),h.state.next({...n}))},ge=(Oe,$e={})=>{const Ae=Oe?Fa(Oe):i,Ue=Fa(Ae),Ze=nc(Oe),Ye=Ze?i:Ue;if($e.keepDefaultValues||(i=Ae),!$e.keepValues){if($e.keepDirtyValues){const Me=new Set([...l.mount,...Object.keys(r2(i,a))]);for(const ze of Array.from(Me))jt(n.dirtyFields,ze)?Ki(Ye,ze,jt(a,ze)):G(ze,jt(Ye,ze))}else{if(bI&&Ia(Oe))for(const Me of l.mount){const ze=jt(r,Me);if(ze&&ze._f){const st=Array.isArray(ze._f.refs)?ze._f.refs[0]:ze._f.ref;if(c$(st)){const Ot=st.closest("form");if(Ot){Ot.reset();break}}}}if($e.keepFieldsRef)for(const Me of l.mount)G(Me,jt(Ye,Me));else r={}}a=t.shouldUnregister?$e.keepDefaultValues?Fa(i):{}:Fa(Ye),h.array.next({values:{...Ye}}),h.state.next({values:{...Ye}})}l={mount:$e.keepDirtyValues?l.mount:new Set,unMount:new Set,array:new Set,disabled:new Set,watch:new Set,watchAll:!1,focus:""},u.mount=!c.isValid||!!$e.keepIsValid||!!$e.keepDirtyValues,u.watch=!!t.shouldUnregister,h.state.next({submitCount:$e.keepSubmitCount?n.submitCount:0,isDirty:Ze?!1:$e.keepDirty?n.isDirty:!!($e.keepDefaultValues&&!jm(Oe,i)),isSubmitted:$e.keepIsSubmitted?n.isSubmitted:!1,dirtyFields:Ze?{}:$e.keepDirtyValues?$e.keepDefaultValues&&a?r2(i,a):n.dirtyFields:$e.keepDefaultValues&&Oe?r2(i,Oe):$e.keepDirty?n.dirtyFields:{},touchedFields:$e.keepTouched?n.touchedFields:{},errors:$e.keepErrors?n.errors:{},isSubmitSuccessful:$e.keepIsSubmitSuccessful?n.isSubmitSuccessful:!1,isSubmitting:!1,defaultValues:i})},we=(Oe,$e)=>ge(Kh(Oe)?Oe(a):Oe,$e),Ne=(Oe,$e={})=>{const Ae=jt(r,Oe),Ue=Ae&&Ae._f;if(Ue){const Ze=Ue.refs?Ue.refs[0]:Ue.ref;Ze.focus&&(Ze.focus(),$e.shouldSelect&&Kh(Ze.select)&&Ze.select())}},Re=Oe=>{n={...n,...Oe}},tt={control:{register:ve,unregister:de,getFieldState:K,handleSubmit:se,setError:B,_subscribe:oe,_runSchema:k,_focusError:pe,_getWatch:q,_getDirty:V,_setValid:v,_setFieldArray:S,_setDisabledField:be,_setErrors:C,_getFieldArray:N,_reset:ge,_resetDefaultValues:()=>Kh(t.defaultValues)&&t.defaultValues().then(Oe=>{we(Oe,t.resetOptions),h.state.next({isLoading:!1})}),_removeUnmounted:j,_disableForm:_e,_subjects:h,_proxyFormState:c,get _fields(){return r},get _formValues(){return a},get _state(){return u},set _state(Oe){u=Oe},get _defaultValues(){return i},get _names(){return l},set _names(Oe){l=Oe},get _formState(){return n},get _options(){return t},set _options(Oe){t={...t,...Oe}}},subscribe:ie,trigger:H,register:ve,handleSubmit:se,watch:ne,setValue:G,getValues:M,reset:we,resetField:me,clearErrors:X,unregister:de,setError:B,setFocus:Ne,getFieldState:K};return{...tt,formControl:tt}}var hv=()=>{if(typeof crypto<"u"&&crypto.randomUUID)return crypto.randomUUID();const e=typeof performance>"u"?Date.now():performance.now()*1e3;return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,t=>{const n=(Math.random()*16+e)%16|0;return(t=="x"?n:n&3|8).toString(16)})},Fk=(e,t,n={})=>n.shouldFocus||Ia(n.shouldFocus)?n.focusName||`${e}.${Ia(n.focusIndex)?t:n.focusIndex}.`:"",Nk=(e,t)=>[...e,...uf(t)],Ik=e=>Array.isArray(e)?e.map(()=>{}):void 0;function Lk(e,t,n){return[...e.slice(0,t),...uf(n),...e.slice(t)]}var Bk=(e,t,n)=>Array.isArray(e)?(Ia(e[n])&&(e[n]=void 0),e.splice(n,0,e.splice(t,1)[0]),e):[],Qk=(e,t)=>[...uf(t),...uf(e)];function PTe(e,t){let n=0;const r=[...e];for(const i of t)r.splice(i-n,1),n++;return ow(r).length?r:[]}var zk=(e,t)=>Ia(t)?[]:PTe(e,uf(t).sort((n,r)=>n-r)),qk=(e,t,n)=>{[e[t],e[n]]=[e[n],e[t]]},XZ=(e,t,n)=>(e[t]=n,e);function pat(e){const t=sw(),{control:n=t.control,name:r,keyName:i="id",shouldUnregister:a,rules:u}=e,[l,o]=ye.useState(n._getFieldArray(r)),s=ye.useRef(n._getFieldArray(r).map(hv)),c=ye.useRef(l),d=ye.useRef(!1);c.current=l,n._names.array.add(r),ye.useMemo(()=>u&&n.register(r,u),[n,u,r]),cw(()=>n._subjects.array.subscribe({next:({values:R,name:$})=>{if($===r||!$){const k=jt(R,r);Array.isArray(k)&&(o(k),s.current=k.map(hv))}}}).unsubscribe,[n,r]);const h=ye.useCallback(R=>{d.current=!0,n._setFieldArray(r,R)},[n,r]),m=(R,$)=>{const k=uf(Fa(R)),F=Nk(n._getFieldArray(r),k);n._names.focus=Fk(r,F.length-1,$),s.current=Nk(s.current,k.map(hv)),h(F),o(F),n._setFieldArray(r,F,Nk,{argA:Ik(R)})},y=(R,$)=>{const k=uf(Fa(R)),F=Qk(n._getFieldArray(r),k);n._names.focus=Fk(r,0,$),s.current=Qk(s.current,k.map(hv)),h(F),o(F),n._setFieldArray(r,F,Qk,{argA:Ik(R)})},v=R=>{const $=zk(n._getFieldArray(r),R);s.current=zk(s.current,R),h($),o($),!Array.isArray(jt(n._fields,r))&&Ki(n._fields,r,void 0),n._setFieldArray(r,$,zk,{argA:R})},_=(R,$,k)=>{const F=uf(Fa($)),L=Lk(n._getFieldArray(r),R,F);n._names.focus=Fk(r,R,k),s.current=Lk(s.current,R,F.map(hv)),h(L),o(L),n._setFieldArray(r,L,Lk,{argA:R,argB:Ik($)})},S=(R,$)=>{const k=n._getFieldArray(r);qk(k,R,$),qk(s.current,R,$),h(k),o(k),n._setFieldArray(r,k,qk,{argA:R,argB:$},!1)},E=(R,$)=>{const k=n._getFieldArray(r);Bk(k,R,$),Bk(s.current,R,$),h(k),o(k),n._setFieldArray(r,k,Bk,{argA:R,argB:$},!1)},C=(R,$)=>{const k=Fa($),F=XZ(n._getFieldArray(r),R,k);s.current=[...F].map((L,j)=>!L||j===R?hv():s.current[j]),h(F),o([...F]),n._setFieldArray(r,F,XZ,{argA:R,argB:k},!0,!1)},T=R=>{const $=uf(Fa(R));s.current=$.map(hv),h([...$]),o([...$]),n._setFieldArray(r,[...$],k=>k,{},!0,!1)};return ye.useEffect(()=>{if(n._state.action=!1,tM(r,n._names)&&n._subjects.state.next({...n._formState}),d.current&&(!jO(n._options.mode).isOnSubmit||n._formState.isSubmitted)&&!jO(n._options.reValidateMode).isOnSubmit)if(n._options.resolver)n._runSchema([r]).then(R=>{const $=jt(R.errors,r),k=jt(n._formState.errors,r);(k?!$&&k.type||$&&(k.type!==$.type||k.message!==$.message):$&&$.type)&&($?Ki(n._formState.errors,r,$):Qu(n._formState.errors,r),n._subjects.state.next({errors:n._formState.errors}))});else{const R=jt(n._fields,r);R&&R._f&&!(jO(n._options.reValidateMode).isOnSubmit&&jO(n._options.mode).isOnSubmit)&&nM(R,n._names.disabled,n._formValues,n._options.criteriaMode===Zd.all,n._options.shouldUseNativeValidation,!0).then($=>!nc($)&&n._subjects.state.next({errors:Ape(n._formState.errors,$,r)}))}n._subjects.state.next({name:r,values:Fa(n._formValues)}),n._names.focus&&c3(n._fields,(R,$)=>{if(n._names.focus&&$.startsWith(n._names.focus)&&R.focus)return R.focus(),1}),n._names.focus="",n._setValid(),d.current=!1},[l,r,n]),ye.useEffect(()=>(!jt(n._formValues,r)&&n._setFieldArray(r),()=>{const R=($,k)=>{const F=jt(n._fields,$);F&&F._f&&(F._f.mount=k)};n._options.shouldUnregister||a?n.unregister(r):R(r,!1)}),[r,n,i,a]),{swap:ye.useCallback(S,[h,r,n]),move:ye.useCallback(E,[h,r,n]),prepend:ye.useCallback(y,[h,r,n]),append:ye.useCallback(m,[h,r,n]),remove:ye.useCallback(v,[h,r,n]),insert:ye.useCallback(_,[h,r,n]),update:ye.useCallback(C,[h,r,n]),replace:ye.useCallback(T,[h,r,n]),fields:ye.useMemo(()=>l.map((R,$)=>({...R,[i]:s.current[$]||hv()})),[l,i])}}function mat(e={}){const t=ye.useRef(void 0),n=ye.useRef(void 0),[r,i]=ye.useState({isDirty:!1,isValidating:!1,isLoading:Kh(e.defaultValues),isSubmitted:!1,isSubmitting:!1,isSubmitSuccessful:!1,isValid:!1,submitCount:0,dirtyFields:{},touchedFields:{},validatingFields:{},errors:e.errors||{},disabled:e.disabled||!1,isReady:!1,defaultValues:Kh(e.defaultValues)?void 0:e.defaultValues});if(!t.current)if(e.formControl)t.current={...e.formControl,formState:r},e.defaultValues&&!Kh(e.defaultValues)&&e.formControl.reset(e.defaultValues,e.resetOptions);else{const{formControl:u,...l}=kTe(e);t.current={...l,formState:r}}const a=t.current.control;return a._options=e,cw(()=>{const u=a._subscribe({formState:a._proxyFormState,callback:()=>i({...a._formState}),reRenderRoot:!0});return i(l=>({...l,isReady:!0})),a._formState.isReady=!0,u},[a]),ye.useEffect(()=>a._disableForm(e.disabled),[a,e.disabled]),ye.useEffect(()=>{e.mode&&(a._options.mode=e.mode),e.reValidateMode&&(a._options.reValidateMode=e.reValidateMode)},[a,e.mode,e.reValidateMode]),ye.useEffect(()=>{e.errors&&(a._setErrors(e.errors),a._focusError())},[a,e.errors]),ye.useEffect(()=>{e.shouldUnregister&&a._subjects.state.next({values:a._getWatch()})},[a,e.shouldUnregister]),ye.useEffect(()=>{if(a._proxyFormState.isDirty){const u=a._getDirty();u!==r.isDirty&&a._subjects.state.next({isDirty:u})}},[a,r.isDirty]),ye.useEffect(()=>{e.values&&!jm(e.values,n.current)?(a._reset(e.values,{keepFieldsRef:!0,...a._options.resetOptions}),n.current=e.values,i(u=>({...u}))):a._resetDefaultValues()},[a,e.values]),ye.useEffect(()=>{a._state.mount||(a._setValid(),a._state.mount=!0),a._state.watch&&(a._state.watch=!1,a._subjects.state.next({...a._formState})),a._removeUnmounted()}),t.current.formState=Spe(r,a),t.current}var MTe=ei(),Vk="Invariant Violation",YZ=Object.setPrototypeOf,FTe=YZ===void 0?function(e,t){return e.__proto__=t,e}:YZ,Tpe=(function(e){qte(t,e);function t(n){n===void 0&&(n=Vk);var r=e.call(this,typeof n=="number"?Vk+": "+n+" (see https://github.com/apollographql/invariant-packages)":n)||this;return r.framesToPop=1,r.name=Vk,FTe(r,t.prototype),r}return t})(Error);function P1(e,t){if(!e)throw new Tpe(t)}var kpe=["debug","log","warn","error","silent"],NTe=kpe.indexOf("log");function Y_(e){return function(){if(kpe.indexOf(e)>=NTe){var t=console[e]||console.log;return t.apply(console,arguments)}}}(function(e){e.debug=Y_("debug"),e.log=Y_("log"),e.warn=Y_("warn"),e.error=Y_("error")})(P1||(P1={}));var Ppe="3.13.9";function Gh(e){try{return e()}catch{}}const GZ=Gh(function(){return globalThis})||Gh(function(){return window})||Gh(function(){return self})||Gh(function(){return global})||Gh(function(){return Gh.constructor("return this")()});var KZ=new Map;function ITe(e){var t=KZ.get(e)||1;return KZ.set(e,t+1),"".concat(e,":").concat(t,":").concat(Math.random().toString(36).slice(2))}function LTe(e,t){var n=ITe("stringifyForDisplay");return JSON.stringify(e,function(r,i){return i===void 0?n:i},t).split(JSON.stringify(n)).join("<undefined>")}function G_(e){return function(t){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];if(typeof t=="number"){var i=t;t=EI(i),t||(t=DI(i,n),n=[])}e.apply(void 0,[t].concat(n))}}Object.assign(function(t,n){for(var r=[],i=2;i<arguments.length;i++)r[i-2]=arguments[i];t||P1(t,EI(n,r)||DI(n,r))},{debug:G_(P1.debug),log:G_(P1.log),warn:G_(P1.warn),error:G_(P1.error)});function BTe(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return new Tpe(EI(e,t)||DI(e,t))}var WZ=Symbol.for("ApolloErrorMessageHandler_"+Ppe);function Mpe(e){if(typeof e=="string")return e;try{return LTe(e,2).slice(0,1e3)}catch{return"<non-serializable>"}}function EI(e,t){if(t===void 0&&(t=[]),!!e)return GZ[WZ]&&GZ[WZ](e,t.map(Mpe))}function DI(e,t){if(t===void 0&&(t=[]),!!e)return"An error occurred! For more details, see the full error text at https://go.apollo.dev/c/err#".concat(encodeURIComponent(JSON.stringify({version:Ppe,message:e,args:t.map(Mpe)})))}Gh(function(){return navigator.product})=="ReactNative";var QTe=typeof Symbol=="function"&&typeof Symbol.for=="function",fw=QTe&&Symbol.asyncIterator;Gh(function(){return window.document.createElement});Gh(function(){return navigator.userAgent.indexOf("jsdom")>=0});function Fpe(e){return e!==null&&typeof e=="object"}function zTe(e){return Fpe(e)&&"payload"in e}function qTe(e){var t,n=e[Symbol.asyncIterator]();return t={next:function(){return n.next()}},t[Symbol.asyncIterator]=function(){return this},t}function VTe(e){var t=null,n=null,r=!1,i=[],a=[];function u(d){if(!n){if(a.length){var h=a.shift();if(Array.isArray(h)&&h[0])return h[0]({value:d,done:!1})}i.push(d)}}function l(d){n=d;var h=a.slice();h.forEach(function(m){m[1](d)}),!t||t()}function o(){r=!0;var d=a.slice();d.forEach(function(h){h[0]({value:void 0,done:!0})}),!t||t()}t=function(){t=null,e.removeListener("data",u),e.removeListener("error",l),e.removeListener("end",o),e.removeListener("finish",o),e.removeListener("close",o)},e.on("data",u),e.on("error",l),e.on("end",o),e.on("finish",o),e.on("close",o);function s(){return new Promise(function(d,h){if(n)return h(n);if(i.length)return d({value:i.shift(),done:!1});if(r)return d({value:void 0,done:!0});a.push([d,h])})}var c={next:function(){return s()}};return fw&&(c[Symbol.asyncIterator]=function(){return this}),c}function UTe(e){var t=!1,n={next:function(){return t?Promise.resolve({value:void 0,done:!0}):(t=!0,new Promise(function(r,i){e.then(function(a){r({value:a,done:!1})}).catch(i)}))}};return fw&&(n[Symbol.asyncIterator]=function(){return this}),n}function JZ(e){var t={next:function(){return e.read()}};return fw&&(t[Symbol.asyncIterator]=function(){return this}),t}function jTe(e){return!!e.body}function ZTe(e){return!!e.getReader}function HTe(e){return!!(fw&&e[Symbol.asyncIterator])}function XTe(e){return!!e.stream}function YTe(e){return!!e.arrayBuffer}function GTe(e){return!!e.pipe}function KTe(e){var t=e;if(jTe(e)&&(t=e.body),HTe(t))return qTe(t);if(ZTe(t))return JZ(t.getReader());if(XTe(t))return JZ(t.stream().getReader());if(YTe(t))return UTe(t.arrayBuffer());if(GTe(t))return VTe(t);throw new Error("Unknown body type for responseIterator. Please pass a streamable response.")}var WTe=function(e,t,n){var r=new Error(n);throw r.name="ServerError",r.response=e,r.statusCode=e.status,r.result=t,r},JTe=Symbol(),eke=function(e){var t=r3(r3(r3([],e.graphQLErrors,!0),e.clientErrors,!0),e.protocolErrors,!0);return e.networkError&&t.push(e.networkError),t.map(function(n){return Fpe(n)&&n.message||"Error message not found."}).join(`
`)};(function(e){qte(t,e);function t(n){var r=n.graphQLErrors,i=n.protocolErrors,a=n.clientErrors,u=n.networkError,l=n.errorMessage,o=n.extraInfo,s=e.call(this,l)||this;return s.name="ApolloError",s.graphQLErrors=r||[],s.protocolErrors=i||[],s.clientErrors=a||[],s.networkError=u||null,s.message=l||eke(s),s.extraInfo=o,s.cause=r3(r3(r3([u],r||[],!0),i||[],!0),a||[],!0).find(function(c){return!!c})||null,s.__proto__=t.prototype,s}return t})(Error);function tke(e,t){return C_e(this,void 0,void 0,function(){var n,r,i,a,u,l,o,s,c,d,h,m,y,v,_,S,E,C,T,R,$,k,F,L;return w_e(this,function(j){switch(j.label){case 0:if(TextDecoder===void 0)throw new Error("TextDecoder must be defined in the environment: please import a polyfill.");n=new TextDecoder("utf-8"),r=(L=e.headers)===null||L===void 0?void 0:L.get("content-type"),i="boundary=",a=r!=null&&r.includes(i)?r==null?void 0:r.substring((r==null?void 0:r.indexOf(i))+i.length).replace(/['"]/g,"").replace(/\;(.*)/gm,"").trim():"-",u=`\r
--`.concat(a),l="",o=KTe(e),s=!0,j.label=1;case 1:return s?[4,o.next()]:[3,3];case 2:for(c=j.sent(),d=c.value,h=c.done,m=typeof d=="string"?d:n.decode(d),y=l.length-u.length+1,s=!h,l+=m,v=l.indexOf(u,y);v>-1;){if(_=void 0,k=[l.slice(0,v),l.slice(v+u.length)],_=k[0],l=k[1],S=_.indexOf(`\r
\r
`),E=nke(_.slice(0,S)),C=E["content-type"],C&&C.toLowerCase().indexOf("application/json")===-1)throw new Error("Unsupported patch content type: application/json is required.");if(T=_.slice(S),T){if(R=rke(e,T),Object.keys(R).length>1||"data"in R||"incremental"in R||"errors"in R||"payload"in R)if(zTe(R)){if($={},"payload"in R){if(Object.keys(R).length===1&&R.payload===null)return[2];$=jd({},R.payload)}"errors"in R&&($=jd(jd({},$),{extensions:jd(jd({},"extensions"in $?$.extensions:null),(F={},F[JTe]=R.errors,F))})),t($)}else t(R);else if(Object.keys(R).length===1&&"hasNext"in R&&!R.hasNext)return[2]}v=l.indexOf(u)}return[3,1];case 3:return[2]}})})}function nke(e){var t={};return e.split(`
`).forEach(function(n){var r=n.indexOf(":");if(r>-1){var i=n.slice(0,r).trim().toLowerCase(),a=n.slice(r+1).trim();t[i]=a}}),t}function rke(e,t){if(e.status>=300){var n=function(){try{return JSON.parse(t)}catch{return t}};WTe(e,n(),"Response not successful: Received status code ".concat(e.status))}try{return JSON.parse(t)}catch(i){var r=i;throw r.name="ServerParseError",r.response=e,r.statusCode=e.status,r.bodyText=t,r}}function ike(e,t){e.result&&e.result.errors&&e.result.data&&t.next(e.result),t.error(e)}var ake=function(e,t){var n;try{n=JSON.stringify(e)}catch(i){var r=BTe(42,t,i.message);throw r.parseError=i,r}return n},uke={accept:"*/*","content-type":"application/json"},lke={method:"POST"},eH={headers:uke,options:lke};function oke(e){var t=jd(jd({},eH.options),{headers:jd(jd(jd({},e||{}),eH.headers),{accept:"multipart/mixed;boundary=graphql;subscriptionSpec=1.0,application/json"})});return t}var ske=Gh(function(){return fetch});function gat(e,t){var n=t===void 0?{}:t,r=n.fetch,i=n.headers;return function(u,l){var o={operationName:u.name,variables:l,query:u.text||""},s=oke(i||{});return MTe.Observable.create(function(c){try{s.body=ake(o,"Payload")}catch(m){c.error(m)}var d=r||Gh(function(){return fetch})||ske,h=c.next.bind(c);d(e,s).then(function(m){var y,v=(y=m.headers)===null||y===void 0?void 0:y.get("content-type");if(v!==null&&/^multipart\/mixed/i.test(v))return tke(m,h);c.error(new Error("Expected multipart response"))}).then(function(){c.complete()}).catch(function(m){ike(m,c)})})}}var cke="Invariant failed";function vat(e,t){if(!e)throw new Error(cke)}const fke="modulepreload",dke=function(e){return"/"+e},tH={},yat=function(t,n,r){let i=Promise.resolve();if(n&&n.length>0){let u=function(s){return Promise.all(s.map(c=>Promise.resolve(c).then(d=>({status:"fulfilled",value:d}),d=>({status:"rejected",reason:d}))))};document.getElementsByTagName("link");const l=document.querySelector("meta[property=csp-nonce]"),o=(l==null?void 0:l.nonce)||(l==null?void 0:l.getAttribute("nonce"));i=u(n.map(s=>{if(s=dke(s),s in tH)return;tH[s]=!0;const c=s.endsWith(".css"),d=c?'[rel="stylesheet"]':"";if(document.querySelector(`link[href="${s}"]${d}`))return;const h=document.createElement("link");if(h.rel=c?"stylesheet":fke,c||(h.as="script"),h.crossOrigin="",h.href=s,o&&h.setAttribute("nonce",o),document.head.appendChild(h),c)return new Promise((m,y)=>{h.addEventListener("load",m),h.addEventListener("error",()=>y(new Error(`Unable to preload CSS for ${s}`)))})}))}function a(u){const l=new Event("vite:preloadError",{cancelable:!0});if(l.payload=u,window.dispatchEvent(l),!l.defaultPrevented)throw u}return i.then(u=>{for(const l of u||[])l.status==="rejected"&&a(l.reason);return t().catch(a)})};function bat(e){return P.createElement(K6e,{flushSync:Vf.flushSync,...e})}/**
   * table-core
   *
   * Copyright (c) TanStack
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE.md file in the root directory of this source tree.
   *
   * @license MIT
   */function Oat(){return{accessor:(e,t)=>typeof e=="function"?{...t,accessorFn:e}:{...t,accessorKey:e},display:e=>e,group:e=>e}}function Lv(e,t){return typeof e=="function"?e(t):e}function Xf(e,t){return n=>{t.setState(r=>({...r,[e]:Lv(n,r[e])}))}}function dw(e){return e instanceof Function}function hke(e){return Array.isArray(e)&&e.every(t=>typeof t=="number")}function pke(e,t){const n=[],r=i=>{i.forEach(a=>{n.push(a);const u=t(a);u!=null&&u.length&&r(u)})};return r(e),n}function Fn(e,t,n){let r=[],i;return a=>{let u;n.key&&n.debug&&(u=Date.now());const l=e(a);if(!(l.length!==r.length||l.some((c,d)=>r[d]!==c)))return i;r=l;let s;if(n.key&&n.debug&&(s=Date.now()),i=t(...l),n==null||n.onChange==null||n.onChange(i),n.key&&n.debug&&n!=null&&n.debug()){const c=Math.round((Date.now()-u)*100)/100,d=Math.round((Date.now()-s)*100)/100,h=d/16,m=(y,v)=>{for(y=String(y);y.length<v;)y=" "+y;return y};console.info(`%c⏱ ${m(d,5)} /${m(c,5)} ms`,`
            font-size: .6rem;
            font-weight: bold;
            color: hsl(${Math.max(0,Math.min(120-120*h,120))}deg 100% 31%);`,n==null?void 0:n.key)}return i}}function Nn(e,t,n,r){return{debug:()=>{var i;return(i=e==null?void 0:e.debugAll)!=null?i:e[t]},key:!1,onChange:r}}function mke(e,t,n,r){const i=()=>{var u;return(u=a.getValue())!=null?u:e.options.renderFallbackValue},a={id:`${t.id}_${n.id}`,row:t,column:n,getValue:()=>t.getValue(r),renderValue:i,getContext:Fn(()=>[e,n,t,a],(u,l,o,s)=>({table:u,column:l,row:o,cell:s,getValue:s.getValue,renderValue:s.renderValue}),Nn(e.options,"debugCells"))};return e._features.forEach(u=>{u.createCell==null||u.createCell(a,n,t,e)},{}),a}function gke(e,t,n,r){var i,a;const l={...e._getDefaultColumnDef(),...t},o=l.accessorKey;let s=(i=(a=l.id)!=null?a:o?typeof String.prototype.replaceAll=="function"?o.replaceAll(".","_"):o.replace(/\./g,"_"):void 0)!=null?i:typeof l.header=="string"?l.header:void 0,c;if(l.accessorFn?c=l.accessorFn:o&&(o.includes(".")?c=h=>{let m=h;for(const v of o.split(".")){var y;m=(y=m)==null?void 0:y[v]}return m}:c=h=>h[l.accessorKey]),!s)throw new Error;let d={id:`${String(s)}`,accessorFn:c,parent:r,depth:n,columnDef:l,columns:[],getFlatColumns:Fn(()=>[!0],()=>{var h;return[d,...(h=d.columns)==null?void 0:h.flatMap(m=>m.getFlatColumns())]},Nn(e.options,"debugColumns")),getLeafColumns:Fn(()=>[e._getOrderColumnsFn()],h=>{var m;if((m=d.columns)!=null&&m.length){let y=d.columns.flatMap(v=>v.getLeafColumns());return h(y)}return[d]},Nn(e.options,"debugColumns"))};for(const h of e._features)h.createColumn==null||h.createColumn(d,e);return d}const fs="debugHeaders";function nH(e,t,n){var r;let a={id:(r=n.id)!=null?r:t.id,column:t,index:n.index,isPlaceholder:!!n.isPlaceholder,placeholderId:n.placeholderId,depth:n.depth,subHeaders:[],colSpan:0,rowSpan:0,headerGroup:null,getLeafHeaders:()=>{const u=[],l=o=>{o.subHeaders&&o.subHeaders.length&&o.subHeaders.map(l),u.push(o)};return l(a),u},getContext:()=>({table:e,header:a,column:t})};return e._features.forEach(u=>{u.createHeader==null||u.createHeader(a,e)}),a}const vke={createTable:e=>{e.getHeaderGroups=Fn(()=>[e.getAllColumns(),e.getVisibleLeafColumns(),e.getState().columnPinning.left,e.getState().columnPinning.right],(t,n,r,i)=>{var a,u;const l=(a=r==null?void 0:r.map(d=>n.find(h=>h.id===d)).filter(Boolean))!=null?a:[],o=(u=i==null?void 0:i.map(d=>n.find(h=>h.id===d)).filter(Boolean))!=null?u:[],s=n.filter(d=>!(r!=null&&r.includes(d.id))&&!(i!=null&&i.includes(d.id)));return K_(t,[...l,...s,...o],e)},Nn(e.options,fs)),e.getCenterHeaderGroups=Fn(()=>[e.getAllColumns(),e.getVisibleLeafColumns(),e.getState().columnPinning.left,e.getState().columnPinning.right],(t,n,r,i)=>(n=n.filter(a=>!(r!=null&&r.includes(a.id))&&!(i!=null&&i.includes(a.id))),K_(t,n,e,"center")),Nn(e.options,fs)),e.getLeftHeaderGroups=Fn(()=>[e.getAllColumns(),e.getVisibleLeafColumns(),e.getState().columnPinning.left],(t,n,r)=>{var i;const a=(i=r==null?void 0:r.map(u=>n.find(l=>l.id===u)).filter(Boolean))!=null?i:[];return K_(t,a,e,"left")},Nn(e.options,fs)),e.getRightHeaderGroups=Fn(()=>[e.getAllColumns(),e.getVisibleLeafColumns(),e.getState().columnPinning.right],(t,n,r)=>{var i;const a=(i=r==null?void 0:r.map(u=>n.find(l=>l.id===u)).filter(Boolean))!=null?i:[];return K_(t,a,e,"right")},Nn(e.options,fs)),e.getFooterGroups=Fn(()=>[e.getHeaderGroups()],t=>[...t].reverse(),Nn(e.options,fs)),e.getLeftFooterGroups=Fn(()=>[e.getLeftHeaderGroups()],t=>[...t].reverse(),Nn(e.options,fs)),e.getCenterFooterGroups=Fn(()=>[e.getCenterHeaderGroups()],t=>[...t].reverse(),Nn(e.options,fs)),e.getRightFooterGroups=Fn(()=>[e.getRightHeaderGroups()],t=>[...t].reverse(),Nn(e.options,fs)),e.getFlatHeaders=Fn(()=>[e.getHeaderGroups()],t=>t.map(n=>n.headers).flat(),Nn(e.options,fs)),e.getLeftFlatHeaders=Fn(()=>[e.getLeftHeaderGroups()],t=>t.map(n=>n.headers).flat(),Nn(e.options,fs)),e.getCenterFlatHeaders=Fn(()=>[e.getCenterHeaderGroups()],t=>t.map(n=>n.headers).flat(),Nn(e.options,fs)),e.getRightFlatHeaders=Fn(()=>[e.getRightHeaderGroups()],t=>t.map(n=>n.headers).flat(),Nn(e.options,fs)),e.getCenterLeafHeaders=Fn(()=>[e.getCenterFlatHeaders()],t=>t.filter(n=>{var r;return!((r=n.subHeaders)!=null&&r.length)}),Nn(e.options,fs)),e.getLeftLeafHeaders=Fn(()=>[e.getLeftFlatHeaders()],t=>t.filter(n=>{var r;return!((r=n.subHeaders)!=null&&r.length)}),Nn(e.options,fs)),e.getRightLeafHeaders=Fn(()=>[e.getRightFlatHeaders()],t=>t.filter(n=>{var r;return!((r=n.subHeaders)!=null&&r.length)}),Nn(e.options,fs)),e.getLeafHeaders=Fn(()=>[e.getLeftHeaderGroups(),e.getCenterHeaderGroups(),e.getRightHeaderGroups()],(t,n,r)=>{var i,a,u,l,o,s;return[...(i=(a=t[0])==null?void 0:a.headers)!=null?i:[],...(u=(l=n[0])==null?void 0:l.headers)!=null?u:[],...(o=(s=r[0])==null?void 0:s.headers)!=null?o:[]].map(c=>c.getLeafHeaders()).flat()},Nn(e.options,fs))}};function K_(e,t,n,r){var i,a;let u=0;const l=function(h,m){m===void 0&&(m=1),u=Math.max(u,m),h.filter(y=>y.getIsVisible()).forEach(y=>{var v;(v=y.columns)!=null&&v.length&&l(y.columns,m+1)},0)};l(e);let o=[];const s=(h,m)=>{const y={depth:m,id:[r,`${m}`].filter(Boolean).join("_"),headers:[]},v=[];h.forEach(_=>{const S=[...v].reverse()[0],E=_.column.depth===y.depth;let C,T=!1;if(E&&_.column.parent?C=_.column.parent:(C=_.column,T=!0),S&&(S==null?void 0:S.column)===C)S.subHeaders.push(_);else{const R=nH(n,C,{id:[r,m,C.id,_==null?void 0:_.id].filter(Boolean).join("_"),isPlaceholder:T,placeholderId:T?`${v.filter($=>$.column===C).length}`:void 0,depth:m,index:v.length});R.subHeaders.push(_),v.push(R)}y.headers.push(_),_.headerGroup=y}),o.push(y),m>0&&s(v,m-1)},c=t.map((h,m)=>nH(n,h,{depth:u,index:m}));s(c,u-1),o.reverse();const d=h=>h.filter(y=>y.column.getIsVisible()).map(y=>{let v=0,_=0,S=[0];y.subHeaders&&y.subHeaders.length?(S=[],d(y.subHeaders).forEach(C=>{let{colSpan:T,rowSpan:R}=C;v+=T,S.push(R)})):v=1;const E=Math.min(...S);return _=_+E,y.colSpan=v,y.rowSpan=_,{colSpan:v,rowSpan:_}});return d((i=(a=o[0])==null?void 0:a.headers)!=null?i:[]),o}const $I=(e,t,n,r,i,a,u)=>{let l={id:t,index:r,original:n,depth:i,parentId:u,_valuesCache:{},_uniqueValuesCache:{},getValue:o=>{if(l._valuesCache.hasOwnProperty(o))return l._valuesCache[o];const s=e.getColumn(o);if(s!=null&&s.accessorFn)return l._valuesCache[o]=s.accessorFn(l.original,r),l._valuesCache[o]},getUniqueValues:o=>{if(l._uniqueValuesCache.hasOwnProperty(o))return l._uniqueValuesCache[o];const s=e.getColumn(o);if(s!=null&&s.accessorFn)return s.columnDef.getUniqueValues?(l._uniqueValuesCache[o]=s.columnDef.getUniqueValues(l.original,r),l._uniqueValuesCache[o]):(l._uniqueValuesCache[o]=[l.getValue(o)],l._uniqueValuesCache[o])},renderValue:o=>{var s;return(s=l.getValue(o))!=null?s:e.options.renderFallbackValue},subRows:[],getLeafRows:()=>pke(l.subRows,o=>o.subRows),getParentRow:()=>l.parentId?e.getRow(l.parentId,!0):void 0,getParentRows:()=>{let o=[],s=l;for(;;){const c=s.getParentRow();if(!c)break;o.push(c),s=c}return o.reverse()},getAllCells:Fn(()=>[e.getAllLeafColumns()],o=>o.map(s=>mke(e,l,s,s.id)),Nn(e.options,"debugRows")),_getAllCellsByColumnId:Fn(()=>[l.getAllCells()],o=>o.reduce((s,c)=>(s[c.column.id]=c,s),{}),Nn(e.options,"debugRows"))};for(let o=0;o<e._features.length;o++){const s=e._features[o];s==null||s.createRow==null||s.createRow(l,e)}return l},yke={createColumn:(e,t)=>{e._getFacetedRowModel=t.options.getFacetedRowModel&&t.options.getFacetedRowModel(t,e.id),e.getFacetedRowModel=()=>e._getFacetedRowModel?e._getFacetedRowModel():t.getPreFilteredRowModel(),e._getFacetedUniqueValues=t.options.getFacetedUniqueValues&&t.options.getFacetedUniqueValues(t,e.id),e.getFacetedUniqueValues=()=>e._getFacetedUniqueValues?e._getFacetedUniqueValues():new Map,e._getFacetedMinMaxValues=t.options.getFacetedMinMaxValues&&t.options.getFacetedMinMaxValues(t,e.id),e.getFacetedMinMaxValues=()=>{if(e._getFacetedMinMaxValues)return e._getFacetedMinMaxValues()}}},Npe=(e,t,n)=>{var r,i;const a=n==null||(r=n.toString())==null?void 0:r.toLowerCase();return!!(!((i=e.getValue(t))==null||(i=i.toString())==null||(i=i.toLowerCase())==null)&&i.includes(a))};Npe.autoRemove=e=>np(e);const Ipe=(e,t,n)=>{var r;return!!(!((r=e.getValue(t))==null||(r=r.toString())==null)&&r.includes(n))};Ipe.autoRemove=e=>np(e);const Lpe=(e,t,n)=>{var r;return((r=e.getValue(t))==null||(r=r.toString())==null?void 0:r.toLowerCase())===(n==null?void 0:n.toLowerCase())};Lpe.autoRemove=e=>np(e);const Bpe=(e,t,n)=>{var r;return(r=e.getValue(t))==null?void 0:r.includes(n)};Bpe.autoRemove=e=>np(e);const Qpe=(e,t,n)=>!n.some(r=>{var i;return!((i=e.getValue(t))!=null&&i.includes(r))});Qpe.autoRemove=e=>np(e)||!(e!=null&&e.length);const zpe=(e,t,n)=>n.some(r=>{var i;return(i=e.getValue(t))==null?void 0:i.includes(r)});zpe.autoRemove=e=>np(e)||!(e!=null&&e.length);const qpe=(e,t,n)=>e.getValue(t)===n;qpe.autoRemove=e=>np(e);const Vpe=(e,t,n)=>e.getValue(t)==n;Vpe.autoRemove=e=>np(e);const CI=(e,t,n)=>{let[r,i]=n;const a=e.getValue(t);return a>=r&&a<=i};CI.resolveFilterValue=e=>{let[t,n]=e,r=typeof t!="number"?parseFloat(t):t,i=typeof n!="number"?parseFloat(n):n,a=t===null||Number.isNaN(r)?-1/0:r,u=n===null||Number.isNaN(i)?1/0:i;if(a>u){const l=a;a=u,u=l}return[a,u]};CI.autoRemove=e=>np(e)||np(e[0])&&np(e[1]);const Bm={includesString:Npe,includesStringSensitive:Ipe,equalsString:Lpe,arrIncludes:Bpe,arrIncludesAll:Qpe,arrIncludesSome:zpe,equals:qpe,weakEquals:Vpe,inNumberRange:CI};function np(e){return e==null||e===""}const bke={getDefaultColumnDef:()=>({filterFn:"auto"}),getInitialState:e=>({columnFilters:[],...e}),getDefaultOptions:e=>({onColumnFiltersChange:Xf("columnFilters",e),filterFromLeafRows:!1,maxLeafRowFilterDepth:100}),createColumn:(e,t)=>{e.getAutoFilterFn=()=>{const n=t.getCoreRowModel().flatRows[0],r=n==null?void 0:n.getValue(e.id);return typeof r=="string"?Bm.includesString:typeof r=="number"?Bm.inNumberRange:typeof r=="boolean"||r!==null&&typeof r=="object"?Bm.equals:Array.isArray(r)?Bm.arrIncludes:Bm.weakEquals},e.getFilterFn=()=>{var n,r;return dw(e.columnDef.filterFn)?e.columnDef.filterFn:e.columnDef.filterFn==="auto"?e.getAutoFilterFn():(n=(r=t.options.filterFns)==null?void 0:r[e.columnDef.filterFn])!=null?n:Bm[e.columnDef.filterFn]},e.getCanFilter=()=>{var n,r,i;return((n=e.columnDef.enableColumnFilter)!=null?n:!0)&&((r=t.options.enableColumnFilters)!=null?r:!0)&&((i=t.options.enableFilters)!=null?i:!0)&&!!e.accessorFn},e.getIsFiltered=()=>e.getFilterIndex()>-1,e.getFilterValue=()=>{var n;return(n=t.getState().columnFilters)==null||(n=n.find(r=>r.id===e.id))==null?void 0:n.value},e.getFilterIndex=()=>{var n,r;return(n=(r=t.getState().columnFilters)==null?void 0:r.findIndex(i=>i.id===e.id))!=null?n:-1},e.setFilterValue=n=>{t.setColumnFilters(r=>{const i=e.getFilterFn(),a=r==null?void 0:r.find(c=>c.id===e.id),u=Lv(n,a?a.value:void 0);if(rH(i,u,e)){var l;return(l=r==null?void 0:r.filter(c=>c.id!==e.id))!=null?l:[]}const o={id:e.id,value:u};if(a){var s;return(s=r==null?void 0:r.map(c=>c.id===e.id?o:c))!=null?s:[]}return r!=null&&r.length?[...r,o]:[o]})}},createRow:(e,t)=>{e.columnFilters={},e.columnFiltersMeta={}},createTable:e=>{e.setColumnFilters=t=>{const n=e.getAllLeafColumns(),r=i=>{var a;return(a=Lv(t,i))==null?void 0:a.filter(u=>{const l=n.find(o=>o.id===u.id);if(l){const o=l.getFilterFn();if(rH(o,u.value,l))return!1}return!0})};e.options.onColumnFiltersChange==null||e.options.onColumnFiltersChange(r)},e.resetColumnFilters=t=>{var n,r;e.setColumnFilters(t?[]:(n=(r=e.initialState)==null?void 0:r.columnFilters)!=null?n:[])},e.getPreFilteredRowModel=()=>e.getCoreRowModel(),e.getFilteredRowModel=()=>(!e._getFilteredRowModel&&e.options.getFilteredRowModel&&(e._getFilteredRowModel=e.options.getFilteredRowModel(e)),e.options.manualFiltering||!e._getFilteredRowModel?e.getPreFilteredRowModel():e._getFilteredRowModel())}};function rH(e,t,n){return(e&&e.autoRemove?e.autoRemove(t,n):!1)||typeof t>"u"||typeof t=="string"&&!t}const Oke=(e,t,n)=>n.reduce((r,i)=>{const a=i.getValue(e);return r+(typeof a=="number"?a:0)},0),xke=(e,t,n)=>{let r;return n.forEach(i=>{const a=i.getValue(e);a!=null&&(r>a||r===void 0&&a>=a)&&(r=a)}),r},Ske=(e,t,n)=>{let r;return n.forEach(i=>{const a=i.getValue(e);a!=null&&(r<a||r===void 0&&a>=a)&&(r=a)}),r},_ke=(e,t,n)=>{let r,i;return n.forEach(a=>{const u=a.getValue(e);u!=null&&(r===void 0?u>=u&&(r=i=u):(r>u&&(r=u),i<u&&(i=u)))}),[r,i]},Eke=(e,t)=>{let n=0,r=0;if(t.forEach(i=>{let a=i.getValue(e);a!=null&&(a=+a)>=a&&(++n,r+=a)}),n)return r/n},Dke=(e,t)=>{if(!t.length)return;const n=t.map(a=>a.getValue(e));if(!hke(n))return;if(n.length===1)return n[0];const r=Math.floor(n.length/2),i=n.sort((a,u)=>a-u);return n.length%2!==0?i[r]:(i[r-1]+i[r])/2},$ke=(e,t)=>Array.from(new Set(t.map(n=>n.getValue(e))).values()),Cke=(e,t)=>new Set(t.map(n=>n.getValue(e))).size,wke=(e,t)=>t.length,Uk={sum:Oke,min:xke,max:Ske,extent:_ke,mean:Eke,median:Dke,unique:$ke,uniqueCount:Cke,count:wke},Rke={getDefaultColumnDef:()=>({aggregatedCell:e=>{var t,n;return(t=(n=e.getValue())==null||n.toString==null?void 0:n.toString())!=null?t:null},aggregationFn:"auto"}),getInitialState:e=>({grouping:[],...e}),getDefaultOptions:e=>({onGroupingChange:Xf("grouping",e),groupedColumnMode:"reorder"}),createColumn:(e,t)=>{e.toggleGrouping=()=>{t.setGrouping(n=>n!=null&&n.includes(e.id)?n.filter(r=>r!==e.id):[...n??[],e.id])},e.getCanGroup=()=>{var n,r;return((n=e.columnDef.enableGrouping)!=null?n:!0)&&((r=t.options.enableGrouping)!=null?r:!0)&&(!!e.accessorFn||!!e.columnDef.getGroupingValue)},e.getIsGrouped=()=>{var n;return(n=t.getState().grouping)==null?void 0:n.includes(e.id)},e.getGroupedIndex=()=>{var n;return(n=t.getState().grouping)==null?void 0:n.indexOf(e.id)},e.getToggleGroupingHandler=()=>{const n=e.getCanGroup();return()=>{n&&e.toggleGrouping()}},e.getAutoAggregationFn=()=>{const n=t.getCoreRowModel().flatRows[0],r=n==null?void 0:n.getValue(e.id);if(typeof r=="number")return Uk.sum;if(Object.prototype.toString.call(r)==="[object Date]")return Uk.extent},e.getAggregationFn=()=>{var n,r;if(!e)throw new Error;return dw(e.columnDef.aggregationFn)?e.columnDef.aggregationFn:e.columnDef.aggregationFn==="auto"?e.getAutoAggregationFn():(n=(r=t.options.aggregationFns)==null?void 0:r[e.columnDef.aggregationFn])!=null?n:Uk[e.columnDef.aggregationFn]}},createTable:e=>{e.setGrouping=t=>e.options.onGroupingChange==null?void 0:e.options.onGroupingChange(t),e.resetGrouping=t=>{var n,r;e.setGrouping(t?[]:(n=(r=e.initialState)==null?void 0:r.grouping)!=null?n:[])},e.getPreGroupedRowModel=()=>e.getFilteredRowModel(),e.getGroupedRowModel=()=>(!e._getGroupedRowModel&&e.options.getGroupedRowModel&&(e._getGroupedRowModel=e.options.getGroupedRowModel(e)),e.options.manualGrouping||!e._getGroupedRowModel?e.getPreGroupedRowModel():e._getGroupedRowModel())},createRow:(e,t)=>{e.getIsGrouped=()=>!!e.groupingColumnId,e.getGroupingValue=n=>{if(e._groupingValuesCache.hasOwnProperty(n))return e._groupingValuesCache[n];const r=t.getColumn(n);return r!=null&&r.columnDef.getGroupingValue?(e._groupingValuesCache[n]=r.columnDef.getGroupingValue(e.original),e._groupingValuesCache[n]):e.getValue(n)},e._groupingValuesCache={}},createCell:(e,t,n,r)=>{e.getIsGrouped=()=>t.getIsGrouped()&&t.id===n.groupingColumnId,e.getIsPlaceholder=()=>!e.getIsGrouped()&&t.getIsGrouped(),e.getIsAggregated=()=>{var i;return!e.getIsGrouped()&&!e.getIsPlaceholder()&&!!((i=n.subRows)!=null&&i.length)}}};function Ake(e,t,n){if(!(t!=null&&t.length)||!n)return e;const r=e.filter(a=>!t.includes(a.id));return n==="remove"?r:[...t.map(a=>e.find(u=>u.id===a)).filter(Boolean),...r]}const Tke={getInitialState:e=>({columnOrder:[],...e}),getDefaultOptions:e=>({onColumnOrderChange:Xf("columnOrder",e)}),createColumn:(e,t)=>{e.getIndex=Fn(n=>[Z2(t,n)],n=>n.findIndex(r=>r.id===e.id),Nn(t.options,"debugColumns")),e.getIsFirstColumn=n=>{var r;return((r=Z2(t,n)[0])==null?void 0:r.id)===e.id},e.getIsLastColumn=n=>{var r;const i=Z2(t,n);return((r=i[i.length-1])==null?void 0:r.id)===e.id}},createTable:e=>{e.setColumnOrder=t=>e.options.onColumnOrderChange==null?void 0:e.options.onColumnOrderChange(t),e.resetColumnOrder=t=>{var n;e.setColumnOrder(t?[]:(n=e.initialState.columnOrder)!=null?n:[])},e._getOrderColumnsFn=Fn(()=>[e.getState().columnOrder,e.getState().grouping,e.options.groupedColumnMode],(t,n,r)=>i=>{let a=[];if(!(t!=null&&t.length))a=i;else{const u=[...t],l=[...i];for(;l.length&&u.length;){const o=u.shift(),s=l.findIndex(c=>c.id===o);s>-1&&a.push(l.splice(s,1)[0])}a=[...a,...l]}return Ake(a,n,r)},Nn(e.options,"debugTable"))}},jk=()=>({left:[],right:[]}),kke={getInitialState:e=>({columnPinning:jk(),...e}),getDefaultOptions:e=>({onColumnPinningChange:Xf("columnPinning",e)}),createColumn:(e,t)=>{e.pin=n=>{const r=e.getLeafColumns().map(i=>i.id).filter(Boolean);t.setColumnPinning(i=>{var a,u;if(n==="right"){var l,o;return{left:((l=i==null?void 0:i.left)!=null?l:[]).filter(d=>!(r!=null&&r.includes(d))),right:[...((o=i==null?void 0:i.right)!=null?o:[]).filter(d=>!(r!=null&&r.includes(d))),...r]}}if(n==="left"){var s,c;return{left:[...((s=i==null?void 0:i.left)!=null?s:[]).filter(d=>!(r!=null&&r.includes(d))),...r],right:((c=i==null?void 0:i.right)!=null?c:[]).filter(d=>!(r!=null&&r.includes(d)))}}return{left:((a=i==null?void 0:i.left)!=null?a:[]).filter(d=>!(r!=null&&r.includes(d))),right:((u=i==null?void 0:i.right)!=null?u:[]).filter(d=>!(r!=null&&r.includes(d)))}})},e.getCanPin=()=>e.getLeafColumns().some(r=>{var i,a,u;return((i=r.columnDef.enablePinning)!=null?i:!0)&&((a=(u=t.options.enableColumnPinning)!=null?u:t.options.enablePinning)!=null?a:!0)}),e.getIsPinned=()=>{const n=e.getLeafColumns().map(l=>l.id),{left:r,right:i}=t.getState().columnPinning,a=n.some(l=>r==null?void 0:r.includes(l)),u=n.some(l=>i==null?void 0:i.includes(l));return a?"left":u?"right":!1},e.getPinnedIndex=()=>{var n,r;const i=e.getIsPinned();return i?(n=(r=t.getState().columnPinning)==null||(r=r[i])==null?void 0:r.indexOf(e.id))!=null?n:-1:0}},createRow:(e,t)=>{e.getCenterVisibleCells=Fn(()=>[e._getAllVisibleCells(),t.getState().columnPinning.left,t.getState().columnPinning.right],(n,r,i)=>{const a=[...r??[],...i??[]];return n.filter(u=>!a.includes(u.column.id))},Nn(t.options,"debugRows")),e.getLeftVisibleCells=Fn(()=>[e._getAllVisibleCells(),t.getState().columnPinning.left],(n,r)=>(r??[]).map(a=>n.find(u=>u.column.id===a)).filter(Boolean).map(a=>({...a,position:"left"})),Nn(t.options,"debugRows")),e.getRightVisibleCells=Fn(()=>[e._getAllVisibleCells(),t.getState().columnPinning.right],(n,r)=>(r??[]).map(a=>n.find(u=>u.column.id===a)).filter(Boolean).map(a=>({...a,position:"right"})),Nn(t.options,"debugRows"))},createTable:e=>{e.setColumnPinning=t=>e.options.onColumnPinningChange==null?void 0:e.options.onColumnPinningChange(t),e.resetColumnPinning=t=>{var n,r;return e.setColumnPinning(t?jk():(n=(r=e.initialState)==null?void 0:r.columnPinning)!=null?n:jk())},e.getIsSomeColumnsPinned=t=>{var n;const r=e.getState().columnPinning;if(!t){var i,a;return!!((i=r.left)!=null&&i.length||(a=r.right)!=null&&a.length)}return!!((n=r[t])!=null&&n.length)},e.getLeftLeafColumns=Fn(()=>[e.getAllLeafColumns(),e.getState().columnPinning.left],(t,n)=>(n??[]).map(r=>t.find(i=>i.id===r)).filter(Boolean),Nn(e.options,"debugColumns")),e.getRightLeafColumns=Fn(()=>[e.getAllLeafColumns(),e.getState().columnPinning.right],(t,n)=>(n??[]).map(r=>t.find(i=>i.id===r)).filter(Boolean),Nn(e.options,"debugColumns")),e.getCenterLeafColumns=Fn(()=>[e.getAllLeafColumns(),e.getState().columnPinning.left,e.getState().columnPinning.right],(t,n,r)=>{const i=[...n??[],...r??[]];return t.filter(a=>!i.includes(a.id))},Nn(e.options,"debugColumns"))}};function Pke(e){return e||(typeof document<"u"?document:null)}const W_={size:150,minSize:20,maxSize:Number.MAX_SAFE_INTEGER},Zk=()=>({startOffset:null,startSize:null,deltaOffset:null,deltaPercentage:null,isResizingColumn:!1,columnSizingStart:[]}),Mke={getDefaultColumnDef:()=>W_,getInitialState:e=>({columnSizing:{},columnSizingInfo:Zk(),...e}),getDefaultOptions:e=>({columnResizeMode:"onEnd",columnResizeDirection:"ltr",onColumnSizingChange:Xf("columnSizing",e),onColumnSizingInfoChange:Xf("columnSizingInfo",e)}),createColumn:(e,t)=>{e.getSize=()=>{var n,r,i;const a=t.getState().columnSizing[e.id];return Math.min(Math.max((n=e.columnDef.minSize)!=null?n:W_.minSize,(r=a??e.columnDef.size)!=null?r:W_.size),(i=e.columnDef.maxSize)!=null?i:W_.maxSize)},e.getStart=Fn(n=>[n,Z2(t,n),t.getState().columnSizing],(n,r)=>r.slice(0,e.getIndex(n)).reduce((i,a)=>i+a.getSize(),0),Nn(t.options,"debugColumns")),e.getAfter=Fn(n=>[n,Z2(t,n),t.getState().columnSizing],(n,r)=>r.slice(e.getIndex(n)+1).reduce((i,a)=>i+a.getSize(),0),Nn(t.options,"debugColumns")),e.resetSize=()=>{t.setColumnSizing(n=>{let{[e.id]:r,...i}=n;return i})},e.getCanResize=()=>{var n,r;return((n=e.columnDef.enableResizing)!=null?n:!0)&&((r=t.options.enableColumnResizing)!=null?r:!0)},e.getIsResizing=()=>t.getState().columnSizingInfo.isResizingColumn===e.id},createHeader:(e,t)=>{e.getSize=()=>{let n=0;const r=i=>{if(i.subHeaders.length)i.subHeaders.forEach(r);else{var a;n+=(a=i.column.getSize())!=null?a:0}};return r(e),n},e.getStart=()=>{if(e.index>0){const n=e.headerGroup.headers[e.index-1];return n.getStart()+n.getSize()}return 0},e.getResizeHandler=n=>{const r=t.getColumn(e.column.id),i=r==null?void 0:r.getCanResize();return a=>{if(!r||!i||(a.persist==null||a.persist(),Hk(a)&&a.touches&&a.touches.length>1))return;const u=e.getSize(),l=e?e.getLeafHeaders().map(S=>[S.column.id,S.column.getSize()]):[[r.id,r.getSize()]],o=Hk(a)?Math.round(a.touches[0].clientX):a.clientX,s={},c=(S,E)=>{typeof E=="number"&&(t.setColumnSizingInfo(C=>{var T,R;const $=t.options.columnResizeDirection==="rtl"?-1:1,k=(E-((T=C==null?void 0:C.startOffset)!=null?T:0))*$,F=Math.max(k/((R=C==null?void 0:C.startSize)!=null?R:0),-.999999);return C.columnSizingStart.forEach(L=>{let[j,V]=L;s[j]=Math.round(Math.max(V+V*F,0)*100)/100}),{...C,deltaOffset:k,deltaPercentage:F}}),(t.options.columnResizeMode==="onChange"||S==="end")&&t.setColumnSizing(C=>({...C,...s})))},d=S=>c("move",S),h=S=>{c("end",S),t.setColumnSizingInfo(E=>({...E,isResizingColumn:!1,startOffset:null,startSize:null,deltaOffset:null,deltaPercentage:null,columnSizingStart:[]}))},m=Pke(n),y={moveHandler:S=>d(S.clientX),upHandler:S=>{m==null||m.removeEventListener("mousemove",y.moveHandler),m==null||m.removeEventListener("mouseup",y.upHandler),h(S.clientX)}},v={moveHandler:S=>(S.cancelable&&(S.preventDefault(),S.stopPropagation()),d(S.touches[0].clientX),!1),upHandler:S=>{var E;m==null||m.removeEventListener("touchmove",v.moveHandler),m==null||m.removeEventListener("touchend",v.upHandler),S.cancelable&&(S.preventDefault(),S.stopPropagation()),h((E=S.touches[0])==null?void 0:E.clientX)}},_=Fke()?{passive:!1}:!1;Hk(a)?(m==null||m.addEventListener("touchmove",v.moveHandler,_),m==null||m.addEventListener("touchend",v.upHandler,_)):(m==null||m.addEventListener("mousemove",y.moveHandler,_),m==null||m.addEventListener("mouseup",y.upHandler,_)),t.setColumnSizingInfo(S=>({...S,startOffset:o,startSize:u,deltaOffset:0,deltaPercentage:0,columnSizingStart:l,isResizingColumn:r.id}))}}},createTable:e=>{e.setColumnSizing=t=>e.options.onColumnSizingChange==null?void 0:e.options.onColumnSizingChange(t),e.setColumnSizingInfo=t=>e.options.onColumnSizingInfoChange==null?void 0:e.options.onColumnSizingInfoChange(t),e.resetColumnSizing=t=>{var n;e.setColumnSizing(t?{}:(n=e.initialState.columnSizing)!=null?n:{})},e.resetHeaderSizeInfo=t=>{var n;e.setColumnSizingInfo(t?Zk():(n=e.initialState.columnSizingInfo)!=null?n:Zk())},e.getTotalSize=()=>{var t,n;return(t=(n=e.getHeaderGroups()[0])==null?void 0:n.headers.reduce((r,i)=>r+i.getSize(),0))!=null?t:0},e.getLeftTotalSize=()=>{var t,n;return(t=(n=e.getLeftHeaderGroups()[0])==null?void 0:n.headers.reduce((r,i)=>r+i.getSize(),0))!=null?t:0},e.getCenterTotalSize=()=>{var t,n;return(t=(n=e.getCenterHeaderGroups()[0])==null?void 0:n.headers.reduce((r,i)=>r+i.getSize(),0))!=null?t:0},e.getRightTotalSize=()=>{var t,n;return(t=(n=e.getRightHeaderGroups()[0])==null?void 0:n.headers.reduce((r,i)=>r+i.getSize(),0))!=null?t:0}}};let J_=null;function Fke(){if(typeof J_=="boolean")return J_;let e=!1;try{const t={get passive(){return e=!0,!1}},n=()=>{};window.addEventListener("test",n,t),window.removeEventListener("test",n)}catch{e=!1}return J_=e,J_}function Hk(e){return e.type==="touchstart"}const Nke={getInitialState:e=>({columnVisibility:{},...e}),getDefaultOptions:e=>({onColumnVisibilityChange:Xf("columnVisibility",e)}),createColumn:(e,t)=>{e.toggleVisibility=n=>{e.getCanHide()&&t.setColumnVisibility(r=>({...r,[e.id]:n??!e.getIsVisible()}))},e.getIsVisible=()=>{var n,r;const i=e.columns;return(n=i.length?i.some(a=>a.getIsVisible()):(r=t.getState().columnVisibility)==null?void 0:r[e.id])!=null?n:!0},e.getCanHide=()=>{var n,r;return((n=e.columnDef.enableHiding)!=null?n:!0)&&((r=t.options.enableHiding)!=null?r:!0)},e.getToggleVisibilityHandler=()=>n=>{e.toggleVisibility==null||e.toggleVisibility(n.target.checked)}},createRow:(e,t)=>{e._getAllVisibleCells=Fn(()=>[e.getAllCells(),t.getState().columnVisibility],n=>n.filter(r=>r.column.getIsVisible()),Nn(t.options,"debugRows")),e.getVisibleCells=Fn(()=>[e.getLeftVisibleCells(),e.getCenterVisibleCells(),e.getRightVisibleCells()],(n,r,i)=>[...n,...r,...i],Nn(t.options,"debugRows"))},createTable:e=>{const t=(n,r)=>Fn(()=>[r(),r().filter(i=>i.getIsVisible()).map(i=>i.id).join("_")],i=>i.filter(a=>a.getIsVisible==null?void 0:a.getIsVisible()),Nn(e.options,"debugColumns"));e.getVisibleFlatColumns=t("getVisibleFlatColumns",()=>e.getAllFlatColumns()),e.getVisibleLeafColumns=t("getVisibleLeafColumns",()=>e.getAllLeafColumns()),e.getLeftVisibleLeafColumns=t("getLeftVisibleLeafColumns",()=>e.getLeftLeafColumns()),e.getRightVisibleLeafColumns=t("getRightVisibleLeafColumns",()=>e.getRightLeafColumns()),e.getCenterVisibleLeafColumns=t("getCenterVisibleLeafColumns",()=>e.getCenterLeafColumns()),e.setColumnVisibility=n=>e.options.onColumnVisibilityChange==null?void 0:e.options.onColumnVisibilityChange(n),e.resetColumnVisibility=n=>{var r;e.setColumnVisibility(n?{}:(r=e.initialState.columnVisibility)!=null?r:{})},e.toggleAllColumnsVisible=n=>{var r;n=(r=n)!=null?r:!e.getIsAllColumnsVisible(),e.setColumnVisibility(e.getAllLeafColumns().reduce((i,a)=>({...i,[a.id]:n||!(a.getCanHide!=null&&a.getCanHide())}),{}))},e.getIsAllColumnsVisible=()=>!e.getAllLeafColumns().some(n=>!(n.getIsVisible!=null&&n.getIsVisible())),e.getIsSomeColumnsVisible=()=>e.getAllLeafColumns().some(n=>n.getIsVisible==null?void 0:n.getIsVisible()),e.getToggleAllColumnsVisibilityHandler=()=>n=>{var r;e.toggleAllColumnsVisible((r=n.target)==null?void 0:r.checked)}}};function Z2(e,t){return t?t==="center"?e.getCenterVisibleLeafColumns():t==="left"?e.getLeftVisibleLeafColumns():e.getRightVisibleLeafColumns():e.getVisibleLeafColumns()}const Ike={createTable:e=>{e._getGlobalFacetedRowModel=e.options.getFacetedRowModel&&e.options.getFacetedRowModel(e,"__global__"),e.getGlobalFacetedRowModel=()=>e.options.manualFiltering||!e._getGlobalFacetedRowModel?e.getPreFilteredRowModel():e._getGlobalFacetedRowModel(),e._getGlobalFacetedUniqueValues=e.options.getFacetedUniqueValues&&e.options.getFacetedUniqueValues(e,"__global__"),e.getGlobalFacetedUniqueValues=()=>e._getGlobalFacetedUniqueValues?e._getGlobalFacetedUniqueValues():new Map,e._getGlobalFacetedMinMaxValues=e.options.getFacetedMinMaxValues&&e.options.getFacetedMinMaxValues(e,"__global__"),e.getGlobalFacetedMinMaxValues=()=>{if(e._getGlobalFacetedMinMaxValues)return e._getGlobalFacetedMinMaxValues()}}},Lke={getInitialState:e=>({globalFilter:void 0,...e}),getDefaultOptions:e=>({onGlobalFilterChange:Xf("globalFilter",e),globalFilterFn:"auto",getColumnCanGlobalFilter:t=>{var n;const r=(n=e.getCoreRowModel().flatRows[0])==null||(n=n._getAllCellsByColumnId()[t.id])==null?void 0:n.getValue();return typeof r=="string"||typeof r=="number"}}),createColumn:(e,t)=>{e.getCanGlobalFilter=()=>{var n,r,i,a;return((n=e.columnDef.enableGlobalFilter)!=null?n:!0)&&((r=t.options.enableGlobalFilter)!=null?r:!0)&&((i=t.options.enableFilters)!=null?i:!0)&&((a=t.options.getColumnCanGlobalFilter==null?void 0:t.options.getColumnCanGlobalFilter(e))!=null?a:!0)&&!!e.accessorFn}},createTable:e=>{e.getGlobalAutoFilterFn=()=>Bm.includesString,e.getGlobalFilterFn=()=>{var t,n;const{globalFilterFn:r}=e.options;return dw(r)?r:r==="auto"?e.getGlobalAutoFilterFn():(t=(n=e.options.filterFns)==null?void 0:n[r])!=null?t:Bm[r]},e.setGlobalFilter=t=>{e.options.onGlobalFilterChange==null||e.options.onGlobalFilterChange(t)},e.resetGlobalFilter=t=>{e.setGlobalFilter(t?void 0:e.initialState.globalFilter)}}},Bke={getInitialState:e=>({expanded:{},...e}),getDefaultOptions:e=>({onExpandedChange:Xf("expanded",e),paginateExpandedRows:!0}),createTable:e=>{let t=!1,n=!1;e._autoResetExpanded=()=>{var r,i;if(!t){e._queue(()=>{t=!0});return}if((r=(i=e.options.autoResetAll)!=null?i:e.options.autoResetExpanded)!=null?r:!e.options.manualExpanding){if(n)return;n=!0,e._queue(()=>{e.resetExpanded(),n=!1})}},e.setExpanded=r=>e.options.onExpandedChange==null?void 0:e.options.onExpandedChange(r),e.toggleAllRowsExpanded=r=>{r??!e.getIsAllRowsExpanded()?e.setExpanded(!0):e.setExpanded({})},e.resetExpanded=r=>{var i,a;e.setExpanded(r?{}:(i=(a=e.initialState)==null?void 0:a.expanded)!=null?i:{})},e.getCanSomeRowsExpand=()=>e.getPrePaginationRowModel().flatRows.some(r=>r.getCanExpand()),e.getToggleAllRowsExpandedHandler=()=>r=>{r.persist==null||r.persist(),e.toggleAllRowsExpanded()},e.getIsSomeRowsExpanded=()=>{const r=e.getState().expanded;return r===!0||Object.values(r).some(Boolean)},e.getIsAllRowsExpanded=()=>{const r=e.getState().expanded;return typeof r=="boolean"?r===!0:!(!Object.keys(r).length||e.getRowModel().flatRows.some(i=>!i.getIsExpanded()))},e.getExpandedDepth=()=>{let r=0;return(e.getState().expanded===!0?Object.keys(e.getRowModel().rowsById):Object.keys(e.getState().expanded)).forEach(a=>{const u=a.split(".");r=Math.max(r,u.length)}),r},e.getPreExpandedRowModel=()=>e.getSortedRowModel(),e.getExpandedRowModel=()=>(!e._getExpandedRowModel&&e.options.getExpandedRowModel&&(e._getExpandedRowModel=e.options.getExpandedRowModel(e)),e.options.manualExpanding||!e._getExpandedRowModel?e.getPreExpandedRowModel():e._getExpandedRowModel())},createRow:(e,t)=>{e.toggleExpanded=n=>{t.setExpanded(r=>{var i;const a=r===!0?!0:!!(r!=null&&r[e.id]);let u={};if(r===!0?Object.keys(t.getRowModel().rowsById).forEach(l=>{u[l]=!0}):u=r,n=(i=n)!=null?i:!a,!a&&n)return{...u,[e.id]:!0};if(a&&!n){const{[e.id]:l,...o}=u;return o}return r})},e.getIsExpanded=()=>{var n;const r=t.getState().expanded;return!!((n=t.options.getIsRowExpanded==null?void 0:t.options.getIsRowExpanded(e))!=null?n:r===!0||r!=null&&r[e.id])},e.getCanExpand=()=>{var n,r,i;return(n=t.options.getRowCanExpand==null?void 0:t.options.getRowCanExpand(e))!=null?n:((r=t.options.enableExpanding)!=null?r:!0)&&!!((i=e.subRows)!=null&&i.length)},e.getIsAllParentsExpanded=()=>{let n=!0,r=e;for(;n&&r.parentId;)r=t.getRow(r.parentId,!0),n=r.getIsExpanded();return n},e.getToggleExpandedHandler=()=>{const n=e.getCanExpand();return()=>{n&&e.toggleExpanded()}}}},rM=0,iM=10,Xk=()=>({pageIndex:rM,pageSize:iM}),Qke={getInitialState:e=>({...e,pagination:{...Xk(),...e==null?void 0:e.pagination}}),getDefaultOptions:e=>({onPaginationChange:Xf("pagination",e)}),createTable:e=>{let t=!1,n=!1;e._autoResetPageIndex=()=>{var r,i;if(!t){e._queue(()=>{t=!0});return}if((r=(i=e.options.autoResetAll)!=null?i:e.options.autoResetPageIndex)!=null?r:!e.options.manualPagination){if(n)return;n=!0,e._queue(()=>{e.resetPageIndex(),n=!1})}},e.setPagination=r=>{const i=a=>Lv(r,a);return e.options.onPaginationChange==null?void 0:e.options.onPaginationChange(i)},e.resetPagination=r=>{var i;e.setPagination(r?Xk():(i=e.initialState.pagination)!=null?i:Xk())},e.setPageIndex=r=>{e.setPagination(i=>{let a=Lv(r,i.pageIndex);const u=typeof e.options.pageCount>"u"||e.options.pageCount===-1?Number.MAX_SAFE_INTEGER:e.options.pageCount-1;return a=Math.max(0,Math.min(a,u)),{...i,pageIndex:a}})},e.resetPageIndex=r=>{var i,a;e.setPageIndex(r?rM:(i=(a=e.initialState)==null||(a=a.pagination)==null?void 0:a.pageIndex)!=null?i:rM)},e.resetPageSize=r=>{var i,a;e.setPageSize(r?iM:(i=(a=e.initialState)==null||(a=a.pagination)==null?void 0:a.pageSize)!=null?i:iM)},e.setPageSize=r=>{e.setPagination(i=>{const a=Math.max(1,Lv(r,i.pageSize)),u=i.pageSize*i.pageIndex,l=Math.floor(u/a);return{...i,pageIndex:l,pageSize:a}})},e.setPageCount=r=>e.setPagination(i=>{var a;let u=Lv(r,(a=e.options.pageCount)!=null?a:-1);return typeof u=="number"&&(u=Math.max(-1,u)),{...i,pageCount:u}}),e.getPageOptions=Fn(()=>[e.getPageCount()],r=>{let i=[];return r&&r>0&&(i=[...new Array(r)].fill(null).map((a,u)=>u)),i},Nn(e.options,"debugTable")),e.getCanPreviousPage=()=>e.getState().pagination.pageIndex>0,e.getCanNextPage=()=>{const{pageIndex:r}=e.getState().pagination,i=e.getPageCount();return i===-1?!0:i===0?!1:r<i-1},e.previousPage=()=>e.setPageIndex(r=>r-1),e.nextPage=()=>e.setPageIndex(r=>r+1),e.firstPage=()=>e.setPageIndex(0),e.lastPage=()=>e.setPageIndex(e.getPageCount()-1),e.getPrePaginationRowModel=()=>e.getExpandedRowModel(),e.getPaginationRowModel=()=>(!e._getPaginationRowModel&&e.options.getPaginationRowModel&&(e._getPaginationRowModel=e.options.getPaginationRowModel(e)),e.options.manualPagination||!e._getPaginationRowModel?e.getPrePaginationRowModel():e._getPaginationRowModel()),e.getPageCount=()=>{var r;return(r=e.options.pageCount)!=null?r:Math.ceil(e.getRowCount()/e.getState().pagination.pageSize)},e.getRowCount=()=>{var r;return(r=e.options.rowCount)!=null?r:e.getPrePaginationRowModel().rows.length}}},Yk=()=>({top:[],bottom:[]}),zke={getInitialState:e=>({rowPinning:Yk(),...e}),getDefaultOptions:e=>({onRowPinningChange:Xf("rowPinning",e)}),createRow:(e,t)=>{e.pin=(n,r,i)=>{const a=r?e.getLeafRows().map(o=>{let{id:s}=o;return s}):[],u=i?e.getParentRows().map(o=>{let{id:s}=o;return s}):[],l=new Set([...u,e.id,...a]);t.setRowPinning(o=>{var s,c;if(n==="bottom"){var d,h;return{top:((d=o==null?void 0:o.top)!=null?d:[]).filter(v=>!(l!=null&&l.has(v))),bottom:[...((h=o==null?void 0:o.bottom)!=null?h:[]).filter(v=>!(l!=null&&l.has(v))),...Array.from(l)]}}if(n==="top"){var m,y;return{top:[...((m=o==null?void 0:o.top)!=null?m:[]).filter(v=>!(l!=null&&l.has(v))),...Array.from(l)],bottom:((y=o==null?void 0:o.bottom)!=null?y:[]).filter(v=>!(l!=null&&l.has(v)))}}return{top:((s=o==null?void 0:o.top)!=null?s:[]).filter(v=>!(l!=null&&l.has(v))),bottom:((c=o==null?void 0:o.bottom)!=null?c:[]).filter(v=>!(l!=null&&l.has(v)))}})},e.getCanPin=()=>{var n;const{enableRowPinning:r,enablePinning:i}=t.options;return typeof r=="function"?r(e):(n=r??i)!=null?n:!0},e.getIsPinned=()=>{const n=[e.id],{top:r,bottom:i}=t.getState().rowPinning,a=n.some(l=>r==null?void 0:r.includes(l)),u=n.some(l=>i==null?void 0:i.includes(l));return a?"top":u?"bottom":!1},e.getPinnedIndex=()=>{var n,r;const i=e.getIsPinned();if(!i)return-1;const a=(n=i==="top"?t.getTopRows():t.getBottomRows())==null?void 0:n.map(u=>{let{id:l}=u;return l});return(r=a==null?void 0:a.indexOf(e.id))!=null?r:-1}},createTable:e=>{e.setRowPinning=t=>e.options.onRowPinningChange==null?void 0:e.options.onRowPinningChange(t),e.resetRowPinning=t=>{var n,r;return e.setRowPinning(t?Yk():(n=(r=e.initialState)==null?void 0:r.rowPinning)!=null?n:Yk())},e.getIsSomeRowsPinned=t=>{var n;const r=e.getState().rowPinning;if(!t){var i,a;return!!((i=r.top)!=null&&i.length||(a=r.bottom)!=null&&a.length)}return!!((n=r[t])!=null&&n.length)},e._getPinnedRows=(t,n,r)=>{var i;return((i=e.options.keepPinnedRows)==null||i?(n??[]).map(u=>{const l=e.getRow(u,!0);return l.getIsAllParentsExpanded()?l:null}):(n??[]).map(u=>t.find(l=>l.id===u))).filter(Boolean).map(u=>({...u,position:r}))},e.getTopRows=Fn(()=>[e.getRowModel().rows,e.getState().rowPinning.top],(t,n)=>e._getPinnedRows(t,n,"top"),Nn(e.options,"debugRows")),e.getBottomRows=Fn(()=>[e.getRowModel().rows,e.getState().rowPinning.bottom],(t,n)=>e._getPinnedRows(t,n,"bottom"),Nn(e.options,"debugRows")),e.getCenterRows=Fn(()=>[e.getRowModel().rows,e.getState().rowPinning.top,e.getState().rowPinning.bottom],(t,n,r)=>{const i=new Set([...n??[],...r??[]]);return t.filter(a=>!i.has(a.id))},Nn(e.options,"debugRows"))}},qke={getInitialState:e=>({rowSelection:{},...e}),getDefaultOptions:e=>({onRowSelectionChange:Xf("rowSelection",e),enableRowSelection:!0,enableMultiRowSelection:!0,enableSubRowSelection:!0}),createTable:e=>{e.setRowSelection=t=>e.options.onRowSelectionChange==null?void 0:e.options.onRowSelectionChange(t),e.resetRowSelection=t=>{var n;return e.setRowSelection(t?{}:(n=e.initialState.rowSelection)!=null?n:{})},e.toggleAllRowsSelected=t=>{e.setRowSelection(n=>{t=typeof t<"u"?t:!e.getIsAllRowsSelected();const r={...n},i=e.getPreGroupedRowModel().flatRows;return t?i.forEach(a=>{a.getCanSelect()&&(r[a.id]=!0)}):i.forEach(a=>{delete r[a.id]}),r})},e.toggleAllPageRowsSelected=t=>e.setRowSelection(n=>{const r=typeof t<"u"?t:!e.getIsAllPageRowsSelected(),i={...n};return e.getRowModel().rows.forEach(a=>{aM(i,a.id,r,!0,e)}),i}),e.getPreSelectedRowModel=()=>e.getCoreRowModel(),e.getSelectedRowModel=Fn(()=>[e.getState().rowSelection,e.getCoreRowModel()],(t,n)=>Object.keys(t).length?Gk(e,n):{rows:[],flatRows:[],rowsById:{}},Nn(e.options,"debugTable")),e.getFilteredSelectedRowModel=Fn(()=>[e.getState().rowSelection,e.getFilteredRowModel()],(t,n)=>Object.keys(t).length?Gk(e,n):{rows:[],flatRows:[],rowsById:{}},Nn(e.options,"debugTable")),e.getGroupedSelectedRowModel=Fn(()=>[e.getState().rowSelection,e.getSortedRowModel()],(t,n)=>Object.keys(t).length?Gk(e,n):{rows:[],flatRows:[],rowsById:{}},Nn(e.options,"debugTable")),e.getIsAllRowsSelected=()=>{const t=e.getFilteredRowModel().flatRows,{rowSelection:n}=e.getState();let r=!!(t.length&&Object.keys(n).length);return r&&t.some(i=>i.getCanSelect()&&!n[i.id])&&(r=!1),r},e.getIsAllPageRowsSelected=()=>{const t=e.getPaginationRowModel().flatRows.filter(i=>i.getCanSelect()),{rowSelection:n}=e.getState();let r=!!t.length;return r&&t.some(i=>!n[i.id])&&(r=!1),r},e.getIsSomeRowsSelected=()=>{var t;const n=Object.keys((t=e.getState().rowSelection)!=null?t:{}).length;return n>0&&n<e.getFilteredRowModel().flatRows.length},e.getIsSomePageRowsSelected=()=>{const t=e.getPaginationRowModel().flatRows;return e.getIsAllPageRowsSelected()?!1:t.filter(n=>n.getCanSelect()).some(n=>n.getIsSelected()||n.getIsSomeSelected())},e.getToggleAllRowsSelectedHandler=()=>t=>{e.toggleAllRowsSelected(t.target.checked)},e.getToggleAllPageRowsSelectedHandler=()=>t=>{e.toggleAllPageRowsSelected(t.target.checked)}},createRow:(e,t)=>{e.toggleSelected=(n,r)=>{const i=e.getIsSelected();t.setRowSelection(a=>{var u;if(n=typeof n<"u"?n:!i,e.getCanSelect()&&i===n)return a;const l={...a};return aM(l,e.id,n,(u=r==null?void 0:r.selectChildren)!=null?u:!0,t),l})},e.getIsSelected=()=>{const{rowSelection:n}=t.getState();return wI(e,n)},e.getIsSomeSelected=()=>{const{rowSelection:n}=t.getState();return uM(e,n)==="some"},e.getIsAllSubRowsSelected=()=>{const{rowSelection:n}=t.getState();return uM(e,n)==="all"},e.getCanSelect=()=>{var n;return typeof t.options.enableRowSelection=="function"?t.options.enableRowSelection(e):(n=t.options.enableRowSelection)!=null?n:!0},e.getCanSelectSubRows=()=>{var n;return typeof t.options.enableSubRowSelection=="function"?t.options.enableSubRowSelection(e):(n=t.options.enableSubRowSelection)!=null?n:!0},e.getCanMultiSelect=()=>{var n;return typeof t.options.enableMultiRowSelection=="function"?t.options.enableMultiRowSelection(e):(n=t.options.enableMultiRowSelection)!=null?n:!0},e.getToggleSelectedHandler=()=>{const n=e.getCanSelect();return r=>{var i;n&&e.toggleSelected((i=r.target)==null?void 0:i.checked)}}}},aM=(e,t,n,r,i)=>{var a;const u=i.getRow(t,!0);n?(u.getCanMultiSelect()||Object.keys(e).forEach(l=>delete e[l]),u.getCanSelect()&&(e[t]=!0)):delete e[t],r&&(a=u.subRows)!=null&&a.length&&u.getCanSelectSubRows()&&u.subRows.forEach(l=>aM(e,l.id,n,r,i))};function Gk(e,t){const n=e.getState().rowSelection,r=[],i={},a=function(u,l){return u.map(o=>{var s;const c=wI(o,n);if(c&&(r.push(o),i[o.id]=o),(s=o.subRows)!=null&&s.length&&(o={...o,subRows:a(o.subRows)}),c)return o}).filter(Boolean)};return{rows:a(t.rows),flatRows:r,rowsById:i}}function wI(e,t){var n;return(n=t[e.id])!=null?n:!1}function uM(e,t,n){var r;if(!((r=e.subRows)!=null&&r.length))return!1;let i=!0,a=!1;return e.subRows.forEach(u=>{if(!(a&&!i)&&(u.getCanSelect()&&(wI(u,t)?a=!0:i=!1),u.subRows&&u.subRows.length)){const l=uM(u,t);l==="all"?a=!0:(l==="some"&&(a=!0),i=!1)}}),i?"all":a?"some":!1}const lM=/([0-9]+)/gm,Vke=(e,t,n)=>Upe(ty(e.getValue(n)).toLowerCase(),ty(t.getValue(n)).toLowerCase()),Uke=(e,t,n)=>Upe(ty(e.getValue(n)),ty(t.getValue(n))),jke=(e,t,n)=>RI(ty(e.getValue(n)).toLowerCase(),ty(t.getValue(n)).toLowerCase()),Zke=(e,t,n)=>RI(ty(e.getValue(n)),ty(t.getValue(n))),Hke=(e,t,n)=>{const r=e.getValue(n),i=t.getValue(n);return r>i?1:r<i?-1:0},Xke=(e,t,n)=>RI(e.getValue(n),t.getValue(n));function RI(e,t){return e===t?0:e>t?1:-1}function ty(e){return typeof e=="number"?isNaN(e)||e===1/0||e===-1/0?"":String(e):typeof e=="string"?e:""}function Upe(e,t){const n=e.split(lM).filter(Boolean),r=t.split(lM).filter(Boolean);for(;n.length&&r.length;){const i=n.shift(),a=r.shift(),u=parseInt(i,10),l=parseInt(a,10),o=[u,l].sort();if(isNaN(o[0])){if(i>a)return 1;if(a>i)return-1;continue}if(isNaN(o[1]))return isNaN(u)?-1:1;if(u>l)return 1;if(l>u)return-1}return n.length-r.length}const a2={alphanumeric:Vke,alphanumericCaseSensitive:Uke,text:jke,textCaseSensitive:Zke,datetime:Hke,basic:Xke},Yke={getInitialState:e=>({sorting:[],...e}),getDefaultColumnDef:()=>({sortingFn:"auto",sortUndefined:1}),getDefaultOptions:e=>({onSortingChange:Xf("sorting",e),isMultiSortEvent:t=>t.shiftKey}),createColumn:(e,t)=>{e.getAutoSortingFn=()=>{const n=t.getFilteredRowModel().flatRows.slice(10);let r=!1;for(const i of n){const a=i==null?void 0:i.getValue(e.id);if(Object.prototype.toString.call(a)==="[object Date]")return a2.datetime;if(typeof a=="string"&&(r=!0,a.split(lM).length>1))return a2.alphanumeric}return r?a2.text:a2.basic},e.getAutoSortDir=()=>{const n=t.getFilteredRowModel().flatRows[0];return typeof(n==null?void 0:n.getValue(e.id))=="string"?"asc":"desc"},e.getSortingFn=()=>{var n,r;if(!e)throw new Error;return dw(e.columnDef.sortingFn)?e.columnDef.sortingFn:e.columnDef.sortingFn==="auto"?e.getAutoSortingFn():(n=(r=t.options.sortingFns)==null?void 0:r[e.columnDef.sortingFn])!=null?n:a2[e.columnDef.sortingFn]},e.toggleSorting=(n,r)=>{const i=e.getNextSortingOrder(),a=typeof n<"u"&&n!==null;t.setSorting(u=>{const l=u==null?void 0:u.find(m=>m.id===e.id),o=u==null?void 0:u.findIndex(m=>m.id===e.id);let s=[],c,d=a?n:i==="desc";if(u!=null&&u.length&&e.getCanMultiSort()&&r?l?c="toggle":c="add":u!=null&&u.length&&o!==u.length-1?c="replace":l?c="toggle":c="replace",c==="toggle"&&(a||i||(c="remove")),c==="add"){var h;s=[...u,{id:e.id,desc:d}],s.splice(0,s.length-((h=t.options.maxMultiSortColCount)!=null?h:Number.MAX_SAFE_INTEGER))}else c==="toggle"?s=u.map(m=>m.id===e.id?{...m,desc:d}:m):c==="remove"?s=u.filter(m=>m.id!==e.id):s=[{id:e.id,desc:d}];return s})},e.getFirstSortDir=()=>{var n,r;return((n=(r=e.columnDef.sortDescFirst)!=null?r:t.options.sortDescFirst)!=null?n:e.getAutoSortDir()==="desc")?"desc":"asc"},e.getNextSortingOrder=n=>{var r,i;const a=e.getFirstSortDir(),u=e.getIsSorted();return u?u!==a&&((r=t.options.enableSortingRemoval)==null||r)&&(!(n&&(i=t.options.enableMultiRemove)!=null)||i)?!1:u==="desc"?"asc":"desc":a},e.getCanSort=()=>{var n,r;return((n=e.columnDef.enableSorting)!=null?n:!0)&&((r=t.options.enableSorting)!=null?r:!0)&&!!e.accessorFn},e.getCanMultiSort=()=>{var n,r;return(n=(r=e.columnDef.enableMultiSort)!=null?r:t.options.enableMultiSort)!=null?n:!!e.accessorFn},e.getIsSorted=()=>{var n;const r=(n=t.getState().sorting)==null?void 0:n.find(i=>i.id===e.id);return r?r.desc?"desc":"asc":!1},e.getSortIndex=()=>{var n,r;return(n=(r=t.getState().sorting)==null?void 0:r.findIndex(i=>i.id===e.id))!=null?n:-1},e.clearSorting=()=>{t.setSorting(n=>n!=null&&n.length?n.filter(r=>r.id!==e.id):[])},e.getToggleSortingHandler=()=>{const n=e.getCanSort();return r=>{n&&(r.persist==null||r.persist(),e.toggleSorting==null||e.toggleSorting(void 0,e.getCanMultiSort()?t.options.isMultiSortEvent==null?void 0:t.options.isMultiSortEvent(r):!1))}}},createTable:e=>{e.setSorting=t=>e.options.onSortingChange==null?void 0:e.options.onSortingChange(t),e.resetSorting=t=>{var n,r;e.setSorting(t?[]:(n=(r=e.initialState)==null?void 0:r.sorting)!=null?n:[])},e.getPreSortedRowModel=()=>e.getGroupedRowModel(),e.getSortedRowModel=()=>(!e._getSortedRowModel&&e.options.getSortedRowModel&&(e._getSortedRowModel=e.options.getSortedRowModel(e)),e.options.manualSorting||!e._getSortedRowModel?e.getPreSortedRowModel():e._getSortedRowModel())}},Gke=[vke,Nke,Tke,kke,yke,bke,Ike,Lke,Yke,Rke,Bke,Qke,zke,qke,Mke];function Kke(e){var t,n;const r=[...Gke,...(t=e._features)!=null?t:[]];let i={_features:r};const a=i._features.reduce((h,m)=>Object.assign(h,m.getDefaultOptions==null?void 0:m.getDefaultOptions(i)),{}),u=h=>i.options.mergeOptions?i.options.mergeOptions(a,h):{...a,...h};let o={...{},...(n=e.initialState)!=null?n:{}};i._features.forEach(h=>{var m;o=(m=h.getInitialState==null?void 0:h.getInitialState(o))!=null?m:o});const s=[];let c=!1;const d={_features:r,options:{...a,...e},initialState:o,_queue:h=>{s.push(h),c||(c=!0,Promise.resolve().then(()=>{for(;s.length;)s.shift()();c=!1}).catch(m=>setTimeout(()=>{throw m})))},reset:()=>{i.setState(i.initialState)},setOptions:h=>{const m=Lv(h,i.options);i.options=u(m)},getState:()=>i.options.state,setState:h=>{i.options.onStateChange==null||i.options.onStateChange(h)},_getRowId:(h,m,y)=>{var v;return(v=i.options.getRowId==null?void 0:i.options.getRowId(h,m,y))!=null?v:`${y?[y.id,m].join("."):m}`},getCoreRowModel:()=>(i._getCoreRowModel||(i._getCoreRowModel=i.options.getCoreRowModel(i)),i._getCoreRowModel()),getRowModel:()=>i.getPaginationRowModel(),getRow:(h,m)=>{let y=(m?i.getPrePaginationRowModel():i.getRowModel()).rowsById[h];if(!y&&(y=i.getCoreRowModel().rowsById[h],!y))throw new Error;return y},_getDefaultColumnDef:Fn(()=>[i.options.defaultColumn],h=>{var m;return h=(m=h)!=null?m:{},{header:y=>{const v=y.header.column.columnDef;return v.accessorKey?v.accessorKey:v.accessorFn?v.id:null},cell:y=>{var v,_;return(v=(_=y.renderValue())==null||_.toString==null?void 0:_.toString())!=null?v:null},...i._features.reduce((y,v)=>Object.assign(y,v.getDefaultColumnDef==null?void 0:v.getDefaultColumnDef()),{}),...h}},Nn(e,"debugColumns")),_getColumnDefs:()=>i.options.columns,getAllColumns:Fn(()=>[i._getColumnDefs()],h=>{const m=function(y,v,_){return _===void 0&&(_=0),y.map(S=>{const E=gke(i,S,_,v),C=S;return E.columns=C.columns?m(C.columns,E,_+1):[],E})};return m(h)},Nn(e,"debugColumns")),getAllFlatColumns:Fn(()=>[i.getAllColumns()],h=>h.flatMap(m=>m.getFlatColumns()),Nn(e,"debugColumns")),_getAllFlatColumnsById:Fn(()=>[i.getAllFlatColumns()],h=>h.reduce((m,y)=>(m[y.id]=y,m),{}),Nn(e,"debugColumns")),getAllLeafColumns:Fn(()=>[i.getAllColumns(),i._getOrderColumnsFn()],(h,m)=>{let y=h.flatMap(v=>v.getLeafColumns());return m(y)},Nn(e,"debugColumns")),getColumn:h=>i._getAllFlatColumnsById()[h]};Object.assign(i,d);for(let h=0;h<i._features.length;h++){const m=i._features[h];m==null||m.createTable==null||m.createTable(i)}return i}function xat(){return e=>Fn(()=>[e.options.data],t=>{const n={rows:[],flatRows:[],rowsById:{}},r=function(i,a,u){a===void 0&&(a=0);const l=[];for(let s=0;s<i.length;s++){const c=$I(e,e._getRowId(i[s],s,u),i[s],s,a,void 0,u==null?void 0:u.id);if(n.flatRows.push(c),n.rowsById[c.id]=c,l.push(c),e.options.getSubRows){var o;c.originalSubRows=e.options.getSubRows(i[s],s),(o=c.originalSubRows)!=null&&o.length&&(c.subRows=r(c.originalSubRows,a+1,c))}}return l};return n.rows=r(t),n},Nn(e.options,"debugTable","getRowModel",()=>e._autoResetPageIndex()))}function Sat(){return e=>Fn(()=>[e.getState().expanded,e.getPreExpandedRowModel(),e.options.paginateExpandedRows],(t,n,r)=>!n.rows.length||t!==!0&&!Object.keys(t??{}).length||!r?n:jpe(n),Nn(e.options,"debugTable"))}function jpe(e){const t=[],n=r=>{var i;t.push(r),(i=r.subRows)!=null&&i.length&&r.getIsExpanded()&&r.subRows.forEach(n)};return e.rows.forEach(n),{rows:t,flatRows:e.flatRows,rowsById:e.rowsById}}function Wke(e,t,n){return n.options.filterFromLeafRows?Jke(e,t,n):ePe(e,t,n)}function Jke(e,t,n){var r;const i=[],a={},u=(r=n.options.maxLeafRowFilterDepth)!=null?r:100,l=function(o,s){s===void 0&&(s=0);const c=[];for(let h=0;h<o.length;h++){var d;let m=o[h];const y=$I(n,m.id,m.original,m.index,m.depth,void 0,m.parentId);if(y.columnFilters=m.columnFilters,(d=m.subRows)!=null&&d.length&&s<u){if(y.subRows=l(m.subRows,s+1),m=y,t(m)&&!y.subRows.length){c.push(m),a[m.id]=m,i.push(m);continue}if(t(m)||y.subRows.length){c.push(m),a[m.id]=m,i.push(m);continue}}else m=y,t(m)&&(c.push(m),a[m.id]=m,i.push(m))}return c};return{rows:l(e),flatRows:i,rowsById:a}}function ePe(e,t,n){var r;const i=[],a={},u=(r=n.options.maxLeafRowFilterDepth)!=null?r:100,l=function(o,s){s===void 0&&(s=0);const c=[];for(let h=0;h<o.length;h++){let m=o[h];if(t(m)){var d;if((d=m.subRows)!=null&&d.length&&s<u){const v=$I(n,m.id,m.original,m.index,m.depth,void 0,m.parentId);v.subRows=l(m.subRows,s+1),m=v}c.push(m),i.push(m),a[m.id]=m}}return c};return{rows:l(e),flatRows:i,rowsById:a}}function _at(){return e=>Fn(()=>[e.getPreFilteredRowModel(),e.getState().columnFilters,e.getState().globalFilter],(t,n,r)=>{if(!t.rows.length||!(n!=null&&n.length)&&!r){for(let h=0;h<t.flatRows.length;h++)t.flatRows[h].columnFilters={},t.flatRows[h].columnFiltersMeta={};return t}const i=[],a=[];(n??[]).forEach(h=>{var m;const y=e.getColumn(h.id);if(!y)return;const v=y.getFilterFn();v&&i.push({id:h.id,filterFn:v,resolvedValue:(m=v.resolveFilterValue==null?void 0:v.resolveFilterValue(h.value))!=null?m:h.value})});const u=(n??[]).map(h=>h.id),l=e.getGlobalFilterFn(),o=e.getAllLeafColumns().filter(h=>h.getCanGlobalFilter());r&&l&&o.length&&(u.push("__global__"),o.forEach(h=>{var m;a.push({id:h.id,filterFn:l,resolvedValue:(m=l.resolveFilterValue==null?void 0:l.resolveFilterValue(r))!=null?m:r})}));let s,c;for(let h=0;h<t.flatRows.length;h++){const m=t.flatRows[h];if(m.columnFilters={},i.length)for(let y=0;y<i.length;y++){s=i[y];const v=s.id;m.columnFilters[v]=s.filterFn(m,v,s.resolvedValue,_=>{m.columnFiltersMeta[v]=_})}if(a.length){for(let y=0;y<a.length;y++){c=a[y];const v=c.id;if(c.filterFn(m,v,c.resolvedValue,_=>{m.columnFiltersMeta[v]=_})){m.columnFilters.__global__=!0;break}}m.columnFilters.__global__!==!0&&(m.columnFilters.__global__=!1)}}const d=h=>{for(let m=0;m<u.length;m++)if(h.columnFilters[u[m]]===!1)return!1;return!0};return Wke(t.rows,d,e)},Nn(e.options,"debugTable","getFilteredRowModel",()=>e._autoResetPageIndex()))}function Eat(e){return t=>Fn(()=>[t.getState().pagination,t.getPrePaginationRowModel(),t.options.paginateExpandedRows?void 0:t.getState().expanded],(n,r)=>{if(!r.rows.length)return r;const{pageSize:i,pageIndex:a}=n;let{rows:u,flatRows:l,rowsById:o}=r;const s=i*a,c=s+i;u=u.slice(s,c);let d;t.options.paginateExpandedRows?d={rows:u,flatRows:l,rowsById:o}:d=jpe({rows:u,flatRows:l,rowsById:o}),d.flatRows=[];const h=m=>{d.flatRows.push(m),m.subRows.length&&m.subRows.forEach(h)};return d.rows.forEach(h),d},Nn(t.options,"debugTable"))}function Dat(){return e=>Fn(()=>[e.getState().sorting,e.getPreSortedRowModel()],(t,n)=>{if(!n.rows.length||!(t!=null&&t.length))return n;const r=e.getState().sorting,i=[],a=r.filter(o=>{var s;return(s=e.getColumn(o.id))==null?void 0:s.getCanSort()}),u={};a.forEach(o=>{const s=e.getColumn(o.id);s&&(u[o.id]={sortUndefined:s.columnDef.sortUndefined,invertSorting:s.columnDef.invertSorting,sortingFn:s.getSortingFn()})});const l=o=>{const s=o.map(c=>({...c}));return s.sort((c,d)=>{for(let m=0;m<a.length;m+=1){var h;const y=a[m],v=u[y.id],_=v.sortUndefined,S=(h=y==null?void 0:y.desc)!=null?h:!1;let E=0;if(_){const C=c.getValue(y.id),T=d.getValue(y.id),R=C===void 0,$=T===void 0;if(R||$){if(_==="first")return R?-1:1;if(_==="last")return R?1:-1;E=R&&$?0:R?_:-_}}if(E===0&&(E=v.sortingFn(c,d,y.id)),E!==0)return S&&(E*=-1),v.invertSorting&&(E*=-1),E}return c.index-d.index}),s.forEach(c=>{var d;i.push(c),(d=c.subRows)!=null&&d.length&&(c.subRows=l(c.subRows))}),s};return{rows:l(n.rows),flatRows:i,rowsById:n.rowsById}},Nn(e.options,"debugTable","getSortedRowModel",()=>e._autoResetPageIndex()))}/**
   * react-table
   *
   * Copyright (c) TanStack
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE.md file in the root directory of this source tree.
   *
   * @license MIT
   */function $at(e,t){return e?tPe(e)?P.createElement(e,t):e:null}function tPe(e){return nPe(e)||typeof e=="function"||rPe(e)}function nPe(e){return typeof e=="function"&&(()=>{const t=Object.getPrototypeOf(e);return t.prototype&&t.prototype.isReactComponent})()}function rPe(e){return typeof e=="object"&&typeof e.$$typeof=="symbol"&&["react.memo","react.forward_ref"].includes(e.$$typeof.description)}function Cat(e){const t={state:{},onStateChange:()=>{},renderFallbackValue:null,...e},[n]=P.useState(()=>({current:Kke(t)})),[r,i]=P.useState(()=>n.current.initialState);return n.current.setOptions(a=>({...a,...e,state:{...r,...e.state},onStateChange:u=>{i(u),e.onStateChange==null||e.onStateChange(u)}})),n.current}function AI(e){for(var t=e.length/6|0,n=new Array(t),r=0;r<t;)n[r]="#"+e.slice(r*6,++r*6);return n}const wat=AI("1f77b4ff7f0e2ca02cd627289467bd8c564be377c27f7f7fbcbd2217becf"),Rat=AI("a6cee31f78b4b2df8a33a02cfb9a99e31a1cfdbf6fff7f00cab2d66a3d9affff99b15928"),Aat=AI("66c2a5fc8d628da0cbe78ac3a6d854ffd92fe5c494b3b3b3");function hw(e,t,n){e.prototype=t.prototype=n,n.constructor=e}function TI(e,t){var n=Object.create(e.prototype);for(var r in t)n[r]=t[r];return n}function e4(){}var fb=.7,A3=1/fb,f3="\\s*([+-]?\\d+)\\s*",Ex="\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)\\s*",R0="\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)%\\s*",iPe=/^#([0-9a-f]{3,8})$/,aPe=new RegExp(`^rgb\\(${f3},${f3},${f3}\\)$`),uPe=new RegExp(`^rgb\\(${R0},${R0},${R0}\\)$`),lPe=new RegExp(`^rgba\\(${f3},${f3},${f3},${Ex}\\)$`),oPe=new RegExp(`^rgba\\(${R0},${R0},${R0},${Ex}\\)$`),sPe=new RegExp(`^hsl\\(${Ex},${R0},${R0}\\)$`),cPe=new RegExp(`^hsla\\(${Ex},${R0},${R0},${Ex}\\)$`),iH={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};hw(e4,Dx,{copy(e){return Object.assign(new this.constructor,this,e)},displayable(){return this.rgb().displayable()},hex:aH,formatHex:aH,formatHex8:fPe,formatHsl:dPe,formatRgb:uH,toString:uH});function aH(){return this.rgb().formatHex()}function fPe(){return this.rgb().formatHex8()}function dPe(){return Hpe(this).formatHsl()}function uH(){return this.rgb().formatRgb()}function Dx(e){var t,n;return e=(e+"").trim().toLowerCase(),(t=iPe.exec(e))?(n=t[1].length,t=parseInt(t[1],16),n===6?lH(t):n===3?new ps(t>>8&15|t>>4&240,t>>4&15|t&240,(t&15)<<4|t&15,1):n===8?eE(t>>24&255,t>>16&255,t>>8&255,(t&255)/255):n===4?eE(t>>12&15|t>>8&240,t>>8&15|t>>4&240,t>>4&15|t&240,((t&15)<<4|t&15)/255):null):(t=aPe.exec(e))?new ps(t[1],t[2],t[3],1):(t=uPe.exec(e))?new ps(t[1]*255/100,t[2]*255/100,t[3]*255/100,1):(t=lPe.exec(e))?eE(t[1],t[2],t[3],t[4]):(t=oPe.exec(e))?eE(t[1]*255/100,t[2]*255/100,t[3]*255/100,t[4]):(t=sPe.exec(e))?cH(t[1],t[2]/100,t[3]/100,1):(t=cPe.exec(e))?cH(t[1],t[2]/100,t[3]/100,t[4]):iH.hasOwnProperty(e)?lH(iH[e]):e==="transparent"?new ps(NaN,NaN,NaN,0):null}function lH(e){return new ps(e>>16&255,e>>8&255,e&255,1)}function eE(e,t,n,r){return r<=0&&(e=t=n=NaN),new ps(e,t,n,r)}function Zpe(e){return e instanceof e4||(e=Dx(e)),e?(e=e.rgb(),new ps(e.r,e.g,e.b,e.opacity)):new ps}function h$(e,t,n,r){return arguments.length===1?Zpe(e):new ps(e,t,n,r??1)}function ps(e,t,n,r){this.r=+e,this.g=+t,this.b=+n,this.opacity=+r}hw(ps,h$,TI(e4,{brighter(e){return e=e==null?A3:Math.pow(A3,e),new ps(this.r*e,this.g*e,this.b*e,this.opacity)},darker(e){return e=e==null?fb:Math.pow(fb,e),new ps(this.r*e,this.g*e,this.b*e,this.opacity)},rgb(){return this},clamp(){return new ps(Z1(this.r),Z1(this.g),Z1(this.b),p$(this.opacity))},displayable(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:oH,formatHex:oH,formatHex8:hPe,formatRgb:sH,toString:sH}));function oH(){return`#${B1(this.r)}${B1(this.g)}${B1(this.b)}`}function hPe(){return`#${B1(this.r)}${B1(this.g)}${B1(this.b)}${B1((isNaN(this.opacity)?1:this.opacity)*255)}`}function sH(){const e=p$(this.opacity);return`${e===1?"rgb(":"rgba("}${Z1(this.r)}, ${Z1(this.g)}, ${Z1(this.b)}${e===1?")":`, ${e})`}`}function p$(e){return isNaN(e)?1:Math.max(0,Math.min(1,e))}function Z1(e){return Math.max(0,Math.min(255,Math.round(e)||0))}function B1(e){return e=Z1(e),(e<16?"0":"")+e.toString(16)}function cH(e,t,n,r){return r<=0?e=t=n=NaN:n<=0||n>=1?e=t=NaN:t<=0&&(e=NaN),new Wh(e,t,n,r)}function Hpe(e){if(e instanceof Wh)return new Wh(e.h,e.s,e.l,e.opacity);if(e instanceof e4||(e=Dx(e)),!e)return new Wh;if(e instanceof Wh)return e;e=e.rgb();var t=e.r/255,n=e.g/255,r=e.b/255,i=Math.min(t,n,r),a=Math.max(t,n,r),u=NaN,l=a-i,o=(a+i)/2;return l?(t===a?u=(n-r)/l+(n<r)*6:n===a?u=(r-t)/l+2:u=(t-n)/l+4,l/=o<.5?a+i:2-a-i,u*=60):l=o>0&&o<1?0:u,new Wh(u,l,o,e.opacity)}function pPe(e,t,n,r){return arguments.length===1?Hpe(e):new Wh(e,t,n,r??1)}function Wh(e,t,n,r){this.h=+e,this.s=+t,this.l=+n,this.opacity=+r}hw(Wh,pPe,TI(e4,{brighter(e){return e=e==null?A3:Math.pow(A3,e),new Wh(this.h,this.s,this.l*e,this.opacity)},darker(e){return e=e==null?fb:Math.pow(fb,e),new Wh(this.h,this.s,this.l*e,this.opacity)},rgb(){var e=this.h%360+(this.h<0)*360,t=isNaN(e)||isNaN(this.s)?0:this.s,n=this.l,r=n+(n<.5?n:1-n)*t,i=2*n-r;return new ps(Kk(e>=240?e-240:e+120,i,r),Kk(e,i,r),Kk(e<120?e+240:e-120,i,r),this.opacity)},clamp(){return new Wh(fH(this.h),tE(this.s),tE(this.l),p$(this.opacity))},displayable(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl(){const e=p$(this.opacity);return`${e===1?"hsl(":"hsla("}${fH(this.h)}, ${tE(this.s)*100}%, ${tE(this.l)*100}%${e===1?")":`, ${e})`}`}}));function fH(e){return e=(e||0)%360,e<0?e+360:e}function tE(e){return Math.max(0,Math.min(1,e||0))}function Kk(e,t,n){return(e<60?t+(n-t)*e/60:e<180?n:e<240?t+(n-t)*(240-e)/60:t)*255}const mPe=Math.PI/180,gPe=180/Math.PI;var Xpe=-.14861,kI=1.78277,PI=-.29227,pw=-.90649,$x=1.97294,dH=$x*pw,hH=$x*kI,pH=kI*PI-pw*Xpe;function vPe(e){if(e instanceof H1)return new H1(e.h,e.s,e.l,e.opacity);e instanceof ps||(e=Zpe(e));var t=e.r/255,n=e.g/255,r=e.b/255,i=(pH*r+dH*t-hH*n)/(pH+dH-hH),a=r-i,u=($x*(n-i)-PI*a)/pw,l=Math.sqrt(u*u+a*a)/($x*i*(1-i)),o=l?Math.atan2(u,a)*gPe-120:NaN;return new H1(o<0?o+360:o,l,i,e.opacity)}function ny(e,t,n,r){return arguments.length===1?vPe(e):new H1(e,t,n,r??1)}function H1(e,t,n,r){this.h=+e,this.s=+t,this.l=+n,this.opacity=+r}hw(H1,ny,TI(e4,{brighter(e){return e=e==null?A3:Math.pow(A3,e),new H1(this.h,this.s,this.l*e,this.opacity)},darker(e){return e=e==null?fb:Math.pow(fb,e),new H1(this.h,this.s,this.l*e,this.opacity)},rgb(){var e=isNaN(this.h)?0:(this.h+120)*mPe,t=+this.l,n=isNaN(this.s)?0:this.s*t*(1-t),r=Math.cos(e),i=Math.sin(e);return new ps(255*(t+n*(Xpe*r+kI*i)),255*(t+n*(PI*r+pw*i)),255*(t+n*($x*r)),this.opacity)}}));const mw=e=>()=>e;function Ype(e,t){return function(n){return e+n*t}}function yPe(e,t,n){return e=Math.pow(e,n),t=Math.pow(t,n)-e,n=1/n,function(r){return Math.pow(e+r*t,n)}}function bPe(e,t){var n=t-e;return n?Ype(e,n>180||n<-180?n-360*Math.round(n/360):n):mw(isNaN(e)?t:e)}function OPe(e){return(e=+e)==1?d3:function(t,n){return n-t?yPe(t,n,e):mw(isNaN(t)?n:t)}}function d3(e,t){var n=t-e;return n?Ype(e,n):mw(isNaN(e)?t:e)}const mH=(function e(t){var n=OPe(t);function r(i,a){var u=n((i=h$(i)).r,(a=h$(a)).r),l=n(i.g,a.g),o=n(i.b,a.b),s=d3(i.opacity,a.opacity);return function(c){return i.r=u(c),i.g=l(c),i.b=o(c),i.opacity=s(c),i+""}}return r.gamma=e,r})(1);function xPe(e,t){t||(t=[]);var n=e?Math.min(t.length,e.length):0,r=t.slice(),i;return function(a){for(i=0;i<n;++i)r[i]=e[i]*(1-a)+t[i]*a;return r}}function SPe(e){return ArrayBuffer.isView(e)&&!(e instanceof DataView)}function _Pe(e,t){var n=t?t.length:0,r=e?Math.min(n,e.length):0,i=new Array(r),a=new Array(n),u;for(u=0;u<r;++u)i[u]=t4(e[u],t[u]);for(;u<n;++u)a[u]=t[u];return function(l){for(u=0;u<r;++u)a[u]=i[u](l);return a}}function EPe(e,t){var n=new Date;return e=+e,t=+t,function(r){return n.setTime(e*(1-r)+t*r),n}}function m$(e,t){return e=+e,t=+t,function(n){return e*(1-n)+t*n}}function DPe(e,t){var n={},r={},i;(e===null||typeof e!="object")&&(e={}),(t===null||typeof t!="object")&&(t={});for(i in t)i in e?n[i]=t4(e[i],t[i]):r[i]=t[i];return function(a){for(i in n)r[i]=n[i](a);return r}}var oM=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,Wk=new RegExp(oM.source,"g");function $Pe(e){return function(){return e}}function CPe(e){return function(t){return e(t)+""}}function wPe(e,t){var n=oM.lastIndex=Wk.lastIndex=0,r,i,a,u=-1,l=[],o=[];for(e=e+"",t=t+"";(r=oM.exec(e))&&(i=Wk.exec(t));)(a=i.index)>n&&(a=t.slice(n,a),l[u]?l[u]+=a:l[++u]=a),(r=r[0])===(i=i[0])?l[u]?l[u]+=i:l[++u]=i:(l[++u]=null,o.push({i:u,x:m$(r,i)})),n=Wk.lastIndex;return n<t.length&&(a=t.slice(n),l[u]?l[u]+=a:l[++u]=a),l.length<2?o[0]?CPe(o[0].x):$Pe(t):(t=o.length,function(s){for(var c=0,d;c<t;++c)l[(d=o[c]).i]=d.x(s);return l.join("")})}function t4(e,t){var n=typeof t,r;return t==null||n==="boolean"?mw(t):(n==="number"?m$:n==="string"?(r=Dx(t))?(t=r,mH):wPe:t instanceof Dx?mH:t instanceof Date?EPe:SPe(t)?xPe:Array.isArray(t)?_Pe:typeof t.valueOf!="function"&&typeof t.toString!="function"||isNaN(t)?DPe:m$)(e,t)}function MI(e,t){return e=+e,t=+t,function(n){return Math.round(e*(1-n)+t*n)}}function Gpe(e){return(function t(n){n=+n;function r(i,a){var u=e((i=ny(i)).h,(a=ny(a)).h),l=d3(i.s,a.s),o=d3(i.l,a.l),s=d3(i.opacity,a.opacity);return function(c){return i.h=u(c),i.s=l(c),i.l=o(Math.pow(c,n)),i.opacity=s(c),i+""}}return r.gamma=t,r})(1)}Gpe(bPe);var Kpe=Gpe(d3);function RPe(e,t){t===void 0&&(t=e,e=t4);for(var n=0,r=t.length-1,i=t[0],a=new Array(r<0?0:r);n<r;)a[n]=e(i,i=t[++n]);return function(u){var l=Math.max(0,Math.min(r-1,Math.floor(u*=r)));return a[l](u-l)}}Kpe(ny(-100,.75,.35),ny(80,1.5,.8));var Tat=Kpe(ny(260,.75,.35),ny(80,1.5,.8));ny();var nE=h$(),APe=Math.PI/3,TPe=Math.PI*2/3;function kat(e){var t;return e=(.5-e)*Math.PI,nE.r=255*(t=Math.sin(e))*t,nE.g=255*(t=Math.sin(e+APe))*t,nE.b=255*(t=Math.sin(e+TPe))*t,nE+""}function kPe(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function Cx(e,t){return Cx=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,r){return n.__proto__=r,n},Cx(e,t)}function PPe(e,t){e.prototype=Object.create(t.prototype),e.prototype.constructor=e,Cx(e,t)}function sM(e){return sM=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},sM(e)}function MPe(e){try{return Function.toString.call(e).indexOf("[native code]")!==-1}catch{return typeof e=="function"}}function Wpe(){try{var e=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch{}return(Wpe=function(){return!!e})()}function FPe(e,t,n){if(Wpe())return Reflect.construct.apply(null,arguments);var r=[null];r.push.apply(r,t);var i=new(e.bind.apply(e,r));return n&&Cx(i,n.prototype),i}function cM(e){var t=typeof Map=="function"?new Map:void 0;return cM=function(r){if(r===null||!MPe(r))return r;if(typeof r!="function")throw new TypeError("Super expression must either be null or a function");if(t!==void 0){if(t.has(r))return t.get(r);t.set(r,i)}function i(){return FPe(r,arguments,sM(this).constructor)}return i.prototype=Object.create(r.prototype,{constructor:{value:i,enumerable:!1,writable:!0,configurable:!0}}),Cx(i,r)},cM(e)}var x0=(function(e){PPe(t,e);function t(n){var r;return r=e.call(this,"An error occurred. See https://github.com/styled-components/polished/blob/main/src/internalHelpers/errors.md#"+n+" for more information.")||this,kPe(r)}return t})(cM(Error));function Jk(e){return Math.round(e*255)}function NPe(e,t,n){return Jk(e)+","+Jk(t)+","+Jk(n)}function wx(e,t,n,r){if(r===void 0&&(r=NPe),t===0)return r(n,n,n);var i=(e%360+360)%360/60,a=(1-Math.abs(2*n-1))*t,u=a*(1-Math.abs(i%2-1)),l=0,o=0,s=0;i>=0&&i<1?(l=a,o=u):i>=1&&i<2?(l=u,o=a):i>=2&&i<3?(o=a,s=u):i>=3&&i<4?(o=u,s=a):i>=4&&i<5?(l=u,s=a):i>=5&&i<6&&(l=a,s=u);var c=n-a/2,d=l+c,h=o+c,m=s+c;return r(d,h,m)}var gH={aliceblue:"f0f8ff",antiquewhite:"faebd7",aqua:"00ffff",aquamarine:"7fffd4",azure:"f0ffff",beige:"f5f5dc",bisque:"ffe4c4",black:"000",blanchedalmond:"ffebcd",blue:"0000ff",blueviolet:"8a2be2",brown:"a52a2a",burlywood:"deb887",cadetblue:"5f9ea0",chartreuse:"7fff00",chocolate:"d2691e",coral:"ff7f50",cornflowerblue:"6495ed",cornsilk:"fff8dc",crimson:"dc143c",cyan:"00ffff",darkblue:"00008b",darkcyan:"008b8b",darkgoldenrod:"b8860b",darkgray:"a9a9a9",darkgreen:"006400",darkgrey:"a9a9a9",darkkhaki:"bdb76b",darkmagenta:"8b008b",darkolivegreen:"556b2f",darkorange:"ff8c00",darkorchid:"9932cc",darkred:"8b0000",darksalmon:"e9967a",darkseagreen:"8fbc8f",darkslateblue:"483d8b",darkslategray:"2f4f4f",darkslategrey:"2f4f4f",darkturquoise:"00ced1",darkviolet:"9400d3",deeppink:"ff1493",deepskyblue:"00bfff",dimgray:"696969",dimgrey:"696969",dodgerblue:"1e90ff",firebrick:"b22222",floralwhite:"fffaf0",forestgreen:"228b22",fuchsia:"ff00ff",gainsboro:"dcdcdc",ghostwhite:"f8f8ff",gold:"ffd700",goldenrod:"daa520",gray:"808080",green:"008000",greenyellow:"adff2f",grey:"808080",honeydew:"f0fff0",hotpink:"ff69b4",indianred:"cd5c5c",indigo:"4b0082",ivory:"fffff0",khaki:"f0e68c",lavender:"e6e6fa",lavenderblush:"fff0f5",lawngreen:"7cfc00",lemonchiffon:"fffacd",lightblue:"add8e6",lightcoral:"f08080",lightcyan:"e0ffff",lightgoldenrodyellow:"fafad2",lightgray:"d3d3d3",lightgreen:"90ee90",lightgrey:"d3d3d3",lightpink:"ffb6c1",lightsalmon:"ffa07a",lightseagreen:"20b2aa",lightskyblue:"87cefa",lightslategray:"789",lightslategrey:"789",lightsteelblue:"b0c4de",lightyellow:"ffffe0",lime:"0f0",limegreen:"32cd32",linen:"faf0e6",magenta:"f0f",maroon:"800000",mediumaquamarine:"66cdaa",mediumblue:"0000cd",mediumorchid:"ba55d3",mediumpurple:"9370db",mediumseagreen:"3cb371",mediumslateblue:"7b68ee",mediumspringgreen:"00fa9a",mediumturquoise:"48d1cc",mediumvioletred:"c71585",midnightblue:"191970",mintcream:"f5fffa",mistyrose:"ffe4e1",moccasin:"ffe4b5",navajowhite:"ffdead",navy:"000080",oldlace:"fdf5e6",olive:"808000",olivedrab:"6b8e23",orange:"ffa500",orangered:"ff4500",orchid:"da70d6",palegoldenrod:"eee8aa",palegreen:"98fb98",paleturquoise:"afeeee",palevioletred:"db7093",papayawhip:"ffefd5",peachpuff:"ffdab9",peru:"cd853f",pink:"ffc0cb",plum:"dda0dd",powderblue:"b0e0e6",purple:"800080",rebeccapurple:"639",red:"f00",rosybrown:"bc8f8f",royalblue:"4169e1",saddlebrown:"8b4513",salmon:"fa8072",sandybrown:"f4a460",seagreen:"2e8b57",seashell:"fff5ee",sienna:"a0522d",silver:"c0c0c0",skyblue:"87ceeb",slateblue:"6a5acd",slategray:"708090",slategrey:"708090",snow:"fffafa",springgreen:"00ff7f",steelblue:"4682b4",tan:"d2b48c",teal:"008080",thistle:"d8bfd8",tomato:"ff6347",turquoise:"40e0d0",violet:"ee82ee",wheat:"f5deb3",white:"fff",whitesmoke:"f5f5f5",yellow:"ff0",yellowgreen:"9acd32"};function IPe(e){if(typeof e!="string")return e;var t=e.toLowerCase();return gH[t]?"#"+gH[t]:e}var LPe=/^#[a-fA-F0-9]{6}$/,BPe=/^#[a-fA-F0-9]{8}$/,QPe=/^#[a-fA-F0-9]{3}$/,zPe=/^#[a-fA-F0-9]{4}$/,eP=/^rgb\(\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*\)$/i,qPe=/^rgb(?:a)?\(\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,|\/)\s*([-+]?\d*[.]?\d+[%]?)\s*\)$/i,VPe=/^hsl\(\s*(\d{0,3}[.]?[0-9]+(?:deg)?)\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*\)$/i,UPe=/^hsl(?:a)?\(\s*(\d{0,3}[.]?[0-9]+(?:deg)?)\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,|\/)\s*([-+]?\d*[.]?\d+[%]?)\s*\)$/i;function db(e){if(typeof e!="string")throw new x0(3);var t=IPe(e);if(t.match(LPe))return{red:parseInt(""+t[1]+t[2],16),green:parseInt(""+t[3]+t[4],16),blue:parseInt(""+t[5]+t[6],16)};if(t.match(BPe)){var n=parseFloat((parseInt(""+t[7]+t[8],16)/255).toFixed(2));return{red:parseInt(""+t[1]+t[2],16),green:parseInt(""+t[3]+t[4],16),blue:parseInt(""+t[5]+t[6],16),alpha:n}}if(t.match(QPe))return{red:parseInt(""+t[1]+t[1],16),green:parseInt(""+t[2]+t[2],16),blue:parseInt(""+t[3]+t[3],16)};if(t.match(zPe)){var r=parseFloat((parseInt(""+t[4]+t[4],16)/255).toFixed(2));return{red:parseInt(""+t[1]+t[1],16),green:parseInt(""+t[2]+t[2],16),blue:parseInt(""+t[3]+t[3],16),alpha:r}}var i=eP.exec(t);if(i)return{red:parseInt(""+i[1],10),green:parseInt(""+i[2],10),blue:parseInt(""+i[3],10)};var a=qPe.exec(t.substring(0,50));if(a)return{red:parseInt(""+a[1],10),green:parseInt(""+a[2],10),blue:parseInt(""+a[3],10),alpha:parseFloat(""+a[4])>1?parseFloat(""+a[4])/100:parseFloat(""+a[4])};var u=VPe.exec(t);if(u){var l=parseInt(""+u[1],10),o=parseInt(""+u[2],10)/100,s=parseInt(""+u[3],10)/100,c="rgb("+wx(l,o,s)+")",d=eP.exec(c);if(!d)throw new x0(4,t,c);return{red:parseInt(""+d[1],10),green:parseInt(""+d[2],10),blue:parseInt(""+d[3],10)}}var h=UPe.exec(t.substring(0,50));if(h){var m=parseInt(""+h[1],10),y=parseInt(""+h[2],10)/100,v=parseInt(""+h[3],10)/100,_="rgb("+wx(m,y,v)+")",S=eP.exec(_);if(!S)throw new x0(4,t,_);return{red:parseInt(""+S[1],10),green:parseInt(""+S[2],10),blue:parseInt(""+S[3],10),alpha:parseFloat(""+h[4])>1?parseFloat(""+h[4])/100:parseFloat(""+h[4])}}throw new x0(5)}function jPe(e){var t=e.red/255,n=e.green/255,r=e.blue/255,i=Math.max(t,n,r),a=Math.min(t,n,r),u=(i+a)/2;if(i===a)return e.alpha!==void 0?{hue:0,saturation:0,lightness:u,alpha:e.alpha}:{hue:0,saturation:0,lightness:u};var l,o=i-a,s=u>.5?o/(2-i-a):o/(i+a);switch(i){case t:l=(n-r)/o+(n<r?6:0);break;case n:l=(r-t)/o+2;break;default:l=(t-n)/o+4;break}return l*=60,e.alpha!==void 0?{hue:l,saturation:s,lightness:u,alpha:e.alpha}:{hue:l,saturation:s,lightness:u}}function by(e){return jPe(db(e))}var ZPe=function(t){return t.length===7&&t[1]===t[2]&&t[3]===t[4]&&t[5]===t[6]?"#"+t[1]+t[3]+t[5]:t},fM=ZPe;function $1(e){var t=e.toString(16);return t.length===1?"0"+t:t}function tP(e){return $1(Math.round(e*255))}function HPe(e,t,n){return fM("#"+tP(e)+tP(t)+tP(n))}function g$(e,t,n){return wx(e,t,n,HPe)}function XPe(e,t,n){if(typeof e=="number"&&typeof t=="number"&&typeof n=="number")return g$(e,t,n);if(typeof e=="object"&&t===void 0&&n===void 0)return g$(e.hue,e.saturation,e.lightness);throw new x0(1)}function YPe(e,t,n,r){if(typeof e=="number"&&typeof t=="number"&&typeof n=="number"&&typeof r=="number")return r>=1?g$(e,t,n):"rgba("+wx(e,t,n)+","+r+")";if(typeof e=="object"&&t===void 0&&n===void 0&&r===void 0)return e.alpha>=1?g$(e.hue,e.saturation,e.lightness):"rgba("+wx(e.hue,e.saturation,e.lightness)+","+e.alpha+")";throw new x0(2)}function dM(e,t,n){if(typeof e=="number"&&typeof t=="number"&&typeof n=="number")return fM("#"+$1(e)+$1(t)+$1(n));if(typeof e=="object"&&t===void 0&&n===void 0)return fM("#"+$1(e.red)+$1(e.green)+$1(e.blue));throw new x0(6)}function gw(e,t,n,r){if(typeof e=="string"&&typeof t=="number"){var i=db(e);return"rgba("+i.red+","+i.green+","+i.blue+","+t+")"}else{if(typeof e=="number"&&typeof t=="number"&&typeof n=="number"&&typeof r=="number")return r>=1?dM(e,t,n):"rgba("+e+","+t+","+n+","+r+")";if(typeof e=="object"&&t===void 0&&n===void 0&&r===void 0)return e.alpha>=1?dM(e.red,e.green,e.blue):"rgba("+e.red+","+e.green+","+e.blue+","+e.alpha+")"}throw new x0(7)}var GPe=function(t){return typeof t.red=="number"&&typeof t.green=="number"&&typeof t.blue=="number"&&(typeof t.alpha!="number"||typeof t.alpha>"u")},KPe=function(t){return typeof t.red=="number"&&typeof t.green=="number"&&typeof t.blue=="number"&&typeof t.alpha=="number"},WPe=function(t){return typeof t.hue=="number"&&typeof t.saturation=="number"&&typeof t.lightness=="number"&&(typeof t.alpha!="number"||typeof t.alpha>"u")},JPe=function(t){return typeof t.hue=="number"&&typeof t.saturation=="number"&&typeof t.lightness=="number"&&typeof t.alpha=="number"};function Oy(e){if(typeof e!="object")throw new x0(8);if(KPe(e))return gw(e);if(GPe(e))return dM(e);if(JPe(e))return YPe(e);if(WPe(e))return XPe(e);throw new x0(8)}function Jpe(e,t,n){return function(){var i=n.concat(Array.prototype.slice.call(arguments));return i.length>=t?e.apply(this,i):Jpe(e,t,i)}}function ed(e){return Jpe(e,e.length,[])}function e8e(e,t){if(t==="transparent")return t;var n=by(t);return Oy(of({},n,{hue:n.hue+parseFloat(e)}))}ed(e8e);function n4(e,t,n){return Math.max(e,Math.min(t,n))}function t8e(e,t){if(t==="transparent")return t;var n=by(t);return Oy(of({},n,{lightness:n4(0,1,n.lightness-parseFloat(e))}))}var n8e=ed(t8e),Pat=n8e;function r8e(e,t){if(t==="transparent")return t;var n=by(t);return Oy(of({},n,{saturation:n4(0,1,n.saturation-parseFloat(e))}))}ed(r8e);function vH(e){if(e==="transparent")return 0;var t=db(e),n=Object.keys(t).map(function(u){var l=t[u]/255;return l<=.03928?l/12.92:Math.pow((l+.055)/1.055,2.4)}),r=n[0],i=n[1],a=n[2];return parseFloat((.2126*r+.7152*i+.0722*a).toFixed(3))}function Mat(e,t){var n=vH(e),r=vH(t);return parseFloat((n>r?(n+.05)/(r+.05):(r+.05)/(n+.05)).toFixed(2))}function i8e(e,t){if(t==="transparent")return t;var n=by(t);return Oy(of({},n,{lightness:n4(0,1,n.lightness+parseFloat(e))}))}var a8e=ed(i8e),Fat=a8e;function u8e(e,t,n){if(t==="transparent")return n;if(n==="transparent")return t;if(e===0)return n;var r=db(t),i=of({},r,{alpha:typeof r.alpha=="number"?r.alpha:1}),a=db(n),u=of({},a,{alpha:typeof a.alpha=="number"?a.alpha:1}),l=i.alpha-u.alpha,o=parseFloat(e)*2-1,s=o*l===-1?o:o+l,c=1+o*l,d=(s/c+1)/2,h=1-d,m={red:Math.floor(i.red*d+u.red*h),green:Math.floor(i.green*d+u.green*h),blue:Math.floor(i.blue*d+u.blue*h),alpha:i.alpha*parseFloat(e)+u.alpha*(1-parseFloat(e))};return gw(m)}var l8e=ed(u8e),e0e=l8e;function o8e(e,t){if(t==="transparent")return t;var n=db(t),r=typeof n.alpha=="number"?n.alpha:1,i=of({},n,{alpha:n4(0,1,(r*100+parseFloat(e)*100)/100)});return gw(i)}ed(o8e);function s8e(e,t){if(t==="transparent")return t;var n=by(t);return Oy(of({},n,{saturation:n4(0,1,n.saturation+parseFloat(e))}))}ed(s8e);function c8e(e,t){return t==="transparent"?t:Oy(of({},by(t),{hue:parseFloat(e)}))}ed(c8e);function f8e(e,t){return t==="transparent"?t:Oy(of({},by(t),{lightness:parseFloat(e)}))}ed(f8e);function d8e(e,t){return t==="transparent"?t:Oy(of({},by(t),{saturation:parseFloat(e)}))}ed(d8e);function h8e(e,t){return t==="transparent"?t:e0e(parseFloat(e),"rgb(0, 0, 0)",t)}var p8e=ed(h8e),Nat=p8e;function m8e(e,t){return t==="transparent"?t:e0e(parseFloat(e),"rgb(255, 255, 255)",t)}ed(m8e);function g8e(e,t){if(t==="transparent")return t;var n=db(t),r=typeof n.alpha=="number"?n.alpha:1,i=of({},n,{alpha:n4(0,1,+(r*100-parseFloat(e)*100).toFixed(2)/100)});return gw(i)}var v8e=ed(g8e),Iat=v8e;function y8e(e){return Math.abs(e=Math.round(e))>=1e21?e.toLocaleString("en").replace(/,/g,""):e.toString(10)}function v$(e,t){if((n=(e=t?e.toExponential(t-1):e.toExponential()).indexOf("e"))<0)return null;var n,r=e.slice(0,n);return[r.length>1?r[0]+r.slice(2):r,+e.slice(n+1)]}function T3(e){return e=v$(Math.abs(e)),e?e[1]:NaN}function b8e(e,t){return function(n,r){for(var i=n.length,a=[],u=0,l=e[0],o=0;i>0&&l>0&&(o+l+1>r&&(l=Math.max(1,r-o)),a.push(n.substring(i-=l,i+l)),!((o+=l+1)>r));)l=e[u=(u+1)%e.length];return a.reverse().join(t)}}function O8e(e){return function(t){return t.replace(/[0-9]/g,function(n){return e[+n]})}}var x8e=/^(?:(.)?([<>=^]))?([+\-( ])?([$#])?(0)?(\d+)?(,)?(\.\d+)?(~)?([a-z%])?$/i;function Rx(e){if(!(t=x8e.exec(e)))throw new Error("invalid format: "+e);var t;return new FI({fill:t[1],align:t[2],sign:t[3],symbol:t[4],zero:t[5],width:t[6],comma:t[7],precision:t[8]&&t[8].slice(1),trim:t[9],type:t[10]})}Rx.prototype=FI.prototype;function FI(e){this.fill=e.fill===void 0?" ":e.fill+"",this.align=e.align===void 0?">":e.align+"",this.sign=e.sign===void 0?"-":e.sign+"",this.symbol=e.symbol===void 0?"":e.symbol+"",this.zero=!!e.zero,this.width=e.width===void 0?void 0:+e.width,this.comma=!!e.comma,this.precision=e.precision===void 0?void 0:+e.precision,this.trim=!!e.trim,this.type=e.type===void 0?"":e.type+""}FI.prototype.toString=function(){return this.fill+this.align+this.sign+this.symbol+(this.zero?"0":"")+(this.width===void 0?"":Math.max(1,this.width|0))+(this.comma?",":"")+(this.precision===void 0?"":"."+Math.max(0,this.precision|0))+(this.trim?"~":"")+this.type};function S8e(e){e:for(var t=e.length,n=1,r=-1,i;n<t;++n)switch(e[n]){case".":r=i=n;break;case"0":r===0&&(r=n),i=n;break;default:if(!+e[n])break e;r>0&&(r=0);break}return r>0?e.slice(0,r)+e.slice(i+1):e}var t0e;function _8e(e,t){var n=v$(e,t);if(!n)return e+"";var r=n[0],i=n[1],a=i-(t0e=Math.max(-8,Math.min(8,Math.floor(i/3)))*3)+1,u=r.length;return a===u?r:a>u?r+new Array(a-u+1).join("0"):a>0?r.slice(0,a)+"."+r.slice(a):"0."+new Array(1-a).join("0")+v$(e,Math.max(0,t+a-1))[0]}function yH(e,t){var n=v$(e,t);if(!n)return e+"";var r=n[0],i=n[1];return i<0?"0."+new Array(-i).join("0")+r:r.length>i+1?r.slice(0,i+1)+"."+r.slice(i+1):r+new Array(i-r.length+2).join("0")}const bH={"%":(e,t)=>(e*100).toFixed(t),b:e=>Math.round(e).toString(2),c:e=>e+"",d:y8e,e:(e,t)=>e.toExponential(t),f:(e,t)=>e.toFixed(t),g:(e,t)=>e.toPrecision(t),o:e=>Math.round(e).toString(8),p:(e,t)=>yH(e*100,t),r:yH,s:_8e,X:e=>Math.round(e).toString(16).toUpperCase(),x:e=>Math.round(e).toString(16)};function OH(e){return e}var xH=Array.prototype.map,SH=["y","z","a","f","p","n","µ","m","","k","M","G","T","P","E","Z","Y"];function E8e(e){var t=e.grouping===void 0||e.thousands===void 0?OH:b8e(xH.call(e.grouping,Number),e.thousands+""),n=e.currency===void 0?"":e.currency[0]+"",r=e.currency===void 0?"":e.currency[1]+"",i=e.decimal===void 0?".":e.decimal+"",a=e.numerals===void 0?OH:O8e(xH.call(e.numerals,String)),u=e.percent===void 0?"%":e.percent+"",l=e.minus===void 0?"−":e.minus+"",o=e.nan===void 0?"NaN":e.nan+"";function s(d){d=Rx(d);var h=d.fill,m=d.align,y=d.sign,v=d.symbol,_=d.zero,S=d.width,E=d.comma,C=d.precision,T=d.trim,R=d.type;R==="n"?(E=!0,R="g"):bH[R]||(C===void 0&&(C=12),T=!0,R="g"),(_||h==="0"&&m==="=")&&(_=!0,h="0",m="=");var $=v==="$"?n:v==="#"&&/[boxX]/.test(R)?"0"+R.toLowerCase():"",k=v==="$"?r:/[%p]/.test(R)?u:"",F=bH[R],L=/[defgprs%]/.test(R);C=C===void 0?6:/[gprs]/.test(R)?Math.max(1,Math.min(21,C)):Math.max(0,Math.min(20,C));function j(V){var q=$,N=k,U,W,G;if(R==="c")N=F(V)+N,V="";else{V=+V;var J=V<0||1/V<0;if(V=isNaN(V)?o:F(Math.abs(V),C),T&&(V=S8e(V)),J&&+V==0&&y!=="+"&&(J=!1),q=(J?y==="("?y:l:y==="-"||y==="("?"":y)+q,N=(R==="s"?SH[8+t0e/3]:"")+N+(J&&y==="("?")":""),L){for(U=-1,W=V.length;++U<W;)if(G=V.charCodeAt(U),48>G||G>57){N=(G===46?i+V.slice(U+1):V.slice(U))+N,V=V.slice(0,U);break}}}E&&!_&&(V=t(V,1/0));var te=q.length+V.length+N.length,H=te<S?new Array(S-te+1).join(h):"";switch(E&&_&&(V=t(H+V,H.length?S-N.length:1/0),H=""),m){case"<":V=q+V+N+H;break;case"=":V=q+H+V+N;break;case"^":V=H.slice(0,te=H.length>>1)+q+V+N+H.slice(te);break;default:V=H+q+V+N;break}return a(V)}return j.toString=function(){return d+""},j}function c(d,h){var m=s((d=Rx(d),d.type="f",d)),y=Math.max(-8,Math.min(8,Math.floor(T3(h)/3)))*3,v=Math.pow(10,-y),_=SH[8+y/3];return function(S){return m(v*S)+_}}return{format:s,formatPrefix:c}}var rE,NI,n0e;D8e({thousands:",",grouping:[3],currency:["$",""]});function D8e(e){return rE=E8e(e),NI=rE.format,n0e=rE.formatPrefix,rE}function $8e(e){return Math.max(0,-T3(Math.abs(e)))}function C8e(e,t){return Math.max(0,Math.max(-8,Math.min(8,Math.floor(T3(t)/3)))*3-T3(Math.abs(e)))}function w8e(e,t){return e=Math.abs(e),t=Math.abs(t)-e,Math.max(0,T3(t)-T3(e))+1}const R8e=nN({String:ot.string,Number:ot.number,"True False":ot.bool,PropertyName:ot.propertyName,Null:ot.null,", :":ot.separator,"[ ]":ot.squareBracket,"{ }":ot.brace}),Lat=$3.deserialize({version:14,states:"$bOVQPOOOOQO'#Cb'#CbOnQPO'#CeOvQPO'#ClOOQO'#Cr'#CrQOQPOOOOQO'#Cg'#CgO}QPO'#CfO!SQPO'#CtOOQO,59P,59PO![QPO,59PO!aQPO'#CuOOQO,59W,59WO!iQPO,59WOVQPO,59QOqQPO'#CmO!nQPO,59`OOQO1G.k1G.kOVQPO'#CnO!vQPO,59aOOQO1G.r1G.rOOQO1G.l1G.lOOQO,59X,59XOOQO-E6k-E6kOOQO,59Y,59YOOQO-E6l-E6l",stateData:"#O~OeOS~OQSORSOSSOTSOWQO_ROgPO~OVXOgUO~O^[O~PVO[^O~O]_OVhX~OVaO~O]bO^iX~O^dO~O]_OVha~O]bO^ia~O",goto:"!kjPPPPPPkPPkqwPPPPk{!RPPP!XP!e!hXSOR^bQWQRf_TVQ_Q`WRg`QcZRicQTOQZRQe^RhbRYQR]R",nodeNames:"⚠ JsonText True False Null Number String } { Object Property PropertyName : , ] [ Array",maxTerm:25,nodeProps:[["isolate",-2,6,11,""],["openedBy",7,"{",14,"["],["closedBy",8,"}",15,"]"]],propSources:[R8e],skippedNodes:[0],repeatNodeCount:2,tokenData:"(|~RaXY!WYZ!W]^!Wpq!Wrs!]|}$u}!O$z!Q!R%T!R![&c![!]&t!}#O&y#P#Q'O#Y#Z'T#b#c'r#h#i(Z#o#p(r#q#r(w~!]Oe~~!`Wpq!]qr!]rs!xs#O!]#O#P!}#P;'S!];'S;=`$o<%lO!]~!}Og~~#QXrs!]!P!Q!]#O#P!]#U#V!]#Y#Z!]#b#c!]#f#g!]#h#i!]#i#j#m~#pR!Q![#y!c!i#y#T#Z#y~#|R!Q![$V!c!i$V#T#Z$V~$YR!Q![$c!c!i$c#T#Z$c~$fR!Q![!]!c!i!]#T#Z!]~$rP;=`<%l!]~$zO]~~$}Q!Q!R%T!R![&c~%YRT~!O!P%c!g!h%w#X#Y%w~%fP!Q![%i~%nRT~!Q![%i!g!h%w#X#Y%w~%zR{|&T}!O&T!Q![&Z~&WP!Q![&Z~&`PT~!Q![&Z~&hST~!O!P%c!Q![&c!g!h%w#X#Y%w~&yO[~~'OO_~~'TO^~~'WP#T#U'Z~'^P#`#a'a~'dP#g#h'g~'jP#X#Y'm~'rOR~~'uP#i#j'x~'{P#`#a(O~(RP#`#a(U~(ZOS~~(^P#f#g(a~(dP#i#j(g~(jP#X#Y(m~(rOQ~~(wOW~~(|OV~",tokenizers:[0],topRules:{JsonText:[0,1]},tokenPrec:0});function ry(){return ry=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},ry.apply(null,arguments)}function Bat(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}const A8e=1024;let T8e=0;class nP{constructor(t,n){this.from=t,this.to=n}}class su{constructor(t={}){this.id=T8e++,this.perNode=!!t.perNode,this.deserialize=t.deserialize||(()=>{throw new Error("This node type doesn't define a deserialize function")}),this.combine=t.combine||null}add(t){if(this.perNode)throw new RangeError("Can't add per-node props to node types");return typeof t!="function"&&(t=fg.match(t)),n=>{let r=t(n);return r===void 0?null:[this,r]}}}su.closedBy=new su({deserialize:e=>e.split(" ")});su.openedBy=new su({deserialize:e=>e.split(" ")});su.group=new su({deserialize:e=>e.split(" ")});su.isolate=new su({deserialize:e=>{if(e&&e!="rtl"&&e!="ltr"&&e!="auto")throw new RangeError("Invalid value for isolate: "+e);return e||"auto"}});su.contextHash=new su({perNode:!0});su.lookAhead=new su({perNode:!0});su.mounted=new su({perNode:!0});class y${constructor(t,n,r){this.tree=t,this.overlay=n,this.parser=r}static get(t){return t&&t.props&&t.props[su.mounted.id]}}const k8e=Object.create(null);class fg{constructor(t,n,r,i=0){this.name=t,this.props=n,this.id=r,this.flags=i}static define(t){let n=t.props&&t.props.length?Object.create(null):k8e,r=(t.top?1:0)|(t.skipped?2:0)|(t.error?4:0)|(t.name==null?8:0),i=new fg(t.name||"",n,t.id,r);if(t.props){for(let a of t.props)if(Array.isArray(a)||(a=a(i)),a){if(a[0].perNode)throw new RangeError("Can't store a per-node prop on a node type");n[a[0].id]=a[1]}}return i}prop(t){return this.props[t.id]}get isTop(){return(this.flags&1)>0}get isSkipped(){return(this.flags&2)>0}get isError(){return(this.flags&4)>0}get isAnonymous(){return(this.flags&8)>0}is(t){if(typeof t=="string"){if(this.name==t)return!0;let n=this.prop(su.group);return n?n.indexOf(t)>-1:!1}return this.id==t}static match(t){let n=Object.create(null);for(let r in t)for(let i of r.split(" "))n[i]=t[r];return r=>{for(let i=r.prop(su.group),a=-1;a<(i?i.length:0);a++){let u=n[a<0?r.name:i[a]];if(u)return u}}}}fg.none=new fg("",Object.create(null),0,8);const iE=new WeakMap,_H=new WeakMap;var hs;(function(e){e[e.ExcludeBuffers=1]="ExcludeBuffers",e[e.IncludeAnonymous=2]="IncludeAnonymous",e[e.IgnoreMounts=4]="IgnoreMounts",e[e.IgnoreOverlays=8]="IgnoreOverlays"})(hs||(hs={}));class A0{constructor(t,n,r,i,a){if(this.type=t,this.children=n,this.positions=r,this.length=i,this.props=null,a&&a.length){this.props=Object.create(null);for(let[u,l]of a)this.props[typeof u=="number"?u:u.id]=l}}toString(){let t=y$.get(this);if(t&&!t.overlay)return t.tree.toString();let n="";for(let r of this.children){let i=r.toString();i&&(n&&(n+=","),n+=i)}return this.type.name?(/\W/.test(this.type.name)&&!this.type.isError?JSON.stringify(this.type.name):this.type.name)+(n.length?"("+n+")":""):n}cursor(t=0){return new pM(this.topNode,t)}cursorAt(t,n=0,r=0){let i=iE.get(this)||this.topNode,a=new pM(i);return a.moveTo(t,n),iE.set(this,a._tree),a}get topNode(){return new Gd(this,0,0,null)}resolve(t,n=0){let r=Ax(iE.get(this)||this.topNode,t,n,!1);return iE.set(this,r),r}resolveInner(t,n=0){let r=Ax(_H.get(this)||this.topNode,t,n,!0);return _H.set(this,r),r}resolveStack(t,n=0){return F8e(this,t,n)}iterate(t){let{enter:n,leave:r,from:i=0,to:a=this.length}=t,u=t.mode||0,l=(u&hs.IncludeAnonymous)>0;for(let o=this.cursor(u|hs.IncludeAnonymous);;){let s=!1;if(o.from<=a&&o.to>=i&&(!l&&o.type.isAnonymous||n(o)!==!1)){if(o.firstChild())continue;s=!0}for(;s&&r&&(l||!o.type.isAnonymous)&&r(o),!o.nextSibling();){if(!o.parent())return;s=!0}}}prop(t){return t.perNode?this.props?this.props[t.id]:void 0:this.type.prop(t)}get propValues(){let t=[];if(this.props)for(let n in this.props)t.push([+n,this.props[n]]);return t}balance(t={}){return this.children.length<=8?this:BI(fg.none,this.children,this.positions,0,this.children.length,0,this.length,(n,r,i)=>new A0(this.type,n,r,i,this.propValues),t.makeTree||((n,r,i)=>new A0(fg.none,n,r,i)))}static build(t){return N8e(t)}}A0.empty=new A0(fg.none,[],[],0);class II{constructor(t,n){this.buffer=t,this.index=n}get id(){return this.buffer[this.index-4]}get start(){return this.buffer[this.index-3]}get end(){return this.buffer[this.index-2]}get size(){return this.buffer[this.index-1]}get pos(){return this.index}next(){this.index-=4}fork(){return new II(this.buffer,this.index)}}class iy{constructor(t,n,r){this.buffer=t,this.length=n,this.set=r}get type(){return fg.none}toString(){let t=[];for(let n=0;n<this.buffer.length;)t.push(this.childString(n)),n=this.buffer[n+3];return t.join(",")}childString(t){let n=this.buffer[t],r=this.buffer[t+3],i=this.set.types[n],a=i.name;if(/\W/.test(a)&&!i.isError&&(a=JSON.stringify(a)),t+=4,r==t)return a;let u=[];for(;t<r;)u.push(this.childString(t)),t=this.buffer[t+3];return a+"("+u.join(",")+")"}findChild(t,n,r,i,a){let{buffer:u}=this,l=-1;for(let o=t;o!=n&&!(r0e(a,i,u[o+1],u[o+2])&&(l=o,r>0));o=u[o+3]);return l}slice(t,n,r){let i=this.buffer,a=new Uint16Array(n-t),u=0;for(let l=t,o=0;l<n;){a[o++]=i[l++],a[o++]=i[l++]-r;let s=a[o++]=i[l++]-r;a[o++]=i[l++]-t,u=Math.max(u,s)}return new iy(a,u,this.set)}}function r0e(e,t,n,r){switch(e){case-2:return n<t;case-1:return r>=t&&n<t;case 0:return n<t&&r>t;case 1:return n<=t&&r>t;case 2:return r>t;case 4:return!0}}function Ax(e,t,n,r){for(var i;e.from==e.to||(n<1?e.from>=t:e.from>t)||(n>-1?e.to<=t:e.to<t);){let u=!r&&e instanceof Gd&&e.index<0?null:e.parent;if(!u)return e;e=u}let a=r?0:hs.IgnoreOverlays;if(r)for(let u=e,l=u.parent;l;u=l,l=u.parent)u instanceof Gd&&u.index<0&&((i=l.enter(t,n,a))===null||i===void 0?void 0:i.from)!=u.from&&(e=l);for(;;){let u=e.enter(t,n,a);if(!u)return e;e=u}}class i0e{cursor(t=0){return new pM(this,t)}getChild(t,n=null,r=null){let i=EH(this,t,n,r);return i.length?i[0]:null}getChildren(t,n=null,r=null){return EH(this,t,n,r)}resolve(t,n=0){return Ax(this,t,n,!1)}resolveInner(t,n=0){return Ax(this,t,n,!0)}matchContext(t){return hM(this.parent,t)}enterUnfinishedNodesBefore(t){let n=this.childBefore(t),r=this;for(;n;){let i=n.lastChild;if(!i||i.to!=n.to)break;i.type.isError&&i.from==i.to?(r=n,n=i.prevSibling):n=i}return r}get node(){return this}get next(){return this.parent}}class Gd extends i0e{constructor(t,n,r,i){super(),this._tree=t,this.from=n,this.index=r,this._parent=i}get type(){return this._tree.type}get name(){return this._tree.type.name}get to(){return this.from+this._tree.length}nextChild(t,n,r,i,a=0){for(let u=this;;){for(let{children:l,positions:o}=u._tree,s=n>0?l.length:-1;t!=s;t+=n){let c=l[t],d=o[t]+u.from;if(r0e(i,r,d,d+c.length)){if(c instanceof iy){if(a&hs.ExcludeBuffers)continue;let h=c.findChild(0,c.buffer.length,n,r-d,i);if(h>-1)return new Bv(new P8e(u,c,t,d),null,h)}else if(a&hs.IncludeAnonymous||!c.type.isAnonymous||LI(c)){let h;if(!(a&hs.IgnoreMounts)&&(h=y$.get(c))&&!h.overlay)return new Gd(h.tree,d,t,u);let m=new Gd(c,d,t,u);return a&hs.IncludeAnonymous||!m.type.isAnonymous?m:m.nextChild(n<0?c.children.length-1:0,n,r,i)}}}if(a&hs.IncludeAnonymous||!u.type.isAnonymous||(u.index>=0?t=u.index+n:t=n<0?-1:u._parent._tree.children.length,u=u._parent,!u))return null}}get firstChild(){return this.nextChild(0,1,0,4)}get lastChild(){return this.nextChild(this._tree.children.length-1,-1,0,4)}childAfter(t){return this.nextChild(0,1,t,2)}childBefore(t){return this.nextChild(this._tree.children.length-1,-1,t,-2)}enter(t,n,r=0){let i;if(!(r&hs.IgnoreOverlays)&&(i=y$.get(this._tree))&&i.overlay){let a=t-this.from;for(let{from:u,to:l}of i.overlay)if((n>0?u<=a:u<a)&&(n<0?l>=a:l>a))return new Gd(i.tree,i.overlay[0].from+this.from,-1,this)}return this.nextChild(0,1,t,n,r)}nextSignificantParent(){let t=this;for(;t.type.isAnonymous&&t._parent;)t=t._parent;return t}get parent(){return this._parent?this._parent.nextSignificantParent():null}get nextSibling(){return this._parent&&this.index>=0?this._parent.nextChild(this.index+1,1,0,4):null}get prevSibling(){return this._parent&&this.index>=0?this._parent.nextChild(this.index-1,-1,0,4):null}get tree(){return this._tree}toTree(){return this._tree}toString(){return this._tree.toString()}}function EH(e,t,n,r){let i=e.cursor(),a=[];if(!i.firstChild())return a;if(n!=null){for(let u=!1;!u;)if(u=i.type.is(n),!i.nextSibling())return a}for(;;){if(r!=null&&i.type.is(r))return a;if(i.type.is(t)&&a.push(i.node),!i.nextSibling())return r==null?a:[]}}function hM(e,t,n=t.length-1){for(let r=e;n>=0;r=r.parent){if(!r)return!1;if(!r.type.isAnonymous){if(t[n]&&t[n]!=r.name)return!1;n--}}return!0}class P8e{constructor(t,n,r,i){this.parent=t,this.buffer=n,this.index=r,this.start=i}}class Bv extends i0e{get name(){return this.type.name}get from(){return this.context.start+this.context.buffer.buffer[this.index+1]}get to(){return this.context.start+this.context.buffer.buffer[this.index+2]}constructor(t,n,r){super(),this.context=t,this._parent=n,this.index=r,this.type=t.buffer.set.types[t.buffer.buffer[r]]}child(t,n,r){let{buffer:i}=this.context,a=i.findChild(this.index+4,i.buffer[this.index+3],t,n-this.context.start,r);return a<0?null:new Bv(this.context,this,a)}get firstChild(){return this.child(1,0,4)}get lastChild(){return this.child(-1,0,4)}childAfter(t){return this.child(1,t,2)}childBefore(t){return this.child(-1,t,-2)}enter(t,n,r=0){if(r&hs.ExcludeBuffers)return null;let{buffer:i}=this.context,a=i.findChild(this.index+4,i.buffer[this.index+3],n>0?1:-1,t-this.context.start,n);return a<0?null:new Bv(this.context,this,a)}get parent(){return this._parent||this.context.parent.nextSignificantParent()}externalSibling(t){return this._parent?null:this.context.parent.nextChild(this.context.index+t,t,0,4)}get nextSibling(){let{buffer:t}=this.context,n=t.buffer[this.index+3];return n<(this._parent?t.buffer[this._parent.index+3]:t.buffer.length)?new Bv(this.context,this._parent,n):this.externalSibling(1)}get prevSibling(){let{buffer:t}=this.context,n=this._parent?this._parent.index+4:0;return this.index==n?this.externalSibling(-1):new Bv(this.context,this._parent,t.findChild(n,this.index,-1,0,4))}get tree(){return null}toTree(){let t=[],n=[],{buffer:r}=this.context,i=this.index+4,a=r.buffer[this.index+3];if(a>i){let u=r.buffer[this.index+1];t.push(r.slice(i,a,u)),n.push(0)}return new A0(this.type,t,n,this.to-this.from)}toString(){return this.context.buffer.childString(this.index)}}function a0e(e){if(!e.length)return null;let t=0,n=e[0];for(let a=1;a<e.length;a++){let u=e[a];(u.from>n.from||u.to<n.to)&&(n=u,t=a)}let r=n instanceof Gd&&n.index<0?null:n.parent,i=e.slice();return r?i[t]=r:i.splice(t,1),new M8e(i,n)}class M8e{constructor(t,n){this.heads=t,this.node=n}get next(){return a0e(this.heads)}}function F8e(e,t,n){let r=e.resolveInner(t,n),i=null;for(let a=r instanceof Gd?r:r.context.parent;a;a=a.parent)if(a.index<0){let u=a.parent;(i||(i=[r])).push(u.resolve(t,n)),a=u}else{let u=y$.get(a.tree);if(u&&u.overlay&&u.overlay[0].from<=t&&u.overlay[u.overlay.length-1].to>=t){let l=new Gd(u.tree,u.overlay[0].from+a.from,-1,a);(i||(i=[r])).push(Ax(l,t,n,!1))}}return i?a0e(i):r}class pM{get name(){return this.type.name}constructor(t,n=0){if(this.mode=n,this.buffer=null,this.stack=[],this.index=0,this.bufferNode=null,t instanceof Gd)this.yieldNode(t);else{this._tree=t.context.parent,this.buffer=t.context;for(let r=t._parent;r;r=r._parent)this.stack.unshift(r.index);this.bufferNode=t,this.yieldBuf(t.index)}}yieldNode(t){return t?(this._tree=t,this.type=t.type,this.from=t.from,this.to=t.to,!0):!1}yieldBuf(t,n){this.index=t;let{start:r,buffer:i}=this.buffer;return this.type=n||i.set.types[i.buffer[t]],this.from=r+i.buffer[t+1],this.to=r+i.buffer[t+2],!0}yield(t){return t?t instanceof Gd?(this.buffer=null,this.yieldNode(t)):(this.buffer=t.context,this.yieldBuf(t.index,t.type)):!1}toString(){return this.buffer?this.buffer.buffer.childString(this.index):this._tree.toString()}enterChild(t,n,r){if(!this.buffer)return this.yield(this._tree.nextChild(t<0?this._tree._tree.children.length-1:0,t,n,r,this.mode));let{buffer:i}=this.buffer,a=i.findChild(this.index+4,i.buffer[this.index+3],t,n-this.buffer.start,r);return a<0?!1:(this.stack.push(this.index),this.yieldBuf(a))}firstChild(){return this.enterChild(1,0,4)}lastChild(){return this.enterChild(-1,0,4)}childAfter(t){return this.enterChild(1,t,2)}childBefore(t){return this.enterChild(-1,t,-2)}enter(t,n,r=this.mode){return this.buffer?r&hs.ExcludeBuffers?!1:this.enterChild(1,t,n):this.yield(this._tree.enter(t,n,r))}parent(){if(!this.buffer)return this.yieldNode(this.mode&hs.IncludeAnonymous?this._tree._parent:this._tree.parent);if(this.stack.length)return this.yieldBuf(this.stack.pop());let t=this.mode&hs.IncludeAnonymous?this.buffer.parent:this.buffer.parent.nextSignificantParent();return this.buffer=null,this.yieldNode(t)}sibling(t){if(!this.buffer)return this._tree._parent?this.yield(this._tree.index<0?null:this._tree._parent.nextChild(this._tree.index+t,t,0,4,this.mode)):!1;let{buffer:n}=this.buffer,r=this.stack.length-1;if(t<0){let i=r<0?0:this.stack[r]+4;if(this.index!=i)return this.yieldBuf(n.findChild(i,this.index,-1,0,4))}else{let i=n.buffer[this.index+3];if(i<(r<0?n.buffer.length:n.buffer[this.stack[r]+3]))return this.yieldBuf(i)}return r<0?this.yield(this.buffer.parent.nextChild(this.buffer.index+t,t,0,4,this.mode)):!1}nextSibling(){return this.sibling(1)}prevSibling(){return this.sibling(-1)}atLastNode(t){let n,r,{buffer:i}=this;if(i){if(t>0){if(this.index<i.buffer.buffer.length)return!1}else for(let a=0;a<this.index;a++)if(i.buffer.buffer[a+3]<this.index)return!1;({index:n,parent:r}=i)}else({index:n,_parent:r}=this._tree);for(;r;{index:n,_parent:r}=r)if(n>-1)for(let a=n+t,u=t<0?-1:r._tree.children.length;a!=u;a+=t){let l=r._tree.children[a];if(this.mode&hs.IncludeAnonymous||l instanceof iy||!l.type.isAnonymous||LI(l))return!1}return!0}move(t,n){if(n&&this.enterChild(t,0,4))return!0;for(;;){if(this.sibling(t))return!0;if(this.atLastNode(t)||!this.parent())return!1}}next(t=!0){return this.move(1,t)}prev(t=!0){return this.move(-1,t)}moveTo(t,n=0){for(;(this.from==this.to||(n<1?this.from>=t:this.from>t)||(n>-1?this.to<=t:this.to<t))&&this.parent(););for(;this.enterChild(1,t,n););return this}get node(){if(!this.buffer)return this._tree;let t=this.bufferNode,n=null,r=0;if(t&&t.context==this.buffer)e:for(let i=this.index,a=this.stack.length;a>=0;){for(let u=t;u;u=u._parent)if(u.index==i){if(i==this.index)return u;n=u,r=a+1;break e}i=this.stack[--a]}for(let i=r;i<this.stack.length;i++)n=new Bv(this.buffer,n,this.stack[i]);return this.bufferNode=new Bv(this.buffer,n,this.index)}get tree(){return this.buffer?null:this._tree._tree}iterate(t,n){for(let r=0;;){let i=!1;if(this.type.isAnonymous||t(this)!==!1){if(this.firstChild()){r++;continue}this.type.isAnonymous||(i=!0)}for(;;){if(i&&n&&n(this),i=this.type.isAnonymous,!r)return;if(this.nextSibling())break;this.parent(),r--,i=!0}}}matchContext(t){if(!this.buffer)return hM(this.node.parent,t);let{buffer:n}=this.buffer,{types:r}=n.set;for(let i=t.length-1,a=this.stack.length-1;i>=0;a--){if(a<0)return hM(this._tree,t,i);let u=r[n.buffer[this.stack[a]]];if(!u.isAnonymous){if(t[i]&&t[i]!=u.name)return!1;i--}}return!0}}function LI(e){return e.children.some(t=>t instanceof iy||!t.type.isAnonymous||LI(t))}function N8e(e){var t;let{buffer:n,nodeSet:r,maxBufferLength:i=A8e,reused:a=[],minRepeatType:u=r.types.length}=e,l=Array.isArray(n)?new II(n,n.length):n,o=r.types,s=0,c=0;function d(R,$,k,F,L,j){let{id:V,start:q,end:N,size:U}=l,W=c,G=s;if(U<0)if(l.next(),U==-1){let K=a[V];k.push(K),F.push(q-R);return}else if(U==-3){s=V;return}else if(U==-4){c=V;return}else throw new RangeError(`Unrecognized record size: ${U}`);let J=o[V],te,H,M=q-R;if(N-q<=i&&(H=_(l.pos-$,L))){let K=new Uint16Array(H.size-H.skip),X=l.pos-H.size,B=K.length;for(;l.pos>X;)B=S(H.start,K,B);te=new iy(K,N-H.start,r),M=H.start-R}else{let K=l.pos-U;l.next();let X=[],B=[],ne=V>=u?V:-1,oe=0,ie=N;for(;l.pos>K;)ne>=0&&l.id==ne&&l.size>=0?(l.end<=ie-i&&(y(X,B,q,oe,l.end,ie,ne,W,G),oe=X.length,ie=l.end),l.next()):j>2500?h(q,K,X,B):d(q,K,X,B,ne,j+1);if(ne>=0&&oe>0&&oe<X.length&&y(X,B,q,oe,q,ie,ne,W,G),X.reverse(),B.reverse(),ne>-1&&oe>0){let de=m(J,G);te=BI(J,X,B,0,X.length,0,N-q,de,de)}else te=v(J,X,B,N-q,W-N,G)}k.push(te),F.push(M)}function h(R,$,k,F){let L=[],j=0,V=-1;for(;l.pos>$;){let{id:q,start:N,end:U,size:W}=l;if(W>4)l.next();else{if(V>-1&&N<V)break;V<0&&(V=U-i),L.push(q,N,U),j++,l.next()}}if(j){let q=new Uint16Array(j*4),N=L[L.length-2];for(let U=L.length-3,W=0;U>=0;U-=3)q[W++]=L[U],q[W++]=L[U+1]-N,q[W++]=L[U+2]-N,q[W++]=W;k.push(new iy(q,L[2]-N,r)),F.push(N-R)}}function m(R,$){return(k,F,L)=>{let j=0,V=k.length-1,q,N;if(V>=0&&(q=k[V])instanceof A0){if(!V&&q.type==R&&q.length==L)return q;(N=q.prop(su.lookAhead))&&(j=F[V]+q.length+N)}return v(R,k,F,L,j,$)}}function y(R,$,k,F,L,j,V,q,N){let U=[],W=[];for(;R.length>F;)U.push(R.pop()),W.push($.pop()+k-L);R.push(v(r.types[V],U,W,j-L,q-j,N)),$.push(L-k)}function v(R,$,k,F,L,j,V){if(j){let q=[su.contextHash,j];V=V?[q].concat(V):[q]}if(L>25){let q=[su.lookAhead,L];V=V?[q].concat(V):[q]}return new A0(R,$,k,F,V)}function _(R,$){let k=l.fork(),F=0,L=0,j=0,V=k.end-i,q={size:0,start:0,skip:0};e:for(let N=k.pos-R;k.pos>N;){let U=k.size;if(k.id==$&&U>=0){q.size=F,q.start=L,q.skip=j,j+=4,F+=4,k.next();continue}let W=k.pos-U;if(U<0||W<N||k.start<V)break;let G=k.id>=u?4:0,J=k.start;for(k.next();k.pos>W;){if(k.size<0)if(k.size==-3)G+=4;else break e;else k.id>=u&&(G+=4);k.next()}L=J,F+=U,j+=G}return($<0||F==R)&&(q.size=F,q.start=L,q.skip=j),q.size>4?q:void 0}function S(R,$,k){let{id:F,start:L,end:j,size:V}=l;if(l.next(),V>=0&&F<u){let q=k;if(V>4){let N=l.pos-(V-4);for(;l.pos>N;)k=S(R,$,k)}$[--k]=q,$[--k]=j-R,$[--k]=L-R,$[--k]=F}else V==-3?s=F:V==-4&&(c=F);return k}let E=[],C=[];for(;l.pos>0;)d(e.start||0,e.bufferStart||0,E,C,-1,0);let T=(t=e.length)!==null&&t!==void 0?t:E.length?C[0]+E[0].length:0;return new A0(o[e.topID],E.reverse(),C.reverse(),T)}const DH=new WeakMap;function aD(e,t){if(!e.isAnonymous||t instanceof iy||t.type!=e)return 1;let n=DH.get(t);if(n==null){n=1;for(let r of t.children){if(r.type!=e||!(r instanceof A0)){n=1;break}n+=aD(e,r)}DH.set(t,n)}return n}function BI(e,t,n,r,i,a,u,l,o){let s=0;for(let y=r;y<i;y++)s+=aD(e,t[y]);let c=Math.ceil(s*1.5/8),d=[],h=[];function m(y,v,_,S,E){for(let C=_;C<S;){let T=C,R=v[C],$=aD(e,y[C]);for(C++;C<S;C++){let k=aD(e,y[C]);if($+k>=c)break;$+=k}if(C==T+1){if($>c){let k=y[T];m(k.children,k.positions,0,k.children.length,v[T]+E);continue}d.push(y[T])}else{let k=v[C-1]+y[C-1].length-R;d.push(BI(e,y,v,T,C,R,k,null,o))}h.push(R+E-a)}}return m(t,n,r,i,0),(l||o)(d,h,u)}class mM{constructor(t,n,r,i,a=!1,u=!1){this.from=t,this.to=n,this.tree=r,this.offset=i,this.open=(a?1:0)|(u?2:0)}get openStart(){return(this.open&1)>0}get openEnd(){return(this.open&2)>0}static addTree(t,n=[],r=!1){let i=[new mM(0,t.length,t,0,!1,r)];for(let a of n)a.to>t.length&&i.push(a);return i}static applyChanges(t,n,r=128){if(!n.length)return t;let i=[],a=1,u=t.length?t[0]:null;for(let l=0,o=0,s=0;;l++){let c=l<n.length?n[l]:null,d=c?c.fromA:1e9;if(d-o>=r)for(;u&&u.from<d;){let h=u;if(o>=h.from||d<=h.to||s){let m=Math.max(h.from,o)-s,y=Math.min(h.to,d)-s;h=m>=y?null:new mM(m,y,h.tree,h.offset+s,l>0,!!c)}if(h&&i.push(h),u.to>d)break;u=a<t.length?t[a++]:null}if(!c)break;o=c.toA,s=c.toA-c.toB}return i}}let Qat=class{startParse(t,n,r){return typeof t=="string"&&(t=new I8e(t)),r=r?r.length?r.map(i=>new nP(i.from,i.to)):[new nP(0,0)]:[new nP(0,t.length)],this.createParse(t,n||[],r)}parse(t,n,r){let i=this.startParse(t,n,r);for(;;){let a=i.advance();if(a)return a}}};class I8e{constructor(t){this.string=t}get length(){return this.string.length}chunk(t){return this.string.slice(t)}get lineChunks(){return!1}read(t,n){return this.string.slice(t,n)}}new su({perNode:!0});let L8e=0;class Vd{constructor(t,n,r,i){this.name=t,this.set=n,this.base=r,this.modified=i,this.id=L8e++}toString(){let{name:t}=this;for(let n of this.modified)n.name&&(t=`${n.name}(${t})`);return t}static define(t,n){let r=typeof t=="string"?t:"?";if(t instanceof Vd&&(n=t),n!=null&&n.base)throw new Error("Can not derive from a modified tag");let i=new Vd(r,[],null,[]);if(i.set.push(i),n)for(let a of n.set)i.set.push(a);return i}static defineModifier(t){let n=new b$(t);return r=>r.modified.indexOf(n)>-1?r:b$.get(r.base||r,r.modified.concat(n).sort((i,a)=>i.id-a.id))}}let B8e=0;class b${constructor(t){this.name=t,this.instances=[],this.id=B8e++}static get(t,n){if(!n.length)return t;let r=n[0].instances.find(l=>l.base==t&&Q8e(n,l.modified));if(r)return r;let i=[],a=new Vd(t.name,i,t,n);for(let l of n)l.instances.push(a);let u=z8e(n);for(let l of t.set)if(!l.modified.length)for(let o of u)i.push(b$.get(l,o));return a}}function Q8e(e,t){return e.length==t.length&&e.every((n,r)=>n==t[r])}function z8e(e){let t=[[]];for(let n=0;n<e.length;n++)for(let r=0,i=t.length;r<i;r++)t.push(t[r].concat(e[n]));return t.sort((n,r)=>r.length-n.length)}function qat(e){let t=Object.create(null);for(let n in e){let r=e[n];Array.isArray(r)||(r=[r]);for(let i of n.split(" "))if(i){let a=[],u=2,l=i;for(let d=0;;){if(l=="..."&&d>0&&d+3==i.length){u=1;break}let h=/^"(?:[^"\\]|\\.)*?"|[^\/!]+/.exec(l);if(!h)throw new RangeError("Invalid path: "+i);if(a.push(h[0]=="*"?"":h[0][0]=='"'?JSON.parse(h[0]):h[0]),d+=h[0].length,d==i.length)break;let m=i[d++];if(d==i.length&&m=="!"){u=0;break}if(m!="/")throw new RangeError("Invalid path: "+i);l=i.slice(d)}let o=a.length-1,s=a[o];if(!s)throw new RangeError("Invalid path: "+i);let c=new Tx(r,u,o>0?a.slice(0,o):null);t[s]=c.sort(t[s])}}return u0e.add(t)}const u0e=new su({combine(e,t){let n,r,i;for(;e||t;){if(!e||t&&e.depth>=t.depth?(i=t,t=t.next):(i=e,e=e.next),n&&n.mode==i.mode&&!i.context&&!n.context)continue;let a=new Tx(i.tags,i.mode,i.context);n?n.next=a:r=a,n=a}return r}});class Tx{constructor(t,n,r,i){this.tags=t,this.mode=n,this.context=r,this.next=i}get opaque(){return this.mode==0}get inherit(){return this.mode==1}sort(t){return!t||t.depth<this.depth?(this.next=t,this):(t.next=this.sort(t.next),t)}get depth(){return this.context?this.context.length:0}}Tx.empty=new Tx([],2,null);function q8e(e,t){let n=Object.create(null);for(let a of e)if(!Array.isArray(a.tag))n[a.tag.id]=a.class;else for(let u of a.tag)n[u.id]=a.class;let{scope:r,all:i=null}=t||{};return{style:a=>{let u=i;for(let l of a)for(let o of l.set){let s=n[o.id];if(s){u=u?u+" "+s:s;break}}return u},scope:r}}function V8e(e,t){let n=null;for(let r of e){let i=r.style(t);i&&(n=n?n+" "+i:i)}return n}function Vat(e,t,n,r=0,i=e.length){let a=new U8e(r,Array.isArray(t)?t:[t],n);a.highlightRange(e.cursor(),r,i,"",a.highlighters),a.flush(i)}class U8e{constructor(t,n,r){this.at=t,this.highlighters=n,this.span=r,this.class=""}startSpan(t,n){n!=this.class&&(this.flush(t),t>this.at&&(this.at=t),this.class=n)}flush(t){t>this.at&&this.class&&this.span(this.at,t,this.class)}highlightRange(t,n,r,i,a){let{type:u,from:l,to:o}=t;if(l>=r||o<=n)return;u.isTop&&(a=this.highlighters.filter(m=>!m.scope||m.scope(u)));let s=i,c=j8e(t)||Tx.empty,d=V8e(a,c.tags);if(d&&(s&&(s+=" "),s+=d,c.mode==1&&(i+=(i?" ":"")+d)),this.startSpan(Math.max(n,l),s),c.opaque)return;let h=t.tree&&t.tree.prop(su.mounted);if(h&&h.overlay){let m=t.node.enter(h.overlay[0].from+l,1),y=this.highlighters.filter(_=>!_.scope||_.scope(h.tree.type)),v=t.firstChild();for(let _=0,S=l;;_++){let E=_<h.overlay.length?h.overlay[_]:null,C=E?E.from+l:o,T=Math.max(n,S),R=Math.min(r,C);if(T<R&&v)for(;t.from<R&&(this.highlightRange(t,T,R,i,a),this.startSpan(Math.min(R,t.to),s),!(t.to>=C||!t.nextSibling())););if(!E||C>r)break;S=E.to+l,S>n&&(this.highlightRange(m.cursor(),Math.max(n,E.from+l),Math.min(r,S),"",y),this.startSpan(Math.min(r,S),s))}v&&t.parent()}else if(t.firstChild()){h&&(i="");do if(!(t.to<=n)){if(t.from>=r)break;this.highlightRange(t,n,r,i,a),this.startSpan(Math.min(r,t.to),s)}while(t.nextSibling());t.parent()}}}function j8e(e){let t=e.type.prop(u0e);for(;t&&t.context&&!e.matchContext(t.context);)t=t.next;return t||null}const Yt=Vd.define,aE=Yt(),Sv=Yt(),$H=Yt(Sv),CH=Yt(Sv),_v=Yt(),uE=Yt(_v),rP=Yt(_v),d0=Yt(),y1=Yt(d0),l0=Yt(),o0=Yt(),gM=Yt(),u2=Yt(gM),lE=Yt(),$r={comment:aE,lineComment:Yt(aE),blockComment:Yt(aE),docComment:Yt(aE),name:Sv,variableName:Yt(Sv),typeName:$H,tagName:Yt($H),propertyName:CH,attributeName:Yt(CH),className:Yt(Sv),labelName:Yt(Sv),namespace:Yt(Sv),macroName:Yt(Sv),literal:_v,string:uE,docString:Yt(uE),character:Yt(uE),attributeValue:Yt(uE),number:rP,integer:Yt(rP),float:Yt(rP),bool:Yt(_v),regexp:Yt(_v),escape:Yt(_v),color:Yt(_v),url:Yt(_v),keyword:l0,self:Yt(l0),null:Yt(l0),atom:Yt(l0),unit:Yt(l0),modifier:Yt(l0),operatorKeyword:Yt(l0),controlKeyword:Yt(l0),definitionKeyword:Yt(l0),moduleKeyword:Yt(l0),operator:o0,derefOperator:Yt(o0),arithmeticOperator:Yt(o0),logicOperator:Yt(o0),bitwiseOperator:Yt(o0),compareOperator:Yt(o0),updateOperator:Yt(o0),definitionOperator:Yt(o0),typeOperator:Yt(o0),controlOperator:Yt(o0),punctuation:gM,separator:Yt(gM),bracket:u2,angleBracket:Yt(u2),squareBracket:Yt(u2),paren:Yt(u2),brace:Yt(u2),content:d0,heading:y1,heading1:Yt(y1),heading2:Yt(y1),heading3:Yt(y1),heading4:Yt(y1),heading5:Yt(y1),heading6:Yt(y1),contentSeparator:Yt(d0),list:Yt(d0),quote:Yt(d0),emphasis:Yt(d0),strong:Yt(d0),link:Yt(d0),monospace:Yt(d0),strikethrough:Yt(d0),inserted:Yt(),deleted:Yt(),changed:Yt(),invalid:Yt(),meta:lE,documentMeta:Yt(lE),annotation:Yt(lE),processingInstruction:Yt(lE),definition:Vd.defineModifier("definition"),constant:Vd.defineModifier("constant"),function:Vd.defineModifier("function"),standard:Vd.defineModifier("standard"),local:Vd.defineModifier("local"),special:Vd.defineModifier("special")};for(let e in $r){let t=$r[e];t instanceof Vd&&(t.name=e)}q8e([{tag:$r.link,class:"tok-link"},{tag:$r.heading,class:"tok-heading"},{tag:$r.emphasis,class:"tok-emphasis"},{tag:$r.strong,class:"tok-strong"},{tag:$r.keyword,class:"tok-keyword"},{tag:$r.atom,class:"tok-atom"},{tag:$r.bool,class:"tok-bool"},{tag:$r.url,class:"tok-url"},{tag:$r.labelName,class:"tok-labelName"},{tag:$r.inserted,class:"tok-inserted"},{tag:$r.deleted,class:"tok-deleted"},{tag:$r.literal,class:"tok-literal"},{tag:$r.string,class:"tok-string"},{tag:$r.number,class:"tok-number"},{tag:[$r.regexp,$r.escape,$r.special($r.string)],class:"tok-string2"},{tag:$r.variableName,class:"tok-variableName"},{tag:$r.local($r.variableName),class:"tok-variableName tok-local"},{tag:$r.definition($r.variableName),class:"tok-variableName tok-definition"},{tag:$r.special($r.variableName),class:"tok-variableName2"},{tag:$r.definition($r.propertyName),class:"tok-propertyName tok-definition"},{tag:$r.typeName,class:"tok-typeName"},{tag:$r.namespace,class:"tok-namespace"},{tag:$r.className,class:"tok-className"},{tag:$r.macroName,class:"tok-macroName"},{tag:$r.propertyName,class:"tok-propertyName"},{tag:$r.operator,class:"tok-operator"},{tag:$r.comment,class:"tok-comment"},{tag:$r.meta,class:"tok-meta"},{tag:$r.invalid,class:"tok-invalid"},{tag:$r.punctuation,class:"tok-punctuation"}]);const vM="ͼ",wH=typeof Symbol>"u"?"__"+vM:Symbol.for(vM),yM=typeof Symbol>"u"?"__styleSet"+Math.floor(Math.random()*1e8):Symbol("styleSet"),RH=typeof globalThis<"u"?globalThis:typeof window<"u"?window:{};class Uat{constructor(t,n){this.rules=[];let{finish:r}=n||{};function i(u){return/^@/.test(u)?[u]:u.split(/,\s*/)}function a(u,l,o,s){let c=[],d=/^@(\w+)\b/.exec(u[0]),h=d&&d[1]=="keyframes";if(d&&l==null)return o.push(u[0]+";");for(let m in l){let y=l[m];if(/&/.test(m))a(m.split(/,\s*/).map(v=>u.map(_=>v.replace(/&/,_))).reduce((v,_)=>v.concat(_)),y,o);else if(y&&typeof y=="object"){if(!d)throw new RangeError("The value of a property ("+m+") should be a primitive value.");a(i(m),y,c,h)}else y!=null&&c.push(m.replace(/_.*/,"").replace(/[A-Z]/g,v=>"-"+v.toLowerCase())+": "+y+";")}(c.length||h)&&o.push((r&&!d&&!s?u.map(r):u).join(", ")+" {"+c.join(" ")+"}")}for(let u in t)a(i(u),t[u],this.rules)}getRules(){return this.rules.join(`
`)}static newName(){let t=RH[wH]||1;return RH[wH]=t+1,vM+t.toString(36)}static mount(t,n,r){let i=t[yM],a=r&&r.nonce;i?a&&i.setNonce(a):i=new Z8e(t,a),i.mount(Array.isArray(n)?n:[n],t)}}let AH=new Map;class Z8e{constructor(t,n){let r=t.ownerDocument||t,i=r.defaultView;if(!t.head&&t.adoptedStyleSheets&&i.CSSStyleSheet){let a=AH.get(r);if(a)return t[yM]=a;this.sheet=new i.CSSStyleSheet,AH.set(r,this)}else this.styleTag=r.createElement("style"),n&&this.styleTag.setAttribute("nonce",n);this.modules=[],t[yM]=this}mount(t,n){let r=this.sheet,i=0,a=0;for(let u=0;u<t.length;u++){let l=t[u],o=this.modules.indexOf(l);if(o<a&&o>-1&&(this.modules.splice(o,1),a--,o=-1),o==-1){if(this.modules.splice(a++,0,l),r)for(let s=0;s<l.rules.length;s++)r.insertRule(l.rules[s],i++)}else{for(;a<o;)i+=this.modules[a++].rules.length;i+=l.rules.length,a++}}if(r)n.adoptedStyleSheets.indexOf(this.sheet)<0&&(n.adoptedStyleSheets=[this.sheet,...n.adoptedStyleSheets]);else{let u="";for(let o=0;o<this.modules.length;o++)u+=this.modules[o].getRules()+`
`;this.styleTag.textContent=u;let l=n.head||n;this.styleTag.parentNode!=l&&l.insertBefore(this.styleTag,l.firstChild)}}setNonce(t){this.styleTag&&this.styleTag.getAttribute("nonce")!=t&&this.styleTag.setAttribute("nonce",t)}}var uD={exports:{}},H8e=uD.exports,TH;function X8e(){return TH||(TH=1,(function(e){(function(t,n){e.exports?e.exports=n():t.log=n()})(H8e,function(){var t=function(){},n="undefined",r=typeof window!==n&&typeof window.navigator!==n&&/Trident\/|MSIE /.test(window.navigator.userAgent),i=["trace","debug","info","warn","error"],a={},u=null;function l(v,_){var S=v[_];if(typeof S.bind=="function")return S.bind(v);try{return Function.prototype.bind.call(S,v)}catch{return function(){return Function.prototype.apply.apply(S,[v,arguments])}}}function o(){console.log&&(console.log.apply?console.log.apply(console,arguments):Function.prototype.apply.apply(console.log,[console,arguments])),console.trace&&console.trace()}function s(v){return v==="debug"&&(v="log"),typeof console===n?!1:v==="trace"&&r?o:console[v]!==void 0?l(console,v):console.log!==void 0?l(console,"log"):t}function c(){for(var v=this.getLevel(),_=0;_<i.length;_++){var S=i[_];this[S]=_<v?t:this.methodFactory(S,v,this.name)}if(this.log=this.debug,typeof console===n&&v<this.levels.SILENT)return"No console available for logging"}function d(v){return function(){typeof console!==n&&(c.call(this),this[v].apply(this,arguments))}}function h(v,_,S){return s(v)||d.apply(this,arguments)}function m(v,_){var S=this,E,C,T,R="loglevel";typeof v=="string"?R+=":"+v:typeof v=="symbol"&&(R=void 0);function $(V){var q=(i[V]||"silent").toUpperCase();if(!(typeof window===n||!R)){try{window.localStorage[R]=q;return}catch{}try{window.document.cookie=encodeURIComponent(R)+"="+q+";"}catch{}}}function k(){var V;if(!(typeof window===n||!R)){try{V=window.localStorage[R]}catch{}if(typeof V===n)try{var q=window.document.cookie,N=encodeURIComponent(R),U=q.indexOf(N+"=");U!==-1&&(V=/^([^;]+)/.exec(q.slice(U+N.length+1))[1])}catch{}return S.levels[V]===void 0&&(V=void 0),V}}function F(){if(!(typeof window===n||!R)){try{window.localStorage.removeItem(R)}catch{}try{window.document.cookie=encodeURIComponent(R)+"=; expires=Thu, 01 Jan 1970 00:00:00 UTC"}catch{}}}function L(V){var q=V;if(typeof q=="string"&&S.levels[q.toUpperCase()]!==void 0&&(q=S.levels[q.toUpperCase()]),typeof q=="number"&&q>=0&&q<=S.levels.SILENT)return q;throw new TypeError("log.setLevel() called with invalid level: "+V)}S.name=v,S.levels={TRACE:0,DEBUG:1,INFO:2,WARN:3,ERROR:4,SILENT:5},S.methodFactory=_||h,S.getLevel=function(){return T??C??E},S.setLevel=function(V,q){return T=L(V),q!==!1&&$(T),c.call(S)},S.setDefaultLevel=function(V){C=L(V),k()||S.setLevel(V,!1)},S.resetLevel=function(){T=null,F(),c.call(S)},S.enableAll=function(V){S.setLevel(S.levels.TRACE,V)},S.disableAll=function(V){S.setLevel(S.levels.SILENT,V)},S.rebuild=function(){if(u!==S&&(E=L(u.getLevel())),c.call(S),u===S)for(var V in a)a[V].rebuild()},E=L(u?u.getLevel():"WARN");var j=k();j!=null&&(T=L(j)),c.call(S)}u=new m,u.getLogger=function(_){if(typeof _!="symbol"&&typeof _!="string"||_==="")throw new TypeError("You must supply a name when creating a logger.");var S=a[_];return S||(S=a[_]=new m(_,u.methodFactory)),S};var y=typeof window!==n?window.log:void 0;return u.noConflict=function(){return typeof window!==n&&window.log===u&&(window.log=y),u},u.getLoggers=function(){return a},u.default=u,u})})(uD)),uD.exports}var Y8e=X8e();const jat=sa(Y8e),G8e={AdditionalItemsError:"Array at `{{pointer}}` may not have an additional item `{{key}}`",AdditionalPropertiesError:"Additional property `{{property}}` on `{{pointer}}` does not match schema `{{schema}}`",AllOfError:"Value `{{value}}` at `{{pointer}}` does not match schema of `{{allOf}}`",AnyOfError:"Value `{{value}}` at `{{pointer}}` does not match any schema of `{{anyOf}}`",ConstError:"Expected value at `{{pointer}}` to be `{{expected}}`, but value given is `{{value}}`",containsAnyError:"The array at `{{pointer}}` must contain at least one item",ContainsArrayError:"The property at `{{pointer}}` must not be an array",ContainsError:"The array at `{{pointer}}` must contain an element that matches `{{schema}}`",EnumError:"Expected given value `{{value}}` in `{{pointer}}` to be one of `{{values}}`",ForbiddenPropertyError:"Property name `{{property}}` at `{{pointer}}` is not allowed",FormatDateError:"Value `{{value}}` at `{{pointer}}` is not a valid date",FormatDateTimeError:"Value `{{value}}` at `{{pointer}}` is not a valid date-time",FormatEmailError:"Value `{{value}}` at `{{pointer}}` is not a valid email",FormatHostnameError:"Value `{{value}}` at `{{pointer}}` is not a valid hostname",FormatIPV4Error:"Value `{{value}}` at `{{pointer}}` is not a valid IPv4 address",FormatIPV4LeadingZeroError:"IPv4 addresses starting with zero are invalid, since they are interpreted as octals",FormatIPV6Error:"Value `{{value}}` at `{{pointer}}` is not a valid IPv6 address",FormatIPV6LeadingZeroError:"IPv6 addresses starting with zero are invalid, since they are interpreted as octals",FormatJsonPointerError:"Value `{{value}}` at `{{pointer}}` is not a valid json-pointer",FormatRegExError:"Value `{{value}}` at `{{pointer}}` is not a valid regular expression",FormatTimeError:"Value `{{value}}` at `{{pointer}}` is not a valid time",FormatURIError:"Value `{{value}}` at `{{pointer}}` is not a valid uri",FormatURIReferenceError:"Value `{{value}}` at `{{pointer}}` is not a valid uri-reference",FormatURITemplateError:"Value `{{value}}` at `{{pointer}}` is not a valid uri-template",FormatURLError:"Value `{{value}}` at `{{pointer}}` is not a valid url",InvalidDataError:"No value may be specified in `{{pointer}}`",InvalidPropertyNameError:"Invalid property name `{{property}}` at `{{pointer}}`",MaximumError:"Value in `{{pointer}}` is `{{length}}`, but should be `{{maximum}}` at maximum",MaxItemsError:"Too many items in `{{pointer}}`, should be `{{maximum}}` at most, but got `{{length}}`",MaxLengthError:"Value `{{pointer}}` should have a maximum length of `{{maxLength}}`, but got `{{length}}`.",MaxPropertiesError:"Too many properties in `{{pointer}}`, should be `{{maximum}}` at most, but got `{{length}}`",MinimumError:"Value in `{{pointer}}` is `{{length}}`, but should be `{{minimum}}` at minimum",MinItemsError:"Too few items in `{{pointer}}`, should be at least `{{minItems}}`, but got `{{length}}`",MinItemsOneError:"At least one item is required in `{{pointer}}`",MinLengthError:"Value `{{pointer}}` should have a minimum length of `{{minLength}}`, but got `{{length}}`.",MinLengthOneError:"A value is required in `{{pointer}}`",MinPropertiesError:"Too few properties in `{{pointer}}`, should be at least `{{minimum}}`, but got `{{length}}`",MissingDependencyError:"The required propery '{{missingProperty}}' in `{{pointer}}` is missing",MissingOneOfPropertyError:"Value at `{{pointer}}` property: `{{property}}`",MultipleOfError:"Expected `{{value}}` in `{{pointer}}` to be multiple of `{{multipleOf}}`",MultipleOneOfError:"Value `{{value}}` should not match multiple schemas in oneOf `{{matches}}`",NoAdditionalPropertiesError:"Additional property `{{property}}` in `{{pointer}}` is not allowed",NotError:"Value `{{value}}` at pointer should not match schema `{{not}}`",OneOfError:"Value `{{value}}` in `{{pointer}}` does not match any given oneof schema",OneOfPropertyError:"Failed finding a matching oneOfProperty schema in `{{pointer}}` where `{{property}}` matches `{{value}}`",PatternError:"Value in `{{pointer}}` should match `{{description}}`, but received `{{received}}`",PatternPropertiesError:"Property `{{key}}` does not match any patterns in `{{pointer}}`. Valid patterns are: {{patterns}}",RequiredPropertyError:"The required property `{{key}}` is missing at `{{pointer}}`",SchemaWarning:"Failed retrieving a schema from '{{pointer}}' to key '{{key}}'",TypeError:"Expected `{{value}}` ({{received}}) in `{{pointer}}` to be of type `{{expected}}`",UndefinedValueError:"Value must not be undefined in `{{pointer}}`",UniqueItemsError:"Items in array must be unique. Value `{{value}}` in `{{pointer}}` is a duplicate of {{duplicatePointer}}.",UnknownPropertyError:"Could not find a valid schema for property `{{pointer}}` within object",ValueNotEmptyError:"A value for `{{property}}` is required at `{{pointer}}`"},K8e=Object.prototype.toString;function hi(e){const t=K8e.call(e).match(/\s([^\]]+)\]/).pop().toLowerCase();return t==="file"?"object":t}const W8e="object",J8e="array";function e7e(e,t={}){return e.replace(/\{\{\w+\}\}/g,n=>{const r=n.replace(/[{}]/g,""),i=t[r],a=hi(i);return a===W8e||a===J8e?JSON.stringify(i):i})}function t7e(e,t,n=e){var r;const i=(r=G8e[e])!==null&&r!==void 0?r:n;return e7e(i,t)}function n7e(e){return e.replace(/([a-z])([A-Z])/g,"$1-$2").toLowerCase()}function r7e(e,t){return{type:"error",name:e,code:n7e(e),message:t7e(e,t),data:t}}function $n(e){return r7e.bind(null,e)}function kx(e,t=[]){for(let n=0;n<e.length;n+=1){const r=e[n];Array.isArray(r)?kx(r,t):t.push(r)}return t}const r4={DECLARATOR_ONEOF:"oneOfProperty",GET_TEMPLATE_RECURSION_LIMIT:1,propertyBlacklist:["_id"],templateDefaultOptions:{addOptionalProps:!1,removeInvalidData:!1,extendDefaults:!0}};function H2(e,t,n){const r={...t};return Object.defineProperty(r,"getOneOfOrigin",{enumerable:!1,value:()=>({index:n,schema:e})}),r}function Yf(e){return(e==null?void 0:e.type)==="error"}function i7e(e){return e instanceof Promise}function O$(e){return Yf(e)||i7e(e)}const{DECLARATOR_ONEOF:h3}=r4;function l0e(e,t,n=e.rootSchema,r="#"){if(t!=null&&n[h3]){const u=[],l=n[h3],o=t[n[h3]];if(o===void 0)return e.errors.missingOneOfPropertyError({property:l,pointer:r,schema:n,value:t});for(let s=0;s<n.oneOf.length;s+=1){const c=e.resolveRef(n.oneOf[s]),d=e.step(l,c,t,r);if(Yf(d))return d;let h=kx(e.validate(o,d,r));if(h=h.filter(O$),h.length>0)u.push(...h);else return H2(n,c,s)}return e.errors.oneOfPropertyError({property:l,value:o,pointer:r,schema:n,errors:u})}const i=[],a=[];for(let u=0;u<n.oneOf.length;u+=1){const l=e.resolveRef(n.oneOf[u]);let o=kx(e.validate(t,l,r));o=o.filter(O$),o.length>0?a.push(...o):i.push({index:u,schema:l})}return i.length===1?H2(n,i[0].schema,i[0].index):i.length>1?e.errors.multipleOneOfError({value:t,pointer:r,schema:n,matches:i}):e.errors.oneOfError({value:JSON.stringify(t),pointer:r,schema:n,oneOf:n.oneOf,errors:a})}function a7e(e,t,n,r){if(n==null||t.properties==null)return-1;let i=0;const a=Object.keys(t.properties);for(let u=0;u<a.length;u+=1){const l=a[u];n[l]!=null&&e.isValid(n[l],t.properties[l],r)&&(i+=1)}return i}function QI(e,t,n=e.rootSchema,r="#"){if(t!=null&&n[h3]){const a=[],u=n[h3],l=t[n[h3]];if(l===void 0)return e.errors.missingOneOfPropertyError({property:u,pointer:r,schema:n,value:t});for(let o=0;o<n.oneOf.length;o+=1){const s=e.resolveRef(n.oneOf[o]),c=e.step(u,s,t,r);if(Yf(c))return c;let d=kx(e.validate(l,c,r));if(d=d.filter(O$),d.length>0)a.push(...d);else return H2(n,s,o)}return e.errors.oneOfPropertyError({property:u,value:l,pointer:r,schema:n,errors:a})}const i=[];for(let a=0;a<n.oneOf.length;a+=1){const u=e.resolveRef(n.oneOf[a]);e.isValid(t,u,r)&&i.push({schema:u,index:a})}if(i.length===1)return H2(n,i[0].schema,i[0].index);if(hi(t)==="object"){let a,u=-1,l=0;for(let o=0;o<n.oneOf.length;o+=1){const s=e.resolveRef(n.oneOf[o]),c=a7e(e,s,t);l<c&&(l=c,a=n.oneOf[o],u=o)}return a===void 0?e.errors.oneOfError({value:JSON.stringify(t),pointer:r,schema:n,oneOf:n.oneOf}):H2(n,a,u)}return i.length>1?e.errors.multipleOneOfError({matches:i,pointer:r,schema:n,value:t}):e.errors.oneOfError({value:JSON.stringify(t),pointer:r,schema:n,oneOf:n.oneOf})}const u7e=(e,t,n,r)=>{if(Array.isArray(t.oneOf)){const i=e.resolveOneOf(n,t,r);if(Yf(i))return i}};var iP,kH;function l7e(){if(kH)return iP;kH=1;var e=function(E){return t(E)&&!n(E)};function t(S){return!!S&&typeof S=="object"}function n(S){var E=Object.prototype.toString.call(S);return E==="[object RegExp]"||E==="[object Date]"||a(S)}var r=typeof Symbol=="function"&&Symbol.for,i=r?Symbol.for("react.element"):60103;function a(S){return S.$$typeof===i}function u(S){return Array.isArray(S)?[]:{}}function l(S,E){return E.clone!==!1&&E.isMergeableObject(S)?v(u(S),S,E):S}function o(S,E,C){return S.concat(E).map(function(T){return l(T,C)})}function s(S,E){if(!E.customMerge)return v;var C=E.customMerge(S);return typeof C=="function"?C:v}function c(S){return Object.getOwnPropertySymbols?Object.getOwnPropertySymbols(S).filter(function(E){return Object.propertyIsEnumerable.call(S,E)}):[]}function d(S){return Object.keys(S).concat(c(S))}function h(S,E){try{return E in S}catch{return!1}}function m(S,E){return h(S,E)&&!(Object.hasOwnProperty.call(S,E)&&Object.propertyIsEnumerable.call(S,E))}function y(S,E,C){var T={};return C.isMergeableObject(S)&&d(S).forEach(function(R){T[R]=l(S[R],C)}),d(E).forEach(function(R){m(S,R)||(h(S,R)&&C.isMergeableObject(E[R])?T[R]=s(R,C)(S[R],E[R],C):T[R]=l(E[R],C))}),T}function v(S,E,C){C=C||{},C.arrayMerge=C.arrayMerge||o,C.isMergeableObject=C.isMergeableObject||e,C.cloneUnlessOtherwiseSpecified=l;var T=Array.isArray(E),R=Array.isArray(S),$=T===R;return $?T?C.arrayMerge(S,E,C):y(S,E,C):l(E,C)}v.all=function(E,C){if(!Array.isArray(E))throw new Error("first argument should be an array");return E.reduce(function(T,R){return v(T,R,C)},{})};var _=v;return iP=_,iP}var o7e=l7e();const o0e=sa(o7e),s7e=(e,t)=>t,zI=(e,t)=>o0e(e,t,{arrayMerge:s7e}),c7e=(e,t)=>{const n=e.concat(t);return n.filter((r,i)=>n.indexOf(r)===i)},f7e=(e,t)=>o0e(e,t,{arrayMerge:c7e});function uc(e,t){const n=hi(e),r=hi(t);if(n!==r)return e;const i=f7e(e,t);return e.getOneOfOrigin?Object.defineProperty(i,"getOneOfOrigin",{enumerable:!1,value:e.getOneOfOrigin}):t.getOneOfOrigin&&Object.defineProperty(i,"getOneOfOrigin",{enumerable:!1,value:t.getOneOfOrigin}),i}function Px(e,...t){const n={};return Object.keys(e).forEach(r=>{t.includes(r)||(n[r]=e[r])}),e.getOneOfOrigin&&Object.defineProperty(n,"getOneOfOrigin",{enumerable:!1,value:e.getOneOfOrigin}),n}var d7e=Function.prototype.toString,aP=Object.create,h7e=Object.prototype.toString,p7e=(function(){function e(){this._keys=[],this._values=[]}return e.prototype.has=function(t){return!!~this._keys.indexOf(t)},e.prototype.get=function(t){return this._values[this._keys.indexOf(t)]},e.prototype.set=function(t,n){this._keys.push(t),this._values.push(n)},e})();function m7e(){return new p7e}function g7e(){return new WeakMap}var v7e=typeof WeakMap<"u"?g7e:m7e;function qI(e){if(!e)return aP(null);var t=e.constructor;if(t===Object)return e===Object.prototype?{}:aP(e);if(t&&~d7e.call(t).indexOf("[native code]"))try{return new t}catch{}return aP(e)}function y7e(e){var t="";return e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.unicode&&(t+="u"),e.sticky&&(t+="y"),t}function b7e(e){return e.flags}var O7e=/test/g.flags==="g"?b7e:y7e;function s0e(e){var t=h7e.call(e);return t.substring(8,t.length-1)}function x7e(e){return e[Symbol.toStringTag]||s0e(e)}var S7e=typeof Symbol<"u"?x7e:s0e,_7e=Object.defineProperty,E7e=Object.getOwnPropertyDescriptor,c0e=Object.getOwnPropertyNames,VI=Object.getOwnPropertySymbols,f0e=Object.prototype,d0e=f0e.hasOwnProperty,D7e=f0e.propertyIsEnumerable,h0e=typeof VI=="function";function $7e(e){return c0e(e).concat(VI(e))}var C7e=h0e?$7e:c0e;function vw(e,t,n){for(var r=C7e(e),i=0,a=r.length,u=void 0,l=void 0;i<a;++i)if(u=r[i],!(u==="callee"||u==="caller")){if(l=E7e(e,u),!l){t[u]=n.copier(e[u],n);continue}!l.get&&!l.set&&(l.value=n.copier(l.value,n));try{_7e(t,u,l)}catch{t[u]=l.value}}return t}function w7e(e,t){var n=new t.Constructor;t.cache.set(e,n);for(var r=0,i=e.length;r<i;++r)n[r]=t.copier(e[r],t);return n}function R7e(e,t){var n=new t.Constructor;return t.cache.set(e,n),vw(e,n,t)}function p0e(e,t){return e.slice(0)}function A7e(e,t){return e.slice(0,e.size,e.type)}function T7e(e,t){return new t.Constructor(p0e(e.buffer))}function k7e(e,t){return new t.Constructor(e.getTime())}function m0e(e,t){var n=new t.Constructor;return t.cache.set(e,n),e.forEach(function(r,i){n.set(i,t.copier(r,t))}),n}function P7e(e,t){return vw(e,m0e(e,t),t)}function M7e(e,t){var n=qI(t.prototype);t.cache.set(e,n);for(var r in e)d0e.call(e,r)&&(n[r]=t.copier(e[r],t));return n}function F7e(e,t){var n=qI(t.prototype);t.cache.set(e,n);for(var r in e)d0e.call(e,r)&&(n[r]=t.copier(e[r],t));for(var i=VI(e),a=0,u=i.length,l=void 0;a<u;++a)l=i[a],D7e.call(e,l)&&(n[l]=t.copier(e[l],t));return n}var N7e=h0e?F7e:M7e;function I7e(e,t){var n=qI(t.prototype);return t.cache.set(e,n),vw(e,n,t)}function uP(e,t){return new t.Constructor(e.valueOf())}function L7e(e,t){var n=new t.Constructor(e.source,O7e(e));return n.lastIndex=e.lastIndex,n}function lD(e,t){return e}function g0e(e,t){var n=new t.Constructor;return t.cache.set(e,n),e.forEach(function(r){n.add(t.copier(r,t))}),n}function B7e(e,t){return vw(e,g0e(e,t),t)}var Q7e=Array.isArray,UI=Object.assign,z7e=Object.getPrototypeOf||(function(e){return e.__proto__}),v0e={array:w7e,arrayBuffer:p0e,blob:A7e,dataView:T7e,date:k7e,error:lD,map:m0e,object:N7e,regExp:L7e,set:g0e},q7e=UI({},v0e,{array:R7e,map:P7e,object:I7e,set:B7e});function V7e(e){return{Arguments:e.object,Array:e.array,ArrayBuffer:e.arrayBuffer,Blob:e.blob,Boolean:uP,DataView:e.dataView,Date:e.date,Error:e.error,Float32Array:e.arrayBuffer,Float64Array:e.arrayBuffer,Int8Array:e.arrayBuffer,Int16Array:e.arrayBuffer,Int32Array:e.arrayBuffer,Map:e.map,Number:uP,Object:e.object,Promise:lD,RegExp:e.regExp,Set:e.set,String:uP,WeakMap:lD,WeakSet:lD,Uint8Array:e.arrayBuffer,Uint8ClampedArray:e.arrayBuffer,Uint16Array:e.arrayBuffer,Uint32Array:e.arrayBuffer,Uint64Array:e.arrayBuffer}}function y0e(e){var t=UI({},v0e,e),n=V7e(t),r=n.Array,i=n.Object;function a(u,l){if(l.prototype=l.Constructor=void 0,!u||typeof u!="object")return u;if(l.cache.has(u))return l.cache.get(u);if(l.prototype=z7e(u),l.Constructor=l.prototype&&l.prototype.constructor,!l.Constructor||l.Constructor===Object)return i(u,l);if(Q7e(u))return r(u,l);var o=n[S7e(u)];return o?o(u,l):typeof u.then=="function"?u:i(u,l)}return function(l){return a(l,{Constructor:void 0,cache:v7e(),copier:a,prototype:void 0})}}function U7e(e){return y0e(UI({},q7e,e))}U7e({});var x$=y0e({});function yw(e,t,n){if(t.if!=null){if(t.if===!1)return t.else;if(t.if&&(t.then||t.else)){const r=e.validate(n,e.resolveRef(t.if));if(r.length===0&&t.then)return e.resolveRef(t.then);if(r.length!==0&&t.else)return e.resolveRef(t.else)}}}const j7e=(e,t,n,r)=>{const i=yw(e,t,n);if(i)return e.validate(n,i,r)};function b0e(e,t,n){var r;const i={...(r=e.resolveRef(t))!==null&&r!==void 0?r:{}},a=yw(e,i,n);return a||Px(i,"if","then","else")}function O0e(e,t,n=e.rootSchema){let r=x$(n);for(let i=0;i<n.allOf.length;i+=1){const a=b0e(e,n.allOf[i],t);r=uc(r,a)}return delete r.allOf,r}function x0e(e,t){const{allOf:n}=t;if(!Array.isArray(n)||n.length===0)return;let r={};return n.forEach(i=>{r=uc(r,e.resolveRef(i))}),r}const Z7e=(e,t,n,r)=>{const{allOf:i}=t;if(!Array.isArray(i)||i.length===0)return;const a=[];return t.allOf.forEach(u=>{a.push(...e.validate(n,u,r))}),a};function S0e(e,t){return e==null||e.$ref==null?e:e.getRoot?e.getRoot().getRef(e):t.getRef(e)}function H7e(e){return e.filter((t,n)=>e.indexOf(t)===n)}function Uv(e){return hi(e)==="object"}function _0e(e,t,n){const{dependencies:r}=t;if(!Uv(r)||!Uv(n))return;let i=!1,a={required:[]};if(Object.keys(r).forEach(u=>{var l,o;if(n[u]==null&&!(!((l=t.required)===null||l===void 0)&&l.includes(u)||!((o=a.required)===null||o===void 0)&&o.includes(u)))return;const s=r[u];if(Array.isArray(s)){i=!0,a.required.push(...s);return}if(Uv(s)){i=!0,a=uc(a,e.resolveRef(s));return}}),i)return a.required=H7e(a.required),a}const X7e=(e,t,n,r)=>{if(hi(t.dependencies)!=="object")return;const i=[];return Object.keys(n).forEach(a=>{if(t.dependencies[a]===void 0||t.dependencies[a]===!0)return;if(t.dependencies[a]===!1){i.push(e.errors.missingDependencyError({pointer:r,schema:t,value:n}));return}let u;const l=hi(t.dependencies[a]);if(l==="array")u=t.dependencies[a].filter(o=>n[o]===void 0).map(o=>e.errors.missingDependencyError({missingProperty:o,pointer:r,schema:t,value:n}));else if(l==="object")u=e.validate(n,t.dependencies[a],r);else throw new Error(`Invalid dependency definition for ${r}/${a}. Must be string[] or schema`);i.push(...u)}),i.length>0?i:void 0};function E0e(e,t,n){if(!Array.isArray(t.anyOf)||t.anyOf.length===0)return;let r;return t.anyOf.forEach(i=>{i=e.resolveRef(i),e.isValid(n,i)&&(r=r?uc(r,i):i)}),r}function D0e(e,t,n=e.rootSchema,r="#"){const{anyOf:i}=n;if(!Array.isArray(i)||i.length===0)return n;const a=E0e(e,n,t);if(a==null)return e.errors.anyOfError({pointer:r,schema:n,value:t,anyOf:JSON.stringify(i)});const u=uc(n,a);return Px(u,"anyOf")}const Y7e=(e,t,n,r)=>{if(!(!Array.isArray(t.anyOf)||t.anyOf.length===0)){for(let i=0;i<t.anyOf.length;i+=1)if(e.isValid(n,t.anyOf[i]))return;return e.errors.anyOfError({pointer:r,schema:t,value:n,anyOf:t.anyOf})}},PH=["allOf","anyOf","oneOf","dependencies","if","then","else"],G7e=["allOf","anyOf","oneOf","dependencies","if"];function K7e(e){const t=Object.keys(e);return G7e.findIndex(n=>t.includes(n))!==-1}function bM(e,t,n,r){let i,a;if(t=e.resolveRef(t),t.oneOf){const c=QI(e,n,t,r);Yf(c)?a=c:c&&(i=uc(i??{},c))}if(Array.isArray(t.allOf)){const c=t.allOf.map(d=>{if(K7e(d)){let h=bM(e,d,n,r);return h?(h=uc(d,h),Px(h,...PH)):void 0}return d});if(c.length>0){const d=x0e(e,{allOf:c});i=uc(i??{},d)}}const u=E0e(e,t,n);u&&(i=uc(i??{},u));const l=_0e(e,t,n);l&&(i=uc(i??{},l));const o=yw(e,t,n);if(o&&(i=uc(i??{},o)),i==null)return a;const s=bM(e,i,n,r);return s&&(i=uc(i,s)),Px(i,...PH)}const W7e=["allOf","anyOf","oneOf","dependencies","if","then","else"];function MH(e,t,n,r){let i=bM(e,t,n,r);return i?(i=uc(t,i),Px(i,...W7e)):t}class $0e{constructor(t,n){this.remotes={},this.errors={},this.typeKeywords={},this.validateKeyword={},this.validateType={},this.validateFormat={},this.config=t,this.typeKeywords=x$(t.typeKeywords),this.validateKeyword=Object.assign({},t.validateKeyword),this.validateType=Object.assign({},t.validateType),this.validateFormat=Object.assign({},t.validateFormat),this.errors=Object.assign({},t.errors),this.setSchema(n)}get rootSchema(){return this.__rootSchema}set rootSchema(t){t!=null&&(this.__rootSchema=this.config.compileSchema(this,t))}addRemoteSchema(t,n){this.config.addRemoteSchema(this,t,n)}compileSchema(t){var n;return this.config.compileSchema(this,t,(n=this.rootSchema)!==null&&n!==void 0?n:t)}createSchemaOf(t){return this.config.createSchemaOf(t)}each(t,n,r,i){return this.config.each(this,t,n,r,i)}eachSchema(t,n=this.rootSchema){return this.config.eachSchema(n,t)}getChildSchemaSelection(t,n){return this.config.getChildSchemaSelection(this,t,n)}getSchema(t){return this.config.getSchema(this,t)}getTemplate(t,n,r=this.config.templateDefaultOptions){return this.config.getTemplate(this,t,n,r)}isValid(t,n,r){return this.config.isValid(this,t,n,r)}resolveAnyOf(t,n,r){return this.config.resolveAnyOf(this,t,n,r)}resolveAllOf(t,n){return this.config.resolveAllOf(this,t,n)}resolveRef(t){return this.config.resolveRef(t,this.rootSchema)}resolveOneOf(t,n,r){return this.config.resolveOneOf(this,t,n,r)}setSchema(t){this.rootSchema=t}step(t,n,r,i){return this.config.step(this,t,n,r,i)}validate(t,n,r){return this.config.validate(this,t,n,r)}}function C0e(e,t,n){n.id=n.id||t,e.remotes[t]=e.compileSchema(n)}var oD={exports:{}},J7e=oD.exports,FH;function e9e(){return FH||(FH=1,(function(e,t){(function(n,r){e.exports=r()})(typeof self<"u"?self:J7e,(()=>(()=>{var n={d:(N,U)=>{for(var W in U)n.o(U,W)&&!n.o(N,W)&&Object.defineProperty(N,W,{enumerable:!0,get:U[W]})},o:(N,U)=>Object.prototype.hasOwnProperty.call(N,U),r:N=>{typeof Symbol<"u"&&Symbol.toStringTag&&Object.defineProperty(N,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(N,"__esModule",{value:!0})}},r={};function i(N){return N==="#"||N===""||Array.isArray(N)&&N.length===0||!1}n.r(r),n.d(r,{default:()=>q,get:()=>h,isRoot:()=>i,join:()=>j,remove:()=>R,removeUndefinedItems:()=>T,set:()=>S,split:()=>d,splitLast:()=>V});const a=/~1/g,u=/~0/g,l=/\/+/g,o=/(^[#/]*|\/+$)/g;function s(N){return N.replace(a,"/").replace(u,"~")}function c(N){return s(decodeURIComponent(N))}function d(N){if(N==null||typeof N!="string"||i(N))return Array.isArray(N)?N:[];const U=N.indexOf("#")>=0?c:s,W=(N=(N=N.replace(l,"/")).replace(o,"")).split("/");for(let G=0,J=W.length;G<J;G+=1)W[G]=U(W[G]);return W}function h(N,U,W=void 0){if(U==null||N==null)return W;if(i(U))return N;const G=m(N,d(U));return G===void 0?W:G}function m(N,U){const W=U.shift();if(N!==void 0)return W!==void 0?m(N[W],U):N}const y=/^\[.*\]$/,v=/^\[(.+)\]$/;function _(N,U){return N==="__proto__"||N=="constructor"&&U.length>0&&U[0]=="prototype"}function S(N,U,W){if(U==null)return N;const G=d(U);if(G.length===0)return N;N==null&&(N=y.test(G[0])?[]:{});let J,te,H=N;for(;G.length>1;)J=G.shift(),te=y.test(G[0]),_(J,G)||(H=C(H,J,te));return J=G.pop(),E(H,J,W),N}function E(N,U,W){let G;const J=U.match(v);U==="[]"&&Array.isArray(N)?N.push(W):J?(G=J.pop(),N[G]=W):N[U]=W}function C(N,U,W){if(N[U]!=null)return N[U];const G=W?[]:{};return E(N,U,G),G}function T(N){let U=0,W=0;for(;U+W<N.length;)N[U+W]===void 0&&(W+=1),N[U]=N[U+W],U+=1;return N.length=N.length-W,N}function R(N,U,W){const G=d(U),J=G.pop(),te=h(N,G);return te&&delete te[J],Array.isArray(te)&&W!==!0&&T(te),N}const $=/\/+/g,k=/~/g,F=/\//g;function L(N,U){if(N.length===0)return U?"#":"";for(let W=0,G=N.length;W<G;W+=1)N[W]=N[W].replace(k,"~0").replace(F,"~1"),U&&(N[W]=encodeURIComponent(N[W]));return((U?"#/":"/")+N.join("/")).replace($,"/")}function j(N,...U){const W=[];if(Array.isArray(N))return L(N,arguments[1]===!0);const G=arguments[arguments.length-1],J=typeof G=="boolean"?G:N&&N[0]==="#";for(let H=0,M=arguments.length;H<M;H+=1)W.push.apply(W,d(arguments[H]));const te=[];for(let H=0,M=W.length;H<M;H+=1)if(W[H]===".."){if(te.length===0)return J?"#":"";te.pop()}else te.push(W[H]);return L(te,J)}function V(N){const U=d(N);if(U.length===0)return typeof N=="string"&&N[0]==="#"?["#",U[0]]:["",void 0];if(U.length===1)return N[0]==="#"?["#",U[0]]:["",U[0]];const W=U.pop();return[j(U,N[0]==="#"),W]}const q={get:h,set:S,remove:R,join:j,split:d,splitLast:V,isRoot:i,removeUndefinedItems:T};return r})()))})(oD)),oD.exports}var Q1=e9e();const Mx=sa(Q1);var oE={},Zc={},l2={},NH;function t9e(){if(NH)return l2;NH=1,Object.defineProperty(l2,"__esModule",{value:!0}),l2.TokenError=void 0;let e=class extends Error{constructor(n,r){if(super(n),this.message=n,this.token=r,r&&r.errors)r.errors.push(this);else throw this}inspect(){return"SyntaxError: "+this.message}};return l2.TokenError=e,l2}var IH;function n9e(){if(IH)return Zc;IH=1,Object.defineProperty(Zc,"__esModule",{value:!0}),Zc.Parser=Zc.findRuleByName=Zc.parseRuleName=Zc.escapeRegExp=Zc.readToken=void 0;const e=/^[A-Z0-9_]+$/,t=/(\?|\+|\*)$/,n=/^(@|&|!)/,r="WS",i=t9e();function a(v,_){let S=_.exec(v);return S&&S.index==0?S[0].length==0&&_.source.length>0?null:{type:null,text:S[0],rest:v.substr(S[0].length),start:0,end:S[0].length-1,fullText:S[0],errors:[],children:[],parent:null}:null}Zc.readToken=a;function u(v){return v.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g,"\\$&")}Zc.escapeRegExp=u;function l(v){v.rest="",v.children&&v.children.forEach(_=>l(_))}function o(v,_){v.start+=_,v.end+=_,v.children&&v.children.forEach(S=>o(S,v.start))}function s(v,_){_.errors&&_.errors.length&&_.errors.forEach(S=>v.push(S)),_.children&&_.children.forEach(S=>s(v,S))}function c(v){let _=t.exec(v),S=n.exec(v),E=_&&_[0]||"",C=S&&S[0]||"",T={raw:v,name:v.replace(t,"").replace(n,""),isOptional:E=="?"||E=="*",allowRepetition:E=="+"||E=="*",atLeastOne:E=="+",lookupPositive:C=="&",lookupNegative:C=="!",pinned:C=="@",lookup:!1,isLiteral:!1};return T.isLiteral=T.name[0]=="'"||T.name[0]=='"',T.lookup=T.lookupNegative||T.lookupPositive,T}Zc.parseRuleName=c;function d(v,_){let S=c(v);return _.cachedRules[S.name]||null}Zc.findRuleByName=d;function h(v,_){if(v.children){let S=v.children.filter(E=>E.type&&_.test(E.type));for(let E=0;E<S.length;E++){let C=v.children.indexOf(S[E]);C!=-1&&v.children.splice(C,1)}v.children.forEach(E=>h(E,_))}}const m=["EOF"];class y{constructor(_,S){this.grammarRules=_,this.options=S,this.cachedRules={},this.debug=S?S.debug===!0:!1;let E=[],C=[];if(_.forEach(T=>{let R=c(T.name);if(R.name in this.cachedRules){E.push("Duplicated rule "+R.name);return}else this.cachedRules[R.name]=T;if(!T.bnf||!T.bnf.length){let $="Missing rule content, rule: "+T.name;E.indexOf($)==-1&&E.push($)}else T.bnf.forEach($=>{if(typeof $[0]=="string"&&c($[0]).name==T.name){let F="Left recursion is not allowed, rule: "+T.name;E.indexOf(F)==-1&&E.push(F)}$.forEach(k=>{if(typeof k=="string"){let F=c(k);!F.isLiteral&&C.indexOf(F.name)==-1&&m.indexOf(F.name)==-1&&C.push(F.name)}})});r==T.name&&(T.implicitWs=!1),T.implicitWs&&C.indexOf(r)==-1&&C.push(r),T.recover&&C.indexOf(T.recover)==-1&&C.push(T.recover)}),C.forEach(T=>{T in this.cachedRules||E.push("Missing rule "+T)}),E.length)throw new Error(E.join(`
`))}getAST(_,S){S||(S=this.grammarRules.filter(C=>!C.fragment&&C.name.indexOf("%")!=0)[0].name);let E=this.parse(_,S);if(E){s(E.errors,E),o(E,0),h(E,/^%/),(!this.options||!this.options.keepUpperRules)&&h(E,e);let C=E.rest;C&&new i.TokenError(`Unexpected end of input: 
`+C,E),l(E),E.rest=C}return E}emitSource(){return"CANNOT EMIT SOURCE FROM BASE Parser"}parse(_,S,E=0){let C=null,T=c(S),R,$=this.debug&&!e.test(T.name);$&&console.log(new Array(E).join("│  ")+"Trying to get "+S+" from "+JSON.stringify(_.split(`
`)[0]));let k=T.name,F=d(T.name,this);if(T.name=="EOF"){if(_.length)return null;if(_.length==0)return{type:"EOF",text:"",rest:"",start:0,end:0,fullText:"",errors:[],children:[],parent:null}}try{if(!F&&T.isLiteral){let L=T.name.trim();if(L.startsWith('"')?L=JSON.parse(L):L.startsWith("'")&&(L=L.replace(/^'(.+)'$/,"$1").replace(/\\'/g,"'")),L==="")return{type:"%%EMPTY%%",text:"",rest:_,start:0,end:0,fullText:"",errors:[],children:[],parent:null};R=new RegExp(u(L)),k=null}}catch(L){return L instanceof ReferenceError&&console.error(L),null}if(R){let L=a(_,R);if(L)return L.type=k,L}else{let L=F.bnf;L instanceof Array&&L.forEach(j=>{if(C)return;let V=null,q={type:T.name,text:"",children:[],end:0,errors:[],fullText:"",parent:null,start:0,rest:_};F.fragment&&(q.fragment=!0);let N=_,U=0,W=j.length>0,G=!1;for(let J=0;J<j.length;J++)if(typeof j[J]=="string"){let te=c(j[J]);W=W&&te.isOptional;let H,M=!1;do{if(H=null,F.implicitWs&&(H=this.parse(N,te.name,E+1),!H)){let K;do if(K=this.parse(N,r,E+1),K)q.text=q.text+K.text,q.end=q.text.length,K.parent=q,q.children.push(K),N=N.substr(K.text.length),U+=K.text.length;else break;while(K&&K.text.length)}if(H=H||this.parse(N,te.name,E+1),te.lookupNegative){if(H)return;break}if(te.lookupPositive&&!H)return;if(!H&&(te.isOptional||te.atLeastOne&&M))break;if(H&&F.pinned==J+1&&(V=H,$&&console.log(new Array(E+1).join("│  ")+"└─ "+H.type+" PINNED")),H||(H=this.parseRecovery(F,N,E+1)),!H)if(V)C=q,H={type:"SyntaxError",text:N,children:[],end:N.length,errors:[],fullText:"",parent:null,start:0,rest:""},N.length?new i.TokenError(`Unexpected end of input. Expecting ${te.name} Got: ${N}`,H):new i.TokenError(`Unexpected end of input. Missing ${te.name}`,H),$&&console.log(new Array(E+1).join("│  ")+"└─ "+H.type+" "+JSON.stringify(H.text));else return;if(M=!0,G=!0,H.type=="%%EMPTY%%")break;H.start+=U,H.end+=U,!te.lookupPositive&&H.type&&(H.fragment?H.children&&H.children.forEach(K=>{K.start+=U,K.end+=U,K.parent=q,q.children.push(K)}):(H.parent=q,q.children.push(H))),te.lookup&&(H.lookup=!0),$&&console.log(new Array(E+1).join("│  ")+"└─ "+H.type+" "+JSON.stringify(H.text)),!te.lookup&&!H.lookup&&(q.text=q.text+H.text,q.end=q.text.length,N=N.substr(H.text.length),U+=H.text.length),q.rest=N}while(H&&te.allowRepetition&&N.length&&!H.lookup)}else{let te=a(N,j[J]);if(!te)return;$&&console.log(new Array(E+1).join("│  ")+"└> "+JSON.stringify(te.text)+j[J].source),G=!0,te.start+=U,te.end+=U,q.text=q.text+te.text,q.end=q.text.length,N=N.substr(te.text.length),U+=te.text.length,q.rest=N}G&&(C=q,$&&console.log(new Array(E).join("│  ")+"├<─┴< PUSHING "+C.type+" "+JSON.stringify(C.text)))}),C&&F.simplifyWhenOneChildren&&C.children.length==1&&(C=C.children[0])}return C||$&&console.log(S+" NOT RESOLVED FROM "+_),C}parseRecovery(_,S,E){if(_.recover&&S.length){let C=this.debug;C&&console.log(new Array(E+1).join("│  ")+"Trying to recover until token "+_.recover+" from "+JSON.stringify(S.split(`
`)[0]+S.split(`
`)[1]));let T={type:"SyntaxError",text:"",children:[],end:0,errors:[],fullText:"",parent:null,start:0,rest:""},R;do if(R=this.parse(S,_.recover,E+1),R){new i.TokenError('Unexpected input: "'+T.text+`" Expecting: ${_.name}`,T);break}else T.text=T.text+S[0],T.end=T.text.length,S=S.substr(1);while(!R&&S.length>0);if(T.text.length>0&&R)return C&&console.log(new Array(E+1).join("│  ")+"Recovered text: "+JSON.stringify(T.text)),T}return null}}return Zc.Parser=y,Zc.default=y,Zc}var LH;function r9e(){if(LH)return oE;LH=1,Object.defineProperty(oE,"__esModule",{value:!0});const e=n9e();var t;return(function(n){n.RULES=[{name:"Grammar",bnf:[["RULE_S*","%Atomic*","EOF"]]},{name:"%Atomic",bnf:[["Production","RULE_S*"]],fragment:!0},{name:"Production",bnf:[["NCName","RULE_S*",'"::="',"RULE_WHITESPACE*","Choice","RULE_WHITESPACE*","RULE_EOL+","RULE_S*"]]},{name:"NCName",bnf:[[/[a-zA-Z][a-zA-Z_0-9]*/]]},{name:"Choice",bnf:[["SequenceOrDifference","%_Choice_1*"]],fragment:!0},{name:"%_Choice_1",bnf:[["RULE_WHITESPACE*",'"|"',"RULE_WHITESPACE*","SequenceOrDifference"]],fragment:!0},{name:"SequenceOrDifference",bnf:[["Item","RULE_WHITESPACE*","%_Item_1?"]]},{name:"%_Item_1",bnf:[["Minus","Item"],["Item*"]],fragment:!0},{name:"Minus",bnf:[['"-"']]},{name:"Item",bnf:[["RULE_WHITESPACE*","%Primary","PrimaryDecoration?"]],fragment:!0},{name:"PrimaryDecoration",bnf:[['"?"'],['"*"'],['"+"']]},{name:"DecorationName",bnf:[['"ebnf://"',/[^\x5D#]+/]]},{name:"%Primary",bnf:[["NCName"],["StringLiteral"],["CharCode"],["CharClass"],["SubItem"]],fragment:!0},{name:"SubItem",bnf:[['"("',"RULE_WHITESPACE*","Choice","RULE_WHITESPACE*",'")"']]},{name:"StringLiteral",bnf:[[`'"'`,/[^"]*/,`'"'`],[`"'"`,/[^']*/,`"'"`]],pinned:1},{name:"CharCode",bnf:[['"#x"',/[0-9a-zA-Z]+/]]},{name:"CharClass",bnf:[["'['","'^'?","%RULE_CharClass_1+",'"]"']]},{name:"%RULE_CharClass_1",bnf:[["CharCodeRange"],["CharRange"],["CharCode"],["RULE_Char"]],fragment:!0},{name:"RULE_Char",bnf:[[/\x09/],[/\x0A/],[/\x0D/],[/[\x20-\x5c]/],[/[\x5e-\uD7FF]/],[/[\uE000-\uFFFD]/]]},{name:"CharRange",bnf:[["RULE_Char",'"-"',"RULE_Char"]]},{name:"CharCodeRange",bnf:[["CharCode",'"-"',"CharCode"]]},{name:"RULE_WHITESPACE",bnf:[["%RULE_WHITESPACE_CHAR*"],["Comment","RULE_WHITESPACE*"]]},{name:"RULE_S",bnf:[["RULE_WHITESPACE","RULE_S*"],["RULE_EOL","RULE_S*"]]},{name:"%RULE_WHITESPACE_CHAR",bnf:[[/\x09/],[/\x20/]],fragment:!0},{name:"Comment",bnf:[['"/*"',"%RULE_Comment_Body*",'"*/"']]},{name:"%RULE_Comment_Body",bnf:[['!"*/"',/[^*]/]],fragment:!0},{name:"RULE_EOL",bnf:[[/\x0D/,/\x0A/],[/\x0A/],[/\x0D/]]},{name:"Link",bnf:[["'['","Url","']'"]]},{name:"Url",bnf:[[/[^\x5D:/?#]/,'"://"',/[^\x5D#]+/,"%Url1?"]]},{name:"%Url1",bnf:[['"#"',"NCName"]],fragment:!0}],n.defaultParser=new e.Parser(n.RULES,{debug:!1});const r=/^(!|&)/,i=/(\?|\+|\*)$/,a=/^%/;function u(C,T){if(typeof C=="string"){if(r.test(C))return"";if(a.test(C)){let $=i.exec(C),k=$?$[0]+" ":"";return l(C,T)?s(C,T)+k:"("+s(C,T)+")"+k}return C}else return C.source.replace(/\\(?:x|u)([a-zA-Z0-9]+)/g,"#x$1").replace(/\[\\(?:x|u)([a-zA-Z0-9]+)-\\(?:x|u)([a-zA-Z0-9]+)\]/g,"[#x$1-#x$2]")}function l(C,T){let R=e.findRuleByName(C,T);return R&&R.bnf.length==1&&R.bnf[0].length==1&&(R.bnf[0][0]instanceof RegExp||R.bnf[0][0][0]=='"'||R.bnf[0][0][0]=="'")}function o(C,T){return C.map(R=>u(R,T)).join(" ")}function s(C,T){let R=e.findRuleByName(C,T);return R?R.bnf.map($=>o($,T)).join(" | "):"RULE_NOT_FOUND {"+C+"}"}function c(C){let T=[];return C.grammarRules.forEach(R=>{if(!/^%/.test(R.name)){let $=R.recover?" /* { recoverUntil="+R.recover+" } */":"";T.push(R.name+" ::= "+s(R.name,C)+$)}}),T.join(`
`)}n.emit=c;let d=0;function h(C,T){throw console.log("reberia restar "+T+" a "+C),new Error("Difference not supported yet")}function m(C){return new RegExp(C.replace(/#x([a-zA-Z0-9]{4})/g,"\\u$1").replace(/#x([a-zA-Z0-9]{3})/g,"\\u0$1").replace(/#x([a-zA-Z0-9]{2})/g,"\\x$1").replace(/#x([a-zA-Z0-9]{1})/g,"\\x0$1"))}function y(C,T,R){let $=null,k=[];return T.children.forEach((F,L)=>{F.type=="Minus"&&h($,F);let j=T.children[L+1];j=j&&j.type=="PrimaryDecoration"&&j.text||"";let V="";switch(F.type){case"SubItem":let q="%"+(R+d++);v(C,F,q),k.push(V+q+j);break;case"NCName":case"StringLiteral":k.push(V+F.text+j);break;case"CharCode":case"CharClass":if(j||V){let N={name:"%"+(R+d++),bnf:[[m(F.text)]]};C.push(N),k.push(V+N.name+j)}else k.push(m(F.text));break;case"PrimaryDecoration":break;default:throw new Error(" HOW SHOULD I PARSE THIS? "+F.type+" -> "+JSON.stringify(F.text))}$=F}),k}function v(C,T,R){let $=T.children.filter(L=>L.type=="SequenceOrDifference").map(L=>y(C,L,R)),k={name:R,bnf:$},F=null;$.forEach(L=>{F=F||L.recover,delete L.recover}),R.indexOf("%")==0&&(k.fragment=!0),F&&(k.recover=F),C.push(k)}function _(C,T=n.defaultParser){let R=T.getAST(C);if(!R)throw new Error("Could not parse "+C);if(R.errors&&R.errors.length)throw R.errors[0];let $=[];return R.children.filter(k=>k.type=="Production").map(k=>{let F=k.children.filter(L=>L.type=="NCName")[0].text;v($,k,F)}),$}n.getRules=_;function S(C,T=n.defaultParser){return _(C.join(""),T)}n.Transform=S;class E extends e.Parser{constructor(T,R){const $=R&&R.debugRulesParser===!0?new e.Parser(n.RULES,{debug:!0}):n.defaultParser;super(_(T,$),R)}emitSource(){return c(this)}}n.Parser=E})(t||(t={})),oE.default=t,oE}var i9e=r9e();const a9e=sa(i9e),u9e="[^?/{}*,()#]+",l9e=`
root ::= ("#" recursion | recursion | (query | pattern) recursion* | "#" SEP? | SEP)
recursion ::= (SEP query | pattern)*

query ::= (ESC escaped ESC | property | all | any | regex) typecheck? lookahead?
property ::= ${u9e}
regex ::= "{" [^}]+ "}"
SEP ::= "/"
all ::= "**"
any ::= "*"

typecheck ::= "?:" ("value" | "boolean" | "string" | "number" | "object" | "array")
lookahead ::= "?" expression ((andExpr | orExpr) expression)*
andExpr ::= S? "&&" S?
orExpr ::= S? "||" S?

expression ::= (exprProperty | ESC escaped ESC) ((isnot | is) (exprProperty | regex | ESC escaped ESC))*
exprProperty ::= [a-zA-Z0-9-_ $]+
escaped ::= [^"]+
is ::= ":"
isnot ::= ":!"
ESC ::= '"'

pattern ::= S? "(" (SEP query | pattern (orPattern? pattern)*)* ")" quantifier? S? lookahead?
quantifier ::= "+" | "*" | [0-9]+
orPattern ::= S? "," S?

S ::= [ ]*
`,o9e=new a9e.Parser(l9e),s9e=e=>o9e.getAST(e),tf=0,k3=3,S$=(e,t)=>`${e}/${t}`,w0e=Object.prototype.toString,c9e=/Object|Array/,OM=e=>c9e.test(w0e.call(e)),f9e=e=>w0e.call(e).match(/\s([^\]]+)\]/).pop().toLowerCase();function R0e(e){return new RegExp(e.text.replace(/(^{|}$)/g,""))}function d9e(e,t){Array.isArray(e)?e.forEach(t):Object.prototype.toString.call(e)==="[object Object]"&&Object.keys(e).forEach(function(n){t(e[n],n,e)})}function BH(e){return Array.isArray(e)?e.map(function(t,n){return`${n}`}):Object.prototype.toString.call(e)==="[object Object]"?Object.keys(e):[]}const jv={mem:[],get(e,t){const n=e[tf][t];if(!jv.mem.includes(n))return OM(n)&&jv.mem.push(n),[n,t,e[tf],S$(e[k3],t)]},reset(){jv.mem.length=0}},xM={any(e,t){const n=t[tf];return BH(n).map(r=>[n[r],r,n,S$(t[k3],r)])},all(e,t){const n=[t];return d9e(t[tf],(r,i)=>{const a=jv.get(t,i);a&&n.push(...xM.all(e,a))}),n},regex(e,t){const n=R0e(e),r=t[tf];return BH(r).filter(i=>n.test(i)).map(i=>[r[i],i,r,S$(t[k3],i)])}},_$={escaped:(e,t)=>_$.property(e,t),property:(e,t)=>{const n=e.text;if(t[tf]&&t[tf][n]!==void 0)return[t[tf][n],n,t[tf],S$(t[k3],n)]},typecheck:(e,t)=>{const n=e.text.replace(/^\?:/,"");if(n==="value")return OM(t[tf])?void 0:t;if(f9e(t[tf])===n)return t},lookahead:(e,t)=>{let n=!0,r=!1;return e.children.forEach(i=>{if(i.type==="expression"){const a=_$.expression(i,t)!==void 0;n=r===!0?n||a:n&&a}else r=i.type==="orExpr"}),n?t:void 0},expression:(e,t)=>{const n=e.children[0].text,r=e.children[1],i=e.children[2],a=t[tf];if(OM(a)!==!1)return h9e(a[n],r,i)?t:void 0}};function h9e(e,t,n){if(t===void 0)return e!==void 0;let r;const i=`${e}`;return n.type==="regex"?r=R0e(n).test(i):r=i===n.text,t.type==="isnot"&&(r=r===!1&&e!==void 0),r}function p9e(e,t,n,r){const i=[];for(let a=0,u=t.length;a<u;a+=1)i.push(...e(n,t[a],n,r));return i}function m9e(e,t,n,r){const i=[];for(let a=0,u=t.length;a<u;a+=1){const l=e(n,t[a],r);l&&i.push(l)}return i}function g9e(e,t,n){let r=e;return t.children.forEach(i=>{if(xM[i.type])r=p9e(xM[i.type],r,i,n);else if(_$[i.type])r=m9e(_$[i.type],r,i,n);else throw new Error(`Unknown filter ${i.type}`)}),r}function v9e(e,t,n){const r=[];let i=e;return t.children.forEach(a=>{if(a.type==="orPattern"){r.push(...i),i=e;return}i=jI(i,a,n)}),r.push(...i),r}function y9e(e){if(e==null)return 1;if(e==="*"||e==="+")return 1/0;const t=parseInt(e);return isNaN(t)?1:t}function b9e(e,t,n){const r=[],i=t.children.find(o=>o.type==="quantifier"),a=y9e(i&&i.text);let u=e;i&&i.text==="*"&&r.push(...u);let l=0;for(;u.length>0&&l<a;)u=v9e(u,t,n),r.push(...u),l+=1;return r}function O9e(e,t,n){let r=e;return t.children.forEach(i=>r=jI(r,i,n)),r}function jI(e,t,n){let r;return t.type==="query"?r=g9e(e,t,n):t.type==="pattern"?r=b9e(e,t,n):r=O9e(e,t,n),jv.reset(),jv.mem.push(e),r}function x9e(e,t){return jv.reset(),jv.mem.push(e),jI([[e,null,null,"#"]],t)}const QH={value:e=>e.map(t=>t[tf]),pointer:e=>e.map(t=>t[k3]),all:e=>e,map:e=>{const t={};return e.forEach(n=>t[n[k3]]=n[tf]),t}};var hb;(function(e){e.POINTER="pointer",e.VALUE="value",e.ALL="all",e.MAP="map"})(hb||(hb={}));_S.POINTER=hb.POINTER;_S.VALUE=hb.VALUE;_S.ALL=hb.ALL;_S.MAP=hb.MAP;function _S(e,t,n=hb.VALUE){if(t==null)return[];t=t.replace(/(\/$)/g,""),t===""&&(t="#");const r=s9e(t);if(r==null)throw new Error(`empty ast for '${t}'`);if(r.rest!=="")throw new Error(`Failed parsing queryString from: '${r.rest}'`);const i=x9e(e,r);return typeof n=="function"?i.map(a=>n(...a)):QH[n]?QH[n](i):i}var E$;(function(e){e.REPLACE_ITEMS="replace",e.INSERT_ITEMS="insert"})(E$||(E$={}));E$.REPLACE_ITEMS;E$.INSERT_ITEMS;const Zm={$ref:{type:!1},allOf:{type:!1,definitions:["allOf/*"]},anyOf:{type:!1,definitions:["anyOf/*"]},array:{type:!0,definitions:["allOf/*","anyOf/*","oneOf/*","not","items","items/*","additionalItems"],validationKeywords:["minItems","maxItems","uniqueItems"],keywords:["items","additionalItems","minItems","maxItems","uniqueItems"]},boolean:{type:!0},enum:{type:!1},integer:{type:!0,definitions:["allOf/*","anyOf/*","oneOf/*","not"],validationKeywords:["minimum","maximum","multipleOf"]},not:{type:!1,definitions:["not"]},number:{type:!0,definitions:["allOf/*","anyOf/*","oneOf/*","not"],validationKeywords:["minimum","maximum","multipleOf"]},null:{type:!0},object:{type:!0,definitions:["allOf/*","anyOf/*","oneOf/*","not","properties/*","additionalProperties","patternProperties/*","dependencies/*"],validationKeywords:["minProperties","maxProperties","required"],keywords:["properties","additionalProperties","patternProperties","dependencies","minProperties","maxProperties","required"]},oneOf:{type:!1,definitions:["oneOf/*"]},string:{type:!0,definitions:["allOf/*","anyOf/*","oneOf/*","not"],validationKeywords:["minLength","maxLength","pattern"]}},S9e=Object.keys(Zm).filter(e=>Zm[e].type===!1),zH=Object.prototype.hasOwnProperty;function qH(e){if(Uv(e)===!1)return;if(e.enum)return"enum";const t=e.type;if(Array.isArray(t)||Zm[t])return t;const n=S9e.filter(r=>e[r]);if(n.length===1)return n[0];if(n.length===0){for(let r=0,i=Zm.object.keywords.length;r<i;r+=1){const a=Zm.object.keywords[r];if(zH.call(e,a))return"object"}for(let r=0,i=Zm.array.keywords.length;r<i;r+=1){const a=Zm.array.keywords[r];if(zH.call(e,a))return"array"}return}throw new Error(`Mutiple typeIds [${n.join(", ")}] matched in ${JSON.stringify(e)}`)}function _9e(e){const t=[],n=qH(e);if(n==null)return t;let r;if(Array.isArray(n)){r={};for(let i=0,a=n.length;i<a;i+=1)Object.assign(r,Zm[n[i]])}else r=Zm[n];return r.definitions==null||r.definitions.forEach(i=>{_S(e,i,(a,u,l,o)=>{Uv(a)&&qH(a)&&t.push({pointer:Mx.join(Mx.split(o),!1),def:a})})}),t}function E9e(e,t){if(this.callback(e,t)===!0)return;_9e(e).forEach(r=>this.nextTypeDefs(r.def,Mx.join(t,r.pointer,!1)))}function sE(e,t,n,r="definitions"){const i=t[r];Object.keys(i).forEach(a=>{if(i[a]===!1||Uv(i[a])){e.nextTypeDefs(i[a],Mx.join(n,r,a,!1));return}})}function bw(e,t,n="#"){const r={callback:t,nextTypeDefs:E9e};r.nextTypeDefs(e,n),e.definitions!=null&&(r.callback=(i,a)=>{t(i,a),i.definitions!=null&&sE(r,i,a)},sE(r,e,n)),e.$defs!=null&&(r.callback=(i,a)=>{t(i,a),i.definitions!=null&&sE(r,i,a)},sE(r,e,n,"$defs"))}const D9e=/(#|\/)+$/,cE=/#$/,$9e=/^[^:]+:\/\/[^/]+\//,C9e=/\/[^/]*$/,w9e=/#.*$/;function D$(e,t){return e==null&&t==null?"#":t==null?e.replace(cE,""):e==null?t.replace(cE,""):t[0]==="#"?`${e.replace(w9e,"")}${t.replace(D9e,"")}`:$9e.test(t)?t.replace(cE,""):`${e.replace(C9e,"")}/${t.replace(cE,"")}`}const o2=/(#|\/)+$/g,R9e=["",null,"#"];function A9e(e){if(R9e.includes(e))return[];if(e=e.replace(o2,""),e.indexOf("#")===-1)return[e.replace(o2,"")];if(e.indexOf("#")===0)return[e.replace(o2,"")];const t=e.split("#");return t[0]=t[0].replace(o2,""),t[1]=`#${t[1].replace(o2,"")}`,t}const T9e=/(#|\/)+$/g,k9e=e=>hi(e)==="object";function Qm(e,t,n){if(k9e(n)&&(n=n.__ref||n.$ref),n==null)return t;let r;const i=n.replace(T9e,"");if(e.remotes[i])return r=e.remotes[i],r&&r.$ref?Qm(e,t,r.$ref):r;if(e.ids[n])return r=Q1.get(t,e.ids[n]),r&&r.$ref?Qm(e,t,r.$ref):r;const a=A9e(n);if(a.length===0)return t;if(a.length===1){if(n=a[0],e.remotes[n])return r=e.remotes[n],Qm(e,t,r.$ref);if(e.ids[n])return r=Q1.get(t,e.ids[n]),r&&r.$ref?Qm(e,t,r.$ref):r}if(a.length===2){const u=a[0];if(n=a[1],e.remotes[u])return e.remotes[u].getRef?e.remotes[u].getRef(n):Qm(e,e.remotes[u],n);if(e.ids[u])return Qm(e,Q1.get(t,e.ids[u]),n)}return r=Q1.get(t,e.ids[n]||n),r&&r.$ref?Qm(e,t,r.$ref):r}const VH="__compiled",UH="__ref",P9e="getRef",M9e="getRoot",F9e=/(#|\/)+$/g;function N9e(e,t,n=t,r=!1){if(!t||t[VH]!==void 0)return t;const i={ids:{},remotes:e.remotes},a=JSON.stringify(t),u=JSON.parse(a);if(Object.defineProperty(u,VH,{enumerable:!1,value:!0}),Object.defineProperty(u,P9e,{enumerable:!1,value:Qm.bind(null,i,u)}),r===!1&&a.includes("$ref")===!1)return u;t!==n&&Object.defineProperty(u,"definitions",{enumerable:!1,value:Object.assign({},n.definitions,n.$defs,t.definitions,t.$defs)});const l={},o=()=>u;return bw(u,(s,c)=>{var d;if(s.id){if(s.id.startsWith("http")&&/(allOf|anyOf|oneOf)\/\d+$/.test(c)){const _=c.replace(/\/(allOf|anyOf|oneOf)\/\d+$/,""),S=Q1.get(u,_);s.id=(d=S.id)!==null&&d!==void 0?d:s.id}i.ids[s.id.replace(F9e,"")]=c}c=`#${c}`.replace(/##+/,"#");const h=c.replace(/\/[^/]+$/,""),m=c.replace(/\/[^/]+\/[^/]+$/,""),y=l[h]||l[m],v=D$(y,s.id);l[c]=v,i.ids[v]==null&&(i.ids[v]=c),s.$ref&&!s[UH]&&(Object.defineProperty(s,UH,{enumerable:!1,value:D$(v,s.$ref)}),Object.defineProperty(s,M9e,{enumerable:!1,value:o}))}),u}function A0e(e,t,n,r=e.rootSchema,i="#"){r=e.resolveRef(r),n(r,t,i);const a=hi(t);a==="object"?Object.keys(t).forEach(u=>{const l=e.step(u,r,t,i),o=t[u];e.each(o,n,l,`${i}/${u}`)}):a==="array"&&t.forEach((u,l)=>{const o=e.step(l,r,t,i);e.each(u,n,o,`${i}/${l}`)})}const T0e={additionalItemsError:$n("AdditionalItemsError"),additionalPropertiesError:$n("AdditionalPropertiesError"),anyOfError:$n("AnyOfError"),allOfError:$n("AllOfError"),constError:$n("ConstError"),containsError:$n("ContainsError"),containsArrayError:$n("ContainsArrayError"),containsAnyError:$n("ContainsAnyError"),enumError:$n("EnumError"),forbiddenPropertyError:$n("ForbiddenPropertyError"),formatURLError:$n("FormatURLError"),formatURIError:$n("FormatURIError"),formatURIReferenceError:$n("FormatURIReferenceError"),formatURITemplateError:$n("FormatURITemplateError"),formatDateError:$n("FormatDateError"),formatDateTimeError:$n("FormatDateTimeError"),formatEmailError:$n("FormatEmailError"),formatHostnameError:$n("FormatHostnameError"),formatIPV4Error:$n("FormatIPV4Error"),formatIPV4LeadingZeroError:$n("FormatIPV4LeadingZeroError"),formatIPV6Error:$n("FormatIPV6Error"),formatIPV6LeadingZeroError:$n("FormatIPV6LeadingZeroError"),formatJsonPointerError:$n("FormatJsonPointerError"),formatRegExError:$n("FormatRegExError"),formatTimeError:$n("FormatTimeError"),invalidSchemaError:$n("InvalidSchemaError"),invalidDataError:$n("InvalidDataError"),invalidTypeError:$n("InvalidTypeError"),invalidPropertyNameError:$n("InvalidPropertyNameError"),maximumError:$n("MaximumError"),maxItemsError:$n("MaxItemsError"),maxLengthError:$n("MaxLengthError"),maxPropertiesError:$n("MaxPropertiesError"),minimumError:$n("MinimumError"),minItemsError:$n("MinItemsError"),minItemsOneError:$n("MinItemsOneError"),minLengthError:$n("MinLengthError"),minLengthOneError:$n("MinLengthOneError"),minPropertiesError:$n("MinPropertiesError"),missingDependencyError:$n("MissingDependencyError"),missingOneOfPropertyError:$n("MissingOneOfPropertyError"),multipleOfError:$n("MultipleOfError"),multipleOneOfError:$n("MultipleOneOfError"),noAdditionalPropertiesError:$n("NoAdditionalPropertiesError"),notError:$n("NotError"),oneOfError:$n("OneOfError"),oneOfPropertyError:$n("OneOfPropertyError"),patternError:$n("PatternError"),patternPropertiesError:$n("PatternPropertiesError"),requiredPropertyError:$n("RequiredPropertyError"),schemaWarning:$n("SchemaWarning"),typeError:$n("TypeError"),undefinedValueError:$n("UndefinedValueError"),uniqueItemsError:$n("UniqueItemsError"),unknownPropertyError:$n("UnknownPropertyError"),valueNotEmptyError:$n("ValueNotEmptyError")};var lP={exports:{}},jH;function I9e(){return jH||(jH=1,(function(e){(function(t){t.exports.is_uri=r,t.exports.is_http_uri=i,t.exports.is_https_uri=a,t.exports.is_web_uri=u,t.exports.isUri=r,t.exports.isHttpUri=i,t.exports.isHttpsUri=a,t.exports.isWebUri=u;var n=function(l){var o=l.match(/(?:([^:\/?#]+):)?(?:\/\/([^\/?#]*))?([^?#]*)(?:\?([^#]*))?(?:#(.*))?/);return o};function r(l){if(l&&!/[^a-z0-9\:\/\?\#\[\]\@\!\$\&\'\(\)\*\+\,\;\=\.\-\_\~\%]/i.test(l)&&!/%[^0-9a-f]/i.test(l)&&!/%[0-9a-f](:?[^0-9a-f]|$)/i.test(l)){var o=[],s="",c="",d="",h="",m="",y="";if(o=n(l),s=o[1],c=o[2],d=o[3],h=o[4],m=o[5],!!(s&&s.length&&d.length>=0)){if(c&&c.length){if(!(d.length===0||/^\//.test(d)))return}else if(/^\/\//.test(d))return;if(/^[a-z][a-z0-9\+\-\.]*$/.test(s.toLowerCase()))return y+=s+":",c&&c.length&&(y+="//"+c),y+=d,h&&h.length&&(y+="?"+h),m&&m.length&&(y+="#"+m),y}}}function i(l,o){if(r(l)){var s=[],c="",d="",h="",m="",y="",v="",_="";if(s=n(l),c=s[1],d=s[2],h=s[3],y=s[4],v=s[5],!!c){if(o){if(c.toLowerCase()!="https")return}else if(c.toLowerCase()!="http")return;if(d)return/:(\d+)$/.test(d)&&(m=d.match(/:(\d+)$/)[0],d=d.replace(/:\d+$/,"")),_+=c+":",_+="//"+d,m&&(_+=m),_+=h,y&&y.length&&(_+="?"+y),v&&v.length&&(_+="#"+v),_}}}function a(l){return i(l,!0)}function u(l){return i(l)||a(l)}})(e)})(lP)),lP.exports}var L9e=I9e();const ZH=sa(L9e);var tc={},sD={exports:{}},B9e=sD.exports,HH;function Q9e(){return HH||(HH=1,(function(e){(function(t,n){e.exports?e.exports=n():t.nearley=n()})(B9e,function(){function t(s,c,d){return this.id=++t.highestId,this.name=s,this.symbols=c,this.postprocess=d,this}t.highestId=0,t.prototype.toString=function(s){var c=typeof s>"u"?this.symbols.map(o).join(" "):this.symbols.slice(0,s).map(o).join(" ")+" ● "+this.symbols.slice(s).map(o).join(" ");return this.name+" → "+c};function n(s,c,d,h){this.rule=s,this.dot=c,this.reference=d,this.data=[],this.wantedBy=h,this.isComplete=this.dot===s.symbols.length}n.prototype.toString=function(){return"{"+this.rule.toString(this.dot)+"}, from: "+(this.reference||0)},n.prototype.nextState=function(s){var c=new n(this.rule,this.dot+1,this.reference,this.wantedBy);return c.left=this,c.right=s,c.isComplete&&(c.data=c.build(),c.right=void 0),c},n.prototype.build=function(){var s=[],c=this;do s.push(c.right.data),c=c.left;while(c.left);return s.reverse(),s},n.prototype.finish=function(){this.rule.postprocess&&(this.data=this.rule.postprocess(this.data,this.reference,u.fail))};function r(s,c){this.grammar=s,this.index=c,this.states=[],this.wants={},this.scannable=[],this.completed={}}r.prototype.process=function(s){for(var c=this.states,d=this.wants,h=this.completed,m=0;m<c.length;m++){var y=c[m];if(y.isComplete){if(y.finish(),y.data!==u.fail){for(var v=y.wantedBy,_=v.length;_--;){var S=v[_];this.complete(S,y)}if(y.reference===this.index){var E=y.rule.name;(this.completed[E]=this.completed[E]||[]).push(y)}}}else{var E=y.rule.symbols[y.dot];if(typeof E!="string"){this.scannable.push(y);continue}if(d[E]){if(d[E].push(y),h.hasOwnProperty(E))for(var C=h[E],_=0;_<C.length;_++){var T=C[_];this.complete(y,T)}}else d[E]=[y],this.predict(E)}}},r.prototype.predict=function(s){for(var c=this.grammar.byName[s]||[],d=0;d<c.length;d++){var h=c[d],m=this.wants[s],y=new n(h,0,this.index,m);this.states.push(y)}},r.prototype.complete=function(s,c){var d=s.nextState(c);this.states.push(d)};function i(s,c){this.rules=s,this.start=c||this.rules[0].name;var d=this.byName={};this.rules.forEach(function(h){d.hasOwnProperty(h.name)||(d[h.name]=[]),d[h.name].push(h)})}i.fromCompiled=function(h,c){var d=h.Lexer;h.ParserStart&&(c=h.ParserStart,h=h.ParserRules);var h=h.map(function(y){return new t(y.name,y.symbols,y.postprocess)}),m=new i(h,c);return m.lexer=d,m};function a(){this.reset("")}a.prototype.reset=function(s,c){this.buffer=s,this.index=0,this.line=c?c.line:1,this.lastLineBreak=c?-c.col:0},a.prototype.next=function(){if(this.index<this.buffer.length){var s=this.buffer[this.index++];return s===`
`&&(this.line+=1,this.lastLineBreak=this.index),{value:s}}},a.prototype.save=function(){return{line:this.line,col:this.index-this.lastLineBreak}},a.prototype.formatError=function(s,c){var d=this.buffer;if(typeof d=="string"){var h=d.split(`
`).slice(Math.max(0,this.line-5),this.line),m=d.indexOf(`
`,this.index);m===-1&&(m=d.length);var y=this.index-this.lastLineBreak,v=String(this.line).length;return c+=" at line "+this.line+" col "+y+`:

`,c+=h.map(function(S,E){return _(this.line-h.length+E+1,v)+" "+S},this).join(`
`),c+=`
`+_("",v+y)+`^
`,c}else return c+" at index "+(this.index-1);function _(S,E){var C=String(S);return Array(E-C.length+1).join(" ")+C}};function u(s,c,d){if(s instanceof i)var h=s,d=c;else var h=i.fromCompiled(s,c);this.grammar=h,this.options={keepHistory:!1,lexer:h.lexer||new a};for(var m in d||{})this.options[m]=d[m];this.lexer=this.options.lexer,this.lexerState=void 0;var y=new r(h,0);this.table=[y],y.wants[h.start]=[],y.predict(h.start),y.process(),this.current=0}u.fail={},u.prototype.feed=function(s){var c=this.lexer;c.reset(s,this.lexerState);for(var d;;){try{if(d=c.next(),!d)break}catch(k){var v=new r(this.grammar,this.current+1);this.table.push(v);var h=new Error(this.reportLexerError(k));throw h.offset=this.current,h.token=k.token,h}var m=this.table[this.current];this.options.keepHistory||delete this.table[this.current-1];var y=this.current+1,v=new r(this.grammar,y);this.table.push(v);for(var _=d.text!==void 0?d.text:d.value,S=c.constructor===a?d.value:d,E=m.scannable,C=E.length;C--;){var T=E[C],R=T.rule.symbols[T.dot];if(R.test?R.test(S):R.type?R.type===d.type:R.literal===_){var $=T.nextState({data:S,token:d,isToken:!0,reference:y-1});v.states.push($)}}if(v.process(),v.states.length===0){var h=new Error(this.reportError(d));throw h.offset=this.current,h.token=d,h}this.options.keepHistory&&(m.lexerState=c.save()),this.current++}return m&&(this.lexerState=c.save()),this.results=this.finish(),this},u.prototype.reportLexerError=function(s){var c,d,h=s.token;return h?(c="input "+JSON.stringify(h.text[0])+" (lexer error)",d=this.lexer.formatError(h,"Syntax error")):(c="input (lexer error)",d=s.message),this.reportErrorCommon(d,c)},u.prototype.reportError=function(s){var c=(s.type?s.type+" token: ":"")+JSON.stringify(s.value!==void 0?s.value:s),d=this.lexer.formatError(s,"Syntax error");return this.reportErrorCommon(d,c)},u.prototype.reportErrorCommon=function(s,c){var d=[];d.push(s);var h=this.table.length-2,m=this.table[h],y=m.states.filter(function(_){var S=_.rule.symbols[_.dot];return S&&typeof S!="string"});if(y.length===0)d.push("Unexpected "+c+`. I did not expect any more input. Here is the state of my parse table:
`),this.displayStateStack(m.states,d);else{d.push("Unexpected "+c+`. Instead, I was expecting to see one of the following:
`);var v=y.map(function(_){return this.buildFirstStateStack(_,[])||[_]},this);v.forEach(function(_){var S=_[0],E=S.rule.symbols[S.dot],C=this.getSymbolDisplay(E);d.push("A "+C+" based on:"),this.displayStateStack(_,d)},this)}return d.push(""),d.join(`
`)},u.prototype.displayStateStack=function(s,c){for(var d,h=0,m=0;m<s.length;m++){var y=s[m],v=y.rule.toString(y.dot);v===d?h++:(h>0&&c.push("    ^ "+h+" more lines identical to this"),h=0,c.push("    "+v)),d=v}},u.prototype.getSymbolDisplay=function(s){return l(s)},u.prototype.buildFirstStateStack=function(s,c){if(c.indexOf(s)!==-1)return null;if(s.wantedBy.length===0)return[s];var d=s.wantedBy[0],h=[s].concat(c),m=this.buildFirstStateStack(d,h);return m===null?null:[s].concat(m)},u.prototype.save=function(){var s=this.table[this.current];return s.lexerState=this.lexerState,s},u.prototype.restore=function(s){var c=s.index;this.current=c,this.table[c]=s,this.table.splice(c+1),this.lexerState=s.lexerState,this.results=this.finish()},u.prototype.rewind=function(s){if(!this.options.keepHistory)throw new Error("set option `keepHistory` to enable rewinding");this.restore(this.table[s])},u.prototype.finish=function(){var s=[],c=this.grammar.start,d=this.table[this.table.length-1];return d.states.forEach(function(h){h.rule.name===c&&h.dot===h.rule.symbols.length&&h.reference===0&&h.data!==u.fail&&s.push(h)}),s.map(function(h){return h.data})};function l(s){var c=typeof s;if(c==="string")return s;if(c==="object"){if(s.literal)return JSON.stringify(s.literal);if(s instanceof RegExp)return"character matching "+s;if(s.type)return s.type+" token";if(s.test)return"token matching "+String(s.test);throw new Error("Unknown symbol type: "+s)}}function o(s){var c=typeof s;if(c==="string")return s;if(c==="object"){if(s.literal)return JSON.stringify(s.literal);if(s instanceof RegExp)return s.toString();if(s.type)return"%"+s.type;if(s.test)return"<"+String(s.test)+">";throw new Error("Unknown symbol type: "+s)}}return{Parser:u,Grammar:i,Rule:t}})})(sD)),sD.exports}var fE={},XH;function z9e(){if(XH)return fE;XH=1,Object.defineProperty(fE,"__esModule",{value:!0});function e(i){return i[0]}const t=i=>[].concat(...i.map(a=>Array.isArray(a)?t(a):a));function n(i){return i?Array.isArray(i)?t(i).join(""):i:""}const r={Lexer:void 0,ParserRules:[{name:"Reverse_path",symbols:["Path"]},{name:"Reverse_path$string$1",symbols:[{literal:"<"},{literal:">"}],postprocess:i=>i.join("")},{name:"Reverse_path",symbols:["Reverse_path$string$1"]},{name:"Forward_path$subexpression$1$subexpression$1",symbols:[{literal:"<"},/[pP]/,/[oO]/,/[sS]/,/[tT]/,/[mM]/,/[aA]/,/[sS]/,/[tT]/,/[eE]/,/[rR]/,{literal:"@"}],postprocess:function(i){return i.join("")}},{name:"Forward_path$subexpression$1",symbols:["Forward_path$subexpression$1$subexpression$1","Domain",{literal:">"}]},{name:"Forward_path",symbols:["Forward_path$subexpression$1"]},{name:"Forward_path$subexpression$2",symbols:[{literal:"<"},/[pP]/,/[oO]/,/[sS]/,/[tT]/,/[mM]/,/[aA]/,/[sS]/,/[tT]/,/[eE]/,/[rR]/,{literal:">"}],postprocess:function(i){return i.join("")}},{name:"Forward_path",symbols:["Forward_path$subexpression$2"]},{name:"Forward_path",symbols:["Path"]},{name:"Path$ebnf$1$subexpression$1",symbols:["A_d_l",{literal:":"}]},{name:"Path$ebnf$1",symbols:["Path$ebnf$1$subexpression$1"],postprocess:e},{name:"Path$ebnf$1",symbols:[],postprocess:()=>null},{name:"Path",symbols:[{literal:"<"},"Path$ebnf$1","Mailbox",{literal:">"}]},{name:"A_d_l$ebnf$1",symbols:[]},{name:"A_d_l$ebnf$1$subexpression$1",symbols:[{literal:","},"At_domain"]},{name:"A_d_l$ebnf$1",symbols:["A_d_l$ebnf$1","A_d_l$ebnf$1$subexpression$1"],postprocess:i=>i[0].concat([i[1]])},{name:"A_d_l",symbols:["At_domain","A_d_l$ebnf$1"]},{name:"At_domain",symbols:[{literal:"@"},"Domain"]},{name:"Domain$ebnf$1",symbols:[]},{name:"Domain$ebnf$1$subexpression$1",symbols:[{literal:"."},"sub_domain"]},{name:"Domain$ebnf$1",symbols:["Domain$ebnf$1","Domain$ebnf$1$subexpression$1"],postprocess:i=>i[0].concat([i[1]])},{name:"Domain",symbols:["sub_domain","Domain$ebnf$1"]},{name:"sub_domain",symbols:["U_label"]},{name:"Let_dig",symbols:["ALPHA_DIGIT"],postprocess:e},{name:"Ldh_str$ebnf$1",symbols:[]},{name:"Ldh_str$ebnf$1",symbols:["Ldh_str$ebnf$1","ALPHA_DIG_DASH"],postprocess:i=>i[0].concat([i[1]])},{name:"Ldh_str",symbols:["Ldh_str$ebnf$1","Let_dig"]},{name:"U_Let_dig",symbols:["ALPHA_DIGIT_U"],postprocess:e},{name:"U_Ldh_str$ebnf$1",symbols:[]},{name:"U_Ldh_str$ebnf$1",symbols:["U_Ldh_str$ebnf$1","ALPHA_DIG_DASH_U"],postprocess:i=>i[0].concat([i[1]])},{name:"U_Ldh_str",symbols:["U_Ldh_str$ebnf$1","U_Let_dig"]},{name:"U_label$ebnf$1$subexpression$1",symbols:["U_Ldh_str"]},{name:"U_label$ebnf$1",symbols:["U_label$ebnf$1$subexpression$1"],postprocess:e},{name:"U_label$ebnf$1",symbols:[],postprocess:()=>null},{name:"U_label",symbols:["U_Let_dig","U_label$ebnf$1"]},{name:"address_literal$subexpression$1",symbols:["IPv4_address_literal"]},{name:"address_literal$subexpression$1",symbols:["IPv6_address_literal"]},{name:"address_literal$subexpression$1",symbols:["General_address_literal"]},{name:"address_literal",symbols:[{literal:"["},"address_literal$subexpression$1",{literal:"]"}]},{name:"non_local_part",symbols:["Domain"],postprocess:function(i){return{DomainName:n(i[0])}}},{name:"non_local_part",symbols:["address_literal"],postprocess:function(i){return{AddressLiteral:n(i[0])}}},{name:"Mailbox",symbols:["Local_part",{literal:"@"},"non_local_part"],postprocess:function(i){return{localPart:n(i[0]),domainPart:n(i[2])}}},{name:"Local_part",symbols:["Dot_string"],postprocess:function(i){return{DotString:n(i[0])}}},{name:"Local_part",symbols:["Quoted_string"],postprocess:function(i){return{QuotedString:n(i[0])}}},{name:"Dot_string$ebnf$1",symbols:[]},{name:"Dot_string$ebnf$1$subexpression$1",symbols:[{literal:"."},"Atom"]},{name:"Dot_string$ebnf$1",symbols:["Dot_string$ebnf$1","Dot_string$ebnf$1$subexpression$1"],postprocess:i=>i[0].concat([i[1]])},{name:"Dot_string",symbols:["Atom","Dot_string$ebnf$1"]},{name:"Atom$ebnf$1",symbols:[/[0-9A-Za-z!#$%&'*+\-/=?^_`{|}~\u0080-\uFFFF/]/]},{name:"Atom$ebnf$1",symbols:["Atom$ebnf$1",/[0-9A-Za-z!#$%&'*+\-/=?^_`{|}~\u0080-\uFFFF/]/],postprocess:i=>i[0].concat([i[1]])},{name:"Atom",symbols:["Atom$ebnf$1"]},{name:"Quoted_string$ebnf$1",symbols:[]},{name:"Quoted_string$ebnf$1",symbols:["Quoted_string$ebnf$1","QcontentSMTP"],postprocess:i=>i[0].concat([i[1]])},{name:"Quoted_string",symbols:["DQUOTE","Quoted_string$ebnf$1","DQUOTE"]},{name:"QcontentSMTP",symbols:["qtextSMTP"]},{name:"QcontentSMTP",symbols:["quoted_pairSMTP"]},{name:"quoted_pairSMTP",symbols:[{literal:"\\"},/[\x20-\x7e]/]},{name:"qtextSMTP",symbols:[/[\x20-\x21\x23-\x5b\x5d-\x7e\u0080-\uFFFF]/],postprocess:e},{name:"IPv4_address_literal$macrocall$2",symbols:[{literal:"."},"Snum"]},{name:"IPv4_address_literal$macrocall$1",symbols:["IPv4_address_literal$macrocall$2","IPv4_address_literal$macrocall$2","IPv4_address_literal$macrocall$2"]},{name:"IPv4_address_literal",symbols:["Snum","IPv4_address_literal$macrocall$1"]},{name:"IPv6_address_literal$subexpression$1",symbols:[/[iI]/,/[pP]/,/[vV]/,{literal:"6"},{literal:":"}],postprocess:function(i){return i.join("")}},{name:"IPv6_address_literal",symbols:["IPv6_address_literal$subexpression$1","IPv6_addr"]},{name:"General_address_literal$ebnf$1",symbols:["dcontent"]},{name:"General_address_literal$ebnf$1",symbols:["General_address_literal$ebnf$1","dcontent"],postprocess:i=>i[0].concat([i[1]])},{name:"General_address_literal",symbols:["Standardized_tag",{literal:":"},"General_address_literal$ebnf$1"]},{name:"Standardized_tag",symbols:["Ldh_str"]},{name:"dcontent",symbols:[/[\x21-\x5a\x5e-\x7e]/],postprocess:e},{name:"Snum",symbols:["DIGIT"]},{name:"Snum$subexpression$1",symbols:[/[1-9]/,"DIGIT"]},{name:"Snum",symbols:["Snum$subexpression$1"]},{name:"Snum$subexpression$2",symbols:[{literal:"1"},"DIGIT","DIGIT"]},{name:"Snum",symbols:["Snum$subexpression$2"]},{name:"Snum$subexpression$3",symbols:[{literal:"2"},/[0-4]/,"DIGIT"]},{name:"Snum",symbols:["Snum$subexpression$3"]},{name:"Snum$subexpression$4",symbols:[{literal:"2"},{literal:"5"},/[0-5]/]},{name:"Snum",symbols:["Snum$subexpression$4"]},{name:"IPv6_addr",symbols:["IPv6_full"]},{name:"IPv6_addr",symbols:["IPv6_comp"]},{name:"IPv6_addr",symbols:["IPv6v4_full"]},{name:"IPv6_addr",symbols:["IPv6v4_comp"]},{name:"IPv6_hex",symbols:["HEXDIG"]},{name:"IPv6_hex$subexpression$1",symbols:["HEXDIG","HEXDIG"]},{name:"IPv6_hex",symbols:["IPv6_hex$subexpression$1"]},{name:"IPv6_hex$subexpression$2",symbols:["HEXDIG","HEXDIG","HEXDIG"]},{name:"IPv6_hex",symbols:["IPv6_hex$subexpression$2"]},{name:"IPv6_hex$subexpression$3",symbols:["HEXDIG","HEXDIG","HEXDIG","HEXDIG"]},{name:"IPv6_hex",symbols:["IPv6_hex$subexpression$3"]},{name:"IPv6_full$macrocall$2",symbols:[{literal:":"},"IPv6_hex"]},{name:"IPv6_full$macrocall$1",symbols:["IPv6_full$macrocall$2","IPv6_full$macrocall$2","IPv6_full$macrocall$2","IPv6_full$macrocall$2","IPv6_full$macrocall$2","IPv6_full$macrocall$2","IPv6_full$macrocall$2"]},{name:"IPv6_full",symbols:["IPv6_hex","IPv6_full$macrocall$1"]},{name:"IPv6_comp$ebnf$1$subexpression$1$macrocall$2",symbols:[{literal:":"},"IPv6_hex"]},{name:"IPv6_comp$ebnf$1$subexpression$1$macrocall$1",symbols:["IPv6_comp$ebnf$1$subexpression$1$macrocall$2","IPv6_comp$ebnf$1$subexpression$1$macrocall$2","IPv6_comp$ebnf$1$subexpression$1$macrocall$2","IPv6_comp$ebnf$1$subexpression$1$macrocall$2","IPv6_comp$ebnf$1$subexpression$1$macrocall$2"]},{name:"IPv6_comp$ebnf$1$subexpression$1",symbols:["IPv6_hex","IPv6_comp$ebnf$1$subexpression$1$macrocall$1"]},{name:"IPv6_comp$ebnf$1",symbols:["IPv6_comp$ebnf$1$subexpression$1"],postprocess:e},{name:"IPv6_comp$ebnf$1",symbols:[],postprocess:()=>null},{name:"IPv6_comp$string$1",symbols:[{literal:":"},{literal:":"}],postprocess:i=>i.join("")},{name:"IPv6_comp$ebnf$2$subexpression$1$macrocall$2",symbols:[{literal:":"},"IPv6_hex"]},{name:"IPv6_comp$ebnf$2$subexpression$1$macrocall$1",symbols:["IPv6_comp$ebnf$2$subexpression$1$macrocall$2","IPv6_comp$ebnf$2$subexpression$1$macrocall$2","IPv6_comp$ebnf$2$subexpression$1$macrocall$2","IPv6_comp$ebnf$2$subexpression$1$macrocall$2","IPv6_comp$ebnf$2$subexpression$1$macrocall$2"]},{name:"IPv6_comp$ebnf$2$subexpression$1",symbols:["IPv6_hex","IPv6_comp$ebnf$2$subexpression$1$macrocall$1"]},{name:"IPv6_comp$ebnf$2",symbols:["IPv6_comp$ebnf$2$subexpression$1"],postprocess:e},{name:"IPv6_comp$ebnf$2",symbols:[],postprocess:()=>null},{name:"IPv6_comp",symbols:["IPv6_comp$ebnf$1","IPv6_comp$string$1","IPv6_comp$ebnf$2"]},{name:"IPv6v4_full$macrocall$2",symbols:[{literal:":"},"IPv6_hex"]},{name:"IPv6v4_full$macrocall$1",symbols:["IPv6v4_full$macrocall$2","IPv6v4_full$macrocall$2","IPv6v4_full$macrocall$2","IPv6v4_full$macrocall$2","IPv6v4_full$macrocall$2"]},{name:"IPv6v4_full",symbols:["IPv6_hex","IPv6v4_full$macrocall$1",{literal:":"},"IPv4_address_literal"]},{name:"IPv6v4_comp$ebnf$1$subexpression$1$macrocall$2",symbols:[{literal:":"},"IPv6_hex"]},{name:"IPv6v4_comp$ebnf$1$subexpression$1$macrocall$1",symbols:["IPv6v4_comp$ebnf$1$subexpression$1$macrocall$2","IPv6v4_comp$ebnf$1$subexpression$1$macrocall$2","IPv6v4_comp$ebnf$1$subexpression$1$macrocall$2"]},{name:"IPv6v4_comp$ebnf$1$subexpression$1",symbols:["IPv6_hex","IPv6v4_comp$ebnf$1$subexpression$1$macrocall$1"]},{name:"IPv6v4_comp$ebnf$1",symbols:["IPv6v4_comp$ebnf$1$subexpression$1"],postprocess:e},{name:"IPv6v4_comp$ebnf$1",symbols:[],postprocess:()=>null},{name:"IPv6v4_comp$string$1",symbols:[{literal:":"},{literal:":"}],postprocess:i=>i.join("")},{name:"IPv6v4_comp$ebnf$2$subexpression$1$macrocall$2",symbols:[{literal:":"},"IPv6_hex"]},{name:"IPv6v4_comp$ebnf$2$subexpression$1$macrocall$1",symbols:["IPv6v4_comp$ebnf$2$subexpression$1$macrocall$2","IPv6v4_comp$ebnf$2$subexpression$1$macrocall$2","IPv6v4_comp$ebnf$2$subexpression$1$macrocall$2"]},{name:"IPv6v4_comp$ebnf$2$subexpression$1",symbols:["IPv6_hex","IPv6v4_comp$ebnf$2$subexpression$1$macrocall$1",{literal:":"}]},{name:"IPv6v4_comp$ebnf$2",symbols:["IPv6v4_comp$ebnf$2$subexpression$1"],postprocess:e},{name:"IPv6v4_comp$ebnf$2",symbols:[],postprocess:()=>null},{name:"IPv6v4_comp",symbols:["IPv6v4_comp$ebnf$1","IPv6v4_comp$string$1","IPv6v4_comp$ebnf$2","IPv4_address_literal"]},{name:"DIGIT",symbols:[/[0-9]/],postprocess:e},{name:"ALPHA_DIGIT_U",symbols:[/[0-9A-Za-z\u0080-\uFFFF]/],postprocess:e},{name:"ALPHA_DIGIT",symbols:[/[0-9A-Za-z]/],postprocess:e},{name:"ALPHA_DIG_DASH",symbols:[/[-0-9A-Za-z]/],postprocess:e},{name:"ALPHA_DIG_DASH_U",symbols:[/[-0-9A-Za-z\u0080-\uFFFF]/],postprocess:e},{name:"HEXDIG",symbols:[/[0-9A-Fa-f]/],postprocess:e},{name:"DQUOTE",symbols:[{literal:'"'}],postprocess:e}],ParserStart:"Reverse_path"};return fE.default=r,fE}var YH;function q9e(){if(YH)return tc;YH=1;var e=tc&&tc.__importDefault||function(s){return s&&s.__esModule?s:{default:s}};Object.defineProperty(tc,"__esModule",{value:!0}),tc.canonicalize=tc.canonicalize_quoted_string=tc.normalize=tc.normalize_dot_string=tc.parse=void 0;const t=Q9e(),n=e(z9e());n.default.ParserStart="Mailbox";const r=t.Grammar.fromCompiled(n.default);function i(s){const c=new t.Parser(r);if(c.feed(s),c.results.length!==1)throw new Error("address parsing failed: ambiguous grammar");return c.results[0]}tc.parse=i;function a(s){return(function(){const h=s.indexOf("+");return h===-1?s:s.substr(0,h)})().replace(/\./g,"").toLowerCase()}tc.normalize_dot_string=a;function u(s){var c,d;const h=i(s),m=(c=h.domainPart.AddressLiteral)!==null&&c!==void 0?c:h.domainPart.DomainName.toLowerCase();return`${(d=h.localPart.QuotedString)!==null&&d!==void 0?d:a(h.localPart.DotString)}@${m}`}tc.normalize=u;function l(s){return`"${s.substr(1).substr(0,s.length-2).replace(/(?:\\(.))/g,"$1").replace(/(?:(["\\]))/g,"\\$1")}"`}tc.canonicalize_quoted_string=l;function o(s){var c;const d=i(s),h=(c=d.domainPart.AddressLiteral)!==null&&c!==void 0?c:d.domainPart.DomainName.toLowerCase();return`${d.localPart.QuotedString?l(d.localPart.QuotedString):d.localPart.DotString}@${h}`}return tc.canonicalize=o,tc}var V9e=q9e();const U9e=new RegExp("^([0-9]+)-(0[1-9]|1[012])-(0[1-9]|[12][0-9]|3[01])[Tt]([01][0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60)(\\.[0-9]+)?(([Zz])|([\\+|\\-]([01][0-9]|2[0-3]):[0-5][0-9]))$"),j9e=/^(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)$/,Z9e=/^((([0-9a-f]{1,4}:){7}([0-9a-f]{1,4}|:))|(([0-9a-f]{1,4}:){6}(:[0-9a-f]{1,4}|((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9a-f]{1,4}:){5}(((:[0-9a-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9a-f]{1,4}:){4}(((:[0-9a-f]{1,4}){1,3})|((:[0-9a-f]{1,4})?:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9a-f]{1,4}:){3}(((:[0-9a-f]{1,4}){1,4})|((:[0-9a-f]{1,4}){0,2}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9a-f]{1,4}:){2}(((:[0-9a-f]{1,4}){1,5})|((:[0-9a-f]{1,4}){0,3}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9a-f]{1,4}:){1}(((:[0-9a-f]{1,4}){1,6})|((:[0-9a-f]{1,4}){0,4}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(:(((:[0-9a-f]{1,4}){1,7})|((:[0-9a-f]{1,4}){0,5}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))$/i,H9e=/^(?=.{1,255}$)[0-9A-Za-z](?:(?:[0-9A-Za-z]|-){0,61}[0-9A-Za-z])?(?:\.[0-9A-Za-z](?:(?:[0-9A-Za-z]|-){0,61}[0-9A-Za-z])?)*\.?$/,X9e=/^(\d\d\d\d)-(\d\d)-(\d\d)$/,Y9e=/^(?:[0-2]\d:[0-5]\d:[0-5]\d|23:59:60)(?:\.\d+)?(?:z|[+-]\d\d(?::?\d\d)?)?$/i,G9e=[0,31,28,31,30,31,30,31,31,30,31,30,31],K9e=/^(?:\/(?:[^~/]|~0|~1)*)*$/,W9e=/^(?:0|[1-9][0-9]*)(?:#|(?:\/(?:[^~/]|~0|~1)*)*)$/,J9e=/^(?:[a-z][a-z0-9+\-.]*:)?(?:\/?\/(?:(?:[a-z0-9\-._~!$&'()*+,;=:]|%[0-9a-f]{2})*@)?(?:\[(?:(?:(?:(?:[0-9a-f]{1,4}:){6}|::(?:[0-9a-f]{1,4}:){5}|(?:[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){4}|(?:(?:[0-9a-f]{1,4}:){0,1}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){3}|(?:(?:[0-9a-f]{1,4}:){0,2}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){2}|(?:(?:[0-9a-f]{1,4}:){0,3}[0-9a-f]{1,4})?::[0-9a-f]{1,4}:|(?:(?:[0-9a-f]{1,4}:){0,4}[0-9a-f]{1,4})?::)(?:[0-9a-f]{1,4}:[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?))|(?:(?:[0-9a-f]{1,4}:){0,5}[0-9a-f]{1,4})?::[0-9a-f]{1,4}|(?:(?:[0-9a-f]{1,4}:){0,6}[0-9a-f]{1,4})?::)|[Vv][0-9a-f]+\.[a-z0-9\-._~!$&'()*+,;=:]+)\]|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)|(?:[a-z0-9\-._~!$&'"()*+,;=]|%[0-9a-f]{2})*)(?::\d*)?(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*|\/(?:(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*)?|(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*)?(?:\?(?:[a-z0-9\-._~!$&'"()*+,;=:@/?]|%[0-9a-f]{2})*)?(?:#(?:[a-z0-9\-._~!$&'"()*+,;=:@/?]|%[0-9a-f]{2})*)?$/i,eMe=/^(?:(?:[^\x00-\x20"'<>%\\^`{|}]|%[0-9a-f]{2})|\{[+#./;?&=,!@|]?(?:[a-z0-9_]|%[0-9a-f]{2})+(?::[1-9][0-9]{0,3}|\*)?(?:,(?:[a-z0-9_]|%[0-9a-f]{2})+(?::[1-9][0-9]{0,3}|\*)?)*\})*$/i,k0e={date:(e,t,n,r)=>{if(typeof n!="string"||n==="")return;const i=n.match(X9e);if(!i)return e.errors.formatDateTimeError({value:n,pointer:r,schema:t});const a=+i[1],u=+i[2],l=+i[3],o=a%4===0&&(a%100!==0||a%400===0);if(!(u>=1&&u<=12&&l>=1&&l<=(u==2&&o?29:G9e[u])))return e.errors.formatDateError({value:n,pointer:r,schema:t})},"date-time":(e,t,n,r)=>{if(!(typeof n!="string"||n===""))return n===""||U9e.test(n)?new Date(n).toString()==="Invalid Date"?e.errors.formatDateTimeError({value:n,pointer:r,schema:t}):void 0:e.errors.formatDateTimeError({value:n,pointer:r,schema:t})},email:(e,t,n,r)=>{if(typeof n!="string"||n==="")return;if(n[0]==='"')return e.errors.formatEmailError({value:n,pointer:r,schema:t});const[i,a,...u]=n.split("@");if(!i||!a||u.length!==0||i.length>64||a.length>253)return e.errors.formatEmailError({value:n,pointer:r,schema:t});if(i[0]==="."||i.endsWith(".")||i.includes(".."))return e.errors.formatEmailError({value:n,pointer:r,schema:t});if(!/^[a-z0-9.-]+$/i.test(a)||!/^[a-z0-9.!#$%&'*+/=?^_`{|}~-]+$/i.test(i))return e.errors.formatEmailError({value:n,pointer:r,schema:t});if(!a.split(".").every(l=>/^[a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?$/i.test(l)))return e.errors.formatEmailError({value:n,pointer:r,schema:t})},"idn-email":(e,t,n,r)=>{if(!(typeof n!="string"||n===""))try{V9e.parse(n);return}catch{return e.errors.formatEmailError({value:n,pointer:r,schema:t})}},hostname:(e,t,n,r)=>{if(typeof n=="string"&&!(n===""||H9e.test(n)))return e.errors.formatHostnameError({value:n,pointer:r,schema:t})},ipv4:(e,t,n,r)=>{if(!(typeof n!="string"||n==="")){if(n&&n[0]==="0")return e.errors.formatIPV4LeadingZeroError({value:n,pointer:r,schema:t});if(!(n.length<=15&&j9e.test(n)))return e.errors.formatIPV4Error({value:n,pointer:r,schema:t})}},ipv6:(e,t,n,r)=>{if(!(typeof n!="string"||n==="")){if(n&&n[0]==="0")return e.errors.formatIPV6LeadingZeroError({value:n,pointer:r,schema:t});if(!(n.length<=45&&Z9e.test(n)))return e.errors.formatIPV6Error({value:n,pointer:r,schema:t})}},"json-pointer":(e,t,n,r)=>{if(!(typeof n!="string"||n==="")&&!K9e.test(n))return e.errors.formatJsonPointerError({value:n,pointer:r,schema:t})},"relative-json-pointer":(e,t,n,r)=>{if(!(typeof n!="string"||n==="")&&!W9e.test(n))return e.errors.formatJsonPointerError({value:n,pointer:r,schema:t})},regex:(e,t,n,r)=>{if(typeof n=="string"&&/\\Z$/.test(n)===!1){try{new RegExp(n);return}catch{}return e.errors.formatRegExError({value:n,pointer:r,schema:t})}if(!(typeof n=="object"||typeof n=="number"||Array.isArray(n)))return e.errors.formatRegExError({value:n,pointer:r,schema:t})},time:(e,t,n,r)=>typeof n!="string"||n===""||n.match(Y9e)?void 0:e.errors.formatDateTimeError({value:n,pointer:r,schema:t}),uri:(e,t,n,r)=>{if(!(typeof n!="string"||n==="")&&!ZH.isUri(n))return e.errors.formatURIError({value:n,pointer:r,schema:t})},"uri-reference":(e,t,n,r)=>{if(!(typeof n!="string"||n==="")&&!J9e.test(n))return e.errors.formatURIReferenceError({value:n,pointer:r,schema:t})},"uri-template":(e,t,n,r)=>{if(!(typeof n!="string"||n==="")&&!eMe.test(n))return e.errors.formatURITemplateError({value:n,pointer:r,schema:t})},url:(e,t,n,r)=>{if(!(n===""||ZH.isWebUri(n)))return e.errors.formatURLError({value:n,pointer:r,schema:t})}},P0e={};function M0e(e,t=P0e){const{pointer:n="#",data:r,schema:i=e.rootSchema,withSchemaWarning:a=!1}=t,u=Mx.split(n),l=F0e(e,e.resolveRef(i),u,"#",r);if(!(!a&&(l==null?void 0:l.code)==="schema-warning"))return l}function F0e(e,t,n,r,i=P0e){if(n.length===0)return e.resolveRef(t);const a=n.shift();return t=e.step(a,t,i,r),Yf(t)?t:(i=i[a],F0e(e,t,n,`${r}/${a}`,i))}function tMe(e){switch(hi(e)){case"string":case"array":return(e==null?void 0:e.length)===0;case"null":case"undefined":return!0;case"object":return Object.keys(e).length===0;default:return!1}}const GH=r4.templateDefaultOptions;let Hm;function oP(e,t){const{$ref:n}=e;return n==null?!0:(Hm[t]==null||Hm[t][n]==null?0:Hm[t][n])<r4.GET_TEMPLATE_RECURSION_LIMIT}function KH(e,t,n){const{$ref:r}=t;return r==null?t:(Hm[n]=Hm[n]||{},Hm[n][r]=Hm[n][r]||0,Hm[n][r]+=1,e.resolveRef(t))}function nMe(e,t){if(e==="string")return JSON.stringify(t);if(typeof t!="string")return null;try{if(t=JSON.parse(t),typeof t===e)return t}catch{}return null}function N0e(e,t,n,r,i){if(hi(t)!=="object")return Object.assign({pointer:r},t);if(oP(t,r)===!1&&n==null)return!1;let a=x$(KH(e,t,r));if(Array.isArray(t.anyOf)&&t.anyOf.length>0){if(oP(t.anyOf[0],`${r}/anyOf/0`)){const u=KH(e,t.anyOf[0],`${r}/anyOf/0`);a=zI(a,u),a.pointer=t.anyOf[0].$ref||a.pointer}delete a.anyOf}if(Array.isArray(t.allOf)&&t.allOf.map((l,o)=>oP(l,`${r}/allOf/${o}`)).reduceRight((l,o)=>l&&o,!0)){const l=[];let o=x$(n);for(let c=0;c<t.allOf.length;c+=1)l.push(b0e(e,t.allOf[c],o)),o=Xh(e,o,{type:t.type,...l[c]},`${r}/allOf/${c}`,i);const s=x0e(e,{allOf:l});s&&(a=uc(a,s))}return a.pointer=a.pointer||t.$ref||r,a}const WH=e=>e&&typeof e=="object";function Xh(e,t,n,r,i){var a;if(n==null)throw new Error(`getTemplate: missing schema for data: ${JSON.stringify(t)}`);if(r==null)throw new Error("Missing pointer");let u=N0e(e,n,t,r,i);if(!WH(u))return;if(r=u.pointer,u!=null&&u.const)return u.const;if(Array.isArray(u.oneOf))if(tMe(t)){const c=u.oneOf[0].type||u.type||u.const&&typeof u.const||hi(t);u={...u.oneOf[0],type:c}}else{const c=QI(e,t,u);if(Yf(c)){if(t!=null&&i.removeInvalidData!==!0)return t;u=u.oneOf[0],t=void 0}else c.type=(a=c.type)!==null&&a!==void 0?a:u.type,u=c}if(!WH(u)||u.type==null)return;if(t instanceof File)return t;const l=Array.isArray(u.type)?rMe(u.type,t,u.default):u.type,o=hi(t);return t!=null&&o!==l&&!(o==="number"&&l==="integer")&&(t=nMe(l,t)),JH[l]==null?i.removeInvalidData?void 0:t:JH[l](e,u,t,r,i)}function rMe(e,t,n){if(t==null){if(n!=null){const i=hi(n);if(e.includes(i))return i}return e[0]}const r=hi(t);return e.includes(r)?r:e[0]}const JH={null:(e,t,n)=>s2(t,n,null),string:(e,t,n)=>s2(t,n,""),number:(e,t,n)=>s2(t,n,0),integer:(e,t,n)=>s2(t,n,0),boolean:(e,t,n)=>s2(t,n,!1),object:(e,t,n,r,i)=>{var a;const u=t.default===void 0?{}:t.default,l={},o=i.extendDefaults===!1&&t.default!==void 0?[]:(a=t.required)!==null&&a!==void 0?a:[];t.properties&&Object.keys(t.properties).forEach(d=>{const h=n==null||n[d]==null?u[d]:n[d],m=o.includes(d);(h!=null||m||i.addOptionalProps)&&(l[d]=Xh(e,h,t.properties[d],`${r}/properties/${d}`,i))});let s=_0e(e,t,l);if(s){s=uc(t,s),delete s.dependencies;const d=Xh(e,n,s,`${r}/dependencies`,i);Object.assign(l,d)}n&&(i.removeInvalidData===!0&&(t.additionalProperties===!1||hi(t.additionalProperties)==="object")?hi(t.additionalProperties)==="object"&&Object.keys(n).forEach(d=>{l[d]==null&&e.isValid(n[d],t.additionalProperties)&&(l[d]=n[d])}):Object.keys(n).forEach(d=>l[d]==null&&(l[d]=n[d])));const c=yw(e,t,l);if(c){const d=Xh(e,l,{type:"object",...c},r,i);Object.assign(l,d)}return l},array:(e,t,n,r,i)=>{var a,u;if(t.items==null)return n||[];const l=t.default===void 0?[]:t.default,o=n||l,s=i.extendDefaults===!1&&t.default!==void 0?0:t.minItems||0;if(Array.isArray(t.items)){for(let d=0,h=Math.max(s??0,(u=(a=t.items)===null||a===void 0?void 0:a.length)!==null&&u!==void 0?u:0);d<h;d+=1)o[d]=Xh(e,o[d]==null?l[d]:o[d],t.items[d],`${r}/items/${d}`,i);return o}if(hi(t.items)!=="object")return o;const c=N0e(e,t.items,n,r,i);if(c===!1)return o;if(r=c.pointer||r,c.oneOf&&o.length===0){const d=c.oneOf[0];for(let h=0;h<s;h+=1)o[h]=Xh(e,o[h]==null?l[h]:o[h],d,`${r}/oneOf/0`,i);return o}if(c.oneOf&&o.length>0){const d=Math.max(s,o.length);for(let h=0;h<d;h+=1){let m=o[h]==null?l[h]:o[h],y=QI(e,m,c);y==null||Yf(y)?m!=null&&i.removeInvalidData!==!0?o[h]=m:(m=void 0,y=c.oneOf[0],o[h]=Xh(e,m,y,`${r}/oneOf/${h}`,i)):o[h]=Xh(e,m,y,`${r}/oneOf/${h}`,i)}return o}if(c.type){for(let d=0,h=Math.max(s,o.length);d<h;d+=1)o[d]=Xh(e,o[d]==null?l[d]:o[d],c,`${r}/items`,i);return o}return o}};function s2(e,t,n){return t??(e.const?e.const:e.default===void 0&&Array.isArray(e.enum)?e.enum[0]:e.default===void 0?n:e.default)}const I0e=(e,t,n=e.rootSchema,r)=>(Hm={},r?Xh(e,t,n,"#",{...GH,...r}):Xh(e,t,n,"#",GH));function L0e(e,t,n=e.rootSchema,r="#"){return e.validate(t,n,r).length===0}function eX(e){const t=[];let n=0;const r=e.length;for(;n<r;){const i=e.charCodeAt(n++);if(i>=55296&&i<=56319&&n<r){const a=e.charCodeAt(n++);(a&64512)==56320?t.push(((i&1023)<<10)+(a&1023)+65536):(t.push(i),n--)}else t.push(i)}return t}function tX(e){const t=`${e}`,n=t.indexOf(".");return n===-1?0:t.length-(n+1)}var sP,nX;function iMe(){return nX||(nX=1,sP=function e(t,n){if(t===n)return!0;if(t&&n&&typeof t=="object"&&typeof n=="object"){if(t.constructor!==n.constructor)return!1;var r,i,a;if(Array.isArray(t)){if(r=t.length,r!=n.length)return!1;for(i=r;i--!==0;)if(!e(t[i],n[i]))return!1;return!0}if(t.constructor===RegExp)return t.source===n.source&&t.flags===n.flags;if(t.valueOf!==Object.prototype.valueOf)return t.valueOf()===n.valueOf();if(t.toString!==Object.prototype.toString)return t.toString()===n.toString();if(a=Object.keys(t),r=a.length,r!==Object.keys(n).length)return!1;for(i=r;i--!==0;)if(!Object.prototype.hasOwnProperty.call(n,a[i]))return!1;for(i=r;i--!==0;){var u=a[i];if(!e(t[u],n[u]))return!1}return!0}return t!==t&&n!==n}),sP}var aMe=iMe();const B0e=sa(aMe),uMe=Object.prototype.hasOwnProperty,rX=(e,t)=>!(e[t]===void 0||!uMe.call(e,t)),Q0e={additionalProperties:(e,t,n,r)=>{if(t.additionalProperties===!0||t.additionalProperties==null||hi(t.patternProperties)==="object"&&t.additionalProperties===!1)return;const i=[];let a=Object.keys(n).filter(l=>r4.propertyBlacklist.includes(l)===!1);const u=Object.keys(t.properties||{});if(hi(t.patternProperties)==="object"){const l=Object.keys(t.patternProperties).map(o=>new RegExp(o));a=a.filter(o=>{for(let s=0;s<l.length;s+=1)if(l[s].test(o))return!1;return!0})}for(let l=0,o=a.length;l<o;l+=1){const s=a[l];if(u.indexOf(s)===-1){const c=Uv(t.additionalProperties);if(c&&Array.isArray(t.additionalProperties.oneOf)){const d=e.resolveOneOf(n[s],t.additionalProperties,`${r}/${s}`);Yf(d)?i.push(e.errors.additionalPropertiesError({pointer:r,schema:t.additionalProperties,value:n,property:a[l],properties:u,errors:d.data.errors})):i.push(...e.validate(n[s],d,r))}else c?i.push(...e.validate(n[s],t.additionalProperties,`${r}/${s}`)):i.push(e.errors.noAdditionalPropertiesError({pointer:r,schema:t,value:n,property:a[l],properties:u}))}}return i},allOf:Z7e,anyOf:Y7e,dependencies:X7e,enum:(e,t,n,r)=>{const i=hi(n);if(i==="object"||i==="array"){const a=JSON.stringify(n);for(let u=0;u<t.enum.length;u+=1)if(JSON.stringify(t.enum[u])===a)return}else if(t.enum.includes(n))return;return e.errors.enumError({pointer:r,schema:t,value:n,values:t.enum})},format:(e,t,n,r)=>{if(e.validateFormat[t.format])return e.validateFormat[t.format](e,t,n,r)},items:(e,t,n,r)=>{if(t.items===!1)return Array.isArray(n)&&n.length===0?void 0:e.errors.invalidDataError({pointer:r,value:n,schema:t});const i=[];for(let a=0;a<n.length;a+=1){const u=n[a],l=e.step(a,t,n,r);if(Yf(l))return[l];const o=e.validate(u,l,`${r}/${a}`);i.push(...o)}return i},maximum:(e,t,n,r)=>{if(!isNaN(t.maximum)){if(t.maximum&&t.maximum<n)return e.errors.maximumError({maximum:t.maximum,length:n,value:n,pointer:r,schema:t});if(t.maximum&&t.exclusiveMaximum===!0&&t.maximum===n)return e.errors.maximumError({maximum:t.maximum,length:n,pointer:r,schema:t,value:n})}},maxItems:(e,t,n,r)=>{if(!isNaN(t.maxItems)&&t.maxItems<n.length)return e.errors.maxItemsError({maximum:t.maxItems,length:n.length,schema:t,value:n,pointer:r})},maxLength:(e,t,n,r)=>{if(isNaN(t.maxLength))return;const i=eX(n).length;if(t.maxLength<i)return e.errors.maxLengthError({maxLength:t.maxLength,length:i,pointer:r,schema:t,value:n})},maxProperties:(e,t,n,r)=>{const i=Object.keys(n).length;if(isNaN(t.maxProperties)===!1&&t.maxProperties<i)return e.errors.maxPropertiesError({maxProperties:t.maxProperties,length:i,pointer:r,schema:t,value:n})},minLength:(e,t,n,r)=>{if(isNaN(t.minLength))return;const i=eX(n).length;if(t.minLength>i)return t.minLength===1?e.errors.minLengthOneError({minLength:t.minLength,length:i,pointer:r,schema:t,value:n}):e.errors.minLengthError({minLength:t.minLength,length:i,pointer:r,schema:t,value:n})},minimum:(e,t,n,r)=>{if(!isNaN(t.minimum)){if(t.minimum>n)return e.errors.minimumError({minimum:t.minimum,length:n,pointer:r,schema:t,value:n});if(t.exclusiveMinimum===!0&&t.minimum===n)return e.errors.minimumError({minimum:t.minimum,length:n,pointer:r,schema:t,value:n})}},minItems:(e,t,n,r)=>{if(!isNaN(t.minItems)&&t.minItems>n.length)return t.minItems===1?e.errors.minItemsOneError({minItems:t.minItems,length:n.length,pointer:r,schema:t,value:n}):e.errors.minItemsError({minItems:t.minItems,length:n.length,pointer:r,schema:t,value:n})},minProperties:(e,t,n,r)=>{if(isNaN(t.minProperties))return;const i=Object.keys(n).length;if(t.minProperties>i)return e.errors.minPropertiesError({minProperties:t.minProperties,length:i,pointer:r,schema:t,value:n})},multipleOf:(e,t,n,r)=>{if(isNaN(t.multipleOf)||typeof n!="number")return;const i=tX(n),a=tX(t.multipleOf);if(i>a)return e.errors.multipleOfError({multipleOf:t.multipleOf,value:n,pointer:r,schema:t});const u=Math.pow(10,a),l=Math.round(n*u),o=Math.round(t.multipleOf*u);if(l%o/u!==0)return e.errors.multipleOfError({multipleOf:t.multipleOf,value:n,pointer:r,schema:t})},not:(e,t,n,r)=>{const i=[];return e.validate(n,t.not,r).length===0&&i.push(e.errors.notError({value:n,not:t.not,pointer:r,schema:t})),i},oneOf:u7e,pattern:(e,t,n,r)=>{if(new RegExp(t.pattern,"u").test(n)===!1)return e.errors.patternError({pattern:t.pattern,description:t.patternExample||t.pattern,received:n,schema:t,value:n,pointer:r})},patternProperties:(e,t,n,r)=>{const i=t.properties||{},a=t.patternProperties;if(hi(a)!=="object")return;const u=[],l=Object.keys(n),o=Object.keys(a).map(s=>({regex:new RegExp(s),patternSchema:a[s]}));return l.forEach(s=>{let c=!1;for(let d=0,h=o.length;d<h;d+=1)if(o[d].regex.test(s)){c=!0;const m=e.validate(n[s],o[d].patternSchema,`${r}/${s}`);m&&m.length>0&&u.push(...m)}i[s]||c===!1&&t.additionalProperties===!1&&u.push(e.errors.patternPropertiesError({key:s,pointer:r,schema:t,value:n,patterns:Object.keys(a).join(",")}))}),u},properties:(e,t,n,r)=>{const i=[],a=Object.keys(t.properties||{});for(let u=0;u<a.length;u+=1){const l=a[u];if(rX(n,l)){const o=e.step(l,t,n,r),s=e.validate(n[l],o,`${r}/${l}`);i.push(...s)}}return i},propertiesRequired:(e,t,n,r)=>{const i=[],a=Object.keys(t.properties||{});for(let u=0;u<a.length;u+=1){const l=a[u];if(n[l]===void 0)i.push(e.errors.requiredPropertyError({key:l,pointer:r,schema:t,value:n}));else{const o=e.step(l,t,n,r),s=e.validate(n[l],o,`${r}/${l}`);i.push(...s)}}return i},required:(e,t,n,r)=>{if(Array.isArray(t.required)!==!1)return t.required.map(i=>{if(!rX(n,i))return e.errors.requiredPropertyError({key:i,pointer:r,schema:t,value:n})})},requiredNotEmpty:(e,t,n,r)=>{if(Array.isArray(t.required)!==!1)return t.required.map(i=>{if(n[i]==null||n[i]==="")return e.errors.valueNotEmptyError({property:i,pointer:`${r}/${i}`,schema:t,value:n})})},uniqueItems:(e,t,n,r)=>{if((Array.isArray(n)&&t.uniqueItems)===!1)return;const i=[],a=[];return n.forEach((u,l)=>{for(let o=l+1;o<n.length;o+=1)B0e(u,n[o])&&!i.includes(o)&&(a.push(e.errors.uniqueItemsError({pointer:`${r}/${o}`,duplicatePointer:`${r}/${l}`,arrayPointer:r,value:JSON.stringify(u),schema:t})),i.push(o))}),a}};function v0(e){if(e===void 0)return;const t={type:hi(e)};return t.type==="object"&&Uv(e)&&(t.properties={},Object.keys(e).forEach(n=>t.properties[n]=v0(e[n]))),t.type==="array"&&Array.isArray(e)&&(e.length===1?t.items=v0(e[0]):t.items=e.map(v0)),t}const lMe={array:(e,t,n,r,i)=>{const a=r==null?void 0:r[t],u=hi(n.items);if(u==="object")return MH(e,n.items,a,`${i}/${t}`)||e.resolveRef(n.items);if(u==="array"){if(n.items[t]===!0)return v0(a);if(n.items[t]===!1)return e.errors.invalidDataError({key:t,value:a,pointer:i,schema:n});if(n.items[t])return e.resolveRef(n.items[t]);if(n.additionalItems===!1)return e.errors.additionalItemsError({key:t,value:a,pointer:i,schema:n});if(n.additionalItems===!0||n.additionalItems===void 0)return v0(a);if(hi(n.additionalItems)==="object")return n.additionalItems;throw new Error(`Invalid schema ${JSON.stringify(n,null,2)} for ${JSON.stringify(r,null,2)}`)}return n.additionalItems!==!1&&a?v0(a):new Error(`Invalid array schema for ${t} at ${i}`)},object:(e,t,n,r,i)=>{var a;n=MH(e,n,r,i);const u=(a=n==null?void 0:n.properties)===null||a===void 0?void 0:a[t];if(u!==void 0){if(u===!1)return e.errors.forbiddenPropertyError({property:t,value:r,pointer:i,schema:n});if(u===!0)return v0(r==null?void 0:r[t]);const s=e.resolveRef(u);if(Yf(s))return s;if(s&&Array.isArray(s.oneOf)){const c=e.resolveOneOf(r[t],s,`${i}/${t}`);for(const d in s)d!=="oneOf"&&c[d]===void 0&&(c[d]=s[d]);return c}if(s)return s}const{patternProperties:l}=n;if(hi(l)==="object"){let s;const c=Object.keys(l);for(let d=0,h=c.length;d<h;d+=1)if(s=new RegExp(c[d]),s.test(t))return l[c[d]]}const{additionalProperties:o}=n;return hi(o)==="object"?n.additionalProperties:r&&(o===void 0||o===!0)?v0(r[t]):e.errors.unknownPropertyError({property:t,value:r,pointer:`${i}`,schema:n})}};function z0e(e,t,n,r,i="#"){var a;const u=hi(r);let l=(a=n.type)!==null&&a!==void 0?a:u;if(Array.isArray(l)){if(!l.includes(u))return e.errors.typeError({value:r,pointer:i,expected:n.type,received:u,schema:n});l=u}const o=lMe[l];if(o){const s=o(e,`${t}`,n,r,i);return s===void 0?e.errors.schemaWarning({pointer:i,value:r,schema:n,key:t}):s}return new Error(`Unsupported schema type ${n.type} for key ${t}`)}function q0e(e,t,n=e.rootSchema){var r;if(n.oneOf)return n.oneOf.map(a=>e.resolveRef(a));if(!((r=n.items)===null||r===void 0)&&r.oneOf)return n.items.oneOf.map(a=>e.resolveRef(a));const i=e.step(t,n,{},"#");return Yf(i)?i:[i]}const oMe={array:(e,t,n,r)=>e.typeKeywords.array.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),object:(e,t,n,r)=>e.typeKeywords.object.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),string:(e,t,n,r)=>e.typeKeywords.string.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),integer:(e,t,n,r)=>e.typeKeywords.number.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),number:(e,t,n,r)=>e.typeKeywords.number.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),boolean:(e,t,n,r)=>e.typeKeywords.boolean.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),null:(e,t,n,r)=>e.typeKeywords.null.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r))};function sMe(e,t){const n=hi(e);return n==="number"&&(t==="integer"||Array.isArray(t)&&t.includes("integer"))?Number.isInteger(e)||isNaN(e)?"integer":"number":n}function V0e(e,t,n=e.rootSchema,r="#"){if(n=e.resolveRef(n),hi(n)==="boolean")return n?[]:[e.errors.invalidDataError({pointer:r,schema:n,value:t})];if(Yf(n))return[n];if(n.const!==void 0)return B0e(n.const,t)?[]:[e.errors.constError({pointer:r,schema:n,value:t,expected:n.const})];const i=sMe(t,n.type),a=n.type||i;return i!==a&&(!Array.isArray(a)||!a.includes(i))?[e.errors.typeError({pointer:r,schema:n,value:t,received:i,expected:a})]:e.validateType[i]==null?[e.errors.invalidTypeError({pointer:r,schema:n,value:t,receivedType:i})]:kx(e.validateType[i](e,n,t,r)).filter(O$)}const cMe={typeKeywords:{array:["allOf","anyOf","enum","items","maxItems","minItems","not","oneOf","uniqueItems"],boolean:["enum","not","allOf","anyOf","oneOf"],object:["additionalProperties","dependencies","enum","format","minProperties","maxProperties","patternProperties","properties","required","not","oneOf","allOf","anyOf"],string:["allOf","anyOf","enum","format","maxLength","minLength","not","oneOf","pattern"],number:["allOf","anyOf","enum","format","maximum","minimum","multipleOf","not","oneOf"],null:["allOf","anyOf","enum","format","not","oneOf"]},validateKeyword:Q0e,validateType:oMe,validateFormat:k0e,errors:T0e,addRemoteSchema:C0e,compileSchema:N9e,createSchemaOf:v0,each:A0e,eachSchema:bw,getChildSchemaSelection:q0e,getSchema:M0e,getTemplate:I0e,isValid:L0e,resolveAllOf:O0e,resolveAnyOf:D0e,resolveOneOf:l0e,resolveRef:S0e,step:z0e,validate:V0e,templateDefaultOptions:r4.templateDefaultOptions};class Hat extends $0e{constructor(t,n={}){super(zI(cMe,n),t)}}const iX="__compiled",aX="__ref",fMe="getRef",dMe="getRoot",hMe=/(#|\/)+$/g;function pMe(e,t,n=t,r=!1){if(t===!0||t===!1||t===void 0||t[iX]!==void 0)return t;const i={ids:{},remotes:e.remotes},a=JSON.stringify(t),u=JSON.parse(a);if(Object.defineProperty(u,iX,{enumerable:!1,value:!0}),Object.defineProperty(u,fMe,{enumerable:!1,value:Qm.bind(null,i,u)}),r===!1&&a.includes("$ref")===!1)return u;u!==n&&Object.defineProperty(u,"$defs",{enumerable:!0,value:Object.assign({},n.definitions,n.$defs,u.definitions,u.$defs)});const l={},o=()=>u;return bw(u,(s,c)=>{var d;if(s.$id){if(s.$id.startsWith("http")&&/(allOf|anyOf|oneOf)\/\d+$/.test(c)){const _=c.replace(/\/(allOf|anyOf|oneOf)\/\d+$/,""),S=Q1.get(u,_);s.$id=(d=S.$id)!==null&&d!==void 0?d:s.$id}i.ids[s.$id.replace(hMe,"")]=c}c=`#${c}`.replace(/##+/,"#");const h=c.replace(/\/[^/]+$/,""),m=c.replace(/\/[^/]+\/[^/]+$/,""),y=l[h]||l[m],v=D$(y,s.$id);l[c]=v,i.ids[v]==null&&(i.ids[v]=c),s.$ref&&!s[aX]&&(Object.defineProperty(s,aX,{enumerable:!1,value:D$(v,s.$ref)}),Object.defineProperty(s,dMe,{enumerable:!1,value:o}))}),u}const mMe={...Q0e,contains:(e,t,n,r)=>{if(t.contains===!1)return e.errors.containsArrayError({pointer:r,value:n,schema:t});if(t.contains===!0)return Array.isArray(n)&&n.length===0?e.errors.containsAnyError({pointer:r,value:n,schema:t}):void 0;if(hi(t.contains)==="object"){for(let i=0;i<n.length;i+=1)if(e.isValid(n[i],t.contains))return;return e.errors.containsError({pointer:r,schema:t,value:n})}},exclusiveMaximum:(e,t,n,r)=>{if(!isNaN(t.exclusiveMaximum)&&t.exclusiveMaximum<=n)return e.errors.maximumError({maximum:t.exclusiveMaximum,length:n,pointer:r,schema:t,value:n})},exclusiveMinimum:(e,t,n,r)=>{if(!isNaN(t.exclusiveMinimum)&&t.exclusiveMinimum>=n)return e.errors.minimumError({minimum:t.exclusiveMinimum,length:n,pointer:r,schema:t,value:n})},if:j7e,maximum:(e,t,n,r)=>{if(!isNaN(t.maximum)&&t.maximum&&t.maximum<n)return e.errors.maximumError({maximum:t.maximum,length:n,pointer:r,schema:t,value:n})},minimum:(e,t,n,r)=>{if(!isNaN(t.minimum)&&t.minimum>n)return e.errors.minimumError({minimum:t.minimum,length:n,pointer:r,schema:t,value:n})},patternProperties:(e,t,n,r)=>{const i=t.properties||{},a=t.patternProperties;if(hi(a)!=="object")return;const u=[],l=Object.keys(n),o=Object.keys(a).map(s=>({regex:new RegExp(s),patternSchema:a[s]}));return l.forEach(s=>{let c=!1;for(let d=0,h=o.length;d<h;d+=1)if(o[d].regex.test(s)){if(c=!0,o[d].patternSchema===!1){u.push(e.errors.patternPropertiesError({key:s,pointer:r,patterns:Object.keys(a).join(","),schema:t,value:n}));return}const m=e.validate(n[s],o[d].patternSchema,`${r}/${s}`);m&&m.length>0&&u.push(...m)}i[s]||c===!1&&t.additionalProperties===!1&&u.push(e.errors.patternPropertiesError({key:s,pointer:r,patterns:Object.keys(a).join(","),schema:t,value:n}))}),u},propertyNames:(e,t,n,r)=>{if(t.propertyNames===!1)return Object.keys(n).length===0?void 0:e.errors.invalidPropertyNameError({property:Object.keys(n),pointer:r,value:n,schema:t});if(t.propertyNames===!0||hi(t.propertyNames)!=="object")return;const i=[],a=Object.keys(n),u={...t.propertyNames,type:"string"};return a.forEach(l=>{const o=e.validate(l,u,`${r}/${l}`);o.length>0&&i.push(e.errors.invalidPropertyNameError({property:l,pointer:r,validationError:o[0],value:n[l],schema:t}))}),i}},gMe={array:(e,t,n,r)=>e.typeKeywords.array.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),object:(e,t,n,r)=>e.typeKeywords.object.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),string:(e,t,n,r)=>e.typeKeywords.string.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),integer:(e,t,n,r)=>e.typeKeywords.number.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),number:(e,t,n,r)=>e.typeKeywords.number.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),boolean:(e,t,n,r)=>e.typeKeywords.boolean.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r)),null:(e,t,n,r)=>e.typeKeywords.null.filter(i=>t&&t[i]!=null).map(i=>e.validateKeyword[i](e,t,n,r))},U0e={typeKeywords:{array:["allOf","anyOf","contains","enum","if","items","maxItems","minItems","not","oneOf","uniqueItems"],boolean:["allOf","anyOf","enum","not","oneOf"],object:["additionalProperties","allOf","anyOf","dependencies","enum","format","if","maxProperties","minProperties","not","oneOf","patternProperties","properties","propertyNames","required"],string:["allOf","anyOf","enum","format","if","maxLength","minLength","not","oneOf","pattern"],number:["allOf","anyOf","enum","exclusiveMaximum","exclusiveMinimum","format","if","maximum","minimum","multipleOf","not","oneOf"],null:["allOf","anyOf","enum","format","not","oneOf"]},validateKeyword:mMe,validateType:gMe,validateFormat:k0e,errors:T0e,addRemoteSchema:C0e,compileSchema:pMe,createSchemaOf:v0,each:A0e,eachSchema:bw,getChildSchemaSelection:q0e,getSchema:M0e,getTemplate:I0e,isValid:L0e,resolveAllOf:O0e,resolveAnyOf:D0e,resolveOneOf:l0e,resolveRef:S0e,step:z0e,validate:V0e,templateDefaultOptions:r4.templateDefaultOptions};class Xat extends $0e{constructor(t,n={}){super(zI(U0e,n),t)}}({...U0e});const uX={};function vMe(e){let t=uX[e];if(t)return t;t=uX[e]=[];for(let n=0;n<128;n++){const r=String.fromCharCode(n);t.push(r)}for(let n=0;n<e.length;n++){const r=e.charCodeAt(n);t[r]="%"+("0"+r.toString(16).toUpperCase()).slice(-2)}return t}function P3(e,t){typeof t!="string"&&(t=P3.defaultChars);const n=vMe(t);return e.replace(/(%[a-f0-9]{2})+/gi,function(r){let i="";for(let a=0,u=r.length;a<u;a+=3){const l=parseInt(r.slice(a+1,a+3),16);if(l<128){i+=n[l];continue}if((l&224)===192&&a+3<u){const o=parseInt(r.slice(a+4,a+6),16);if((o&192)===128){const s=l<<6&1984|o&63;s<128?i+="��":i+=String.fromCharCode(s),a+=3;continue}}if((l&240)===224&&a+6<u){const o=parseInt(r.slice(a+4,a+6),16),s=parseInt(r.slice(a+7,a+9),16);if((o&192)===128&&(s&192)===128){const c=l<<12&61440|o<<6&4032|s&63;c<2048||c>=55296&&c<=57343?i+="���":i+=String.fromCharCode(c),a+=6;continue}}if((l&248)===240&&a+9<u){const o=parseInt(r.slice(a+4,a+6),16),s=parseInt(r.slice(a+7,a+9),16),c=parseInt(r.slice(a+10,a+12),16);if((o&192)===128&&(s&192)===128&&(c&192)===128){let d=l<<18&1835008|o<<12&258048|s<<6&4032|c&63;d<65536||d>1114111?i+="����":(d-=65536,i+=String.fromCharCode(55296+(d>>10),56320+(d&1023))),a+=9;continue}}i+="�"}return i})}P3.defaultChars=";/?:@&=+$,#";P3.componentChars="";const lX={};function yMe(e){let t=lX[e];if(t)return t;t=lX[e]=[];for(let n=0;n<128;n++){const r=String.fromCharCode(n);/^[0-9a-z]$/i.test(r)?t.push(r):t.push("%"+("0"+n.toString(16).toUpperCase()).slice(-2))}for(let n=0;n<e.length;n++)t[e.charCodeAt(n)]=e[n];return t}function ES(e,t,n){typeof t!="string"&&(n=t,t=ES.defaultChars),typeof n>"u"&&(n=!0);const r=yMe(t);let i="";for(let a=0,u=e.length;a<u;a++){const l=e.charCodeAt(a);if(n&&l===37&&a+2<u&&/^[0-9a-f]{2}$/i.test(e.slice(a+1,a+3))){i+=e.slice(a,a+3),a+=2;continue}if(l<128){i+=r[l];continue}if(l>=55296&&l<=57343){if(l>=55296&&l<=56319&&a+1<u){const o=e.charCodeAt(a+1);if(o>=56320&&o<=57343){i+=encodeURIComponent(e[a]+e[a+1]),a++;continue}}i+="%EF%BF%BD";continue}i+=encodeURIComponent(e[a])}return i}ES.defaultChars=";/?:@&=+$,-_.!~*'()#";ES.componentChars="-_.!~*'()";function ZI(e){let t="";return t+=e.protocol||"",t+=e.slashes?"//":"",t+=e.auth?e.auth+"@":"",e.hostname&&e.hostname.indexOf(":")!==-1?t+="["+e.hostname+"]":t+=e.hostname||"",t+=e.port?":"+e.port:"",t+=e.pathname||"",t+=e.search||"",t+=e.hash||"",t}function $$(){this.protocol=null,this.slashes=null,this.auth=null,this.port=null,this.hostname=null,this.hash=null,this.search=null,this.pathname=null}const bMe=/^([a-z0-9.+-]+:)/i,OMe=/:[0-9]*$/,xMe=/^(\/\/?(?!\/)[^\?\s]*)(\?[^\s]*)?$/,SMe=["<",">",'"',"`"," ","\r",`
`,"	"],_Me=["{","}","|","\\","^","`"].concat(SMe),EMe=["'"].concat(_Me),oX=["%","/","?",";","#"].concat(EMe),sX=["/","?","#"],DMe=255,cX=/^[+a-z0-9A-Z_-]{0,63}$/,$Me=/^([+a-z0-9A-Z_-]{0,63})(.*)$/,fX={javascript:!0,"javascript:":!0},dX={http:!0,https:!0,ftp:!0,gopher:!0,file:!0,"http:":!0,"https:":!0,"ftp:":!0,"gopher:":!0,"file:":!0};function HI(e,t){if(e&&e instanceof $$)return e;const n=new $$;return n.parse(e,t),n}$$.prototype.parse=function(e,t){let n,r,i,a=e;if(a=a.trim(),!t&&e.split("#").length===1){const s=xMe.exec(a);if(s)return this.pathname=s[1],s[2]&&(this.search=s[2]),this}let u=bMe.exec(a);if(u&&(u=u[0],n=u.toLowerCase(),this.protocol=u,a=a.substr(u.length)),(t||u||a.match(/^\/\/[^@\/]+@[^@\/]+/))&&(i=a.substr(0,2)==="//",i&&!(u&&fX[u])&&(a=a.substr(2),this.slashes=!0)),!fX[u]&&(i||u&&!dX[u])){let s=-1;for(let y=0;y<sX.length;y++)r=a.indexOf(sX[y]),r!==-1&&(s===-1||r<s)&&(s=r);let c,d;s===-1?d=a.lastIndexOf("@"):d=a.lastIndexOf("@",s),d!==-1&&(c=a.slice(0,d),a=a.slice(d+1),this.auth=c),s=-1;for(let y=0;y<oX.length;y++)r=a.indexOf(oX[y]),r!==-1&&(s===-1||r<s)&&(s=r);s===-1&&(s=a.length),a[s-1]===":"&&s--;const h=a.slice(0,s);a=a.slice(s),this.parseHost(h),this.hostname=this.hostname||"";const m=this.hostname[0]==="["&&this.hostname[this.hostname.length-1]==="]";if(!m){const y=this.hostname.split(/\./);for(let v=0,_=y.length;v<_;v++){const S=y[v];if(S&&!S.match(cX)){let E="";for(let C=0,T=S.length;C<T;C++)S.charCodeAt(C)>127?E+="x":E+=S[C];if(!E.match(cX)){const C=y.slice(0,v),T=y.slice(v+1),R=S.match($Me);R&&(C.push(R[1]),T.unshift(R[2])),T.length&&(a=T.join(".")+a),this.hostname=C.join(".");break}}}}this.hostname.length>DMe&&(this.hostname=""),m&&(this.hostname=this.hostname.substr(1,this.hostname.length-2))}const l=a.indexOf("#");l!==-1&&(this.hash=a.substr(l),a=a.slice(0,l));const o=a.indexOf("?");return o!==-1&&(this.search=a.substr(o),a=a.slice(0,o)),a&&(this.pathname=a),dX[n]&&this.hostname&&!this.pathname&&(this.pathname=""),this};$$.prototype.parseHost=function(e){let t=OMe.exec(e);t&&(t=t[0],t!==":"&&(this.port=t.substr(1)),e=e.substr(0,e.length-t.length)),e&&(this.hostname=e)};const CMe=Object.freeze(Object.defineProperty({__proto__:null,decode:P3,encode:ES,format:ZI,parse:HI},Symbol.toStringTag,{value:"Module"})),j0e=/[\0-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/,Z0e=/[\0-\x1F\x7F-\x9F]/,wMe=/[\xAD\u0600-\u0605\u061C\u06DD\u070F\u0890\u0891\u08E2\u180E\u200B-\u200F\u202A-\u202E\u2060-\u2064\u2066-\u206F\uFEFF\uFFF9-\uFFFB]|\uD804[\uDCBD\uDCCD]|\uD80D[\uDC30-\uDC3F]|\uD82F[\uDCA0-\uDCA3]|\uD834[\uDD73-\uDD7A]|\uDB40[\uDC01\uDC20-\uDC7F]/,XI=/[!-#%-\*,-\/:;\?@\[-\]_\{\}\xA1\xA7\xAB\xB6\xB7\xBB\xBF\u037E\u0387\u055A-\u055F\u0589\u058A\u05BE\u05C0\u05C3\u05C6\u05F3\u05F4\u0609\u060A\u060C\u060D\u061B\u061D-\u061F\u066A-\u066D\u06D4\u0700-\u070D\u07F7-\u07F9\u0830-\u083E\u085E\u0964\u0965\u0970\u09FD\u0A76\u0AF0\u0C77\u0C84\u0DF4\u0E4F\u0E5A\u0E5B\u0F04-\u0F12\u0F14\u0F3A-\u0F3D\u0F85\u0FD0-\u0FD4\u0FD9\u0FDA\u104A-\u104F\u10FB\u1360-\u1368\u1400\u166E\u169B\u169C\u16EB-\u16ED\u1735\u1736\u17D4-\u17D6\u17D8-\u17DA\u1800-\u180A\u1944\u1945\u1A1E\u1A1F\u1AA0-\u1AA6\u1AA8-\u1AAD\u1B5A-\u1B60\u1B7D\u1B7E\u1BFC-\u1BFF\u1C3B-\u1C3F\u1C7E\u1C7F\u1CC0-\u1CC7\u1CD3\u2010-\u2027\u2030-\u2043\u2045-\u2051\u2053-\u205E\u207D\u207E\u208D\u208E\u2308-\u230B\u2329\u232A\u2768-\u2775\u27C5\u27C6\u27E6-\u27EF\u2983-\u2998\u29D8-\u29DB\u29FC\u29FD\u2CF9-\u2CFC\u2CFE\u2CFF\u2D70\u2E00-\u2E2E\u2E30-\u2E4F\u2E52-\u2E5D\u3001-\u3003\u3008-\u3011\u3014-\u301F\u3030\u303D\u30A0\u30FB\uA4FE\uA4FF\uA60D-\uA60F\uA673\uA67E\uA6F2-\uA6F7\uA874-\uA877\uA8CE\uA8CF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA95F\uA9C1-\uA9CD\uA9DE\uA9DF\uAA5C-\uAA5F\uAADE\uAADF\uAAF0\uAAF1\uABEB\uFD3E\uFD3F\uFE10-\uFE19\uFE30-\uFE52\uFE54-\uFE61\uFE63\uFE68\uFE6A\uFE6B\uFF01-\uFF03\uFF05-\uFF0A\uFF0C-\uFF0F\uFF1A\uFF1B\uFF1F\uFF20\uFF3B-\uFF3D\uFF3F\uFF5B\uFF5D\uFF5F-\uFF65]|\uD800[\uDD00-\uDD02\uDF9F\uDFD0]|\uD801\uDD6F|\uD802[\uDC57\uDD1F\uDD3F\uDE50-\uDE58\uDE7F\uDEF0-\uDEF6\uDF39-\uDF3F\uDF99-\uDF9C]|\uD803[\uDEAD\uDF55-\uDF59\uDF86-\uDF89]|\uD804[\uDC47-\uDC4D\uDCBB\uDCBC\uDCBE-\uDCC1\uDD40-\uDD43\uDD74\uDD75\uDDC5-\uDDC8\uDDCD\uDDDB\uDDDD-\uDDDF\uDE38-\uDE3D\uDEA9]|\uD805[\uDC4B-\uDC4F\uDC5A\uDC5B\uDC5D\uDCC6\uDDC1-\uDDD7\uDE41-\uDE43\uDE60-\uDE6C\uDEB9\uDF3C-\uDF3E]|\uD806[\uDC3B\uDD44-\uDD46\uDDE2\uDE3F-\uDE46\uDE9A-\uDE9C\uDE9E-\uDEA2\uDF00-\uDF09]|\uD807[\uDC41-\uDC45\uDC70\uDC71\uDEF7\uDEF8\uDF43-\uDF4F\uDFFF]|\uD809[\uDC70-\uDC74]|\uD80B[\uDFF1\uDFF2]|\uD81A[\uDE6E\uDE6F\uDEF5\uDF37-\uDF3B\uDF44]|\uD81B[\uDE97-\uDE9A\uDFE2]|\uD82F\uDC9F|\uD836[\uDE87-\uDE8B]|\uD83A[\uDD5E\uDD5F]/,H0e=/[\$\+<->\^`\|~\xA2-\xA6\xA8\xA9\xAC\xAE-\xB1\xB4\xB8\xD7\xF7\u02C2-\u02C5\u02D2-\u02DF\u02E5-\u02EB\u02ED\u02EF-\u02FF\u0375\u0384\u0385\u03F6\u0482\u058D-\u058F\u0606-\u0608\u060B\u060E\u060F\u06DE\u06E9\u06FD\u06FE\u07F6\u07FE\u07FF\u0888\u09F2\u09F3\u09FA\u09FB\u0AF1\u0B70\u0BF3-\u0BFA\u0C7F\u0D4F\u0D79\u0E3F\u0F01-\u0F03\u0F13\u0F15-\u0F17\u0F1A-\u0F1F\u0F34\u0F36\u0F38\u0FBE-\u0FC5\u0FC7-\u0FCC\u0FCE\u0FCF\u0FD5-\u0FD8\u109E\u109F\u1390-\u1399\u166D\u17DB\u1940\u19DE-\u19FF\u1B61-\u1B6A\u1B74-\u1B7C\u1FBD\u1FBF-\u1FC1\u1FCD-\u1FCF\u1FDD-\u1FDF\u1FED-\u1FEF\u1FFD\u1FFE\u2044\u2052\u207A-\u207C\u208A-\u208C\u20A0-\u20C0\u2100\u2101\u2103-\u2106\u2108\u2109\u2114\u2116-\u2118\u211E-\u2123\u2125\u2127\u2129\u212E\u213A\u213B\u2140-\u2144\u214A-\u214D\u214F\u218A\u218B\u2190-\u2307\u230C-\u2328\u232B-\u2426\u2440-\u244A\u249C-\u24E9\u2500-\u2767\u2794-\u27C4\u27C7-\u27E5\u27F0-\u2982\u2999-\u29D7\u29DC-\u29FB\u29FE-\u2B73\u2B76-\u2B95\u2B97-\u2BFF\u2CE5-\u2CEA\u2E50\u2E51\u2E80-\u2E99\u2E9B-\u2EF3\u2F00-\u2FD5\u2FF0-\u2FFF\u3004\u3012\u3013\u3020\u3036\u3037\u303E\u303F\u309B\u309C\u3190\u3191\u3196-\u319F\u31C0-\u31E3\u31EF\u3200-\u321E\u322A-\u3247\u3250\u3260-\u327F\u328A-\u32B0\u32C0-\u33FF\u4DC0-\u4DFF\uA490-\uA4C6\uA700-\uA716\uA720\uA721\uA789\uA78A\uA828-\uA82B\uA836-\uA839\uAA77-\uAA79\uAB5B\uAB6A\uAB6B\uFB29\uFBB2-\uFBC2\uFD40-\uFD4F\uFDCF\uFDFC-\uFDFF\uFE62\uFE64-\uFE66\uFE69\uFF04\uFF0B\uFF1C-\uFF1E\uFF3E\uFF40\uFF5C\uFF5E\uFFE0-\uFFE6\uFFE8-\uFFEE\uFFFC\uFFFD]|\uD800[\uDD37-\uDD3F\uDD79-\uDD89\uDD8C-\uDD8E\uDD90-\uDD9C\uDDA0\uDDD0-\uDDFC]|\uD802[\uDC77\uDC78\uDEC8]|\uD805\uDF3F|\uD807[\uDFD5-\uDFF1]|\uD81A[\uDF3C-\uDF3F\uDF45]|\uD82F\uDC9C|\uD833[\uDF50-\uDFC3]|\uD834[\uDC00-\uDCF5\uDD00-\uDD26\uDD29-\uDD64\uDD6A-\uDD6C\uDD83\uDD84\uDD8C-\uDDA9\uDDAE-\uDDEA\uDE00-\uDE41\uDE45\uDF00-\uDF56]|\uD835[\uDEC1\uDEDB\uDEFB\uDF15\uDF35\uDF4F\uDF6F\uDF89\uDFA9\uDFC3]|\uD836[\uDC00-\uDDFF\uDE37-\uDE3A\uDE6D-\uDE74\uDE76-\uDE83\uDE85\uDE86]|\uD838[\uDD4F\uDEFF]|\uD83B[\uDCAC\uDCB0\uDD2E\uDEF0\uDEF1]|\uD83C[\uDC00-\uDC2B\uDC30-\uDC93\uDCA0-\uDCAE\uDCB1-\uDCBF\uDCC1-\uDCCF\uDCD1-\uDCF5\uDD0D-\uDDAD\uDDE6-\uDE02\uDE10-\uDE3B\uDE40-\uDE48\uDE50\uDE51\uDE60-\uDE65\uDF00-\uDFFF]|\uD83D[\uDC00-\uDED7\uDEDC-\uDEEC\uDEF0-\uDEFC\uDF00-\uDF76\uDF7B-\uDFD9\uDFE0-\uDFEB\uDFF0]|\uD83E[\uDC00-\uDC0B\uDC10-\uDC47\uDC50-\uDC59\uDC60-\uDC87\uDC90-\uDCAD\uDCB0\uDCB1\uDD00-\uDE53\uDE60-\uDE6D\uDE70-\uDE7C\uDE80-\uDE88\uDE90-\uDEBD\uDEBF-\uDEC5\uDECE-\uDEDB\uDEE0-\uDEE8\uDEF0-\uDEF8\uDF00-\uDF92\uDF94-\uDFCA]/,X0e=/[ \xA0\u1680\u2000-\u200A\u2028\u2029\u202F\u205F\u3000]/,RMe=Object.freeze(Object.defineProperty({__proto__:null,Any:j0e,Cc:Z0e,Cf:wMe,P:XI,S:H0e,Z:X0e},Symbol.toStringTag,{value:"Module"})),AMe=new Uint16Array('ᵁ<Õıʊҝջאٵ۞ޢߖࠏ੊ઑඡ๭༉༦჊ረዡᐕᒝᓃᓟᔥ\0\0\0\0\0\0ᕫᛍᦍᰒᷝ὾⁠↰⊍⏀⏻⑂⠤⤒ⴈ⹈⿎〖㊺㘹㞬㣾㨨㩱㫠㬮ࠀEMabcfglmnoprstu\\bfms¦³¹ÈÏlig耻Æ䃆P耻&䀦cute耻Á䃁reve;䄂Āiyx}rc耻Â䃂;䐐r;쀀𝔄rave耻À䃀pha;䎑acr;䄀d;橓Āgp¡on;䄄f;쀀𝔸plyFunction;恡ing耻Å䃅Ācs¾Ãr;쀀𝒜ign;扔ilde耻Ã䃃ml耻Ä䃄ЀaceforsuåûþėĜĢħĪĀcrêòkslash;或Ŷöø;櫧ed;挆y;䐑ƀcrtąċĔause;戵noullis;愬a;䎒r;쀀𝔅pf;쀀𝔹eve;䋘còēmpeq;扎܀HOacdefhilorsuōőŖƀƞƢƵƷƺǜȕɳɸɾcy;䐧PY耻©䂩ƀcpyŝŢźute;䄆Ā;iŧŨ拒talDifferentialD;慅leys;愭ȀaeioƉƎƔƘron;䄌dil耻Ç䃇rc;䄈nint;戰ot;䄊ĀdnƧƭilla;䂸terDot;䂷òſi;䎧rcleȀDMPTǇǋǑǖot;抙inus;抖lus;投imes;抗oĀcsǢǸkwiseContourIntegral;戲eCurlyĀDQȃȏoubleQuote;思uote;怙ȀlnpuȞȨɇɕonĀ;eȥȦ户;橴ƀgitȯȶȺruent;扡nt;戯ourIntegral;戮ĀfrɌɎ;愂oduct;成nterClockwiseContourIntegral;戳oss;樯cr;쀀𝒞pĀ;Cʄʅ拓ap;才րDJSZacefiosʠʬʰʴʸˋ˗ˡ˦̳ҍĀ;oŹʥtrahd;椑cy;䐂cy;䐅cy;䐏ƀgrsʿ˄ˇger;怡r;憡hv;櫤Āayː˕ron;䄎;䐔lĀ;t˝˞戇a;䎔r;쀀𝔇Āaf˫̧Ācm˰̢riticalȀADGT̖̜̀̆cute;䂴oŴ̋̍;䋙bleAcute;䋝rave;䁠ilde;䋜ond;拄ferentialD;慆Ѱ̽\0\0\0͔͂\0Ѕf;쀀𝔻ƀ;DE͈͉͍䂨ot;惜qual;扐blèCDLRUVͣͲ΂ϏϢϸontourIntegraìȹoɴ͹\0\0ͻ»͉nArrow;懓Āeo·ΤftƀARTΐΖΡrrow;懐ightArrow;懔eåˊngĀLRΫτeftĀARγιrrow;柸ightArrow;柺ightArrow;柹ightĀATϘϞrrow;懒ee;抨pɁϩ\0\0ϯrrow;懑ownArrow;懕erticalBar;戥ǹABLRTaВЪаўѿͼrrowƀ;BUНОТ憓ar;椓pArrow;懵reve;䌑eft˒к\0ц\0ѐightVector;楐eeVector;楞ectorĀ;Bљњ憽ar;楖ightǔѧ\0ѱeeVector;楟ectorĀ;BѺѻ懁ar;楗eeĀ;A҆҇护rrow;憧ĀctҒҗr;쀀𝒟rok;䄐ࠀNTacdfglmopqstuxҽӀӄӋӞӢӧӮӵԡԯԶՒ՝ՠեG;䅊H耻Ð䃐cute耻É䃉ƀaiyӒӗӜron;䄚rc耻Ê䃊;䐭ot;䄖r;쀀𝔈rave耻È䃈ement;戈ĀapӺӾcr;䄒tyɓԆ\0\0ԒmallSquare;旻erySmallSquare;斫ĀgpԦԪon;䄘f;쀀𝔼silon;䎕uĀaiԼՉlĀ;TՂՃ橵ilde;扂librium;懌Āci՗՚r;愰m;橳a;䎗ml耻Ë䃋Āipժկsts;戃onentialE;慇ʀcfiosօֈ֍ֲ׌y;䐤r;쀀𝔉lledɓ֗\0\0֣mallSquare;旼erySmallSquare;斪Ͱֺ\0ֿ\0\0ׄf;쀀𝔽All;戀riertrf;愱cò׋؀JTabcdfgorstר׬ׯ׺؀ؒؖ؛؝أ٬ٲcy;䐃耻>䀾mmaĀ;d׷׸䎓;䏜reve;䄞ƀeiy؇،ؐdil;䄢rc;䄜;䐓ot;䄠r;쀀𝔊;拙pf;쀀𝔾eater̀EFGLSTصلَٖٛ٦qualĀ;Lؾؿ扥ess;招ullEqual;执reater;檢ess;扷lantEqual;橾ilde;扳cr;쀀𝒢;扫ЀAacfiosuڅڋږڛڞڪھۊRDcy;䐪Āctڐڔek;䋇;䁞irc;䄤r;愌lbertSpace;愋ǰگ\0ڲf;愍izontalLine;攀Āctۃۅòکrok;䄦mpńېۘownHumðįqual;扏܀EJOacdfgmnostuۺ۾܃܇܎ܚܞܡܨ݄ݸދޏޕcy;䐕lig;䄲cy;䐁cute耻Í䃍Āiyܓܘrc耻Î䃎;䐘ot;䄰r;愑rave耻Ì䃌ƀ;apܠܯܿĀcgܴܷr;䄪inaryI;慈lieóϝǴ݉\0ݢĀ;eݍݎ戬Āgrݓݘral;戫section;拂isibleĀCTݬݲomma;恣imes;恢ƀgptݿރވon;䄮f;쀀𝕀a;䎙cr;愐ilde;䄨ǫޚ\0ޞcy;䐆l耻Ï䃏ʀcfosuެ޷޼߂ߐĀiyޱ޵rc;䄴;䐙r;쀀𝔍pf;쀀𝕁ǣ߇\0ߌr;쀀𝒥rcy;䐈kcy;䐄΀HJacfosߤߨ߽߬߱ࠂࠈcy;䐥cy;䐌ppa;䎚Āey߶߻dil;䄶;䐚r;쀀𝔎pf;쀀𝕂cr;쀀𝒦րJTaceflmostࠥࠩࠬࡐࡣ঳সে্਷ੇcy;䐉耻<䀼ʀcmnpr࠷࠼ࡁࡄࡍute;䄹bda;䎛g;柪lacetrf;愒r;憞ƀaeyࡗ࡜ࡡron;䄽dil;䄻;䐛Āfsࡨ॰tԀACDFRTUVarࡾࢩࢱࣦ࣠ࣼयज़ΐ४Ānrࢃ࢏gleBracket;柨rowƀ;BR࢙࢚࢞憐ar;懤ightArrow;懆eiling;挈oǵࢷ\0ࣃbleBracket;柦nǔࣈ\0࣒eeVector;楡ectorĀ;Bࣛࣜ懃ar;楙loor;挊ightĀAV࣯ࣵrrow;憔ector;楎Āerँगeƀ;AVउऊऐ抣rrow;憤ector;楚iangleƀ;BEतथऩ抲ar;槏qual;抴pƀDTVषूौownVector;楑eeVector;楠ectorĀ;Bॖॗ憿ar;楘ectorĀ;B॥०憼ar;楒ightáΜs̀EFGLSTॾঋকঝঢভqualGreater;拚ullEqual;扦reater;扶ess;檡lantEqual;橽ilde;扲r;쀀𝔏Ā;eঽা拘ftarrow;懚idot;䄿ƀnpw৔ਖਛgȀLRlr৞৷ਂਐeftĀAR০৬rrow;柵ightArrow;柷ightArrow;柶eftĀarγਊightáοightáϊf;쀀𝕃erĀLRਢਬeftArrow;憙ightArrow;憘ƀchtਾੀੂòࡌ;憰rok;䅁;扪Ѐacefiosuਗ਼੝੠੷੼અઋ઎p;椅y;䐜Ādl੥੯iumSpace;恟lintrf;愳r;쀀𝔐nusPlus;戓pf;쀀𝕄cò੶;䎜ҀJacefostuણધભીଔଙඑ඗ඞcy;䐊cute;䅃ƀaey઴હાron;䅇dil;䅅;䐝ƀgswે૰଎ativeƀMTV૓૟૨ediumSpace;怋hiĀcn૦૘ë૙eryThiî૙tedĀGL૸ଆreaterGreateòٳessLesóੈLine;䀊r;쀀𝔑ȀBnptଢନଷ଺reak;恠BreakingSpace;䂠f;愕ڀ;CDEGHLNPRSTV୕ୖ୪୼஡௫ఄ౞಄ದ೘ൡඅ櫬Āou୛୤ngruent;扢pCap;扭oubleVerticalBar;戦ƀlqxஃஊ஛ement;戉ualĀ;Tஒஓ扠ilde;쀀≂̸ists;戄reater΀;EFGLSTஶஷ஽௉௓௘௥扯qual;扱ullEqual;쀀≧̸reater;쀀≫̸ess;批lantEqual;쀀⩾̸ilde;扵umpń௲௽ownHump;쀀≎̸qual;쀀≏̸eĀfsఊధtTriangleƀ;BEచఛడ拪ar;쀀⧏̸qual;括s̀;EGLSTవశ఼ౄోౘ扮qual;扰reater;扸ess;쀀≪̸lantEqual;쀀⩽̸ilde;扴estedĀGL౨౹reaterGreater;쀀⪢̸essLess;쀀⪡̸recedesƀ;ESಒಓಛ技qual;쀀⪯̸lantEqual;拠ĀeiಫಹverseElement;戌ghtTriangleƀ;BEೋೌ೒拫ar;쀀⧐̸qual;拭ĀquೝഌuareSuĀbp೨೹setĀ;E೰ೳ쀀⊏̸qual;拢ersetĀ;Eഃആ쀀⊐̸qual;拣ƀbcpഓതൎsetĀ;Eഛഞ쀀⊂⃒qual;抈ceedsȀ;ESTലള഻െ抁qual;쀀⪰̸lantEqual;拡ilde;쀀≿̸ersetĀ;E൘൛쀀⊃⃒qual;抉ildeȀ;EFT൮൯൵ൿ扁qual;扄ullEqual;扇ilde;扉erticalBar;戤cr;쀀𝒩ilde耻Ñ䃑;䎝܀Eacdfgmoprstuvලෂ෉෕ෛ෠෧෼ขภยา฿ไlig;䅒cute耻Ó䃓Āiy෎ීrc耻Ô䃔;䐞blac;䅐r;쀀𝔒rave耻Ò䃒ƀaei෮ෲ෶cr;䅌ga;䎩cron;䎟pf;쀀𝕆enCurlyĀDQฎบoubleQuote;怜uote;怘;橔Āclวฬr;쀀𝒪ash耻Ø䃘iŬื฼de耻Õ䃕es;樷ml耻Ö䃖erĀBP๋๠Āar๐๓r;怾acĀek๚๜;揞et;掴arenthesis;揜Ҁacfhilors๿ງຊຏຒດຝະ໼rtialD;戂y;䐟r;쀀𝔓i;䎦;䎠usMinus;䂱Āipຢອncareplanåڝf;愙Ȁ;eio຺ູ໠໤檻cedesȀ;EST່້໏໚扺qual;檯lantEqual;扼ilde;找me;怳Ādp໩໮uct;戏ortionĀ;aȥ໹l;戝Āci༁༆r;쀀𝒫;䎨ȀUfos༑༖༛༟OT耻"䀢r;쀀𝔔pf;愚cr;쀀𝒬؀BEacefhiorsu༾གྷཇའཱིྦྷྪྭ႖ႩႴႾarr;椐G耻®䂮ƀcnrཎནབute;䅔g;柫rĀ;tཛྷཝ憠l;椖ƀaeyཧཬཱron;䅘dil;䅖;䐠Ā;vླྀཹ愜erseĀEUྂྙĀlq྇ྎement;戋uilibrium;懋pEquilibrium;楯r»ཹo;䎡ghtЀACDFTUVa࿁࿫࿳ဢဨၛႇϘĀnr࿆࿒gleBracket;柩rowƀ;BL࿜࿝࿡憒ar;懥eftArrow;懄eiling;按oǵ࿹\0စbleBracket;柧nǔည\0နeeVector;楝ectorĀ;Bဝသ懂ar;楕loor;挋Āerိ၃eƀ;AVဵံြ抢rrow;憦ector;楛iangleƀ;BEၐၑၕ抳ar;槐qual;抵pƀDTVၣၮၸownVector;楏eeVector;楜ectorĀ;Bႂႃ憾ar;楔ectorĀ;B႑႒懀ar;楓Āpuႛ႞f;愝ndImplies;楰ightarrow;懛ĀchႹႼr;愛;憱leDelayed;槴ڀHOacfhimoqstuფჱჷჽᄙᄞᅑᅖᅡᅧᆵᆻᆿĀCcჩხHcy;䐩y;䐨FTcy;䐬cute;䅚ʀ;aeiyᄈᄉᄎᄓᄗ檼ron;䅠dil;䅞rc;䅜;䐡r;쀀𝔖ortȀDLRUᄪᄴᄾᅉownArrow»ОeftArrow»࢚ightArrow»࿝pArrow;憑gma;䎣allCircle;战pf;쀀𝕊ɲᅭ\0\0ᅰt;戚areȀ;ISUᅻᅼᆉᆯ斡ntersection;抓uĀbpᆏᆞsetĀ;Eᆗᆘ抏qual;抑ersetĀ;Eᆨᆩ抐qual;抒nion;抔cr;쀀𝒮ar;拆ȀbcmpᇈᇛሉላĀ;sᇍᇎ拐etĀ;Eᇍᇕqual;抆ĀchᇠህeedsȀ;ESTᇭᇮᇴᇿ扻qual;檰lantEqual;扽ilde;承Tháྌ;我ƀ;esሒሓሣ拑rsetĀ;Eሜም抃qual;抇et»ሓրHRSacfhiorsሾቄ቉ቕ቞ቱቶኟዂወዑORN耻Þ䃞ADE;愢ĀHc቎ቒcy;䐋y;䐦Ābuቚቜ;䀉;䎤ƀaeyብቪቯron;䅤dil;䅢;䐢r;쀀𝔗Āeiቻ኉ǲኀ\0ኇefore;戴a;䎘Ācn኎ኘkSpace;쀀  Space;怉ldeȀ;EFTካኬኲኼ戼qual;扃ullEqual;扅ilde;扈pf;쀀𝕋ipleDot;惛Āctዖዛr;쀀𝒯rok;䅦ૡዷጎጚጦ\0ጬጱ\0\0\0\0\0ጸጽ፷ᎅ\0᏿ᐄᐊᐐĀcrዻጁute耻Ú䃚rĀ;oጇገ憟cir;楉rǣጓ\0጖y;䐎ve;䅬Āiyጞጣrc耻Û䃛;䐣blac;䅰r;쀀𝔘rave耻Ù䃙acr;䅪Ādiፁ፩erĀBPፈ፝Āarፍፐr;䁟acĀekፗፙ;揟et;掵arenthesis;揝onĀ;P፰፱拃lus;抎Āgp፻፿on;䅲f;쀀𝕌ЀADETadps᎕ᎮᎸᏄϨᏒᏗᏳrrowƀ;BDᅐᎠᎤar;椒ownArrow;懅ownArrow;憕quilibrium;楮eeĀ;AᏋᏌ报rrow;憥ownáϳerĀLRᏞᏨeftArrow;憖ightArrow;憗iĀ;lᏹᏺ䏒on;䎥ing;䅮cr;쀀𝒰ilde;䅨ml耻Ü䃜ҀDbcdefosvᐧᐬᐰᐳᐾᒅᒊᒐᒖash;披ar;櫫y;䐒ashĀ;lᐻᐼ抩;櫦Āerᑃᑅ;拁ƀbtyᑌᑐᑺar;怖Ā;iᑏᑕcalȀBLSTᑡᑥᑪᑴar;戣ine;䁼eparator;杘ilde;所ThinSpace;怊r;쀀𝔙pf;쀀𝕍cr;쀀𝒱dash;抪ʀcefosᒧᒬᒱᒶᒼirc;䅴dge;拀r;쀀𝔚pf;쀀𝕎cr;쀀𝒲Ȁfiosᓋᓐᓒᓘr;쀀𝔛;䎞pf;쀀𝕏cr;쀀𝒳ҀAIUacfosuᓱᓵᓹᓽᔄᔏᔔᔚᔠcy;䐯cy;䐇cy;䐮cute耻Ý䃝Āiyᔉᔍrc;䅶;䐫r;쀀𝔜pf;쀀𝕐cr;쀀𝒴ml;䅸ЀHacdefosᔵᔹᔿᕋᕏᕝᕠᕤcy;䐖cute;䅹Āayᕄᕉron;䅽;䐗ot;䅻ǲᕔ\0ᕛoWidtè૙a;䎖r;愨pf;愤cr;쀀𝒵௡ᖃᖊᖐ\0ᖰᖶᖿ\0\0\0\0ᗆᗛᗫᙟ᙭\0ᚕ᚛ᚲᚹ\0ᚾcute耻á䃡reve;䄃̀;Ediuyᖜᖝᖡᖣᖨᖭ戾;쀀∾̳;房rc耻â䃢te肻´̆;䐰lig耻æ䃦Ā;r²ᖺ;쀀𝔞rave耻à䃠ĀepᗊᗖĀfpᗏᗔsym;愵èᗓha;䎱ĀapᗟcĀclᗤᗧr;䄁g;樿ɤᗰ\0\0ᘊʀ;adsvᗺᗻᗿᘁᘇ戧nd;橕;橜lope;橘;橚΀;elmrszᘘᘙᘛᘞᘿᙏᙙ戠;榤e»ᘙsdĀ;aᘥᘦ戡ѡᘰᘲᘴᘶᘸᘺᘼᘾ;榨;榩;榪;榫;榬;榭;榮;榯tĀ;vᙅᙆ戟bĀ;dᙌᙍ抾;榝Āptᙔᙗh;戢»¹arr;捼Āgpᙣᙧon;䄅f;쀀𝕒΀;Eaeiop዁ᙻᙽᚂᚄᚇᚊ;橰cir;橯;扊d;手s;䀧roxĀ;e዁ᚒñᚃing耻å䃥ƀctyᚡᚦᚨr;쀀𝒶;䀪mpĀ;e዁ᚯñʈilde耻ã䃣ml耻ä䃤Āciᛂᛈoninôɲnt;樑ࠀNabcdefiklnoprsu᛭ᛱᜰ᜼ᝃᝈ᝸᝽០៦ᠹᡐᜍ᤽᥈ᥰot;櫭Ācrᛶ᜞kȀcepsᜀᜅᜍᜓong;扌psilon;䏶rime;怵imĀ;e᜚᜛戽q;拍Ŷᜢᜦee;抽edĀ;gᜬᜭ挅e»ᜭrkĀ;t፜᜷brk;掶Āoyᜁᝁ;䐱quo;怞ʀcmprtᝓ᝛ᝡᝤᝨausĀ;eĊĉptyv;榰séᜌnoõēƀahwᝯ᝱ᝳ;䎲;愶een;扬r;쀀𝔟g΀costuvwឍឝឳេ៕៛៞ƀaiuបពរðݠrc;旯p»፱ƀdptឤឨឭot;樀lus;樁imes;樂ɱឹ\0\0ើcup;樆ar;昅riangleĀdu៍្own;施p;斳plus;樄eåᑄåᒭarow;植ƀako៭ᠦᠵĀcn៲ᠣkƀlst៺֫᠂ozenge;槫riangleȀ;dlr᠒᠓᠘᠝斴own;斾eft;旂ight;斸k;搣Ʊᠫ\0ᠳƲᠯ\0ᠱ;斒;斑4;斓ck;斈ĀeoᠾᡍĀ;qᡃᡆ쀀=⃥uiv;쀀≡⃥t;挐Ȁptwxᡙᡞᡧᡬf;쀀𝕓Ā;tᏋᡣom»Ꮜtie;拈؀DHUVbdhmptuvᢅᢖᢪᢻᣗᣛᣬ᣿ᤅᤊᤐᤡȀLRlrᢎᢐᢒᢔ;敗;敔;敖;敓ʀ;DUduᢡᢢᢤᢦᢨ敐;敦;敩;敤;敧ȀLRlrᢳᢵᢷᢹ;敝;敚;敜;教΀;HLRhlrᣊᣋᣍᣏᣑᣓᣕ救;敬;散;敠;敫;敢;敟ox;槉ȀLRlrᣤᣦᣨᣪ;敕;敒;攐;攌ʀ;DUduڽ᣷᣹᣻᣽;敥;敨;攬;攴inus;抟lus;択imes;抠ȀLRlrᤙᤛᤝ᤟;敛;敘;攘;攔΀;HLRhlrᤰᤱᤳᤵᤷ᤻᤹攂;敪;敡;敞;攼;攤;攜Āevģ᥂bar耻¦䂦Ȁceioᥑᥖᥚᥠr;쀀𝒷mi;恏mĀ;e᜚᜜lƀ;bhᥨᥩᥫ䁜;槅sub;柈Ŭᥴ᥾lĀ;e᥹᥺怢t»᥺pƀ;Eeįᦅᦇ;檮Ā;qۜۛೡᦧ\0᧨ᨑᨕᨲ\0ᨷᩐ\0\0᪴\0\0᫁\0\0ᬡᬮ᭍᭒\0᯽\0ᰌƀcpr᦭ᦲ᧝ute;䄇̀;abcdsᦿᧀᧄ᧊᧕᧙戩nd;橄rcup;橉Āau᧏᧒p;橋p;橇ot;橀;쀀∩︀Āeo᧢᧥t;恁îړȀaeiu᧰᧻ᨁᨅǰ᧵\0᧸s;橍on;䄍dil耻ç䃧rc;䄉psĀ;sᨌᨍ橌m;橐ot;䄋ƀdmnᨛᨠᨦil肻¸ƭptyv;榲t脀¢;eᨭᨮ䂢räƲr;쀀𝔠ƀceiᨽᩀᩍy;䑇ckĀ;mᩇᩈ朓ark»ᩈ;䏇r΀;Ecefms᩟᩠ᩢᩫ᪤᪪᪮旋;槃ƀ;elᩩᩪᩭ䋆q;扗eɡᩴ\0\0᪈rrowĀlr᩼᪁eft;憺ight;憻ʀRSacd᪒᪔᪖᪚᪟»ཇ;擈st;抛irc;抚ash;抝nint;樐id;櫯cir;槂ubsĀ;u᪻᪼晣it»᪼ˬ᫇᫔᫺\0ᬊonĀ;eᫍᫎ䀺Ā;qÇÆɭ᫙\0\0᫢aĀ;t᫞᫟䀬;䁀ƀ;fl᫨᫩᫫戁îᅠeĀmx᫱᫶ent»᫩eóɍǧ᫾\0ᬇĀ;dኻᬂot;橭nôɆƀfryᬐᬔᬗ;쀀𝕔oäɔ脀©;sŕᬝr;愗Āaoᬥᬩrr;憵ss;朗Ācuᬲᬷr;쀀𝒸Ābpᬼ᭄Ā;eᭁᭂ櫏;櫑Ā;eᭉᭊ櫐;櫒dot;拯΀delprvw᭠᭬᭷ᮂᮬᯔ᯹arrĀlr᭨᭪;椸;椵ɰ᭲\0\0᭵r;拞c;拟arrĀ;p᭿ᮀ憶;椽̀;bcdosᮏᮐᮖᮡᮥᮨ截rcap;橈Āauᮛᮞp;橆p;橊ot;抍r;橅;쀀∪︀Ȁalrv᮵ᮿᯞᯣrrĀ;mᮼᮽ憷;椼yƀevwᯇᯔᯘqɰᯎ\0\0ᯒreã᭳uã᭵ee;拎edge;拏en耻¤䂤earrowĀlrᯮ᯳eft»ᮀight»ᮽeäᯝĀciᰁᰇoninôǷnt;戱lcty;挭ঀAHabcdefhijlorstuwz᰸᰻᰿ᱝᱩᱵᲊᲞᲬᲷ᳻᳿ᴍᵻᶑᶫᶻ᷆᷍rò΁ar;楥Ȁglrs᱈ᱍ᱒᱔ger;怠eth;愸òᄳhĀ;vᱚᱛ怐»ऊūᱡᱧarow;椏aã̕Āayᱮᱳron;䄏;䐴ƀ;ao̲ᱼᲄĀgrʿᲁr;懊tseq;橷ƀglmᲑᲔᲘ耻°䂰ta;䎴ptyv;榱ĀirᲣᲨsht;楿;쀀𝔡arĀlrᲳᲵ»ࣜ»သʀaegsv᳂͸᳖᳜᳠mƀ;oș᳊᳔ndĀ;ș᳑uit;晦amma;䏝in;拲ƀ;io᳧᳨᳸䃷de脀÷;o᳧ᳰntimes;拇nø᳷cy;䑒cɯᴆ\0\0ᴊrn;挞op;挍ʀlptuwᴘᴝᴢᵉᵕlar;䀤f;쀀𝕕ʀ;emps̋ᴭᴷᴽᵂqĀ;d͒ᴳot;扑inus;戸lus;戔quare;抡blebarwedgåúnƀadhᄮᵝᵧownarrowóᲃarpoonĀlrᵲᵶefôᲴighôᲶŢᵿᶅkaro÷གɯᶊ\0\0ᶎrn;挟op;挌ƀcotᶘᶣᶦĀryᶝᶡ;쀀𝒹;䑕l;槶rok;䄑Ādrᶰᶴot;拱iĀ;fᶺ᠖斿Āah᷀᷃ròЩaòྦangle;榦Āci᷒ᷕy;䑟grarr;柿ऀDacdefglmnopqrstuxḁḉḙḸոḼṉṡṾấắẽỡἪἷὄ὎὚ĀDoḆᴴoôᲉĀcsḎḔute耻é䃩ter;橮ȀaioyḢḧḱḶron;䄛rĀ;cḭḮ扖耻ê䃪lon;払;䑍ot;䄗ĀDrṁṅot;扒;쀀𝔢ƀ;rsṐṑṗ檚ave耻è䃨Ā;dṜṝ檖ot;檘Ȁ;ilsṪṫṲṴ檙nters;揧;愓Ā;dṹṺ檕ot;檗ƀapsẅẉẗcr;䄓tyƀ;svẒẓẕ戅et»ẓpĀ1;ẝẤĳạả;怄;怅怃ĀgsẪẬ;䅋p;怂ĀgpẴẸon;䄙f;쀀𝕖ƀalsỄỎỒrĀ;sỊị拕l;槣us;橱iƀ;lvỚớở䎵on»ớ;䏵ȀcsuvỪỳἋἣĀioữḱrc»Ḯɩỹ\0\0ỻíՈantĀglἂἆtr»ṝess»Ṻƀaeiἒ἖Ἒls;䀽st;扟vĀ;DȵἠD;橸parsl;槥ĀDaἯἳot;打rr;楱ƀcdiἾὁỸr;愯oô͒ĀahὉὋ;䎷耻ð䃰Āmrὓὗl耻ë䃫o;悬ƀcipὡὤὧl;䀡sôծĀeoὬὴctatioîՙnentialåչৡᾒ\0ᾞ\0ᾡᾧ\0\0ῆῌ\0ΐ\0ῦῪ \0 ⁚llingdotseñṄy;䑄male;晀ƀilrᾭᾳ῁lig;耀ﬃɩᾹ\0\0᾽g;耀ﬀig;耀ﬄ;쀀𝔣lig;耀ﬁlig;쀀fjƀaltῙ῜ῡt;晭ig;耀ﬂns;斱of;䆒ǰ΅\0ῳf;쀀𝕗ĀakֿῷĀ;vῼ´拔;櫙artint;樍Āao‌⁕Ācs‑⁒α‚‰‸⁅⁈\0⁐β•‥‧‪‬\0‮耻½䂽;慓耻¼䂼;慕;慙;慛Ƴ‴\0‶;慔;慖ʴ‾⁁\0\0⁃耻¾䂾;慗;慜5;慘ƶ⁌\0⁎;慚;慝8;慞l;恄wn;挢cr;쀀𝒻ࢀEabcdefgijlnorstv₂₉₟₥₰₴⃰⃵⃺⃿℃ℒℸ̗ℾ⅒↞Ā;lٍ₇;檌ƀcmpₐₕ₝ute;䇵maĀ;dₜ᳚䎳;檆reve;䄟Āiy₪₮rc;䄝;䐳ot;䄡Ȁ;lqsؾق₽⃉ƀ;qsؾٌ⃄lanô٥Ȁ;cdl٥⃒⃥⃕c;檩otĀ;o⃜⃝檀Ā;l⃢⃣檂;檄Ā;e⃪⃭쀀⋛︀s;檔r;쀀𝔤Ā;gٳ؛mel;愷cy;䑓Ȁ;Eajٚℌℎℐ;檒;檥;檤ȀEaesℛℝ℩ℴ;扩pĀ;p℣ℤ檊rox»ℤĀ;q℮ℯ檈Ā;q℮ℛim;拧pf;쀀𝕘Āci⅃ⅆr;愊mƀ;el٫ⅎ⅐;檎;檐茀>;cdlqr׮ⅠⅪⅮⅳⅹĀciⅥⅧ;檧r;橺ot;拗Par;榕uest;橼ʀadelsↄⅪ←ٖ↛ǰ↉\0↎proø₞r;楸qĀlqؿ↖lesó₈ií٫Āen↣↭rtneqq;쀀≩︀Å↪ԀAabcefkosy⇄⇇⇱⇵⇺∘∝∯≨≽ròΠȀilmr⇐⇔⇗⇛rsðᒄf»․ilôکĀdr⇠⇤cy;䑊ƀ;cwࣴ⇫⇯ir;楈;憭ar;意irc;䄥ƀalr∁∎∓rtsĀ;u∉∊晥it»∊lip;怦con;抹r;쀀𝔥sĀew∣∩arow;椥arow;椦ʀamopr∺∾≃≞≣rr;懿tht;戻kĀlr≉≓eftarrow;憩ightarrow;憪f;쀀𝕙bar;怕ƀclt≯≴≸r;쀀𝒽asè⇴rok;䄧Ābp⊂⊇ull;恃hen»ᱛૡ⊣\0⊪\0⊸⋅⋎\0⋕⋳\0\0⋸⌢⍧⍢⍿\0⎆⎪⎴cute耻í䃭ƀ;iyݱ⊰⊵rc耻î䃮;䐸Ācx⊼⊿y;䐵cl耻¡䂡ĀfrΟ⋉;쀀𝔦rave耻ì䃬Ȁ;inoܾ⋝⋩⋮Āin⋢⋦nt;樌t;戭fin;槜ta;愩lig;䄳ƀaop⋾⌚⌝ƀcgt⌅⌈⌗r;䄫ƀelpܟ⌏⌓inåގarôܠh;䄱f;抷ed;䆵ʀ;cfotӴ⌬⌱⌽⍁are;愅inĀ;t⌸⌹戞ie;槝doô⌙ʀ;celpݗ⍌⍐⍛⍡al;抺Āgr⍕⍙eróᕣã⍍arhk;樗rod;樼Ȁcgpt⍯⍲⍶⍻y;䑑on;䄯f;쀀𝕚a;䎹uest耻¿䂿Āci⎊⎏r;쀀𝒾nʀ;EdsvӴ⎛⎝⎡ӳ;拹ot;拵Ā;v⎦⎧拴;拳Ā;iݷ⎮lde;䄩ǫ⎸\0⎼cy;䑖l耻ï䃯̀cfmosu⏌⏗⏜⏡⏧⏵Āiy⏑⏕rc;䄵;䐹r;쀀𝔧ath;䈷pf;쀀𝕛ǣ⏬\0⏱r;쀀𝒿rcy;䑘kcy;䑔Ѐacfghjos␋␖␢␧␭␱␵␻ppaĀ;v␓␔䎺;䏰Āey␛␠dil;䄷;䐺r;쀀𝔨reen;䄸cy;䑅cy;䑜pf;쀀𝕜cr;쀀𝓀஀ABEHabcdefghjlmnoprstuv⑰⒁⒆⒍⒑┎┽╚▀♎♞♥♹♽⚚⚲⛘❝❨➋⟀⠁⠒ƀart⑷⑺⑼rò৆òΕail;椛arr;椎Ā;gঔ⒋;檋ar;楢ॣ⒥\0⒪\0⒱\0\0\0\0\0⒵Ⓔ\0ⓆⓈⓍ\0⓹ute;䄺mptyv;榴raîࡌbda;䎻gƀ;dlࢎⓁⓃ;榑åࢎ;檅uo耻«䂫rЀ;bfhlpst࢙ⓞⓦⓩ⓫⓮⓱⓵Ā;f࢝ⓣs;椟s;椝ë≒p;憫l;椹im;楳l;憢ƀ;ae⓿─┄檫il;椙Ā;s┉┊檭;쀀⪭︀ƀabr┕┙┝rr;椌rk;杲Āak┢┬cĀek┨┪;䁻;䁛Āes┱┳;榋lĀdu┹┻;榏;榍Ȁaeuy╆╋╖╘ron;䄾Ādi═╔il;䄼ìࢰâ┩;䐻Ȁcqrs╣╦╭╽a;椶uoĀ;rนᝆĀdu╲╷har;楧shar;楋h;憲ʀ;fgqs▋▌উ◳◿扤tʀahlrt▘▤▷◂◨rrowĀ;t࢙□aé⓶arpoonĀdu▯▴own»њp»०eftarrows;懇ightƀahs◍◖◞rrowĀ;sࣴࢧarpoonó྘quigarro÷⇰hreetimes;拋ƀ;qs▋ও◺lanôবʀ;cdgsব☊☍☝☨c;檨otĀ;o☔☕橿Ā;r☚☛檁;檃Ā;e☢☥쀀⋚︀s;檓ʀadegs☳☹☽♉♋pproøⓆot;拖qĀgq♃♅ôউgtò⒌ôছiíলƀilr♕࣡♚sht;楼;쀀𝔩Ā;Eজ♣;檑š♩♶rĀdu▲♮Ā;l॥♳;楪lk;斄cy;䑙ʀ;achtੈ⚈⚋⚑⚖rò◁orneòᴈard;楫ri;旺Āio⚟⚤dot;䅀ustĀ;a⚬⚭掰che»⚭ȀEaes⚻⚽⛉⛔;扨pĀ;p⛃⛄檉rox»⛄Ā;q⛎⛏檇Ā;q⛎⚻im;拦Ѐabnoptwz⛩⛴⛷✚✯❁❇❐Ānr⛮⛱g;柬r;懽rëࣁgƀlmr⛿✍✔eftĀar০✇ightá৲apsto;柼ightá৽parrowĀlr✥✩efô⓭ight;憬ƀafl✶✹✽r;榅;쀀𝕝us;樭imes;樴š❋❏st;戗áፎƀ;ef❗❘᠀旊nge»❘arĀ;l❤❥䀨t;榓ʀachmt❳❶❼➅➇ròࢨorneòᶌarĀ;d྘➃;業;怎ri;抿̀achiqt➘➝ੀ➢➮➻quo;怹r;쀀𝓁mƀ;egল➪➬;檍;檏Ābu┪➳oĀ;rฟ➹;怚rok;䅂萀<;cdhilqrࠫ⟒☹⟜⟠⟥⟪⟰Āci⟗⟙;檦r;橹reå◲mes;拉arr;楶uest;橻ĀPi⟵⟹ar;榖ƀ;ef⠀भ᠛旃rĀdu⠇⠍shar;楊har;楦Āen⠗⠡rtneqq;쀀≨︀Å⠞܀Dacdefhilnopsu⡀⡅⢂⢎⢓⢠⢥⢨⣚⣢⣤ઃ⣳⤂Dot;戺Ȁclpr⡎⡒⡣⡽r耻¯䂯Āet⡗⡙;時Ā;e⡞⡟朠se»⡟Ā;sျ⡨toȀ;dluျ⡳⡷⡻owîҌefôएðᏑker;斮Āoy⢇⢌mma;権;䐼ash;怔asuredangle»ᘦr;쀀𝔪o;愧ƀcdn⢯⢴⣉ro耻µ䂵Ȁ;acdᑤ⢽⣀⣄sôᚧir;櫰ot肻·Ƶusƀ;bd⣒ᤃ⣓戒Ā;uᴼ⣘;横ţ⣞⣡p;櫛ò−ðઁĀdp⣩⣮els;抧f;쀀𝕞Āct⣸⣽r;쀀𝓂pos»ᖝƀ;lm⤉⤊⤍䎼timap;抸ఀGLRVabcdefghijlmoprstuvw⥂⥓⥾⦉⦘⧚⧩⨕⨚⩘⩝⪃⪕⪤⪨⬄⬇⭄⭿⮮ⰴⱧⱼ⳩Āgt⥇⥋;쀀⋙̸Ā;v⥐௏쀀≫⃒ƀelt⥚⥲⥶ftĀar⥡⥧rrow;懍ightarrow;懎;쀀⋘̸Ā;v⥻ే쀀≪⃒ightarrow;懏ĀDd⦎⦓ash;抯ash;抮ʀbcnpt⦣⦧⦬⦱⧌la»˞ute;䅄g;쀀∠⃒ʀ;Eiop඄⦼⧀⧅⧈;쀀⩰̸d;쀀≋̸s;䅉roø඄urĀ;a⧓⧔普lĀ;s⧓ସǳ⧟\0⧣p肻 ଷmpĀ;e௹ఀʀaeouy⧴⧾⨃⨐⨓ǰ⧹\0⧻;橃on;䅈dil;䅆ngĀ;dൾ⨊ot;쀀⩭̸p;橂;䐽ash;怓΀;Aadqsxஒ⨩⨭⨻⩁⩅⩐rr;懗rĀhr⨳⨶k;椤Ā;oᏲᏰot;쀀≐̸uiöୣĀei⩊⩎ar;椨í஘istĀ;s஠டr;쀀𝔫ȀEest௅⩦⩹⩼ƀ;qs஼⩭௡ƀ;qs஼௅⩴lanô௢ií௪Ā;rஶ⪁»ஷƀAap⪊⪍⪑rò⥱rr;憮ar;櫲ƀ;svྍ⪜ྌĀ;d⪡⪢拼;拺cy;䑚΀AEadest⪷⪺⪾⫂⫅⫶⫹rò⥦;쀀≦̸rr;憚r;急Ȁ;fqs఻⫎⫣⫯tĀar⫔⫙rro÷⫁ightarro÷⪐ƀ;qs఻⪺⫪lanôౕĀ;sౕ⫴»శiíౝĀ;rవ⫾iĀ;eచథiäඐĀpt⬌⬑f;쀀𝕟膀¬;in⬙⬚⬶䂬nȀ;Edvஉ⬤⬨⬮;쀀⋹̸ot;쀀⋵̸ǡஉ⬳⬵;拷;拶iĀ;vಸ⬼ǡಸ⭁⭃;拾;拽ƀaor⭋⭣⭩rȀ;ast୻⭕⭚⭟lleì୻l;쀀⫽⃥;쀀∂̸lint;樔ƀ;ceಒ⭰⭳uåಥĀ;cಘ⭸Ā;eಒ⭽ñಘȀAait⮈⮋⮝⮧rò⦈rrƀ;cw⮔⮕⮙憛;쀀⤳̸;쀀↝̸ghtarrow»⮕riĀ;eೋೖ΀chimpqu⮽⯍⯙⬄୸⯤⯯Ȁ;cerല⯆ഷ⯉uå൅;쀀𝓃ortɭ⬅\0\0⯖ará⭖mĀ;e൮⯟Ā;q൴൳suĀbp⯫⯭å೸åഋƀbcp⯶ⰑⰙȀ;Ees⯿ⰀഢⰄ抄;쀀⫅̸etĀ;eഛⰋqĀ;qണⰀcĀ;eലⰗñസȀ;EesⰢⰣൟⰧ抅;쀀⫆̸etĀ;e൘ⰮqĀ;qൠⰣȀgilrⰽⰿⱅⱇìௗlde耻ñ䃱çృiangleĀlrⱒⱜeftĀ;eచⱚñదightĀ;eೋⱥñ೗Ā;mⱬⱭ䎽ƀ;esⱴⱵⱹ䀣ro;愖p;怇ҀDHadgilrsⲏⲔⲙⲞⲣⲰⲶⳓⳣash;抭arr;椄p;쀀≍⃒ash;抬ĀetⲨⲬ;쀀≥⃒;쀀>⃒nfin;槞ƀAetⲽⳁⳅrr;椂;쀀≤⃒Ā;rⳊⳍ쀀<⃒ie;쀀⊴⃒ĀAtⳘⳜrr;椃rie;쀀⊵⃒im;쀀∼⃒ƀAan⳰⳴ⴂrr;懖rĀhr⳺⳽k;椣Ā;oᏧᏥear;椧ቓ᪕\0\0\0\0\0\0\0\0\0\0\0\0\0ⴭ\0ⴸⵈⵠⵥ⵲ⶄᬇ\0\0ⶍⶫ\0ⷈⷎ\0ⷜ⸙⸫⸾⹃Ācsⴱ᪗ute耻ó䃳ĀiyⴼⵅrĀ;c᪞ⵂ耻ô䃴;䐾ʀabios᪠ⵒⵗǈⵚlac;䅑v;樸old;榼lig;䅓Ācr⵩⵭ir;榿;쀀𝔬ͯ⵹\0\0⵼\0ⶂn;䋛ave耻ò䃲;槁Ābmⶈ෴ar;榵Ȁacitⶕ⶘ⶥⶨrò᪀Āir⶝ⶠr;榾oss;榻nå๒;槀ƀaeiⶱⶵⶹcr;䅍ga;䏉ƀcdnⷀⷅǍron;䎿;榶pf;쀀𝕠ƀaelⷔ⷗ǒr;榷rp;榹΀;adiosvⷪⷫⷮ⸈⸍⸐⸖戨rò᪆Ȁ;efmⷷⷸ⸂⸅橝rĀ;oⷾⷿ愴f»ⷿ耻ª䂪耻º䂺gof;抶r;橖lope;橗;橛ƀclo⸟⸡⸧ò⸁ash耻ø䃸l;折iŬⸯ⸴de耻õ䃵esĀ;aǛ⸺s;樶ml耻ö䃶bar;挽ૡ⹞\0⹽\0⺀⺝\0⺢⺹\0\0⻋ຜ\0⼓\0\0⼫⾼\0⿈rȀ;astЃ⹧⹲຅脀¶;l⹭⹮䂶leìЃɩ⹸\0\0⹻m;櫳;櫽y;䐿rʀcimpt⺋⺏⺓ᡥ⺗nt;䀥od;䀮il;怰enk;怱r;쀀𝔭ƀimo⺨⺰⺴Ā;v⺭⺮䏆;䏕maô੶ne;明ƀ;tv⺿⻀⻈䏀chfork»´;䏖Āau⻏⻟nĀck⻕⻝kĀ;h⇴⻛;愎ö⇴sҀ;abcdemst⻳⻴ᤈ⻹⻽⼄⼆⼊⼎䀫cir;樣ir;樢Āouᵀ⼂;樥;橲n肻±ຝim;樦wo;樧ƀipu⼙⼠⼥ntint;樕f;쀀𝕡nd耻£䂣Ԁ;Eaceinosu່⼿⽁⽄⽇⾁⾉⾒⽾⾶;檳p;檷uå໙Ā;c໎⽌̀;acens່⽙⽟⽦⽨⽾pproø⽃urlyeñ໙ñ໎ƀaes⽯⽶⽺pprox;檹qq;檵im;拨iíໟmeĀ;s⾈ຮ怲ƀEas⽸⾐⽺ð⽵ƀdfp໬⾙⾯ƀals⾠⾥⾪lar;挮ine;挒urf;挓Ā;t໻⾴ï໻rel;抰Āci⿀⿅r;쀀𝓅;䏈ncsp;怈̀fiopsu⿚⋢⿟⿥⿫⿱r;쀀𝔮pf;쀀𝕢rime;恗cr;쀀𝓆ƀaeo⿸〉〓tĀei⿾々rnionóڰnt;樖stĀ;e【】䀿ñἙô༔઀ABHabcdefhilmnoprstux぀けさすムㄎㄫㅇㅢㅲㆎ㈆㈕㈤㈩㉘㉮㉲㊐㊰㊷ƀartぇおがròႳòϝail;検aròᱥar;楤΀cdenqrtとふへみわゔヌĀeuねぱ;쀀∽̱te;䅕iãᅮmptyv;榳gȀ;del࿑らるろ;榒;榥å࿑uo耻»䂻rր;abcfhlpstw࿜ガクシスゼゾダッデナp;極Ā;f࿠ゴs;椠;椳s;椞ë≝ð✮l;楅im;楴l;憣;憝Āaiパフil;椚oĀ;nホボ戶aló༞ƀabrョリヮrò៥rk;杳ĀakンヽcĀekヹ・;䁽;䁝Āes㄂㄄;榌lĀduㄊㄌ;榎;榐Ȁaeuyㄗㄜㄧㄩron;䅙Ādiㄡㄥil;䅗ì࿲âヺ;䑀Ȁclqsㄴㄷㄽㅄa;椷dhar;楩uoĀ;rȎȍh;憳ƀacgㅎㅟངlȀ;ipsླྀㅘㅛႜnåႻarôྩt;断ƀilrㅩဣㅮsht;楽;쀀𝔯ĀaoㅷㆆrĀduㅽㅿ»ѻĀ;l႑ㆄ;楬Ā;vㆋㆌ䏁;䏱ƀgns㆕ㇹㇼht̀ahlrstㆤㆰ㇂㇘㇤㇮rrowĀ;t࿜ㆭaéトarpoonĀduㆻㆿowîㅾp»႒eftĀah㇊㇐rrowó࿪arpoonóՑightarrows;應quigarro÷ニhreetimes;拌g;䋚ingdotseñἲƀahm㈍㈐㈓rò࿪aòՑ;怏oustĀ;a㈞㈟掱che»㈟mid;櫮Ȁabpt㈲㈽㉀㉒Ānr㈷㈺g;柭r;懾rëဃƀafl㉇㉊㉎r;榆;쀀𝕣us;樮imes;樵Āap㉝㉧rĀ;g㉣㉤䀩t;榔olint;樒arò㇣Ȁachq㉻㊀Ⴜ㊅quo;怺r;쀀𝓇Ābu・㊊oĀ;rȔȓƀhir㊗㊛㊠reåㇸmes;拊iȀ;efl㊪ၙᠡ㊫方tri;槎luhar;楨;愞ൡ㋕㋛㋟㌬㌸㍱\0㍺㎤\0\0㏬㏰\0㐨㑈㑚㒭㒱㓊㓱\0㘖\0\0㘳cute;䅛quï➺Ԁ;Eaceinpsyᇭ㋳㋵㋿㌂㌋㌏㌟㌦㌩;檴ǰ㋺\0㋼;檸on;䅡uåᇾĀ;dᇳ㌇il;䅟rc;䅝ƀEas㌖㌘㌛;檶p;檺im;择olint;樓iíሄ;䑁otƀ;be㌴ᵇ㌵担;橦΀Aacmstx㍆㍊㍗㍛㍞㍣㍭rr;懘rĀhr㍐㍒ë∨Ā;oਸ਼਴t耻§䂧i;䀻war;椩mĀin㍩ðnuóñt;朶rĀ;o㍶⁕쀀𝔰Ȁacoy㎂㎆㎑㎠rp;景Āhy㎋㎏cy;䑉;䑈rtɭ㎙\0\0㎜iäᑤaraì⹯耻­䂭Āgm㎨㎴maƀ;fv㎱㎲㎲䏃;䏂Ѐ;deglnprካ㏅㏉㏎㏖㏞㏡㏦ot;橪Ā;q኱ኰĀ;E㏓㏔檞;檠Ā;E㏛㏜檝;檟e;扆lus;樤arr;楲aròᄽȀaeit㏸㐈㐏㐗Āls㏽㐄lsetmé㍪hp;樳parsl;槤Ādlᑣ㐔e;挣Ā;e㐜㐝檪Ā;s㐢㐣檬;쀀⪬︀ƀflp㐮㐳㑂tcy;䑌Ā;b㐸㐹䀯Ā;a㐾㐿槄r;挿f;쀀𝕤aĀdr㑍ЂesĀ;u㑔㑕晠it»㑕ƀcsu㑠㑹㒟Āau㑥㑯pĀ;sᆈ㑫;쀀⊓︀pĀ;sᆴ㑵;쀀⊔︀uĀbp㑿㒏ƀ;esᆗᆜ㒆etĀ;eᆗ㒍ñᆝƀ;esᆨᆭ㒖etĀ;eᆨ㒝ñᆮƀ;afᅻ㒦ְrť㒫ֱ»ᅼaròᅈȀcemt㒹㒾㓂㓅r;쀀𝓈tmîñiì㐕aræᆾĀar㓎㓕rĀ;f㓔ឿ昆Āan㓚㓭ightĀep㓣㓪psiloîỠhé⺯s»⡒ʀbcmnp㓻㕞ሉ㖋㖎Ҁ;Edemnprs㔎㔏㔑㔕㔞㔣㔬㔱㔶抂;櫅ot;檽Ā;dᇚ㔚ot;櫃ult;櫁ĀEe㔨㔪;櫋;把lus;檿arr;楹ƀeiu㔽㕒㕕tƀ;en㔎㕅㕋qĀ;qᇚ㔏eqĀ;q㔫㔨m;櫇Ābp㕚㕜;櫕;櫓c̀;acensᇭ㕬㕲㕹㕻㌦pproø㋺urlyeñᇾñᇳƀaes㖂㖈㌛pproø㌚qñ㌗g;晪ڀ123;Edehlmnps㖩㖬㖯ሜ㖲㖴㗀㗉㗕㗚㗟㗨㗭耻¹䂹耻²䂲耻³䂳;櫆Āos㖹㖼t;檾ub;櫘Ā;dሢ㗅ot;櫄sĀou㗏㗒l;柉b;櫗arr;楻ult;櫂ĀEe㗤㗦;櫌;抋lus;櫀ƀeiu㗴㘉㘌tƀ;enሜ㗼㘂qĀ;qሢ㖲eqĀ;q㗧㗤m;櫈Ābp㘑㘓;櫔;櫖ƀAan㘜㘠㘭rr;懙rĀhr㘦㘨ë∮Ā;oਫ਩war;椪lig耻ß䃟௡㙑㙝㙠ዎ㙳㙹\0㙾㛂\0\0\0\0\0㛛㜃\0㜉㝬\0\0\0㞇ɲ㙖\0\0㙛get;挖;䏄rë๟ƀaey㙦㙫㙰ron;䅥dil;䅣;䑂lrec;挕r;쀀𝔱Ȁeiko㚆㚝㚵㚼ǲ㚋\0㚑eĀ4fኄኁaƀ;sv㚘㚙㚛䎸ym;䏑Ācn㚢㚲kĀas㚨㚮pproø዁im»ኬsðኞĀas㚺㚮ð዁rn耻þ䃾Ǭ̟㛆⋧es膀×;bd㛏㛐㛘䃗Ā;aᤏ㛕r;樱;樰ƀeps㛡㛣㜀á⩍Ȁ;bcf҆㛬㛰㛴ot;挶ir;櫱Ā;o㛹㛼쀀𝕥rk;櫚á㍢rime;怴ƀaip㜏㜒㝤dåቈ΀adempst㜡㝍㝀㝑㝗㝜㝟ngleʀ;dlqr㜰㜱㜶㝀㝂斵own»ᶻeftĀ;e⠀㜾ñम;扜ightĀ;e㊪㝋ñၚot;旬inus;樺lus;樹b;槍ime;樻ezium;揢ƀcht㝲㝽㞁Āry㝷㝻;쀀𝓉;䑆cy;䑛rok;䅧Āio㞋㞎xô᝷headĀlr㞗㞠eftarro÷ࡏightarrow»ཝऀAHabcdfghlmoprstuw㟐㟓㟗㟤㟰㟼㠎㠜㠣㠴㡑㡝㡫㢩㣌㣒㣪㣶ròϭar;楣Ācr㟜㟢ute耻ú䃺òᅐrǣ㟪\0㟭y;䑞ve;䅭Āiy㟵㟺rc耻û䃻;䑃ƀabh㠃㠆㠋ròᎭlac;䅱aòᏃĀir㠓㠘sht;楾;쀀𝔲rave耻ù䃹š㠧㠱rĀlr㠬㠮»ॗ»ႃlk;斀Āct㠹㡍ɯ㠿\0\0㡊rnĀ;e㡅㡆挜r»㡆op;挏ri;旸Āal㡖㡚cr;䅫肻¨͉Āgp㡢㡦on;䅳f;쀀𝕦̀adhlsuᅋ㡸㡽፲㢑㢠ownáᎳarpoonĀlr㢈㢌efô㠭ighô㠯iƀ;hl㢙㢚㢜䏅»ᏺon»㢚parrows;懈ƀcit㢰㣄㣈ɯ㢶\0\0㣁rnĀ;e㢼㢽挝r»㢽op;挎ng;䅯ri;旹cr;쀀𝓊ƀdir㣙㣝㣢ot;拰lde;䅩iĀ;f㜰㣨»᠓Āam㣯㣲rò㢨l耻ü䃼angle;榧ހABDacdeflnoprsz㤜㤟㤩㤭㦵㦸㦽㧟㧤㧨㧳㧹㧽㨁㨠ròϷarĀ;v㤦㤧櫨;櫩asèϡĀnr㤲㤷grt;榜΀eknprst㓣㥆㥋㥒㥝㥤㦖appá␕othinçẖƀhir㓫⻈㥙opô⾵Ā;hᎷ㥢ïㆍĀiu㥩㥭gmá㎳Ābp㥲㦄setneqĀ;q㥽㦀쀀⊊︀;쀀⫋︀setneqĀ;q㦏㦒쀀⊋︀;쀀⫌︀Āhr㦛㦟etá㚜iangleĀlr㦪㦯eft»थight»ၑy;䐲ash»ံƀelr㧄㧒㧗ƀ;beⷪ㧋㧏ar;抻q;扚lip;拮Ābt㧜ᑨaòᑩr;쀀𝔳tré㦮suĀbp㧯㧱»ജ»൙pf;쀀𝕧roð໻tré㦴Ācu㨆㨋r;쀀𝓋Ābp㨐㨘nĀEe㦀㨖»㥾nĀEe㦒㨞»㦐igzag;榚΀cefoprs㨶㨻㩖㩛㩔㩡㩪irc;䅵Ādi㩀㩑Ābg㩅㩉ar;機eĀ;qᗺ㩏;扙erp;愘r;쀀𝔴pf;쀀𝕨Ā;eᑹ㩦atèᑹcr;쀀𝓌ૣណ㪇\0㪋\0㪐㪛\0\0㪝㪨㪫㪯\0\0㫃㫎\0㫘ៜ៟tré៑r;쀀𝔵ĀAa㪔㪗ròσrò৶;䎾ĀAa㪡㪤ròθrò৫að✓is;拻ƀdptឤ㪵㪾Āfl㪺ឩ;쀀𝕩imåឲĀAa㫇㫊ròώròਁĀcq㫒ីr;쀀𝓍Āpt៖㫜ré។Ѐacefiosu㫰㫽㬈㬌㬑㬕㬛㬡cĀuy㫶㫻te耻ý䃽;䑏Āiy㬂㬆rc;䅷;䑋n耻¥䂥r;쀀𝔶cy;䑗pf;쀀𝕪cr;쀀𝓎Ācm㬦㬩y;䑎l耻ÿ䃿Ԁacdefhiosw㭂㭈㭔㭘㭤㭩㭭㭴㭺㮀cute;䅺Āay㭍㭒ron;䅾;䐷ot;䅼Āet㭝㭡træᕟa;䎶r;쀀𝔷cy;䐶grarr;懝pf;쀀𝕫cr;쀀𝓏Ājn㮅㮇;怍j;怌'.split("").map(e=>e.charCodeAt(0))),TMe=new Uint16Array("Ȁaglq	\x1Bɭ\0\0p;䀦os;䀧t;䀾t;䀼uot;䀢".split("").map(e=>e.charCodeAt(0)));var cP;const kMe=new Map([[0,65533],[128,8364],[130,8218],[131,402],[132,8222],[133,8230],[134,8224],[135,8225],[136,710],[137,8240],[138,352],[139,8249],[140,338],[142,381],[145,8216],[146,8217],[147,8220],[148,8221],[149,8226],[150,8211],[151,8212],[152,732],[153,8482],[154,353],[155,8250],[156,339],[158,382],[159,376]]),PMe=(cP=String.fromCodePoint)!==null&&cP!==void 0?cP:function(e){let t="";return e>65535&&(e-=65536,t+=String.fromCharCode(e>>>10&1023|55296),e=56320|e&1023),t+=String.fromCharCode(e),t};function MMe(e){var t;return e>=55296&&e<=57343||e>1114111?65533:(t=kMe.get(e))!==null&&t!==void 0?t:e}var no;(function(e){e[e.NUM=35]="NUM",e[e.SEMI=59]="SEMI",e[e.EQUALS=61]="EQUALS",e[e.ZERO=48]="ZERO",e[e.NINE=57]="NINE",e[e.LOWER_A=97]="LOWER_A",e[e.LOWER_F=102]="LOWER_F",e[e.LOWER_X=120]="LOWER_X",e[e.LOWER_Z=122]="LOWER_Z",e[e.UPPER_A=65]="UPPER_A",e[e.UPPER_F=70]="UPPER_F",e[e.UPPER_Z=90]="UPPER_Z"})(no||(no={}));const FMe=32;var Qv;(function(e){e[e.VALUE_LENGTH=49152]="VALUE_LENGTH",e[e.BRANCH_LENGTH=16256]="BRANCH_LENGTH",e[e.JUMP_TABLE=127]="JUMP_TABLE"})(Qv||(Qv={}));function SM(e){return e>=no.ZERO&&e<=no.NINE}function NMe(e){return e>=no.UPPER_A&&e<=no.UPPER_F||e>=no.LOWER_A&&e<=no.LOWER_F}function IMe(e){return e>=no.UPPER_A&&e<=no.UPPER_Z||e>=no.LOWER_A&&e<=no.LOWER_Z||SM(e)}function LMe(e){return e===no.EQUALS||IMe(e)}var Kl;(function(e){e[e.EntityStart=0]="EntityStart",e[e.NumericStart=1]="NumericStart",e[e.NumericDecimal=2]="NumericDecimal",e[e.NumericHex=3]="NumericHex",e[e.NamedEntity=4]="NamedEntity"})(Kl||(Kl={}));var Tv;(function(e){e[e.Legacy=0]="Legacy",e[e.Strict=1]="Strict",e[e.Attribute=2]="Attribute"})(Tv||(Tv={}));class BMe{constructor(t,n,r){this.decodeTree=t,this.emitCodePoint=n,this.errors=r,this.state=Kl.EntityStart,this.consumed=1,this.result=0,this.treeIndex=0,this.excess=1,this.decodeMode=Tv.Strict}startEntity(t){this.decodeMode=t,this.state=Kl.EntityStart,this.result=0,this.treeIndex=0,this.excess=1,this.consumed=1}write(t,n){switch(this.state){case Kl.EntityStart:return t.charCodeAt(n)===no.NUM?(this.state=Kl.NumericStart,this.consumed+=1,this.stateNumericStart(t,n+1)):(this.state=Kl.NamedEntity,this.stateNamedEntity(t,n));case Kl.NumericStart:return this.stateNumericStart(t,n);case Kl.NumericDecimal:return this.stateNumericDecimal(t,n);case Kl.NumericHex:return this.stateNumericHex(t,n);case Kl.NamedEntity:return this.stateNamedEntity(t,n)}}stateNumericStart(t,n){return n>=t.length?-1:(t.charCodeAt(n)|FMe)===no.LOWER_X?(this.state=Kl.NumericHex,this.consumed+=1,this.stateNumericHex(t,n+1)):(this.state=Kl.NumericDecimal,this.stateNumericDecimal(t,n))}addToNumericResult(t,n,r,i){if(n!==r){const a=r-n;this.result=this.result*Math.pow(i,a)+parseInt(t.substr(n,a),i),this.consumed+=a}}stateNumericHex(t,n){const r=n;for(;n<t.length;){const i=t.charCodeAt(n);if(SM(i)||NMe(i))n+=1;else return this.addToNumericResult(t,r,n,16),this.emitNumericEntity(i,3)}return this.addToNumericResult(t,r,n,16),-1}stateNumericDecimal(t,n){const r=n;for(;n<t.length;){const i=t.charCodeAt(n);if(SM(i))n+=1;else return this.addToNumericResult(t,r,n,10),this.emitNumericEntity(i,2)}return this.addToNumericResult(t,r,n,10),-1}emitNumericEntity(t,n){var r;if(this.consumed<=n)return(r=this.errors)===null||r===void 0||r.absenceOfDigitsInNumericCharacterReference(this.consumed),0;if(t===no.SEMI)this.consumed+=1;else if(this.decodeMode===Tv.Strict)return 0;return this.emitCodePoint(MMe(this.result),this.consumed),this.errors&&(t!==no.SEMI&&this.errors.missingSemicolonAfterCharacterReference(),this.errors.validateNumericCharacterReference(this.result)),this.consumed}stateNamedEntity(t,n){const{decodeTree:r}=this;let i=r[this.treeIndex],a=(i&Qv.VALUE_LENGTH)>>14;for(;n<t.length;n++,this.excess++){const u=t.charCodeAt(n);if(this.treeIndex=QMe(r,i,this.treeIndex+Math.max(1,a),u),this.treeIndex<0)return this.result===0||this.decodeMode===Tv.Attribute&&(a===0||LMe(u))?0:this.emitNotTerminatedNamedEntity();if(i=r[this.treeIndex],a=(i&Qv.VALUE_LENGTH)>>14,a!==0){if(u===no.SEMI)return this.emitNamedEntityData(this.treeIndex,a,this.consumed+this.excess);this.decodeMode!==Tv.Strict&&(this.result=this.treeIndex,this.consumed+=this.excess,this.excess=0)}}return-1}emitNotTerminatedNamedEntity(){var t;const{result:n,decodeTree:r}=this,i=(r[n]&Qv.VALUE_LENGTH)>>14;return this.emitNamedEntityData(n,i,this.consumed),(t=this.errors)===null||t===void 0||t.missingSemicolonAfterCharacterReference(),this.consumed}emitNamedEntityData(t,n,r){const{decodeTree:i}=this;return this.emitCodePoint(n===1?i[t]&~Qv.VALUE_LENGTH:i[t+1],r),n===3&&this.emitCodePoint(i[t+2],r),r}end(){var t;switch(this.state){case Kl.NamedEntity:return this.result!==0&&(this.decodeMode!==Tv.Attribute||this.result===this.treeIndex)?this.emitNotTerminatedNamedEntity():0;case Kl.NumericDecimal:return this.emitNumericEntity(0,2);case Kl.NumericHex:return this.emitNumericEntity(0,3);case Kl.NumericStart:return(t=this.errors)===null||t===void 0||t.absenceOfDigitsInNumericCharacterReference(this.consumed),0;case Kl.EntityStart:return 0}}}function Y0e(e){let t="";const n=new BMe(e,r=>t+=PMe(r));return function(i,a){let u=0,l=0;for(;(l=i.indexOf("&",l))>=0;){t+=i.slice(u,l),n.startEntity(a);const s=n.write(i,l+1);if(s<0){u=l+n.end();break}u=l+s,l=s===0?u+1:u}const o=t+i.slice(u);return t="",o}}function QMe(e,t,n,r){const i=(t&Qv.BRANCH_LENGTH)>>7,a=t&Qv.JUMP_TABLE;if(i===0)return a!==0&&r===a?n:-1;if(a){const o=r-a;return o<0||o>=i?-1:e[n+o]-1}let u=n,l=u+i-1;for(;u<=l;){const o=u+l>>>1,s=e[o];if(s<r)u=o+1;else if(s>r)l=o-1;else return e[o+i]}return-1}const zMe=Y0e(AMe);Y0e(TMe);function G0e(e,t=Tv.Legacy){return zMe(e,t)}function qMe(e){return Object.prototype.toString.call(e)}function YI(e){return qMe(e)==="[object String]"}const VMe=Object.prototype.hasOwnProperty;function UMe(e,t){return VMe.call(e,t)}function Ow(e){return Array.prototype.slice.call(arguments,1).forEach(function(n){if(n){if(typeof n!="object")throw new TypeError(n+"must be object");Object.keys(n).forEach(function(r){e[r]=n[r]})}}),e}function K0e(e,t,n){return[].concat(e.slice(0,t),n,e.slice(t+1))}function GI(e){return!(e>=55296&&e<=57343||e>=64976&&e<=65007||(e&65535)===65535||(e&65535)===65534||e>=0&&e<=8||e===11||e>=14&&e<=31||e>=127&&e<=159||e>1114111)}function C$(e){if(e>65535){e-=65536;const t=55296+(e>>10),n=56320+(e&1023);return String.fromCharCode(t,n)}return String.fromCharCode(e)}const W0e=/\\([!"#$%&'()*+,\-./:;<=>?@[\\\]^_`{|}~])/g,jMe=/&([a-z#][a-z0-9]{1,31});/gi,ZMe=new RegExp(W0e.source+"|"+jMe.source,"gi"),HMe=/^#((?:x[a-f0-9]{1,8}|[0-9]{1,8}))$/i;function XMe(e,t){if(t.charCodeAt(0)===35&&HMe.test(t)){const r=t[1].toLowerCase()==="x"?parseInt(t.slice(2),16):parseInt(t.slice(1),10);return GI(r)?C$(r):e}const n=G0e(e);return n!==e?n:e}function YMe(e){return e.indexOf("\\")<0?e:e.replace(W0e,"$1")}function M3(e){return e.indexOf("\\")<0&&e.indexOf("&")<0?e:e.replace(ZMe,function(t,n,r){return n||XMe(t,r)})}const GMe=/[&<>"]/,KMe=/[&<>"]/g,WMe={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;"};function JMe(e){return WMe[e]}function ay(e){return GMe.test(e)?e.replace(KMe,JMe):e}const eFe=/[.?*+^$[\]\\(){}|-]/g;function tFe(e){return e.replace(eFe,"\\$&")}function xa(e){switch(e){case 9:case 32:return!0}return!1}function Fx(e){if(e>=8192&&e<=8202)return!0;switch(e){case 9:case 10:case 11:case 12:case 13:case 32:case 160:case 5760:case 8239:case 8287:case 12288:return!0}return!1}function Nx(e){return XI.test(e)||H0e.test(e)}function Ix(e){switch(e){case 33:case 34:case 35:case 36:case 37:case 38:case 39:case 40:case 41:case 42:case 43:case 44:case 45:case 46:case 47:case 58:case 59:case 60:case 61:case 62:case 63:case 64:case 91:case 92:case 93:case 94:case 95:case 96:case 123:case 124:case 125:case 126:return!0;default:return!1}}function xw(e){return e=e.trim().replace(/\s+/g," "),"ẞ".toLowerCase()==="Ṿ"&&(e=e.replace(/ẞ/g,"ß")),e.toLowerCase().toUpperCase()}const nFe={mdurl:CMe,ucmicro:RMe},rFe=Object.freeze(Object.defineProperty({__proto__:null,arrayReplaceAt:K0e,assign:Ow,escapeHtml:ay,escapeRE:tFe,fromCodePoint:C$,has:UMe,isMdAsciiPunct:Ix,isPunctChar:Nx,isSpace:xa,isString:YI,isValidEntityCode:GI,isWhiteSpace:Fx,lib:nFe,normalizeReference:xw,unescapeAll:M3,unescapeMd:YMe},Symbol.toStringTag,{value:"Module"}));function iFe(e,t,n){let r,i,a,u;const l=e.posMax,o=e.pos;for(e.pos=t+1,r=1;e.pos<l;){if(a=e.src.charCodeAt(e.pos),a===93&&(r--,r===0)){i=!0;break}if(u=e.pos,e.md.inline.skipToken(e),a===91){if(u===e.pos-1)r++;else if(n)return e.pos=o,-1}}let s=-1;return i&&(s=e.pos),e.pos=o,s}function aFe(e,t,n){let r,i=t;const a={ok:!1,pos:0,str:""};if(e.charCodeAt(i)===60){for(i++;i<n;){if(r=e.charCodeAt(i),r===10||r===60)return a;if(r===62)return a.pos=i+1,a.str=M3(e.slice(t+1,i)),a.ok=!0,a;if(r===92&&i+1<n){i+=2;continue}i++}return a}let u=0;for(;i<n&&(r=e.charCodeAt(i),!(r===32||r<32||r===127));){if(r===92&&i+1<n){if(e.charCodeAt(i+1)===32)break;i+=2;continue}if(r===40&&(u++,u>32))return a;if(r===41){if(u===0)break;u--}i++}return t===i||u!==0||(a.str=M3(e.slice(t,i)),a.pos=i,a.ok=!0),a}function uFe(e,t,n,r){let i,a=t;const u={ok:!1,can_continue:!1,pos:0,str:"",marker:0};if(r)u.str=r.str,u.marker=r.marker;else{if(a>=n)return u;let l=e.charCodeAt(a);if(l!==34&&l!==39&&l!==40)return u;t++,a++,l===40&&(l=41),u.marker=l}for(;a<n;){if(i=e.charCodeAt(a),i===u.marker)return u.pos=a+1,u.str+=M3(e.slice(t,a)),u.ok=!0,u;if(i===40&&u.marker===41)return u;i===92&&a+1<n&&a++,a++}return u.can_continue=!0,u.str+=M3(e.slice(t,a)),u}const lFe=Object.freeze(Object.defineProperty({__proto__:null,parseLinkDestination:aFe,parseLinkLabel:iFe,parseLinkTitle:uFe},Symbol.toStringTag,{value:"Module"})),V0={};V0.code_inline=function(e,t,n,r,i){const a=e[t];return"<code"+i.renderAttrs(a)+">"+ay(a.content)+"</code>"};V0.code_block=function(e,t,n,r,i){const a=e[t];return"<pre"+i.renderAttrs(a)+"><code>"+ay(e[t].content)+`</code></pre>
`};V0.fence=function(e,t,n,r,i){const a=e[t],u=a.info?M3(a.info).trim():"";let l="",o="";if(u){const c=u.split(/(\s+)/g);l=c[0],o=c.slice(2).join("")}let s;if(n.highlight?s=n.highlight(a.content,l,o)||ay(a.content):s=ay(a.content),s.indexOf("<pre")===0)return s+`
`;if(u){const c=a.attrIndex("class"),d=a.attrs?a.attrs.slice():[];c<0?d.push(["class",n.langPrefix+l]):(d[c]=d[c].slice(),d[c][1]+=" "+n.langPrefix+l);const h={attrs:d};return`<pre><code${i.renderAttrs(h)}>${s}</code></pre>
`}return`<pre><code${i.renderAttrs(a)}>${s}</code></pre>
`};V0.image=function(e,t,n,r,i){const a=e[t];return a.attrs[a.attrIndex("alt")][1]=i.renderInlineAsText(a.children,n,r),i.renderToken(e,t,n)};V0.hardbreak=function(e,t,n){return n.xhtmlOut?`<br />
`:`<br>
`};V0.softbreak=function(e,t,n){return n.breaks?n.xhtmlOut?`<br />
`:`<br>
`:`
`};V0.text=function(e,t){return ay(e[t].content)};V0.html_block=function(e,t){return e[t].content};V0.html_inline=function(e,t){return e[t].content};function i4(){this.rules=Ow({},V0)}i4.prototype.renderAttrs=function(t){let n,r,i;if(!t.attrs)return"";for(i="",n=0,r=t.attrs.length;n<r;n++)i+=" "+ay(t.attrs[n][0])+'="'+ay(t.attrs[n][1])+'"';return i};i4.prototype.renderToken=function(t,n,r){const i=t[n];let a="";if(i.hidden)return"";i.block&&i.nesting!==-1&&n&&t[n-1].hidden&&(a+=`
`),a+=(i.nesting===-1?"</":"<")+i.tag,a+=this.renderAttrs(i),i.nesting===0&&r.xhtmlOut&&(a+=" /");let u=!1;if(i.block&&(u=!0,i.nesting===1&&n+1<t.length)){const l=t[n+1];(l.type==="inline"||l.hidden||l.nesting===-1&&l.tag===i.tag)&&(u=!1)}return a+=u?`>
`:">",a};i4.prototype.renderInline=function(e,t,n){let r="";const i=this.rules;for(let a=0,u=e.length;a<u;a++){const l=e[a].type;typeof i[l]<"u"?r+=i[l](e,a,t,n,this):r+=this.renderToken(e,a,t)}return r};i4.prototype.renderInlineAsText=function(e,t,n){let r="";for(let i=0,a=e.length;i<a;i++)switch(e[i].type){case"text":r+=e[i].content;break;case"image":r+=this.renderInlineAsText(e[i].children,t,n);break;case"html_inline":case"html_block":r+=e[i].content;break;case"softbreak":case"hardbreak":r+=`
`;break}return r};i4.prototype.render=function(e,t,n){let r="";const i=this.rules;for(let a=0,u=e.length;a<u;a++){const l=e[a].type;l==="inline"?r+=this.renderInline(e[a].children,t,n):typeof i[l]<"u"?r+=i[l](e,a,t,n,this):r+=this.renderToken(e,a,t,n)}return r};function ff(){this.__rules__=[],this.__cache__=null}ff.prototype.__find__=function(e){for(let t=0;t<this.__rules__.length;t++)if(this.__rules__[t].name===e)return t;return-1};ff.prototype.__compile__=function(){const e=this,t=[""];e.__rules__.forEach(function(n){n.enabled&&n.alt.forEach(function(r){t.indexOf(r)<0&&t.push(r)})}),e.__cache__={},t.forEach(function(n){e.__cache__[n]=[],e.__rules__.forEach(function(r){r.enabled&&(n&&r.alt.indexOf(n)<0||e.__cache__[n].push(r.fn))})})};ff.prototype.at=function(e,t,n){const r=this.__find__(e),i=n||{};if(r===-1)throw new Error("Parser rule not found: "+e);this.__rules__[r].fn=t,this.__rules__[r].alt=i.alt||[],this.__cache__=null};ff.prototype.before=function(e,t,n,r){const i=this.__find__(e),a=r||{};if(i===-1)throw new Error("Parser rule not found: "+e);this.__rules__.splice(i,0,{name:t,enabled:!0,fn:n,alt:a.alt||[]}),this.__cache__=null};ff.prototype.after=function(e,t,n,r){const i=this.__find__(e),a=r||{};if(i===-1)throw new Error("Parser rule not found: "+e);this.__rules__.splice(i+1,0,{name:t,enabled:!0,fn:n,alt:a.alt||[]}),this.__cache__=null};ff.prototype.push=function(e,t,n){const r=n||{};this.__rules__.push({name:e,enabled:!0,fn:t,alt:r.alt||[]}),this.__cache__=null};ff.prototype.enable=function(e,t){Array.isArray(e)||(e=[e]);const n=[];return e.forEach(function(r){const i=this.__find__(r);if(i<0){if(t)return;throw new Error("Rules manager: invalid rule name "+r)}this.__rules__[i].enabled=!0,n.push(r)},this),this.__cache__=null,n};ff.prototype.enableOnly=function(e,t){Array.isArray(e)||(e=[e]),this.__rules__.forEach(function(n){n.enabled=!1}),this.enable(e,t)};ff.prototype.disable=function(e,t){Array.isArray(e)||(e=[e]);const n=[];return e.forEach(function(r){const i=this.__find__(r);if(i<0){if(t)return;throw new Error("Rules manager: invalid rule name "+r)}this.__rules__[i].enabled=!1,n.push(r)},this),this.__cache__=null,n};ff.prototype.getRules=function(e){return this.__cache__===null&&this.__compile__(),this.__cache__[e]||[]};function vp(e,t,n){this.type=e,this.tag=t,this.attrs=null,this.map=null,this.nesting=n,this.level=0,this.children=null,this.content="",this.markup="",this.info="",this.meta=null,this.block=!1,this.hidden=!1}vp.prototype.attrIndex=function(t){if(!this.attrs)return-1;const n=this.attrs;for(let r=0,i=n.length;r<i;r++)if(n[r][0]===t)return r;return-1};vp.prototype.attrPush=function(t){this.attrs?this.attrs.push(t):this.attrs=[t]};vp.prototype.attrSet=function(t,n){const r=this.attrIndex(t),i=[t,n];r<0?this.attrPush(i):this.attrs[r]=i};vp.prototype.attrGet=function(t){const n=this.attrIndex(t);let r=null;return n>=0&&(r=this.attrs[n][1]),r};vp.prototype.attrJoin=function(t,n){const r=this.attrIndex(t);r<0?this.attrPush([t,n]):this.attrs[r][1]=this.attrs[r][1]+" "+n};function J0e(e,t,n){this.src=e,this.env=n,this.tokens=[],this.inlineMode=!1,this.md=t}J0e.prototype.Token=vp;const oFe=/\r\n?|\n/g,sFe=/\0/g;function cFe(e){let t;t=e.src.replace(oFe,`
`),t=t.replace(sFe,"�"),e.src=t}function fFe(e){let t;e.inlineMode?(t=new e.Token("inline","",0),t.content=e.src,t.map=[0,1],t.children=[],e.tokens.push(t)):e.md.block.parse(e.src,e.md,e.env,e.tokens)}function dFe(e){const t=e.tokens;for(let n=0,r=t.length;n<r;n++){const i=t[n];i.type==="inline"&&e.md.inline.parse(i.content,e.md,e.env,i.children)}}function hFe(e){return/^<a[>\s]/i.test(e)}function pFe(e){return/^<\/a\s*>/i.test(e)}function mFe(e){const t=e.tokens;if(e.md.options.linkify)for(let n=0,r=t.length;n<r;n++){if(t[n].type!=="inline"||!e.md.linkify.pretest(t[n].content))continue;let i=t[n].children,a=0;for(let u=i.length-1;u>=0;u--){const l=i[u];if(l.type==="link_close"){for(u--;i[u].level!==l.level&&i[u].type!=="link_open";)u--;continue}if(l.type==="html_inline"&&(hFe(l.content)&&a>0&&a--,pFe(l.content)&&a++),!(a>0)&&l.type==="text"&&e.md.linkify.test(l.content)){const o=l.content;let s=e.md.linkify.match(o);const c=[];let d=l.level,h=0;s.length>0&&s[0].index===0&&u>0&&i[u-1].type==="text_special"&&(s=s.slice(1));for(let m=0;m<s.length;m++){const y=s[m].url,v=e.md.normalizeLink(y);if(!e.md.validateLink(v))continue;let _=s[m].text;s[m].schema?s[m].schema==="mailto:"&&!/^mailto:/i.test(_)?_=e.md.normalizeLinkText("mailto:"+_).replace(/^mailto:/,""):_=e.md.normalizeLinkText(_):_=e.md.normalizeLinkText("http://"+_).replace(/^http:\/\//,"");const S=s[m].index;if(S>h){const R=new e.Token("text","",0);R.content=o.slice(h,S),R.level=d,c.push(R)}const E=new e.Token("link_open","a",1);E.attrs=[["href",v]],E.level=d++,E.markup="linkify",E.info="auto",c.push(E);const C=new e.Token("text","",0);C.content=_,C.level=d,c.push(C);const T=new e.Token("link_close","a",-1);T.level=--d,T.markup="linkify",T.info="auto",c.push(T),h=s[m].lastIndex}if(h<o.length){const m=new e.Token("text","",0);m.content=o.slice(h),m.level=d,c.push(m)}t[n].children=i=K0e(i,u,c)}}}}const eme=/\+-|\.\.|\?\?\?\?|!!!!|,,|--/,gFe=/\((c|tm|r)\)/i,vFe=/\((c|tm|r)\)/ig,yFe={c:"©",r:"®",tm:"™"};function bFe(e,t){return yFe[t.toLowerCase()]}function OFe(e){let t=0;for(let n=e.length-1;n>=0;n--){const r=e[n];r.type==="text"&&!t&&(r.content=r.content.replace(vFe,bFe)),r.type==="link_open"&&r.info==="auto"&&t--,r.type==="link_close"&&r.info==="auto"&&t++}}function xFe(e){let t=0;for(let n=e.length-1;n>=0;n--){const r=e[n];r.type==="text"&&!t&&eme.test(r.content)&&(r.content=r.content.replace(/\+-/g,"±").replace(/\.{2,}/g,"…").replace(/([?!])…/g,"$1..").replace(/([?!]){4,}/g,"$1$1$1").replace(/,{2,}/g,",").replace(/(^|[^-])---(?=[^-]|$)/mg,"$1—").replace(/(^|\s)--(?=\s|$)/mg,"$1–").replace(/(^|[^-\s])--(?=[^-\s]|$)/mg,"$1–")),r.type==="link_open"&&r.info==="auto"&&t--,r.type==="link_close"&&r.info==="auto"&&t++}}function SFe(e){let t;if(e.md.options.typographer)for(t=e.tokens.length-1;t>=0;t--)e.tokens[t].type==="inline"&&(gFe.test(e.tokens[t].content)&&OFe(e.tokens[t].children),eme.test(e.tokens[t].content)&&xFe(e.tokens[t].children))}const _Fe=/['"]/,hX=/['"]/g,pX="’";function dE(e,t,n){return e.slice(0,t)+n+e.slice(t+1)}function EFe(e,t){let n;const r=[];for(let i=0;i<e.length;i++){const a=e[i],u=e[i].level;for(n=r.length-1;n>=0&&!(r[n].level<=u);n--);if(r.length=n+1,a.type!=="text")continue;let l=a.content,o=0,s=l.length;e:for(;o<s;){hX.lastIndex=o;const c=hX.exec(l);if(!c)break;let d=!0,h=!0;o=c.index+1;const m=c[0]==="'";let y=32;if(c.index-1>=0)y=l.charCodeAt(c.index-1);else for(n=i-1;n>=0&&!(e[n].type==="softbreak"||e[n].type==="hardbreak");n--)if(e[n].content){y=e[n].content.charCodeAt(e[n].content.length-1);break}let v=32;if(o<s)v=l.charCodeAt(o);else for(n=i+1;n<e.length&&!(e[n].type==="softbreak"||e[n].type==="hardbreak");n++)if(e[n].content){v=e[n].content.charCodeAt(0);break}const _=Ix(y)||Nx(String.fromCharCode(y)),S=Ix(v)||Nx(String.fromCharCode(v)),E=Fx(y),C=Fx(v);if(C?d=!1:S&&(E||_||(d=!1)),E?h=!1:_&&(C||S||(h=!1)),v===34&&c[0]==='"'&&y>=48&&y<=57&&(h=d=!1),d&&h&&(d=_,h=S),!d&&!h){m&&(a.content=dE(a.content,c.index,pX));continue}if(h)for(n=r.length-1;n>=0;n--){let T=r[n];if(r[n].level<u)break;if(T.single===m&&r[n].level===u){T=r[n];let R,$;m?(R=t.md.options.quotes[2],$=t.md.options.quotes[3]):(R=t.md.options.quotes[0],$=t.md.options.quotes[1]),a.content=dE(a.content,c.index,$),e[T.token].content=dE(e[T.token].content,T.pos,R),o+=$.length-1,T.token===i&&(o+=R.length-1),l=a.content,s=l.length,r.length=n;continue e}}d?r.push({token:i,pos:c.index,single:m,level:u}):h&&m&&(a.content=dE(a.content,c.index,pX))}}}function DFe(e){if(e.md.options.typographer)for(let t=e.tokens.length-1;t>=0;t--)e.tokens[t].type!=="inline"||!_Fe.test(e.tokens[t].content)||EFe(e.tokens[t].children,e)}function $Fe(e){let t,n;const r=e.tokens,i=r.length;for(let a=0;a<i;a++){if(r[a].type!=="inline")continue;const u=r[a].children,l=u.length;for(t=0;t<l;t++)u[t].type==="text_special"&&(u[t].type="text");for(t=n=0;t<l;t++)u[t].type==="text"&&t+1<l&&u[t+1].type==="text"?u[t+1].content=u[t].content+u[t+1].content:(t!==n&&(u[n]=u[t]),n++);t!==n&&(u.length=n)}}const fP=[["normalize",cFe],["block",fFe],["inline",dFe],["linkify",mFe],["replacements",SFe],["smartquotes",DFe],["text_join",$Fe]];function KI(){this.ruler=new ff;for(let e=0;e<fP.length;e++)this.ruler.push(fP[e][0],fP[e][1])}KI.prototype.process=function(e){const t=this.ruler.getRules("");for(let n=0,r=t.length;n<r;n++)t[n](e)};KI.prototype.State=J0e;function U0(e,t,n,r){this.src=e,this.md=t,this.env=n,this.tokens=r,this.bMarks=[],this.eMarks=[],this.tShift=[],this.sCount=[],this.bsCount=[],this.blkIndent=0,this.line=0,this.lineMax=0,this.tight=!1,this.ddIndent=-1,this.listIndent=-1,this.parentType="root",this.level=0;const i=this.src;for(let a=0,u=0,l=0,o=0,s=i.length,c=!1;u<s;u++){const d=i.charCodeAt(u);if(!c)if(xa(d)){l++,d===9?o+=4-o%4:o++;continue}else c=!0;(d===10||u===s-1)&&(d!==10&&u++,this.bMarks.push(a),this.eMarks.push(u),this.tShift.push(l),this.sCount.push(o),this.bsCount.push(0),c=!1,l=0,o=0,a=u+1)}this.bMarks.push(i.length),this.eMarks.push(i.length),this.tShift.push(0),this.sCount.push(0),this.bsCount.push(0),this.lineMax=this.bMarks.length-1}U0.prototype.push=function(e,t,n){const r=new vp(e,t,n);return r.block=!0,n<0&&this.level--,r.level=this.level,n>0&&this.level++,this.tokens.push(r),r};U0.prototype.isEmpty=function(t){return this.bMarks[t]+this.tShift[t]>=this.eMarks[t]};U0.prototype.skipEmptyLines=function(t){for(let n=this.lineMax;t<n&&!(this.bMarks[t]+this.tShift[t]<this.eMarks[t]);t++);return t};U0.prototype.skipSpaces=function(t){for(let n=this.src.length;t<n;t++){const r=this.src.charCodeAt(t);if(!xa(r))break}return t};U0.prototype.skipSpacesBack=function(t,n){if(t<=n)return t;for(;t>n;)if(!xa(this.src.charCodeAt(--t)))return t+1;return t};U0.prototype.skipChars=function(t,n){for(let r=this.src.length;t<r&&this.src.charCodeAt(t)===n;t++);return t};U0.prototype.skipCharsBack=function(t,n,r){if(t<=r)return t;for(;t>r;)if(n!==this.src.charCodeAt(--t))return t+1;return t};U0.prototype.getLines=function(t,n,r,i){if(t>=n)return"";const a=new Array(n-t);for(let u=0,l=t;l<n;l++,u++){let o=0;const s=this.bMarks[l];let c=s,d;for(l+1<n||i?d=this.eMarks[l]+1:d=this.eMarks[l];c<d&&o<r;){const h=this.src.charCodeAt(c);if(xa(h))h===9?o+=4-(o+this.bsCount[l])%4:o++;else if(c-s<this.tShift[l])o++;else break;c++}o>r?a[u]=new Array(o-r+1).join(" ")+this.src.slice(c,d):a[u]=this.src.slice(c,d)}return a.join("")};U0.prototype.Token=vp;const CFe=65536;function dP(e,t){const n=e.bMarks[t]+e.tShift[t],r=e.eMarks[t];return e.src.slice(n,r)}function mX(e){const t=[],n=e.length;let r=0,i=e.charCodeAt(r),a=!1,u=0,l="";for(;r<n;)i===124&&(a?(l+=e.substring(u,r-1),u=r):(t.push(l+e.substring(u,r)),l="",u=r+1)),a=i===92,r++,i=e.charCodeAt(r);return t.push(l+e.substring(u)),t}function wFe(e,t,n,r){if(t+2>n)return!1;let i=t+1;if(e.sCount[i]<e.blkIndent||e.sCount[i]-e.blkIndent>=4)return!1;let a=e.bMarks[i]+e.tShift[i];if(a>=e.eMarks[i])return!1;const u=e.src.charCodeAt(a++);if(u!==124&&u!==45&&u!==58||a>=e.eMarks[i])return!1;const l=e.src.charCodeAt(a++);if(l!==124&&l!==45&&l!==58&&!xa(l)||u===45&&xa(l))return!1;for(;a<e.eMarks[i];){const T=e.src.charCodeAt(a);if(T!==124&&T!==45&&T!==58&&!xa(T))return!1;a++}let o=dP(e,t+1),s=o.split("|");const c=[];for(let T=0;T<s.length;T++){const R=s[T].trim();if(!R){if(T===0||T===s.length-1)continue;return!1}if(!/^:?-+:?$/.test(R))return!1;R.charCodeAt(R.length-1)===58?c.push(R.charCodeAt(0)===58?"center":"right"):R.charCodeAt(0)===58?c.push("left"):c.push("")}if(o=dP(e,t).trim(),o.indexOf("|")===-1||e.sCount[t]-e.blkIndent>=4)return!1;s=mX(o),s.length&&s[0]===""&&s.shift(),s.length&&s[s.length-1]===""&&s.pop();const d=s.length;if(d===0||d!==c.length)return!1;if(r)return!0;const h=e.parentType;e.parentType="table";const m=e.md.block.ruler.getRules("blockquote"),y=e.push("table_open","table",1),v=[t,0];y.map=v;const _=e.push("thead_open","thead",1);_.map=[t,t+1];const S=e.push("tr_open","tr",1);S.map=[t,t+1];for(let T=0;T<s.length;T++){const R=e.push("th_open","th",1);c[T]&&(R.attrs=[["style","text-align:"+c[T]]]);const $=e.push("inline","",0);$.content=s[T].trim(),$.children=[],e.push("th_close","th",-1)}e.push("tr_close","tr",-1),e.push("thead_close","thead",-1);let E,C=0;for(i=t+2;i<n&&!(e.sCount[i]<e.blkIndent);i++){let T=!1;for(let $=0,k=m.length;$<k;$++)if(m[$](e,i,n,!0)){T=!0;break}if(T||(o=dP(e,i).trim(),!o)||e.sCount[i]-e.blkIndent>=4||(s=mX(o),s.length&&s[0]===""&&s.shift(),s.length&&s[s.length-1]===""&&s.pop(),C+=d-s.length,C>CFe))break;if(i===t+2){const $=e.push("tbody_open","tbody",1);$.map=E=[t+2,0]}const R=e.push("tr_open","tr",1);R.map=[i,i+1];for(let $=0;$<d;$++){const k=e.push("td_open","td",1);c[$]&&(k.attrs=[["style","text-align:"+c[$]]]);const F=e.push("inline","",0);F.content=s[$]?s[$].trim():"",F.children=[],e.push("td_close","td",-1)}e.push("tr_close","tr",-1)}return E&&(e.push("tbody_close","tbody",-1),E[1]=i),e.push("table_close","table",-1),v[1]=i,e.parentType=h,e.line=i,!0}function RFe(e,t,n){if(e.sCount[t]-e.blkIndent<4)return!1;let r=t+1,i=r;for(;r<n;){if(e.isEmpty(r)){r++;continue}if(e.sCount[r]-e.blkIndent>=4){r++,i=r;continue}break}e.line=i;const a=e.push("code_block","code",0);return a.content=e.getLines(t,i,4+e.blkIndent,!1)+`
`,a.map=[t,e.line],!0}function AFe(e,t,n,r){let i=e.bMarks[t]+e.tShift[t],a=e.eMarks[t];if(e.sCount[t]-e.blkIndent>=4||i+3>a)return!1;const u=e.src.charCodeAt(i);if(u!==126&&u!==96)return!1;let l=i;i=e.skipChars(i,u);let o=i-l;if(o<3)return!1;const s=e.src.slice(l,i),c=e.src.slice(i,a);if(u===96&&c.indexOf(String.fromCharCode(u))>=0)return!1;if(r)return!0;let d=t,h=!1;for(;d++,!(d>=n||(i=l=e.bMarks[d]+e.tShift[d],a=e.eMarks[d],i<a&&e.sCount[d]<e.blkIndent));)if(e.src.charCodeAt(i)===u&&!(e.sCount[d]-e.blkIndent>=4)&&(i=e.skipChars(i,u),!(i-l<o)&&(i=e.skipSpaces(i),!(i<a)))){h=!0;break}o=e.sCount[t],e.line=d+(h?1:0);const m=e.push("fence","code",0);return m.info=c,m.content=e.getLines(t+1,d,o,!0),m.markup=s,m.map=[t,e.line],!0}function TFe(e,t,n,r){let i=e.bMarks[t]+e.tShift[t],a=e.eMarks[t];const u=e.lineMax;if(e.sCount[t]-e.blkIndent>=4||e.src.charCodeAt(i)!==62)return!1;if(r)return!0;const l=[],o=[],s=[],c=[],d=e.md.block.ruler.getRules("blockquote"),h=e.parentType;e.parentType="blockquote";let m=!1,y;for(y=t;y<n;y++){const C=e.sCount[y]<e.blkIndent;if(i=e.bMarks[y]+e.tShift[y],a=e.eMarks[y],i>=a)break;if(e.src.charCodeAt(i++)===62&&!C){let R=e.sCount[y]+1,$,k;e.src.charCodeAt(i)===32?(i++,R++,k=!1,$=!0):e.src.charCodeAt(i)===9?($=!0,(e.bsCount[y]+R)%4===3?(i++,R++,k=!1):k=!0):$=!1;let F=R;for(l.push(e.bMarks[y]),e.bMarks[y]=i;i<a;){const L=e.src.charCodeAt(i);if(xa(L))L===9?F+=4-(F+e.bsCount[y]+(k?1:0))%4:F++;else break;i++}m=i>=a,o.push(e.bsCount[y]),e.bsCount[y]=e.sCount[y]+1+($?1:0),s.push(e.sCount[y]),e.sCount[y]=F-R,c.push(e.tShift[y]),e.tShift[y]=i-e.bMarks[y];continue}if(m)break;let T=!1;for(let R=0,$=d.length;R<$;R++)if(d[R](e,y,n,!0)){T=!0;break}if(T){e.lineMax=y,e.blkIndent!==0&&(l.push(e.bMarks[y]),o.push(e.bsCount[y]),c.push(e.tShift[y]),s.push(e.sCount[y]),e.sCount[y]-=e.blkIndent);break}l.push(e.bMarks[y]),o.push(e.bsCount[y]),c.push(e.tShift[y]),s.push(e.sCount[y]),e.sCount[y]=-1}const v=e.blkIndent;e.blkIndent=0;const _=e.push("blockquote_open","blockquote",1);_.markup=">";const S=[t,0];_.map=S,e.md.block.tokenize(e,t,y);const E=e.push("blockquote_close","blockquote",-1);E.markup=">",e.lineMax=u,e.parentType=h,S[1]=e.line;for(let C=0;C<c.length;C++)e.bMarks[C+t]=l[C],e.tShift[C+t]=c[C],e.sCount[C+t]=s[C],e.bsCount[C+t]=o[C];return e.blkIndent=v,!0}function kFe(e,t,n,r){const i=e.eMarks[t];if(e.sCount[t]-e.blkIndent>=4)return!1;let a=e.bMarks[t]+e.tShift[t];const u=e.src.charCodeAt(a++);if(u!==42&&u!==45&&u!==95)return!1;let l=1;for(;a<i;){const s=e.src.charCodeAt(a++);if(s!==u&&!xa(s))return!1;s===u&&l++}if(l<3)return!1;if(r)return!0;e.line=t+1;const o=e.push("hr","hr",0);return o.map=[t,e.line],o.markup=Array(l+1).join(String.fromCharCode(u)),!0}function gX(e,t){const n=e.eMarks[t];let r=e.bMarks[t]+e.tShift[t];const i=e.src.charCodeAt(r++);if(i!==42&&i!==45&&i!==43)return-1;if(r<n){const a=e.src.charCodeAt(r);if(!xa(a))return-1}return r}function vX(e,t){const n=e.bMarks[t]+e.tShift[t],r=e.eMarks[t];let i=n;if(i+1>=r)return-1;let a=e.src.charCodeAt(i++);if(a<48||a>57)return-1;for(;;){if(i>=r)return-1;if(a=e.src.charCodeAt(i++),a>=48&&a<=57){if(i-n>=10)return-1;continue}if(a===41||a===46)break;return-1}return i<r&&(a=e.src.charCodeAt(i),!xa(a))?-1:i}function PFe(e,t){const n=e.level+2;for(let r=t+2,i=e.tokens.length-2;r<i;r++)e.tokens[r].level===n&&e.tokens[r].type==="paragraph_open"&&(e.tokens[r+2].hidden=!0,e.tokens[r].hidden=!0,r+=2)}function MFe(e,t,n,r){let i,a,u,l,o=t,s=!0;if(e.sCount[o]-e.blkIndent>=4||e.listIndent>=0&&e.sCount[o]-e.listIndent>=4&&e.sCount[o]<e.blkIndent)return!1;let c=!1;r&&e.parentType==="paragraph"&&e.sCount[o]>=e.blkIndent&&(c=!0);let d,h,m;if((m=vX(e,o))>=0){if(d=!0,u=e.bMarks[o]+e.tShift[o],h=Number(e.src.slice(u,m-1)),c&&h!==1)return!1}else if((m=gX(e,o))>=0)d=!1;else return!1;if(c&&e.skipSpaces(m)>=e.eMarks[o])return!1;if(r)return!0;const y=e.src.charCodeAt(m-1),v=e.tokens.length;d?(l=e.push("ordered_list_open","ol",1),h!==1&&(l.attrs=[["start",h]])):l=e.push("bullet_list_open","ul",1);const _=[o,0];l.map=_,l.markup=String.fromCharCode(y);let S=!1;const E=e.md.block.ruler.getRules("list"),C=e.parentType;for(e.parentType="list";o<n;){a=m,i=e.eMarks[o];const T=e.sCount[o]+m-(e.bMarks[o]+e.tShift[o]);let R=T;for(;a<i;){const W=e.src.charCodeAt(a);if(W===9)R+=4-(R+e.bsCount[o])%4;else if(W===32)R++;else break;a++}const $=a;let k;$>=i?k=1:k=R-T,k>4&&(k=1);const F=T+k;l=e.push("list_item_open","li",1),l.markup=String.fromCharCode(y);const L=[o,0];l.map=L,d&&(l.info=e.src.slice(u,m-1));const j=e.tight,V=e.tShift[o],q=e.sCount[o],N=e.listIndent;if(e.listIndent=e.blkIndent,e.blkIndent=F,e.tight=!0,e.tShift[o]=$-e.bMarks[o],e.sCount[o]=R,$>=i&&e.isEmpty(o+1)?e.line=Math.min(e.line+2,n):e.md.block.tokenize(e,o,n,!0),(!e.tight||S)&&(s=!1),S=e.line-o>1&&e.isEmpty(e.line-1),e.blkIndent=e.listIndent,e.listIndent=N,e.tShift[o]=V,e.sCount[o]=q,e.tight=j,l=e.push("list_item_close","li",-1),l.markup=String.fromCharCode(y),o=e.line,L[1]=o,o>=n||e.sCount[o]<e.blkIndent||e.sCount[o]-e.blkIndent>=4)break;let U=!1;for(let W=0,G=E.length;W<G;W++)if(E[W](e,o,n,!0)){U=!0;break}if(U)break;if(d){if(m=vX(e,o),m<0)break;u=e.bMarks[o]+e.tShift[o]}else if(m=gX(e,o),m<0)break;if(y!==e.src.charCodeAt(m-1))break}return d?l=e.push("ordered_list_close","ol",-1):l=e.push("bullet_list_close","ul",-1),l.markup=String.fromCharCode(y),_[1]=o,e.line=o,e.parentType=C,s&&PFe(e,v),!0}function FFe(e,t,n,r){let i=e.bMarks[t]+e.tShift[t],a=e.eMarks[t],u=t+1;if(e.sCount[t]-e.blkIndent>=4||e.src.charCodeAt(i)!==91)return!1;function l(E){const C=e.lineMax;if(E>=C||e.isEmpty(E))return null;let T=!1;if(e.sCount[E]-e.blkIndent>3&&(T=!0),e.sCount[E]<0&&(T=!0),!T){const k=e.md.block.ruler.getRules("reference"),F=e.parentType;e.parentType="reference";let L=!1;for(let j=0,V=k.length;j<V;j++)if(k[j](e,E,C,!0)){L=!0;break}if(e.parentType=F,L)return null}const R=e.bMarks[E]+e.tShift[E],$=e.eMarks[E];return e.src.slice(R,$+1)}let o=e.src.slice(i,a+1);a=o.length;let s=-1;for(i=1;i<a;i++){const E=o.charCodeAt(i);if(E===91)return!1;if(E===93){s=i;break}else if(E===10){const C=l(u);C!==null&&(o+=C,a=o.length,u++)}else if(E===92&&(i++,i<a&&o.charCodeAt(i)===10)){const C=l(u);C!==null&&(o+=C,a=o.length,u++)}}if(s<0||o.charCodeAt(s+1)!==58)return!1;for(i=s+2;i<a;i++){const E=o.charCodeAt(i);if(E===10){const C=l(u);C!==null&&(o+=C,a=o.length,u++)}else if(!xa(E))break}const c=e.md.helpers.parseLinkDestination(o,i,a);if(!c.ok)return!1;const d=e.md.normalizeLink(c.str);if(!e.md.validateLink(d))return!1;i=c.pos;const h=i,m=u,y=i;for(;i<a;i++){const E=o.charCodeAt(i);if(E===10){const C=l(u);C!==null&&(o+=C,a=o.length,u++)}else if(!xa(E))break}let v=e.md.helpers.parseLinkTitle(o,i,a);for(;v.can_continue;){const E=l(u);if(E===null)break;o+=E,i=a,a=o.length,u++,v=e.md.helpers.parseLinkTitle(o,i,a,v)}let _;for(i<a&&y!==i&&v.ok?(_=v.str,i=v.pos):(_="",i=h,u=m);i<a;){const E=o.charCodeAt(i);if(!xa(E))break;i++}if(i<a&&o.charCodeAt(i)!==10&&_)for(_="",i=h,u=m;i<a;){const E=o.charCodeAt(i);if(!xa(E))break;i++}if(i<a&&o.charCodeAt(i)!==10)return!1;const S=xw(o.slice(1,s));return S?(r||(typeof e.env.references>"u"&&(e.env.references={}),typeof e.env.references[S]>"u"&&(e.env.references[S]={title:_,href:d}),e.line=u),!0):!1}const NFe=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],IFe="[a-zA-Z_:][a-zA-Z0-9:._-]*",LFe="[^\"'=<>`\\x00-\\x20]+",BFe="'[^']*'",QFe='"[^"]*"',zFe="(?:"+LFe+"|"+BFe+"|"+QFe+")",qFe="(?:\\s+"+IFe+"(?:\\s*=\\s*"+zFe+")?)",tme="<[A-Za-z][A-Za-z0-9\\-]*"+qFe+"*\\s*\\/?>",nme="<\\/[A-Za-z][A-Za-z0-9\\-]*\\s*>",VFe="<!---?>|<!--(?:[^-]|-[^-]|--[^>])*-->",UFe="<[?][\\s\\S]*?[?]>",jFe="<![A-Za-z][^>]*>",ZFe="<!\\[CDATA\\[[\\s\\S]*?\\]\\]>",HFe=new RegExp("^(?:"+tme+"|"+nme+"|"+VFe+"|"+UFe+"|"+jFe+"|"+ZFe+")"),XFe=new RegExp("^(?:"+tme+"|"+nme+")"),_O=[[/^<(script|pre|style|textarea)(?=(\s|>|$))/i,/<\/(script|pre|style|textarea)>/i,!0],[/^<!--/,/-->/,!0],[/^<\?/,/\?>/,!0],[/^<![A-Z]/,/>/,!0],[/^<!\[CDATA\[/,/\]\]>/,!0],[new RegExp("^</?("+NFe.join("|")+")(?=(\\s|/?>|$))","i"),/^$/,!0],[new RegExp(XFe.source+"\\s*$"),/^$/,!1]];function YFe(e,t,n,r){let i=e.bMarks[t]+e.tShift[t],a=e.eMarks[t];if(e.sCount[t]-e.blkIndent>=4||!e.md.options.html||e.src.charCodeAt(i)!==60)return!1;let u=e.src.slice(i,a),l=0;for(;l<_O.length&&!_O[l][0].test(u);l++);if(l===_O.length)return!1;if(r)return _O[l][2];let o=t+1;if(!_O[l][1].test(u)){for(;o<n&&!(e.sCount[o]<e.blkIndent);o++)if(i=e.bMarks[o]+e.tShift[o],a=e.eMarks[o],u=e.src.slice(i,a),_O[l][1].test(u)){u.length!==0&&o++;break}}e.line=o;const s=e.push("html_block","",0);return s.map=[t,o],s.content=e.getLines(t,o,e.blkIndent,!0),!0}function GFe(e,t,n,r){let i=e.bMarks[t]+e.tShift[t],a=e.eMarks[t];if(e.sCount[t]-e.blkIndent>=4)return!1;let u=e.src.charCodeAt(i);if(u!==35||i>=a)return!1;let l=1;for(u=e.src.charCodeAt(++i);u===35&&i<a&&l<=6;)l++,u=e.src.charCodeAt(++i);if(l>6||i<a&&!xa(u))return!1;if(r)return!0;a=e.skipSpacesBack(a,i);const o=e.skipCharsBack(a,35,i);o>i&&xa(e.src.charCodeAt(o-1))&&(a=o),e.line=t+1;const s=e.push("heading_open","h"+String(l),1);s.markup="########".slice(0,l),s.map=[t,e.line];const c=e.push("inline","",0);c.content=e.src.slice(i,a).trim(),c.map=[t,e.line],c.children=[];const d=e.push("heading_close","h"+String(l),-1);return d.markup="########".slice(0,l),!0}function KFe(e,t,n){const r=e.md.block.ruler.getRules("paragraph");if(e.sCount[t]-e.blkIndent>=4)return!1;const i=e.parentType;e.parentType="paragraph";let a=0,u,l=t+1;for(;l<n&&!e.isEmpty(l);l++){if(e.sCount[l]-e.blkIndent>3)continue;if(e.sCount[l]>=e.blkIndent){let m=e.bMarks[l]+e.tShift[l];const y=e.eMarks[l];if(m<y&&(u=e.src.charCodeAt(m),(u===45||u===61)&&(m=e.skipChars(m,u),m=e.skipSpaces(m),m>=y))){a=u===61?1:2;break}}if(e.sCount[l]<0)continue;let h=!1;for(let m=0,y=r.length;m<y;m++)if(r[m](e,l,n,!0)){h=!0;break}if(h)break}if(!a)return!1;const o=e.getLines(t,l,e.blkIndent,!1).trim();e.line=l+1;const s=e.push("heading_open","h"+String(a),1);s.markup=String.fromCharCode(u),s.map=[t,e.line];const c=e.push("inline","",0);c.content=o,c.map=[t,e.line-1],c.children=[];const d=e.push("heading_close","h"+String(a),-1);return d.markup=String.fromCharCode(u),e.parentType=i,!0}function WFe(e,t,n){const r=e.md.block.ruler.getRules("paragraph"),i=e.parentType;let a=t+1;for(e.parentType="paragraph";a<n&&!e.isEmpty(a);a++){if(e.sCount[a]-e.blkIndent>3||e.sCount[a]<0)continue;let s=!1;for(let c=0,d=r.length;c<d;c++)if(r[c](e,a,n,!0)){s=!0;break}if(s)break}const u=e.getLines(t,a,e.blkIndent,!1).trim();e.line=a;const l=e.push("paragraph_open","p",1);l.map=[t,e.line];const o=e.push("inline","",0);return o.content=u,o.map=[t,e.line],o.children=[],e.push("paragraph_close","p",-1),e.parentType=i,!0}const hE=[["table",wFe,["paragraph","reference"]],["code",RFe],["fence",AFe,["paragraph","reference","blockquote","list"]],["blockquote",TFe,["paragraph","reference","blockquote","list"]],["hr",kFe,["paragraph","reference","blockquote","list"]],["list",MFe,["paragraph","reference","blockquote"]],["reference",FFe],["html_block",YFe,["paragraph","reference","blockquote"]],["heading",GFe,["paragraph","reference","blockquote"]],["lheading",KFe],["paragraph",WFe]];function Sw(){this.ruler=new ff;for(let e=0;e<hE.length;e++)this.ruler.push(hE[e][0],hE[e][1],{alt:(hE[e][2]||[]).slice()})}Sw.prototype.tokenize=function(e,t,n){const r=this.ruler.getRules(""),i=r.length,a=e.md.options.maxNesting;let u=t,l=!1;for(;u<n&&(e.line=u=e.skipEmptyLines(u),!(u>=n||e.sCount[u]<e.blkIndent));){if(e.level>=a){e.line=n;break}const o=e.line;let s=!1;for(let c=0;c<i;c++)if(s=r[c](e,u,n,!1),s){if(o>=e.line)throw new Error("block rule didn't increment state.line");break}if(!s)throw new Error("none of the block rules matched");e.tight=!l,e.isEmpty(e.line-1)&&(l=!0),u=e.line,u<n&&e.isEmpty(u)&&(l=!0,u++,e.line=u)}};Sw.prototype.parse=function(e,t,n,r){if(!e)return;const i=new this.State(e,t,n,r);this.tokenize(i,i.line,i.lineMax)};Sw.prototype.State=U0;function DS(e,t,n,r){this.src=e,this.env=n,this.md=t,this.tokens=r,this.tokens_meta=Array(r.length),this.pos=0,this.posMax=this.src.length,this.level=0,this.pending="",this.pendingLevel=0,this.cache={},this.delimiters=[],this._prev_delimiters=[],this.backticks={},this.backticksScanned=!1,this.linkLevel=0}DS.prototype.pushPending=function(){const e=new vp("text","",0);return e.content=this.pending,e.level=this.pendingLevel,this.tokens.push(e),this.pending="",e};DS.prototype.push=function(e,t,n){this.pending&&this.pushPending();const r=new vp(e,t,n);let i=null;return n<0&&(this.level--,this.delimiters=this._prev_delimiters.pop()),r.level=this.level,n>0&&(this.level++,this._prev_delimiters.push(this.delimiters),this.delimiters=[],i={delimiters:this.delimiters}),this.pendingLevel=this.level,this.tokens.push(r),this.tokens_meta.push(i),r};DS.prototype.scanDelims=function(e,t){const n=this.posMax,r=this.src.charCodeAt(e),i=e>0?this.src.charCodeAt(e-1):32;let a=e;for(;a<n&&this.src.charCodeAt(a)===r;)a++;const u=a-e,l=a<n?this.src.charCodeAt(a):32,o=Ix(i)||Nx(String.fromCharCode(i)),s=Ix(l)||Nx(String.fromCharCode(l)),c=Fx(i),d=Fx(l),h=!d&&(!s||c||o),m=!c&&(!o||d||s);return{can_open:h&&(t||!m||o),can_close:m&&(t||!h||s),length:u}};DS.prototype.Token=vp;function JFe(e){switch(e){case 10:case 33:case 35:case 36:case 37:case 38:case 42:case 43:case 45:case 58:case 60:case 61:case 62:case 64:case 91:case 92:case 93:case 94:case 95:case 96:case 123:case 125:case 126:return!0;default:return!1}}function eNe(e,t){let n=e.pos;for(;n<e.posMax&&!JFe(e.src.charCodeAt(n));)n++;return n===e.pos?!1:(t||(e.pending+=e.src.slice(e.pos,n)),e.pos=n,!0)}const tNe=/(?:^|[^a-z0-9.+-])([a-z][a-z0-9.+-]*)$/i;function nNe(e,t){if(!e.md.options.linkify||e.linkLevel>0)return!1;const n=e.pos,r=e.posMax;if(n+3>r||e.src.charCodeAt(n)!==58||e.src.charCodeAt(n+1)!==47||e.src.charCodeAt(n+2)!==47)return!1;const i=e.pending.match(tNe);if(!i)return!1;const a=i[1],u=e.md.linkify.matchAtStart(e.src.slice(n-a.length));if(!u)return!1;let l=u.url;if(l.length<=a.length)return!1;l=l.replace(/\*+$/,"");const o=e.md.normalizeLink(l);if(!e.md.validateLink(o))return!1;if(!t){e.pending=e.pending.slice(0,-a.length);const s=e.push("link_open","a",1);s.attrs=[["href",o]],s.markup="linkify",s.info="auto";const c=e.push("text","",0);c.content=e.md.normalizeLinkText(l);const d=e.push("link_close","a",-1);d.markup="linkify",d.info="auto"}return e.pos+=l.length-a.length,!0}function rNe(e,t){let n=e.pos;if(e.src.charCodeAt(n)!==10)return!1;const r=e.pending.length-1,i=e.posMax;if(!t)if(r>=0&&e.pending.charCodeAt(r)===32)if(r>=1&&e.pending.charCodeAt(r-1)===32){let a=r-1;for(;a>=1&&e.pending.charCodeAt(a-1)===32;)a--;e.pending=e.pending.slice(0,a),e.push("hardbreak","br",0)}else e.pending=e.pending.slice(0,-1),e.push("softbreak","br",0);else e.push("softbreak","br",0);for(n++;n<i&&xa(e.src.charCodeAt(n));)n++;return e.pos=n,!0}const WI=[];for(let e=0;e<256;e++)WI.push(0);"\\!\"#$%&'()*+,./:;<=>?@[]^_`{|}~-".split("").forEach(function(e){WI[e.charCodeAt(0)]=1});function iNe(e,t){let n=e.pos;const r=e.posMax;if(e.src.charCodeAt(n)!==92||(n++,n>=r))return!1;let i=e.src.charCodeAt(n);if(i===10){for(t||e.push("hardbreak","br",0),n++;n<r&&(i=e.src.charCodeAt(n),!!xa(i));)n++;return e.pos=n,!0}let a=e.src[n];if(i>=55296&&i<=56319&&n+1<r){const l=e.src.charCodeAt(n+1);l>=56320&&l<=57343&&(a+=e.src[n+1],n++)}const u="\\"+a;if(!t){const l=e.push("text_special","",0);i<256&&WI[i]!==0?l.content=a:l.content=u,l.markup=u,l.info="escape"}return e.pos=n+1,!0}function aNe(e,t){let n=e.pos;if(e.src.charCodeAt(n)!==96)return!1;const i=n;n++;const a=e.posMax;for(;n<a&&e.src.charCodeAt(n)===96;)n++;const u=e.src.slice(i,n),l=u.length;if(e.backticksScanned&&(e.backticks[l]||0)<=i)return t||(e.pending+=u),e.pos+=l,!0;let o=n,s;for(;(s=e.src.indexOf("`",o))!==-1;){for(o=s+1;o<a&&e.src.charCodeAt(o)===96;)o++;const c=o-s;if(c===l){if(!t){const d=e.push("code_inline","code",0);d.markup=u,d.content=e.src.slice(n,s).replace(/\n/g," ").replace(/^ (.+) $/,"$1")}return e.pos=o,!0}e.backticks[c]=s}return e.backticksScanned=!0,t||(e.pending+=u),e.pos+=l,!0}function uNe(e,t){const n=e.pos,r=e.src.charCodeAt(n);if(t||r!==126)return!1;const i=e.scanDelims(e.pos,!0);let a=i.length;const u=String.fromCharCode(r);if(a<2)return!1;let l;a%2&&(l=e.push("text","",0),l.content=u,a--);for(let o=0;o<a;o+=2)l=e.push("text","",0),l.content=u+u,e.delimiters.push({marker:r,length:0,token:e.tokens.length-1,end:-1,open:i.can_open,close:i.can_close});return e.pos+=i.length,!0}function yX(e,t){let n;const r=[],i=t.length;for(let a=0;a<i;a++){const u=t[a];if(u.marker!==126||u.end===-1)continue;const l=t[u.end];n=e.tokens[u.token],n.type="s_open",n.tag="s",n.nesting=1,n.markup="~~",n.content="",n=e.tokens[l.token],n.type="s_close",n.tag="s",n.nesting=-1,n.markup="~~",n.content="",e.tokens[l.token-1].type==="text"&&e.tokens[l.token-1].content==="~"&&r.push(l.token-1)}for(;r.length;){const a=r.pop();let u=a+1;for(;u<e.tokens.length&&e.tokens[u].type==="s_close";)u++;u--,a!==u&&(n=e.tokens[u],e.tokens[u]=e.tokens[a],e.tokens[a]=n)}}function lNe(e){const t=e.tokens_meta,n=e.tokens_meta.length;yX(e,e.delimiters);for(let r=0;r<n;r++)t[r]&&t[r].delimiters&&yX(e,t[r].delimiters)}const rme={tokenize:uNe,postProcess:lNe};function oNe(e,t){const n=e.pos,r=e.src.charCodeAt(n);if(t||r!==95&&r!==42)return!1;const i=e.scanDelims(e.pos,r===42);for(let a=0;a<i.length;a++){const u=e.push("text","",0);u.content=String.fromCharCode(r),e.delimiters.push({marker:r,length:i.length,token:e.tokens.length-1,end:-1,open:i.can_open,close:i.can_close})}return e.pos+=i.length,!0}function bX(e,t){const n=t.length;for(let r=n-1;r>=0;r--){const i=t[r];if(i.marker!==95&&i.marker!==42||i.end===-1)continue;const a=t[i.end],u=r>0&&t[r-1].end===i.end+1&&t[r-1].marker===i.marker&&t[r-1].token===i.token-1&&t[i.end+1].token===a.token+1,l=String.fromCharCode(i.marker),o=e.tokens[i.token];o.type=u?"strong_open":"em_open",o.tag=u?"strong":"em",o.nesting=1,o.markup=u?l+l:l,o.content="";const s=e.tokens[a.token];s.type=u?"strong_close":"em_close",s.tag=u?"strong":"em",s.nesting=-1,s.markup=u?l+l:l,s.content="",u&&(e.tokens[t[r-1].token].content="",e.tokens[t[i.end+1].token].content="",r--)}}function sNe(e){const t=e.tokens_meta,n=e.tokens_meta.length;bX(e,e.delimiters);for(let r=0;r<n;r++)t[r]&&t[r].delimiters&&bX(e,t[r].delimiters)}const ime={tokenize:oNe,postProcess:sNe};function cNe(e,t){let n,r,i,a,u="",l="",o=e.pos,s=!0;if(e.src.charCodeAt(e.pos)!==91)return!1;const c=e.pos,d=e.posMax,h=e.pos+1,m=e.md.helpers.parseLinkLabel(e,e.pos,!0);if(m<0)return!1;let y=m+1;if(y<d&&e.src.charCodeAt(y)===40){for(s=!1,y++;y<d&&(n=e.src.charCodeAt(y),!(!xa(n)&&n!==10));y++);if(y>=d)return!1;if(o=y,i=e.md.helpers.parseLinkDestination(e.src,y,e.posMax),i.ok){for(u=e.md.normalizeLink(i.str),e.md.validateLink(u)?y=i.pos:u="",o=y;y<d&&(n=e.src.charCodeAt(y),!(!xa(n)&&n!==10));y++);if(i=e.md.helpers.parseLinkTitle(e.src,y,e.posMax),y<d&&o!==y&&i.ok)for(l=i.str,y=i.pos;y<d&&(n=e.src.charCodeAt(y),!(!xa(n)&&n!==10));y++);}(y>=d||e.src.charCodeAt(y)!==41)&&(s=!0),y++}if(s){if(typeof e.env.references>"u")return!1;if(y<d&&e.src.charCodeAt(y)===91?(o=y+1,y=e.md.helpers.parseLinkLabel(e,y),y>=0?r=e.src.slice(o,y++):y=m+1):y=m+1,r||(r=e.src.slice(h,m)),a=e.env.references[xw(r)],!a)return e.pos=c,!1;u=a.href,l=a.title}if(!t){e.pos=h,e.posMax=m;const v=e.push("link_open","a",1),_=[["href",u]];v.attrs=_,l&&_.push(["title",l]),e.linkLevel++,e.md.inline.tokenize(e),e.linkLevel--,e.push("link_close","a",-1)}return e.pos=y,e.posMax=d,!0}function fNe(e,t){let n,r,i,a,u,l,o,s,c="";const d=e.pos,h=e.posMax;if(e.src.charCodeAt(e.pos)!==33||e.src.charCodeAt(e.pos+1)!==91)return!1;const m=e.pos+2,y=e.md.helpers.parseLinkLabel(e,e.pos+1,!1);if(y<0)return!1;if(a=y+1,a<h&&e.src.charCodeAt(a)===40){for(a++;a<h&&(n=e.src.charCodeAt(a),!(!xa(n)&&n!==10));a++);if(a>=h)return!1;for(s=a,l=e.md.helpers.parseLinkDestination(e.src,a,e.posMax),l.ok&&(c=e.md.normalizeLink(l.str),e.md.validateLink(c)?a=l.pos:c=""),s=a;a<h&&(n=e.src.charCodeAt(a),!(!xa(n)&&n!==10));a++);if(l=e.md.helpers.parseLinkTitle(e.src,a,e.posMax),a<h&&s!==a&&l.ok)for(o=l.str,a=l.pos;a<h&&(n=e.src.charCodeAt(a),!(!xa(n)&&n!==10));a++);else o="";if(a>=h||e.src.charCodeAt(a)!==41)return e.pos=d,!1;a++}else{if(typeof e.env.references>"u")return!1;if(a<h&&e.src.charCodeAt(a)===91?(s=a+1,a=e.md.helpers.parseLinkLabel(e,a),a>=0?i=e.src.slice(s,a++):a=y+1):a=y+1,i||(i=e.src.slice(m,y)),u=e.env.references[xw(i)],!u)return e.pos=d,!1;c=u.href,o=u.title}if(!t){r=e.src.slice(m,y);const v=[];e.md.inline.parse(r,e.md,e.env,v);const _=e.push("image","img",0),S=[["src",c],["alt",""]];_.attrs=S,_.children=v,_.content=r,o&&S.push(["title",o])}return e.pos=a,e.posMax=h,!0}const dNe=/^([a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*)$/,hNe=/^([a-zA-Z][a-zA-Z0-9+.-]{1,31}):([^<>\x00-\x20]*)$/;function pNe(e,t){let n=e.pos;if(e.src.charCodeAt(n)!==60)return!1;const r=e.pos,i=e.posMax;for(;;){if(++n>=i)return!1;const u=e.src.charCodeAt(n);if(u===60)return!1;if(u===62)break}const a=e.src.slice(r+1,n);if(hNe.test(a)){const u=e.md.normalizeLink(a);if(!e.md.validateLink(u))return!1;if(!t){const l=e.push("link_open","a",1);l.attrs=[["href",u]],l.markup="autolink",l.info="auto";const o=e.push("text","",0);o.content=e.md.normalizeLinkText(a);const s=e.push("link_close","a",-1);s.markup="autolink",s.info="auto"}return e.pos+=a.length+2,!0}if(dNe.test(a)){const u=e.md.normalizeLink("mailto:"+a);if(!e.md.validateLink(u))return!1;if(!t){const l=e.push("link_open","a",1);l.attrs=[["href",u]],l.markup="autolink",l.info="auto";const o=e.push("text","",0);o.content=e.md.normalizeLinkText(a);const s=e.push("link_close","a",-1);s.markup="autolink",s.info="auto"}return e.pos+=a.length+2,!0}return!1}function mNe(e){return/^<a[>\s]/i.test(e)}function gNe(e){return/^<\/a\s*>/i.test(e)}function vNe(e){const t=e|32;return t>=97&&t<=122}function yNe(e,t){if(!e.md.options.html)return!1;const n=e.posMax,r=e.pos;if(e.src.charCodeAt(r)!==60||r+2>=n)return!1;const i=e.src.charCodeAt(r+1);if(i!==33&&i!==63&&i!==47&&!vNe(i))return!1;const a=e.src.slice(r).match(HFe);if(!a)return!1;if(!t){const u=e.push("html_inline","",0);u.content=a[0],mNe(u.content)&&e.linkLevel++,gNe(u.content)&&e.linkLevel--}return e.pos+=a[0].length,!0}const bNe=/^&#((?:x[a-f0-9]{1,6}|[0-9]{1,7}));/i,ONe=/^&([a-z][a-z0-9]{1,31});/i;function xNe(e,t){const n=e.pos,r=e.posMax;if(e.src.charCodeAt(n)!==38||n+1>=r)return!1;if(e.src.charCodeAt(n+1)===35){const a=e.src.slice(n).match(bNe);if(a){if(!t){const u=a[1][0].toLowerCase()==="x"?parseInt(a[1].slice(1),16):parseInt(a[1],10),l=e.push("text_special","",0);l.content=GI(u)?C$(u):C$(65533),l.markup=a[0],l.info="entity"}return e.pos+=a[0].length,!0}}else{const a=e.src.slice(n).match(ONe);if(a){const u=G0e(a[0]);if(u!==a[0]){if(!t){const l=e.push("text_special","",0);l.content=u,l.markup=a[0],l.info="entity"}return e.pos+=a[0].length,!0}}}return!1}function OX(e){const t={},n=e.length;if(!n)return;let r=0,i=-2;const a=[];for(let u=0;u<n;u++){const l=e[u];if(a.push(0),(e[r].marker!==l.marker||i!==l.token-1)&&(r=u),i=l.token,l.length=l.length||0,!l.close)continue;t.hasOwnProperty(l.marker)||(t[l.marker]=[-1,-1,-1,-1,-1,-1]);const o=t[l.marker][(l.open?3:0)+l.length%3];let s=r-a[r]-1,c=s;for(;s>o;s-=a[s]+1){const d=e[s];if(d.marker===l.marker&&d.open&&d.end<0){let h=!1;if((d.close||l.open)&&(d.length+l.length)%3===0&&(d.length%3!==0||l.length%3!==0)&&(h=!0),!h){const m=s>0&&!e[s-1].open?a[s-1]+1:0;a[u]=u-s+m,a[s]=m,l.open=!1,d.end=u,d.close=!1,c=-1,i=-2;break}}}c!==-1&&(t[l.marker][(l.open?3:0)+(l.length||0)%3]=c)}}function SNe(e){const t=e.tokens_meta,n=e.tokens_meta.length;OX(e.delimiters);for(let r=0;r<n;r++)t[r]&&t[r].delimiters&&OX(t[r].delimiters)}function _Ne(e){let t,n,r=0;const i=e.tokens,a=e.tokens.length;for(t=n=0;t<a;t++)i[t].nesting<0&&r--,i[t].level=r,i[t].nesting>0&&r++,i[t].type==="text"&&t+1<a&&i[t+1].type==="text"?i[t+1].content=i[t].content+i[t+1].content:(t!==n&&(i[n]=i[t]),n++);t!==n&&(i.length=n)}const hP=[["text",eNe],["linkify",nNe],["newline",rNe],["escape",iNe],["backticks",aNe],["strikethrough",rme.tokenize],["emphasis",ime.tokenize],["link",cNe],["image",fNe],["autolink",pNe],["html_inline",yNe],["entity",xNe]],pP=[["balance_pairs",SNe],["strikethrough",rme.postProcess],["emphasis",ime.postProcess],["fragments_join",_Ne]];function $S(){this.ruler=new ff;for(let e=0;e<hP.length;e++)this.ruler.push(hP[e][0],hP[e][1]);this.ruler2=new ff;for(let e=0;e<pP.length;e++)this.ruler2.push(pP[e][0],pP[e][1])}$S.prototype.skipToken=function(e){const t=e.pos,n=this.ruler.getRules(""),r=n.length,i=e.md.options.maxNesting,a=e.cache;if(typeof a[t]<"u"){e.pos=a[t];return}let u=!1;if(e.level<i){for(let l=0;l<r;l++)if(e.level++,u=n[l](e,!0),e.level--,u){if(t>=e.pos)throw new Error("inline rule didn't increment state.pos");break}}else e.pos=e.posMax;u||e.pos++,a[t]=e.pos};$S.prototype.tokenize=function(e){const t=this.ruler.getRules(""),n=t.length,r=e.posMax,i=e.md.options.maxNesting;for(;e.pos<r;){const a=e.pos;let u=!1;if(e.level<i){for(let l=0;l<n;l++)if(u=t[l](e,!1),u){if(a>=e.pos)throw new Error("inline rule didn't increment state.pos");break}}if(u){if(e.pos>=r)break;continue}e.pending+=e.src[e.pos++]}e.pending&&e.pushPending()};$S.prototype.parse=function(e,t,n,r){const i=new this.State(e,t,n,r);this.tokenize(i);const a=this.ruler2.getRules(""),u=a.length;for(let l=0;l<u;l++)a[l](i)};$S.prototype.State=DS;function ENe(e){const t={};e=e||{},t.src_Any=j0e.source,t.src_Cc=Z0e.source,t.src_Z=X0e.source,t.src_P=XI.source,t.src_ZPCc=[t.src_Z,t.src_P,t.src_Cc].join("|"),t.src_ZCc=[t.src_Z,t.src_Cc].join("|");const n="[><｜]";return t.src_pseudo_letter="(?:(?!"+n+"|"+t.src_ZPCc+")"+t.src_Any+")",t.src_ip4="(?:(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)",t.src_auth="(?:(?:(?!"+t.src_ZCc+"|[@/\\[\\]()]).)+@)?",t.src_port="(?::(?:6(?:[0-4]\\d{3}|5(?:[0-4]\\d{2}|5(?:[0-2]\\d|3[0-5])))|[1-5]?\\d{1,4}))?",t.src_host_terminator="(?=$|"+n+"|"+t.src_ZPCc+")(?!"+(e["---"]?"-(?!--)|":"-|")+"_|:\\d|\\.-|\\.(?!$|"+t.src_ZPCc+"))",t.src_path="(?:[/?#](?:(?!"+t.src_ZCc+"|"+n+`|[()[\\]{}.,"'?!\\-;]).|\\[(?:(?!`+t.src_ZCc+"|\\]).)*\\]|\\((?:(?!"+t.src_ZCc+"|[)]).)*\\)|\\{(?:(?!"+t.src_ZCc+'|[}]).)*\\}|\\"(?:(?!'+t.src_ZCc+`|["]).)+\\"|\\'(?:(?!`+t.src_ZCc+"|[']).)+\\'|\\'(?="+t.src_pseudo_letter+"|[-])|\\.{2,}[a-zA-Z0-9%/&]|\\.(?!"+t.src_ZCc+"|[.]|$)|"+(e["---"]?"\\-(?!--(?:[^-]|$))(?:-*)|":"\\-+|")+",(?!"+t.src_ZCc+"|$)|;(?!"+t.src_ZCc+"|$)|\\!+(?!"+t.src_ZCc+"|[!]|$)|\\?(?!"+t.src_ZCc+"|[?]|$))+|\\/)?",t.src_email_name='[\\-;:&=\\+\\$,\\.a-zA-Z0-9_][\\-;:&=\\+\\$,\\"\\.a-zA-Z0-9_]*',t.src_xn="xn--[a-z0-9\\-]{1,59}",t.src_domain_root="(?:"+t.src_xn+"|"+t.src_pseudo_letter+"{1,63})",t.src_domain="(?:"+t.src_xn+"|(?:"+t.src_pseudo_letter+")|(?:"+t.src_pseudo_letter+"(?:-|"+t.src_pseudo_letter+"){0,61}"+t.src_pseudo_letter+"))",t.src_host="(?:(?:(?:(?:"+t.src_domain+")\\.)*"+t.src_domain+"))",t.tpl_host_fuzzy="(?:"+t.src_ip4+"|(?:(?:(?:"+t.src_domain+")\\.)+(?:%TLDS%)))",t.tpl_host_no_ip_fuzzy="(?:(?:(?:"+t.src_domain+")\\.)+(?:%TLDS%))",t.src_host_strict=t.src_host+t.src_host_terminator,t.tpl_host_fuzzy_strict=t.tpl_host_fuzzy+t.src_host_terminator,t.src_host_port_strict=t.src_host+t.src_port+t.src_host_terminator,t.tpl_host_port_fuzzy_strict=t.tpl_host_fuzzy+t.src_port+t.src_host_terminator,t.tpl_host_port_no_ip_fuzzy_strict=t.tpl_host_no_ip_fuzzy+t.src_port+t.src_host_terminator,t.tpl_host_fuzzy_test="localhost|www\\.|\\.\\d{1,3}\\.|(?:\\.(?:%TLDS%)(?:"+t.src_ZPCc+"|>|$))",t.tpl_email_fuzzy="(^|"+n+'|"|\\(|'+t.src_ZCc+")("+t.src_email_name+"@"+t.tpl_host_fuzzy_strict+")",t.tpl_link_fuzzy="(^|(?![.:/\\-_@])(?:[$+<=>^`|｜]|"+t.src_ZPCc+"))((?![$+<=>^`|｜])"+t.tpl_host_port_fuzzy_strict+t.src_path+")",t.tpl_link_no_ip_fuzzy="(^|(?![.:/\\-_@])(?:[$+<=>^`|｜]|"+t.src_ZPCc+"))((?![$+<=>^`|｜])"+t.tpl_host_port_no_ip_fuzzy_strict+t.src_path+")",t}function _M(e){return Array.prototype.slice.call(arguments,1).forEach(function(n){n&&Object.keys(n).forEach(function(r){e[r]=n[r]})}),e}function _w(e){return Object.prototype.toString.call(e)}function DNe(e){return _w(e)==="[object String]"}function $Ne(e){return _w(e)==="[object Object]"}function CNe(e){return _w(e)==="[object RegExp]"}function xX(e){return _w(e)==="[object Function]"}function wNe(e){return e.replace(/[.?*+^$[\]\\(){}|-]/g,"\\$&")}const ame={fuzzyLink:!0,fuzzyEmail:!0,fuzzyIP:!1};function RNe(e){return Object.keys(e||{}).reduce(function(t,n){return t||ame.hasOwnProperty(n)},!1)}const ANe={"http:":{validate:function(e,t,n){const r=e.slice(t);return n.re.http||(n.re.http=new RegExp("^\\/\\/"+n.re.src_auth+n.re.src_host_port_strict+n.re.src_path,"i")),n.re.http.test(r)?r.match(n.re.http)[0].length:0}},"https:":"http:","ftp:":"http:","//":{validate:function(e,t,n){const r=e.slice(t);return n.re.no_http||(n.re.no_http=new RegExp("^"+n.re.src_auth+"(?:localhost|(?:(?:"+n.re.src_domain+")\\.)+"+n.re.src_domain_root+")"+n.re.src_port+n.re.src_host_terminator+n.re.src_path,"i")),n.re.no_http.test(r)?t>=3&&e[t-3]===":"||t>=3&&e[t-3]==="/"?0:r.match(n.re.no_http)[0].length:0}},"mailto:":{validate:function(e,t,n){const r=e.slice(t);return n.re.mailto||(n.re.mailto=new RegExp("^"+n.re.src_email_name+"@"+n.re.src_host_strict,"i")),n.re.mailto.test(r)?r.match(n.re.mailto)[0].length:0}}},TNe="a[cdefgilmnoqrstuwxz]|b[abdefghijmnorstvwyz]|c[acdfghiklmnoruvwxyz]|d[ejkmoz]|e[cegrstu]|f[ijkmor]|g[abdefghilmnpqrstuwy]|h[kmnrtu]|i[delmnoqrst]|j[emop]|k[eghimnprwyz]|l[abcikrstuvy]|m[acdeghklmnopqrstuvwxyz]|n[acefgilopruz]|om|p[aefghklmnrstwy]|qa|r[eosuw]|s[abcdeghijklmnortuvxyz]|t[cdfghjklmnortvwz]|u[agksyz]|v[aceginu]|w[fs]|y[et]|z[amw]",kNe="biz|com|edu|gov|net|org|pro|web|xxx|aero|asia|coop|info|museum|name|shop|рф".split("|");function PNe(e){e.__index__=-1,e.__text_cache__=""}function MNe(e){return function(t,n){const r=t.slice(n);return e.test(r)?r.match(e)[0].length:0}}function SX(){return function(e,t){t.normalize(e)}}function w$(e){const t=e.re=ENe(e.__opts__),n=e.__tlds__.slice();e.onCompile(),e.__tlds_replaced__||n.push(TNe),n.push(t.src_xn),t.src_tlds=n.join("|");function r(l){return l.replace("%TLDS%",t.src_tlds)}t.email_fuzzy=RegExp(r(t.tpl_email_fuzzy),"i"),t.link_fuzzy=RegExp(r(t.tpl_link_fuzzy),"i"),t.link_no_ip_fuzzy=RegExp(r(t.tpl_link_no_ip_fuzzy),"i"),t.host_fuzzy_test=RegExp(r(t.tpl_host_fuzzy_test),"i");const i=[];e.__compiled__={};function a(l,o){throw new Error('(LinkifyIt) Invalid schema "'+l+'": '+o)}Object.keys(e.__schemas__).forEach(function(l){const o=e.__schemas__[l];if(o===null)return;const s={validate:null,link:null};if(e.__compiled__[l]=s,$Ne(o)){CNe(o.validate)?s.validate=MNe(o.validate):xX(o.validate)?s.validate=o.validate:a(l,o),xX(o.normalize)?s.normalize=o.normalize:o.normalize?a(l,o):s.normalize=SX();return}if(DNe(o)){i.push(l);return}a(l,o)}),i.forEach(function(l){e.__compiled__[e.__schemas__[l]]&&(e.__compiled__[l].validate=e.__compiled__[e.__schemas__[l]].validate,e.__compiled__[l].normalize=e.__compiled__[e.__schemas__[l]].normalize)}),e.__compiled__[""]={validate:null,normalize:SX()};const u=Object.keys(e.__compiled__).filter(function(l){return l.length>0&&e.__compiled__[l]}).map(wNe).join("|");e.re.schema_test=RegExp("(^|(?!_)(?:[><｜]|"+t.src_ZPCc+"))("+u+")","i"),e.re.schema_search=RegExp("(^|(?!_)(?:[><｜]|"+t.src_ZPCc+"))("+u+")","ig"),e.re.schema_at_start=RegExp("^"+e.re.schema_search.source,"i"),e.re.pretest=RegExp("("+e.re.schema_test.source+")|("+e.re.host_fuzzy_test.source+")|@","i"),PNe(e)}function FNe(e,t){const n=e.__index__,r=e.__last_index__,i=e.__text_cache__.slice(n,r);this.schema=e.__schema__.toLowerCase(),this.index=n+t,this.lastIndex=r+t,this.raw=i,this.text=i,this.url=i}function EM(e,t){const n=new FNe(e,t);return e.__compiled__[n.schema].normalize(n,e),n}function Gf(e,t){if(!(this instanceof Gf))return new Gf(e,t);t||RNe(e)&&(t=e,e={}),this.__opts__=_M({},ame,t),this.__index__=-1,this.__last_index__=-1,this.__schema__="",this.__text_cache__="",this.__schemas__=_M({},ANe,e),this.__compiled__={},this.__tlds__=kNe,this.__tlds_replaced__=!1,this.re={},w$(this)}Gf.prototype.add=function(t,n){return this.__schemas__[t]=n,w$(this),this};Gf.prototype.set=function(t){return this.__opts__=_M(this.__opts__,t),this};Gf.prototype.test=function(t){if(this.__text_cache__=t,this.__index__=-1,!t.length)return!1;let n,r,i,a,u,l,o,s,c;if(this.re.schema_test.test(t)){for(o=this.re.schema_search,o.lastIndex=0;(n=o.exec(t))!==null;)if(a=this.testSchemaAt(t,n[2],o.lastIndex),a){this.__schema__=n[2],this.__index__=n.index+n[1].length,this.__last_index__=n.index+n[0].length+a;break}}return this.__opts__.fuzzyLink&&this.__compiled__["http:"]&&(s=t.search(this.re.host_fuzzy_test),s>=0&&(this.__index__<0||s<this.__index__)&&(r=t.match(this.__opts__.fuzzyIP?this.re.link_fuzzy:this.re.link_no_ip_fuzzy))!==null&&(u=r.index+r[1].length,(this.__index__<0||u<this.__index__)&&(this.__schema__="",this.__index__=u,this.__last_index__=r.index+r[0].length))),this.__opts__.fuzzyEmail&&this.__compiled__["mailto:"]&&(c=t.indexOf("@"),c>=0&&(i=t.match(this.re.email_fuzzy))!==null&&(u=i.index+i[1].length,l=i.index+i[0].length,(this.__index__<0||u<this.__index__||u===this.__index__&&l>this.__last_index__)&&(this.__schema__="mailto:",this.__index__=u,this.__last_index__=l))),this.__index__>=0};Gf.prototype.pretest=function(t){return this.re.pretest.test(t)};Gf.prototype.testSchemaAt=function(t,n,r){return this.__compiled__[n.toLowerCase()]?this.__compiled__[n.toLowerCase()].validate(t,r,this):0};Gf.prototype.match=function(t){const n=[];let r=0;this.__index__>=0&&this.__text_cache__===t&&(n.push(EM(this,r)),r=this.__last_index__);let i=r?t.slice(r):t;for(;this.test(i);)n.push(EM(this,r)),i=i.slice(this.__last_index__),r+=this.__last_index__;return n.length?n:null};Gf.prototype.matchAtStart=function(t){if(this.__text_cache__=t,this.__index__=-1,!t.length)return null;const n=this.re.schema_at_start.exec(t);if(!n)return null;const r=this.testSchemaAt(t,n[2],n[0].length);return r?(this.__schema__=n[2],this.__index__=n.index+n[1].length,this.__last_index__=n.index+n[0].length+r,EM(this,0)):null};Gf.prototype.tlds=function(t,n){return t=Array.isArray(t)?t:[t],n?(this.__tlds__=this.__tlds__.concat(t).sort().filter(function(r,i,a){return r!==a[i-1]}).reverse(),w$(this),this):(this.__tlds__=t.slice(),this.__tlds_replaced__=!0,w$(this),this)};Gf.prototype.normalize=function(t){t.schema||(t.url="http://"+t.url),t.schema==="mailto:"&&!/^mailto:/i.test(t.url)&&(t.url="mailto:"+t.url)};Gf.prototype.onCompile=function(){};const p3=2147483647,S0=36,JI=1,Lx=26,NNe=38,INe=700,ume=72,lme=128,ome="-",LNe=/^xn--/,BNe=/[^\0-\x7F]/,QNe=/[\x2E\u3002\uFF0E\uFF61]/g,zNe={overflow:"Overflow: input needs wider integers to process","not-basic":"Illegal input >= 0x80 (not a basic code point)","invalid-input":"Invalid input"},mP=S0-JI,_0=Math.floor,gP=String.fromCharCode;function Ev(e){throw new RangeError(zNe[e])}function qNe(e,t){const n=[];let r=e.length;for(;r--;)n[r]=t(e[r]);return n}function sme(e,t){const n=e.split("@");let r="";n.length>1&&(r=n[0]+"@",e=n[1]),e=e.replace(QNe,".");const i=e.split("."),a=qNe(i,t).join(".");return r+a}function cme(e){const t=[];let n=0;const r=e.length;for(;n<r;){const i=e.charCodeAt(n++);if(i>=55296&&i<=56319&&n<r){const a=e.charCodeAt(n++);(a&64512)==56320?t.push(((i&1023)<<10)+(a&1023)+65536):(t.push(i),n--)}else t.push(i)}return t}const VNe=e=>String.fromCodePoint(...e),UNe=function(e){return e>=48&&e<58?26+(e-48):e>=65&&e<91?e-65:e>=97&&e<123?e-97:S0},_X=function(e,t){return e+22+75*(e<26)-((t!=0)<<5)},fme=function(e,t,n){let r=0;for(e=n?_0(e/INe):e>>1,e+=_0(e/t);e>mP*Lx>>1;r+=S0)e=_0(e/mP);return _0(r+(mP+1)*e/(e+NNe))},dme=function(e){const t=[],n=e.length;let r=0,i=lme,a=ume,u=e.lastIndexOf(ome);u<0&&(u=0);for(let l=0;l<u;++l)e.charCodeAt(l)>=128&&Ev("not-basic"),t.push(e.charCodeAt(l));for(let l=u>0?u+1:0;l<n;){const o=r;for(let c=1,d=S0;;d+=S0){l>=n&&Ev("invalid-input");const h=UNe(e.charCodeAt(l++));h>=S0&&Ev("invalid-input"),h>_0((p3-r)/c)&&Ev("overflow"),r+=h*c;const m=d<=a?JI:d>=a+Lx?Lx:d-a;if(h<m)break;const y=S0-m;c>_0(p3/y)&&Ev("overflow"),c*=y}const s=t.length+1;a=fme(r-o,s,o==0),_0(r/s)>p3-i&&Ev("overflow"),i+=_0(r/s),r%=s,t.splice(r++,0,i)}return String.fromCodePoint(...t)},hme=function(e){const t=[];e=cme(e);const n=e.length;let r=lme,i=0,a=ume;for(const o of e)o<128&&t.push(gP(o));const u=t.length;let l=u;for(u&&t.push(ome);l<n;){let o=p3;for(const c of e)c>=r&&c<o&&(o=c);const s=l+1;o-r>_0((p3-i)/s)&&Ev("overflow"),i+=(o-r)*s,r=o;for(const c of e)if(c<r&&++i>p3&&Ev("overflow"),c===r){let d=i;for(let h=S0;;h+=S0){const m=h<=a?JI:h>=a+Lx?Lx:h-a;if(d<m)break;const y=d-m,v=S0-m;t.push(gP(_X(m+y%v,0))),d=_0(y/v)}t.push(gP(_X(d,0))),a=fme(i,s,l===u),i=0,++l}++i,++r}return t.join("")},jNe=function(e){return sme(e,function(t){return LNe.test(t)?dme(t.slice(4).toLowerCase()):t})},ZNe=function(e){return sme(e,function(t){return BNe.test(t)?"xn--"+hme(t):t})},pme={version:"2.3.1",ucs2:{decode:cme,encode:VNe},decode:dme,encode:hme,toASCII:ZNe,toUnicode:jNe},HNe={options:{html:!1,xhtmlOut:!1,breaks:!1,langPrefix:"language-",linkify:!1,typographer:!1,quotes:"“”‘’",highlight:null,maxNesting:100},components:{core:{},block:{},inline:{}}},XNe={options:{html:!1,xhtmlOut:!1,breaks:!1,langPrefix:"language-",linkify:!1,typographer:!1,quotes:"“”‘’",highlight:null,maxNesting:20},components:{core:{rules:["normalize","block","inline","text_join"]},block:{rules:["paragraph"]},inline:{rules:["text"],rules2:["balance_pairs","fragments_join"]}}},YNe={options:{html:!0,xhtmlOut:!0,breaks:!1,langPrefix:"language-",linkify:!1,typographer:!1,quotes:"“”‘’",highlight:null,maxNesting:20},components:{core:{rules:["normalize","block","inline","text_join"]},block:{rules:["blockquote","code","fence","heading","hr","html_block","lheading","list","reference","paragraph"]},inline:{rules:["autolink","backticks","emphasis","entity","escape","html_inline","image","link","newline","text"],rules2:["balance_pairs","emphasis","fragments_join"]}}},GNe={default:HNe,zero:XNe,commonmark:YNe},KNe=/^(vbscript|javascript|file|data):/,WNe=/^data:image\/(gif|png|jpeg|webp);/;function JNe(e){const t=e.trim().toLowerCase();return KNe.test(t)?WNe.test(t):!0}const mme=["http:","https:","mailto:"];function eIe(e){const t=HI(e,!0);if(t.hostname&&(!t.protocol||mme.indexOf(t.protocol)>=0))try{t.hostname=pme.toASCII(t.hostname)}catch{}return ES(ZI(t))}function tIe(e){const t=HI(e,!0);if(t.hostname&&(!t.protocol||mme.indexOf(t.protocol)>=0))try{t.hostname=pme.toUnicode(t.hostname)}catch{}return P3(ZI(t),P3.defaultChars+"%")}function sp(e,t){if(!(this instanceof sp))return new sp(e,t);t||YI(e)||(t=e||{},e="default"),this.inline=new $S,this.block=new Sw,this.core=new KI,this.renderer=new i4,this.linkify=new Gf,this.validateLink=JNe,this.normalizeLink=eIe,this.normalizeLinkText=tIe,this.utils=rFe,this.helpers=Ow({},lFe),this.options={},this.configure(e),t&&this.set(t)}sp.prototype.set=function(e){return Ow(this.options,e),this};sp.prototype.configure=function(e){const t=this;if(YI(e)){const n=e;if(e=GNe[n],!e)throw new Error('Wrong `markdown-it` preset "'+n+'", check name')}if(!e)throw new Error("Wrong `markdown-it` preset, can't be empty");return e.options&&t.set(e.options),e.components&&Object.keys(e.components).forEach(function(n){e.components[n].rules&&t[n].ruler.enableOnly(e.components[n].rules),e.components[n].rules2&&t[n].ruler2.enableOnly(e.components[n].rules2)}),this};sp.prototype.enable=function(e,t){let n=[];Array.isArray(e)||(e=[e]),["core","block","inline"].forEach(function(i){n=n.concat(this[i].ruler.enable(e,!0))},this),n=n.concat(this.inline.ruler2.enable(e,!0));const r=e.filter(function(i){return n.indexOf(i)<0});if(r.length&&!t)throw new Error("MarkdownIt. Failed to enable unknown rule(s): "+r);return this};sp.prototype.disable=function(e,t){let n=[];Array.isArray(e)||(e=[e]),["core","block","inline"].forEach(function(i){n=n.concat(this[i].ruler.disable(e,!0))},this),n=n.concat(this.inline.ruler2.disable(e,!0));const r=e.filter(function(i){return n.indexOf(i)<0});if(r.length&&!t)throw new Error("MarkdownIt. Failed to disable unknown rule(s): "+r);return this};sp.prototype.use=function(e){const t=[this].concat(Array.prototype.slice.call(arguments,1));return e.apply(e,t),this};sp.prototype.parse=function(e,t){if(typeof e!="string")throw new Error("Input data should be a String");const n=new this.core.State(e,this,t);return this.core.process(n),n.tokens};sp.prototype.render=function(e,t){return t=t||{},this.renderer.render(this.parse(e,t),this.options,t)};sp.prototype.parseInline=function(e,t){const n=new this.core.State(e,this,t);return n.inlineMode=!0,this.core.process(n),n.tokens};sp.prototype.renderInline=function(e,t){return t=t||{},this.renderer.render(this.parseInline(e,t),this.options,t)};const nIe=["area","base","basefont","bgsound","br","col","command","embed","frame","hr","image","img","input","keygen","link","meta","param","source","track","wbr"];let CS=class{constructor(t,n,r){this.normal=n,this.property=t,r&&(this.space=r)}};CS.prototype.normal={};CS.prototype.property={};CS.prototype.space=void 0;function gme(e,t){const n={},r={};for(const i of e)Object.assign(n,i.property),Object.assign(r,i.normal);return new CS(n,r,t)}function DM(e){return e.toLowerCase()}class hf{constructor(t,n){this.attribute=n,this.property=t}}hf.prototype.attribute="";hf.prototype.booleanish=!1;hf.prototype.boolean=!1;hf.prototype.commaOrSpaceSeparated=!1;hf.prototype.commaSeparated=!1;hf.prototype.defined=!1;hf.prototype.mustUseProperty=!1;hf.prototype.number=!1;hf.prototype.overloadedBoolean=!1;hf.prototype.property="";hf.prototype.spaceSeparated=!1;hf.prototype.space=void 0;let rIe=0;const hr=Ab(),dl=Ab(),$M=Ab(),Mt=Ab(),ya=Ab(),m3=Ab(),If=Ab();function Ab(){return 2**++rIe}const CM=Object.freeze(Object.defineProperty({__proto__:null,boolean:hr,booleanish:dl,commaOrSpaceSeparated:If,commaSeparated:m3,number:Mt,overloadedBoolean:$M,spaceSeparated:ya},Symbol.toStringTag,{value:"Module"})),vP=Object.keys(CM);class eL extends hf{constructor(t,n,r,i){let a=-1;if(super(t,n),EX(this,"space",i),typeof r=="number")for(;++a<vP.length;){const u=vP[a];EX(this,vP[a],(r&CM[u])===CM[u])}}}eL.prototype.defined=!0;function EX(e,t,n){n&&(e[t]=n)}function a4(e){const t={},n={};for(const[r,i]of Object.entries(e.properties)){const a=new eL(r,e.transform(e.attributes||{},r),i,e.space);e.mustUseProperty&&e.mustUseProperty.includes(r)&&(a.mustUseProperty=!0),t[r]=a,n[DM(r)]=r,n[DM(a.attribute)]=r}return new CS(t,n,e.space)}const vme=a4({properties:{ariaActiveDescendant:null,ariaAtomic:dl,ariaAutoComplete:null,ariaBusy:dl,ariaChecked:dl,ariaColCount:Mt,ariaColIndex:Mt,ariaColSpan:Mt,ariaControls:ya,ariaCurrent:null,ariaDescribedBy:ya,ariaDetails:null,ariaDisabled:dl,ariaDropEffect:ya,ariaErrorMessage:null,ariaExpanded:dl,ariaFlowTo:ya,ariaGrabbed:dl,ariaHasPopup:null,ariaHidden:dl,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:ya,ariaLevel:Mt,ariaLive:null,ariaModal:dl,ariaMultiLine:dl,ariaMultiSelectable:dl,ariaOrientation:null,ariaOwns:ya,ariaPlaceholder:null,ariaPosInSet:Mt,ariaPressed:dl,ariaReadOnly:dl,ariaRelevant:null,ariaRequired:dl,ariaRoleDescription:ya,ariaRowCount:Mt,ariaRowIndex:Mt,ariaRowSpan:Mt,ariaSelected:dl,ariaSetSize:Mt,ariaSort:null,ariaValueMax:Mt,ariaValueMin:Mt,ariaValueNow:Mt,ariaValueText:null,role:null},transform(e,t){return t==="role"?t:"aria-"+t.slice(4).toLowerCase()}});function yme(e,t){return t in e?e[t]:t}function bme(e,t){return yme(e,t.toLowerCase())}const iIe=a4({attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:m3,acceptCharset:ya,accessKey:ya,action:null,allow:null,allowFullScreen:hr,allowPaymentRequest:hr,allowUserMedia:hr,alt:null,as:null,async:hr,autoCapitalize:null,autoComplete:ya,autoFocus:hr,autoPlay:hr,blocking:ya,capture:null,charSet:null,checked:hr,cite:null,className:ya,cols:Mt,colSpan:null,content:null,contentEditable:dl,controls:hr,controlsList:ya,coords:Mt|m3,crossOrigin:null,data:null,dateTime:null,decoding:null,default:hr,defer:hr,dir:null,dirName:null,disabled:hr,download:$M,draggable:dl,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:hr,formTarget:null,headers:ya,height:Mt,hidden:$M,high:Mt,href:null,hrefLang:null,htmlFor:ya,httpEquiv:ya,id:null,imageSizes:null,imageSrcSet:null,inert:hr,inputMode:null,integrity:null,is:null,isMap:hr,itemId:null,itemProp:ya,itemRef:ya,itemScope:hr,itemType:ya,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:hr,low:Mt,manifest:null,max:null,maxLength:Mt,media:null,method:null,min:null,minLength:Mt,multiple:hr,muted:hr,name:null,nonce:null,noModule:hr,noValidate:hr,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:hr,optimum:Mt,pattern:null,ping:ya,placeholder:null,playsInline:hr,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:hr,referrerPolicy:null,rel:ya,required:hr,reversed:hr,rows:Mt,rowSpan:Mt,sandbox:ya,scope:null,scoped:hr,seamless:hr,selected:hr,shadowRootClonable:hr,shadowRootDelegatesFocus:hr,shadowRootMode:null,shape:null,size:Mt,sizes:null,slot:null,span:Mt,spellCheck:dl,src:null,srcDoc:null,srcLang:null,srcSet:null,start:Mt,step:null,style:null,tabIndex:Mt,target:null,title:null,translate:null,type:null,typeMustMatch:hr,useMap:null,value:dl,width:Mt,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:ya,axis:null,background:null,bgColor:null,border:Mt,borderColor:null,bottomMargin:Mt,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:hr,declare:hr,event:null,face:null,frame:null,frameBorder:null,hSpace:Mt,leftMargin:Mt,link:null,longDesc:null,lowSrc:null,marginHeight:Mt,marginWidth:Mt,noResize:hr,noHref:hr,noShade:hr,noWrap:hr,object:null,profile:null,prompt:null,rev:null,rightMargin:Mt,rules:null,scheme:null,scrolling:dl,standby:null,summary:null,text:null,topMargin:Mt,valueType:null,version:null,vAlign:null,vLink:null,vSpace:Mt,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:hr,disableRemotePlayback:hr,prefix:null,property:null,results:Mt,security:null,unselectable:null},space:"html",transform:bme}),aIe=a4({attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},properties:{about:If,accentHeight:Mt,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:Mt,amplitude:Mt,arabicForm:null,ascent:Mt,attributeName:null,attributeType:null,azimuth:Mt,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:Mt,by:null,calcMode:null,capHeight:Mt,className:ya,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:Mt,diffuseConstant:Mt,direction:null,display:null,dur:null,divisor:Mt,dominantBaseline:null,download:hr,dx:null,dy:null,edgeMode:null,editable:null,elevation:Mt,enableBackground:null,end:null,event:null,exponent:Mt,externalResourcesRequired:null,fill:null,fillOpacity:Mt,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:m3,g2:m3,glyphName:m3,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:Mt,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:Mt,horizOriginX:Mt,horizOriginY:Mt,id:null,ideographic:Mt,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:Mt,k:Mt,k1:Mt,k2:Mt,k3:Mt,k4:Mt,kernelMatrix:If,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:Mt,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:Mt,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:Mt,overlineThickness:Mt,paintOrder:null,panose1:null,path:null,pathLength:Mt,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:ya,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:Mt,pointsAtY:Mt,pointsAtZ:Mt,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:If,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:If,rev:If,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:If,requiredFeatures:If,requiredFonts:If,requiredFormats:If,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:Mt,specularExponent:Mt,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:Mt,strikethroughThickness:Mt,string:null,stroke:null,strokeDashArray:If,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:Mt,strokeOpacity:Mt,strokeWidth:null,style:null,surfaceScale:Mt,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:If,tabIndex:Mt,tableValues:null,target:null,targetX:Mt,targetY:Mt,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:If,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:Mt,underlineThickness:Mt,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:Mt,values:null,vAlphabetic:Mt,vMathematical:Mt,vectorEffect:null,vHanging:Mt,vIdeographic:Mt,version:null,vertAdvY:Mt,vertOriginX:Mt,vertOriginY:Mt,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:Mt,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null},space:"svg",transform:yme}),Ome=a4({properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null},space:"xlink",transform(e,t){return"xlink:"+t.slice(5).toLowerCase()}}),xme=a4({attributes:{xmlnsxlink:"xmlns:xlink"},properties:{xmlnsXLink:null,xmlns:null},space:"xmlns",transform:bme}),Sme=a4({properties:{xmlBase:null,xmlLang:null,xmlSpace:null},space:"xml",transform(e,t){return"xml:"+t.slice(3).toLowerCase()}}),uIe={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},lIe=/[A-Z]/g,DX=/-[a-z]/g,oIe=/^data[-\w.:]+$/i;function _me(e,t){const n=DM(t);let r=t,i=hf;if(n in e.normal)return e.property[e.normal[n]];if(n.length>4&&n.slice(0,4)==="data"&&oIe.test(t)){if(t.charAt(4)==="-"){const a=t.slice(5).replace(DX,cIe);r="data"+a.charAt(0).toUpperCase()+a.slice(1)}else{const a=t.slice(4);if(!DX.test(a)){let u=a.replace(lIe,sIe);u.charAt(0)!=="-"&&(u="-"+u),t="data"+u}}i=eL}return new i(r,t)}function sIe(e){return"-"+e.toLowerCase()}function cIe(e){return e.charAt(1).toUpperCase()}const Eme=gme([vme,iIe,Ome,xme,Sme],"html"),wS=gme([vme,aIe,Ome,xme,Sme],"svg"),$X={}.hasOwnProperty;function fIe(e,t){const n=t||{};function r(i,...a){let u=r.invalid;const l=r.handlers;if(i&&$X.call(i,e)){const o=String(i[e]);u=$X.call(l,o)?l[o]:r.unknown}if(u)return u.call(this,i,...a)}return r.handlers=n.handlers||{},r.invalid=n.invalid,r.unknown=n.unknown,r}const dIe=/["&'<>`]/g,hIe=/[\uD800-\uDBFF][\uDC00-\uDFFF]/g,pIe=/[\x01-\t\v\f\x0E-\x1F\x7F\x81\x8D\x8F\x90\x9D\xA0-\uFFFF]/g,mIe=/[|\\{}()[\]^$+*?.]/g,CX=new WeakMap;function gIe(e,t){if(e=e.replace(t.subset?vIe(t.subset):dIe,r),t.subset||t.escapeOnly)return e;return e.replace(hIe,n).replace(pIe,r);function n(i,a,u){return t.format((i.charCodeAt(0)-55296)*1024+i.charCodeAt(1)-56320+65536,u.charCodeAt(a+2),t)}function r(i,a,u){return t.format(i.charCodeAt(0),u.charCodeAt(a+1),t)}}function vIe(e){let t=CX.get(e);return t||(t=yIe(e),CX.set(e,t)),t}function yIe(e){const t=[];let n=-1;for(;++n<e.length;)t.push(e[n].replace(mIe,"\\$&"));return new RegExp("(?:"+t.join("|")+")","g")}const bIe=/[\dA-Fa-f]/;function OIe(e,t,n){const r="&#x"+e.toString(16).toUpperCase();return n&&t&&!bIe.test(String.fromCharCode(t))?r:r+";"}const xIe=/\d/;function SIe(e,t,n){const r="&#"+String(e);return n&&t&&!xIe.test(String.fromCharCode(t))?r:r+";"}const _Ie=["AElig","AMP","Aacute","Acirc","Agrave","Aring","Atilde","Auml","COPY","Ccedil","ETH","Eacute","Ecirc","Egrave","Euml","GT","Iacute","Icirc","Igrave","Iuml","LT","Ntilde","Oacute","Ocirc","Ograve","Oslash","Otilde","Ouml","QUOT","REG","THORN","Uacute","Ucirc","Ugrave","Uuml","Yacute","aacute","acirc","acute","aelig","agrave","amp","aring","atilde","auml","brvbar","ccedil","cedil","cent","copy","curren","deg","divide","eacute","ecirc","egrave","eth","euml","frac12","frac14","frac34","gt","iacute","icirc","iexcl","igrave","iquest","iuml","laquo","lt","macr","micro","middot","nbsp","not","ntilde","oacute","ocirc","ograve","ordf","ordm","oslash","otilde","ouml","para","plusmn","pound","quot","raquo","reg","sect","shy","sup1","sup2","sup3","szlig","thorn","times","uacute","ucirc","ugrave","uml","uuml","yacute","yen","yuml"],yP={nbsp:" ",iexcl:"¡",cent:"¢",pound:"£",curren:"¤",yen:"¥",brvbar:"¦",sect:"§",uml:"¨",copy:"©",ordf:"ª",laquo:"«",not:"¬",shy:"­",reg:"®",macr:"¯",deg:"°",plusmn:"±",sup2:"²",sup3:"³",acute:"´",micro:"µ",para:"¶",middot:"·",cedil:"¸",sup1:"¹",ordm:"º",raquo:"»",frac14:"¼",frac12:"½",frac34:"¾",iquest:"¿",Agrave:"À",Aacute:"Á",Acirc:"Â",Atilde:"Ã",Auml:"Ä",Aring:"Å",AElig:"Æ",Ccedil:"Ç",Egrave:"È",Eacute:"É",Ecirc:"Ê",Euml:"Ë",Igrave:"Ì",Iacute:"Í",Icirc:"Î",Iuml:"Ï",ETH:"Ð",Ntilde:"Ñ",Ograve:"Ò",Oacute:"Ó",Ocirc:"Ô",Otilde:"Õ",Ouml:"Ö",times:"×",Oslash:"Ø",Ugrave:"Ù",Uacute:"Ú",Ucirc:"Û",Uuml:"Ü",Yacute:"Ý",THORN:"Þ",szlig:"ß",agrave:"à",aacute:"á",acirc:"â",atilde:"ã",auml:"ä",aring:"å",aelig:"æ",ccedil:"ç",egrave:"è",eacute:"é",ecirc:"ê",euml:"ë",igrave:"ì",iacute:"í",icirc:"î",iuml:"ï",eth:"ð",ntilde:"ñ",ograve:"ò",oacute:"ó",ocirc:"ô",otilde:"õ",ouml:"ö",divide:"÷",oslash:"ø",ugrave:"ù",uacute:"ú",ucirc:"û",uuml:"ü",yacute:"ý",thorn:"þ",yuml:"ÿ",fnof:"ƒ",Alpha:"Α",Beta:"Β",Gamma:"Γ",Delta:"Δ",Epsilon:"Ε",Zeta:"Ζ",Eta:"Η",Theta:"Θ",Iota:"Ι",Kappa:"Κ",Lambda:"Λ",Mu:"Μ",Nu:"Ν",Xi:"Ξ",Omicron:"Ο",Pi:"Π",Rho:"Ρ",Sigma:"Σ",Tau:"Τ",Upsilon:"Υ",Phi:"Φ",Chi:"Χ",Psi:"Ψ",Omega:"Ω",alpha:"α",beta:"β",gamma:"γ",delta:"δ",epsilon:"ε",zeta:"ζ",eta:"η",theta:"θ",iota:"ι",kappa:"κ",lambda:"λ",mu:"μ",nu:"ν",xi:"ξ",omicron:"ο",pi:"π",rho:"ρ",sigmaf:"ς",sigma:"σ",tau:"τ",upsilon:"υ",phi:"φ",chi:"χ",psi:"ψ",omega:"ω",thetasym:"ϑ",upsih:"ϒ",piv:"ϖ",bull:"•",hellip:"…",prime:"′",Prime:"″",oline:"‾",frasl:"⁄",weierp:"℘",image:"ℑ",real:"ℜ",trade:"™",alefsym:"ℵ",larr:"←",uarr:"↑",rarr:"→",darr:"↓",harr:"↔",crarr:"↵",lArr:"⇐",uArr:"⇑",rArr:"⇒",dArr:"⇓",hArr:"⇔",forall:"∀",part:"∂",exist:"∃",empty:"∅",nabla:"∇",isin:"∈",notin:"∉",ni:"∋",prod:"∏",sum:"∑",minus:"−",lowast:"∗",radic:"√",prop:"∝",infin:"∞",ang:"∠",and:"∧",or:"∨",cap:"∩",cup:"∪",int:"∫",there4:"∴",sim:"∼",cong:"≅",asymp:"≈",ne:"≠",equiv:"≡",le:"≤",ge:"≥",sub:"⊂",sup:"⊃",nsub:"⊄",sube:"⊆",supe:"⊇",oplus:"⊕",otimes:"⊗",perp:"⊥",sdot:"⋅",lceil:"⌈",rceil:"⌉",lfloor:"⌊",rfloor:"⌋",lang:"〈",rang:"〉",loz:"◊",spades:"♠",clubs:"♣",hearts:"♥",diams:"♦",quot:'"',amp:"&",lt:"<",gt:">",OElig:"Œ",oelig:"œ",Scaron:"Š",scaron:"š",Yuml:"Ÿ",circ:"ˆ",tilde:"˜",ensp:" ",emsp:" ",thinsp:" ",zwnj:"‌",zwj:"‍",lrm:"‎",rlm:"‏",ndash:"–",mdash:"—",lsquo:"‘",rsquo:"’",sbquo:"‚",ldquo:"“",rdquo:"”",bdquo:"„",dagger:"†",Dagger:"‡",permil:"‰",lsaquo:"‹",rsaquo:"›",euro:"€"},EIe=["cent","copy","divide","gt","lt","not","para","times"],Dme={}.hasOwnProperty,wM={};let pE;for(pE in yP)Dme.call(yP,pE)&&(wM[yP[pE]]=pE);const DIe=/[^\dA-Za-z]/;function $Ie(e,t,n,r){const i=String.fromCharCode(e);if(Dme.call(wM,i)){const a=wM[i],u="&"+a;return n&&_Ie.includes(a)&&!EIe.includes(a)&&(!r||t&&t!==61&&DIe.test(String.fromCharCode(t)))?u:u+";"}return""}function CIe(e,t,n){let r=OIe(e,t,n.omitOptionalSemicolons),i;if((n.useNamedReferences||n.useShortestReferences)&&(i=$Ie(e,t,n.omitOptionalSemicolons,n.attribute)),(n.useShortestReferences||!i)&&n.useShortestReferences){const a=SIe(e,t,n.omitOptionalSemicolons);a.length<r.length&&(r=a)}return i&&(!n.useShortestReferences||i.length<r.length)?i:r}function g3(e,t){return gIe(e,Object.assign({format:CIe},t))}const wIe=/^>|^->|<!--|-->|--!>|<!-$/g,RIe=[">"],AIe=["<",">"];function TIe(e,t,n,r){return r.settings.bogusComments?"<?"+g3(e.value,Object.assign({},r.settings.characterReferences,{subset:RIe}))+">":"<!--"+e.value.replace(wIe,i)+"-->";function i(a){return g3(a,Object.assign({},r.settings.characterReferences,{subset:AIe}))}}function kIe(e,t,n,r){return"<!"+(r.settings.upperDoctype?"DOCTYPE":"doctype")+(r.settings.tightDoctype?"":" ")+"html>"}function R$(e,t){const n=String(e);if(typeof t!="string")throw new TypeError("Expected character");let r=0,i=n.indexOf(t);for(;i!==-1;)r++,i=n.indexOf(t,i+t.length);return r}function $me(e,t){const n=t||{};return(e[e.length-1]===""?[...e,""]:e).join((n.padRight?" ":"")+","+(n.padLeft===!1?"":" ")).trim()}function Cme(e){return e.join(" ").trim()}const PIe=/[ \t\n\f\r]/g;function Ew(e){return typeof e=="object"?e.type==="text"?wX(e.value):!1:wX(e)}function wX(e){return e.replace(PIe,"")===""}const wl=Rme(1),wme=Rme(-1),MIe=[];function Rme(e){return t;function t(n,r,i){const a=n?n.children:MIe;let u=(r||0)+e,l=a[u];if(!i)for(;l&&Ew(l);)u+=e,l=a[u];return l}}const FIe={}.hasOwnProperty;function Ame(e){return t;function t(n,r,i){return FIe.call(e,n.tagName)&&e[n.tagName](n,r,i)}}const tL=Ame({body:IIe,caption:bP,colgroup:bP,dd:zIe,dt:QIe,head:bP,html:NIe,li:BIe,optgroup:qIe,option:VIe,p:LIe,rp:RX,rt:RX,tbody:jIe,td:AX,tfoot:ZIe,th:AX,thead:UIe,tr:HIe});function bP(e,t,n){const r=wl(n,t,!0);return!r||r.type!=="comment"&&!(r.type==="text"&&Ew(r.value.charAt(0)))}function NIe(e,t,n){const r=wl(n,t);return!r||r.type!=="comment"}function IIe(e,t,n){const r=wl(n,t);return!r||r.type!=="comment"}function LIe(e,t,n){const r=wl(n,t);return r?r.type==="element"&&(r.tagName==="address"||r.tagName==="article"||r.tagName==="aside"||r.tagName==="blockquote"||r.tagName==="details"||r.tagName==="div"||r.tagName==="dl"||r.tagName==="fieldset"||r.tagName==="figcaption"||r.tagName==="figure"||r.tagName==="footer"||r.tagName==="form"||r.tagName==="h1"||r.tagName==="h2"||r.tagName==="h3"||r.tagName==="h4"||r.tagName==="h5"||r.tagName==="h6"||r.tagName==="header"||r.tagName==="hgroup"||r.tagName==="hr"||r.tagName==="main"||r.tagName==="menu"||r.tagName==="nav"||r.tagName==="ol"||r.tagName==="p"||r.tagName==="pre"||r.tagName==="section"||r.tagName==="table"||r.tagName==="ul"):!n||!(n.type==="element"&&(n.tagName==="a"||n.tagName==="audio"||n.tagName==="del"||n.tagName==="ins"||n.tagName==="map"||n.tagName==="noscript"||n.tagName==="video"))}function BIe(e,t,n){const r=wl(n,t);return!r||r.type==="element"&&r.tagName==="li"}function QIe(e,t,n){const r=wl(n,t);return!!(r&&r.type==="element"&&(r.tagName==="dt"||r.tagName==="dd"))}function zIe(e,t,n){const r=wl(n,t);return!r||r.type==="element"&&(r.tagName==="dt"||r.tagName==="dd")}function RX(e,t,n){const r=wl(n,t);return!r||r.type==="element"&&(r.tagName==="rp"||r.tagName==="rt")}function qIe(e,t,n){const r=wl(n,t);return!r||r.type==="element"&&r.tagName==="optgroup"}function VIe(e,t,n){const r=wl(n,t);return!r||r.type==="element"&&(r.tagName==="option"||r.tagName==="optgroup")}function UIe(e,t,n){const r=wl(n,t);return!!(r&&r.type==="element"&&(r.tagName==="tbody"||r.tagName==="tfoot"))}function jIe(e,t,n){const r=wl(n,t);return!r||r.type==="element"&&(r.tagName==="tbody"||r.tagName==="tfoot")}function ZIe(e,t,n){return!wl(n,t)}function HIe(e,t,n){const r=wl(n,t);return!r||r.type==="element"&&r.tagName==="tr"}function AX(e,t,n){const r=wl(n,t);return!r||r.type==="element"&&(r.tagName==="td"||r.tagName==="th")}const XIe=Ame({body:KIe,colgroup:WIe,head:GIe,html:YIe,tbody:JIe});function YIe(e){const t=wl(e,-1);return!t||t.type!=="comment"}function GIe(e){const t=new Set;for(const r of e.children)if(r.type==="element"&&(r.tagName==="base"||r.tagName==="title")){if(t.has(r.tagName))return!1;t.add(r.tagName)}const n=e.children[0];return!n||n.type==="element"}function KIe(e){const t=wl(e,-1,!0);return!t||t.type!=="comment"&&!(t.type==="text"&&Ew(t.value.charAt(0)))&&!(t.type==="element"&&(t.tagName==="meta"||t.tagName==="link"||t.tagName==="script"||t.tagName==="style"||t.tagName==="template"))}function WIe(e,t,n){const r=wme(n,t),i=wl(e,-1,!0);return n&&r&&r.type==="element"&&r.tagName==="colgroup"&&tL(r,n.children.indexOf(r),n)?!1:!!(i&&i.type==="element"&&i.tagName==="col")}function JIe(e,t,n){const r=wme(n,t),i=wl(e,-1);return n&&r&&r.type==="element"&&(r.tagName==="thead"||r.tagName==="tbody")&&tL(r,n.children.indexOf(r),n)?!1:!!(i&&i.type==="element"&&i.tagName==="tr")}const mE={name:[[`	
\f\r &/=>`.split(""),`	
\f\r "&'/=>\``.split("")],[`\0	
\f\r "&'/<=>`.split(""),`\0	
\f\r "&'/<=>\``.split("")]],unquoted:[[`	
\f\r &>`.split(""),`\0	
\f\r "&'<=>\``.split("")],[`\0	
\f\r "&'<=>\``.split(""),`\0	
\f\r "&'<=>\``.split("")]],single:[["&'".split(""),"\"&'`".split("")],["\0&'".split(""),"\0\"&'`".split("")]],double:[['"&'.split(""),"\"&'`".split("")],['\0"&'.split(""),"\0\"&'`".split("")]]};function eLe(e,t,n,r){const i=r.schema,a=i.space==="svg"?!1:r.settings.omitOptionalTags;let u=i.space==="svg"?r.settings.closeEmptyElements:r.settings.voids.includes(e.tagName.toLowerCase());const l=[];let o;i.space==="html"&&e.tagName==="svg"&&(r.schema=wS);const s=tLe(r,e.properties),c=r.all(i.space==="html"&&e.tagName==="template"?e.content:e);return r.schema=i,c&&(u=!1),(s||!a||!XIe(e,t,n))&&(l.push("<",e.tagName,s?" "+s:""),u&&(i.space==="svg"||r.settings.closeSelfClosing)&&(o=s.charAt(s.length-1),(!r.settings.tightSelfClosing||o==="/"||o&&o!=='"'&&o!=="'")&&l.push(" "),l.push("/")),l.push(">")),l.push(c),!u&&(!a||!tL(e,t,n))&&l.push("</"+e.tagName+">"),l.join("")}function tLe(e,t){const n=[];let r=-1,i;if(t){for(i in t)if(t[i]!==null&&t[i]!==void 0){const a=nLe(e,i,t[i]);a&&n.push(a)}}for(;++r<n.length;){const a=e.settings.tightAttributes?n[r].charAt(n[r].length-1):void 0;r!==n.length-1&&a!=='"'&&a!=="'"&&(n[r]+=" ")}return n.join("")}function nLe(e,t,n){const r=_me(e.schema,t),i=e.settings.allowParseErrors&&e.schema.space==="html"?0:1,a=e.settings.allowDangerousCharacters?0:1;let u=e.quote,l;if(r.overloadedBoolean&&(n===r.attribute||n==="")?n=!0:(r.boolean||r.overloadedBoolean)&&(typeof n!="string"||n===r.attribute||n==="")&&(n=!!n),n==null||n===!1||typeof n=="number"&&Number.isNaN(n))return"";const o=g3(r.attribute,Object.assign({},e.settings.characterReferences,{subset:mE.name[i][a]}));return n===!0||(n=Array.isArray(n)?(r.commaSeparated?$me:Cme)(n,{padLeft:!e.settings.tightCommaSeparatedLists}):String(n),e.settings.collapseEmptyAttributes&&!n)?o:(e.settings.preferUnquoted&&(l=g3(n,Object.assign({},e.settings.characterReferences,{attribute:!0,subset:mE.unquoted[i][a]}))),l!==n&&(e.settings.quoteSmart&&R$(n,u)>R$(n,e.alternative)&&(u=e.alternative),l=u+g3(n,Object.assign({},e.settings.characterReferences,{subset:(u==="'"?mE.single:mE.double)[i][a],attribute:!0}))+u),o+(l&&"="+l))}const rLe=["<","&"];function Tme(e,t,n,r){return n&&n.type==="element"&&(n.tagName==="script"||n.tagName==="style")?e.value:g3(e.value,Object.assign({},r.settings.characterReferences,{subset:rLe}))}function iLe(e,t,n,r){return r.settings.allowDangerousHtml?e.value:Tme(e,t,n,r)}function aLe(e,t,n,r){return r.all(e)}const uLe=fIe("type",{invalid:lLe,unknown:oLe,handlers:{comment:TIe,doctype:kIe,element:eLe,raw:iLe,root:aLe,text:Tme}});function lLe(e){throw new Error("Expected node, not `"+e+"`")}function oLe(e){const t=e;throw new Error("Cannot compile unknown node `"+t.type+"`")}const sLe={},cLe={},fLe=[];function Gat(e,t){const n=sLe,r=n.quote||'"',i=r==='"'?"'":'"';if(r!=='"'&&r!=="'")throw new Error("Invalid quote `"+r+"`, expected `'` or `\"`");return{one:dLe,all:hLe,settings:{omitOptionalTags:n.omitOptionalTags||!1,allowParseErrors:n.allowParseErrors||!1,allowDangerousCharacters:n.allowDangerousCharacters||!1,quoteSmart:n.quoteSmart||!1,preferUnquoted:n.preferUnquoted||!1,tightAttributes:n.tightAttributes||!1,upperDoctype:n.upperDoctype||!1,tightDoctype:n.tightDoctype||!1,bogusComments:n.bogusComments||!1,tightCommaSeparatedLists:n.tightCommaSeparatedLists||!1,tightSelfClosing:n.tightSelfClosing||!1,collapseEmptyAttributes:n.collapseEmptyAttributes||!1,allowDangerousHtml:n.allowDangerousHtml||!1,voids:n.voids||nIe,characterReferences:n.characterReferences||cLe,closeSelfClosing:n.closeSelfClosing||!1,closeEmptyElements:n.closeEmptyElements||!1},schema:n.space==="svg"?wS:Eme,quote:r,alternative:i}.one(Array.isArray(e)?{type:"root",children:e}:e,void 0,void 0)}function dLe(e,t,n){return uLe(e,t,n,this)}function hLe(e){const t=[],n=e&&e.children||fLe;let r=-1;for(;++r<n.length;)t[r]=this.one(n[r],r,e);return t.join("")}var OP={},TX;function pLe(){return TX||(TX=1,(function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.parse=e.enableErrorLogging=e.disableErrorLogging=e.setErrorLogger=void 0;let t=console.error;function n(k){t=k}e.setErrorLogger=n;function r(){t=()=>{}}e.disableErrorLogging=r;function i(){t=console.error}e.enableErrorLogging=i;function a(k){if(k!==void 0){if(k===null)return null;if(k==="")return"";k=k.replace(/\\+$/,F=>F.length%2===0?F:F.slice(0,-1));try{return JSON.parse(k)}catch(F){const[L,j]=k.trimLeft()[0]===":"?u(k,F):u(k,F,S);if(a.lastParseReminding=j,a.onExtraToken&&j.length>0){const V=j.trimRight();a.lastParseReminding=V,V.length>0&&a.onExtraToken(k,L,V)}return L}}}e.parse=a,(function(k){k.onExtraToken=(F,L,j)=>{t("parsed json with extra tokens:",{text:F,data:L,reminding:j})}})(a=e.parse||(e.parse={}));function u(k,F,L){const j=o[k[0]]||L;if(!j)throw t(`no parser registered for ${JSON.stringify(k[0])}:`,{s:k}),F;return j(k,F)}function l(k,F,L){return k[0]==='"'?y(k):k[0]==="'"?_(k):S(k,F,L)}const o={};function s(k){return k.trimLeft()}o[" "]=c,o["\r"]=c,o[`
`]=c,o["	"]=c;function c(k,F){return k=s(k),u(k,F)}o["["]=d;function d(k,F){k=k.substr(1);const L=[];for(k=s(k);k.length>0;){if(k[0]==="]"){k=k.substr(1);break}const j=u(k,F,(V,q)=>S(V,q,[",","]"]));L.push(j[0]),k=j[1],k=s(k),k[0]===","&&(k=k.substring(1),k=s(k))}return[L,k]}for(const k of"0123456789.-".slice())o[k]=h;function h(k){for(let F=0;F<k.length;F++){const L=k[F];if(o[L]===h)continue;const j=k.substring(0,F);return k=k.substring(F),[m(j),k]}return[m(k),""]}function m(k){if(k==="-")return-0;const F=+k;return Number.isNaN(F)?k:F}o['"']=y;function y(k){for(let F=1;F<k.length;F++){const L=k[F];if(L==="\\"){F++;continue}if(L==='"'){const j=v(k.substring(0,F+1));return k=k.substring(F+1),[JSON.parse(j),k]}}return[JSON.parse(v(k)+'"'),""]}function v(k){return k.replace(/\n/g,"\\n").replace(/\t/g,"\\t").replace(/\r/g,"\\r")}o["'"]=_;function _(k){for(let F=1;F<k.length;F++){const L=k[F];if(L==="\\"){F++;continue}if(L==="'"){const j=v(k.substring(0,F+1));return k=k.substring(F+1),[JSON.parse('"'+j.slice(1,-1)+'"'),k]}}return[JSON.parse('"'+v(k.slice(1))+'"'),""]}function S(k,F,L=[" "]){const j=Math.min(...L.map(N=>{const U=k.indexOf(N);return U===-1?k.length:U})),V=k.substring(0,j).trim(),q=k.substring(j);return[V,q]}o["{"]=E;function E(k,F){k=k.substr(1);const L={};for(k=s(k);k.length>0;){if(k[0]==="}"){k=k.substr(1);break}const j=l(k,F,[":","}"]),V=j[0];if(k=j[1],k=s(k),k[0]!==":"){L[V]=void 0;break}if(k=k.substr(1),k=s(k),k.length===0){L[V]=void 0;break}const q=u(k,F);L[V]=q[0],k=q[1],k=s(k),k[0]===","&&(k=k.substr(1),k=s(k))}return[L,k]}o.t=C;function C(k,F){return $(k,"true",!0,F)}o.f=T;function T(k,F){return $(k,"false",!1,F)}o.n=R;function R(k,F){return $(k,"null",null,F)}function $(k,F,L,j){for(let V=F.length;V>=1;V--)if(k.startsWith(F.slice(0,V)))return[L,k.slice(V)];{const V=JSON.stringify(k.slice(0,F.length));throw t(`unknown token starting with ${V}:`,{s:k}),j}}})(OP)),OP}var Kat=pLe(),mLe=/[\u1680\u2000-\u200A\u202F\u205F\u3000]/,gLe=/[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312E\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FEA\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF2D-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDE00\uDE0B-\uDE32\uDE3A\uDE50\uDE5C-\uDE83\uDE86-\uDE89\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC72-\uDC8F\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD30\uDD46]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F\uDFE0\uDFE1]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00-\uDD1E\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4\uDD00-\uDD43]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]/,vLe=/[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u0860-\u086A\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u09FC\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9-\u0AFF\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D00-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19D9\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF9\u1D00-\u1DF9\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u2E2F\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099\u309A\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312E\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FEA\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF2D-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE3E\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC00-\uDC4A\uDC50-\uDC59\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDE00-\uDE3E\uDE47\uDE50-\uDE83\uDE86-\uDE99\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC36\uDC38-\uDC40\uDC50-\uDC59\uDC72-\uDC8F\uDC92-\uDCA7\uDCA9-\uDCB6\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD36\uDD3A\uDD3C\uDD3D\uDD3F-\uDD47\uDD50-\uDD59]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F\uDFE0\uDFE1]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00-\uDD1E\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD838[\uDC00-\uDC06\uDC08-\uDC18\uDC1B-\uDC21\uDC23\uDC24\uDC26-\uDC2A]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6\uDD00-\uDD4A\uDD50-\uDD59]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/,xP={Space_Separator:mLe,ID_Start:gLe,ID_Continue:vLe},zu={isSpaceSeparator(e){return typeof e=="string"&&xP.Space_Separator.test(e)},isIdStartChar(e){return typeof e=="string"&&(e>="a"&&e<="z"||e>="A"&&e<="Z"||e==="$"||e==="_"||xP.ID_Start.test(e))},isIdContinueChar(e){return typeof e=="string"&&(e>="a"&&e<="z"||e>="A"&&e<="Z"||e>="0"&&e<="9"||e==="$"||e==="_"||e==="‌"||e==="‍"||xP.ID_Continue.test(e))},isDigit(e){return typeof e=="string"&&/[0-9]/.test(e)},isHexDigit(e){return typeof e=="string"&&/[0-9A-Fa-f]/.test(e)}};let RM,lc,Xm,A$,uy,rp,Wl,nL,X2;var yLe=function(t,n){RM=String(t),lc="start",Xm=[],A$=0,uy=1,rp=0,Wl=void 0,nL=void 0,X2=void 0;do Wl=bLe(),SLe[lc]();while(Wl.type!=="eof");return typeof n=="function"?AM({"":X2},"",n):X2};function AM(e,t,n){const r=e[t];if(r!=null&&typeof r=="object")if(Array.isArray(r))for(let i=0;i<r.length;i++){const a=String(i),u=AM(r,a,n);u===void 0?delete r[a]:Object.defineProperty(r,a,{value:u,writable:!0,enumerable:!0,configurable:!0})}else for(const i in r){const a=AM(r,i,n);a===void 0?delete r[i]:Object.defineProperty(r,i,{value:a,writable:!0,enumerable:!0,configurable:!0})}return n.call(e,t,r)}let Or,sr,N2,Mm,jr;function bLe(){for(Or="default",sr="",N2=!1,Mm=1;;){jr=ig();const e=kme[Or]();if(e)return e}}function ig(){if(RM[A$])return String.fromCodePoint(RM.codePointAt(A$))}function Dt(){const e=ig();return e===`
`?(uy++,rp=0):e?rp+=e.length:rp++,e&&(A$+=e.length),e}const kme={default(){switch(jr){case"	":case"\v":case"\f":case" ":case" ":case"\uFEFF":case`
`:case"\r":case"\u2028":case"\u2029":Dt();return;case"/":Dt(),Or="comment";return;case void 0:return Dt(),Pa("eof")}if(zu.isSpaceSeparator(jr)){Dt();return}return kme[lc]()},comment(){switch(jr){case"*":Dt(),Or="multiLineComment";return;case"/":Dt(),Or="singleLineComment";return}throw Ma(Dt())},multiLineComment(){switch(jr){case"*":Dt(),Or="multiLineCommentAsterisk";return;case void 0:throw Ma(Dt())}Dt()},multiLineCommentAsterisk(){switch(jr){case"*":Dt();return;case"/":Dt(),Or="default";return;case void 0:throw Ma(Dt())}Dt(),Or="multiLineComment"},singleLineComment(){switch(jr){case`
`:case"\r":case"\u2028":case"\u2029":Dt(),Or="default";return;case void 0:return Dt(),Pa("eof")}Dt()},value(){switch(jr){case"{":case"[":return Pa("punctuator",Dt());case"n":return Dt(),b1("ull"),Pa("null",null);case"t":return Dt(),b1("rue"),Pa("boolean",!0);case"f":return Dt(),b1("alse"),Pa("boolean",!1);case"-":case"+":Dt()==="-"&&(Mm=-1),Or="sign";return;case".":sr=Dt(),Or="decimalPointLeading";return;case"0":sr=Dt(),Or="zero";return;case"1":case"2":case"3":case"4":case"5":case"6":case"7":case"8":case"9":sr=Dt(),Or="decimalInteger";return;case"I":return Dt(),b1("nfinity"),Pa("numeric",1/0);case"N":return Dt(),b1("aN"),Pa("numeric",NaN);case'"':case"'":N2=Dt()==='"',sr="",Or="string";return}throw Ma(Dt())},identifierNameStartEscape(){if(jr!=="u")throw Ma(Dt());Dt();const e=TM();switch(e){case"$":case"_":break;default:if(!zu.isIdStartChar(e))throw kX();break}sr+=e,Or="identifierName"},identifierName(){switch(jr){case"$":case"_":case"‌":case"‍":sr+=Dt();return;case"\\":Dt(),Or="identifierNameEscape";return}if(zu.isIdContinueChar(jr)){sr+=Dt();return}return Pa("identifier",sr)},identifierNameEscape(){if(jr!=="u")throw Ma(Dt());Dt();const e=TM();switch(e){case"$":case"_":case"‌":case"‍":break;default:if(!zu.isIdContinueChar(e))throw kX();break}sr+=e,Or="identifierName"},sign(){switch(jr){case".":sr=Dt(),Or="decimalPointLeading";return;case"0":sr=Dt(),Or="zero";return;case"1":case"2":case"3":case"4":case"5":case"6":case"7":case"8":case"9":sr=Dt(),Or="decimalInteger";return;case"I":return Dt(),b1("nfinity"),Pa("numeric",Mm*(1/0));case"N":return Dt(),b1("aN"),Pa("numeric",NaN)}throw Ma(Dt())},zero(){switch(jr){case".":sr+=Dt(),Or="decimalPoint";return;case"e":case"E":sr+=Dt(),Or="decimalExponent";return;case"x":case"X":sr+=Dt(),Or="hexadecimal";return}return Pa("numeric",Mm*0)},decimalInteger(){switch(jr){case".":sr+=Dt(),Or="decimalPoint";return;case"e":case"E":sr+=Dt(),Or="decimalExponent";return}if(zu.isDigit(jr)){sr+=Dt();return}return Pa("numeric",Mm*Number(sr))},decimalPointLeading(){if(zu.isDigit(jr)){sr+=Dt(),Or="decimalFraction";return}throw Ma(Dt())},decimalPoint(){switch(jr){case"e":case"E":sr+=Dt(),Or="decimalExponent";return}if(zu.isDigit(jr)){sr+=Dt(),Or="decimalFraction";return}return Pa("numeric",Mm*Number(sr))},decimalFraction(){switch(jr){case"e":case"E":sr+=Dt(),Or="decimalExponent";return}if(zu.isDigit(jr)){sr+=Dt();return}return Pa("numeric",Mm*Number(sr))},decimalExponent(){switch(jr){case"+":case"-":sr+=Dt(),Or="decimalExponentSign";return}if(zu.isDigit(jr)){sr+=Dt(),Or="decimalExponentInteger";return}throw Ma(Dt())},decimalExponentSign(){if(zu.isDigit(jr)){sr+=Dt(),Or="decimalExponentInteger";return}throw Ma(Dt())},decimalExponentInteger(){if(zu.isDigit(jr)){sr+=Dt();return}return Pa("numeric",Mm*Number(sr))},hexadecimal(){if(zu.isHexDigit(jr)){sr+=Dt(),Or="hexadecimalInteger";return}throw Ma(Dt())},hexadecimalInteger(){if(zu.isHexDigit(jr)){sr+=Dt();return}return Pa("numeric",Mm*Number(sr))},string(){switch(jr){case"\\":Dt(),sr+=OLe();return;case'"':if(N2)return Dt(),Pa("string",sr);sr+=Dt();return;case"'":if(!N2)return Dt(),Pa("string",sr);sr+=Dt();return;case`
`:case"\r":throw Ma(Dt());case"\u2028":case"\u2029":_Le(jr);break;case void 0:throw Ma(Dt())}sr+=Dt()},start(){switch(jr){case"{":case"[":return Pa("punctuator",Dt())}Or="value"},beforePropertyName(){switch(jr){case"$":case"_":sr=Dt(),Or="identifierName";return;case"\\":Dt(),Or="identifierNameStartEscape";return;case"}":return Pa("punctuator",Dt());case'"':case"'":N2=Dt()==='"',Or="string";return}if(zu.isIdStartChar(jr)){sr+=Dt(),Or="identifierName";return}throw Ma(Dt())},afterPropertyName(){if(jr===":")return Pa("punctuator",Dt());throw Ma(Dt())},beforePropertyValue(){Or="value"},afterPropertyValue(){switch(jr){case",":case"}":return Pa("punctuator",Dt())}throw Ma(Dt())},beforeArrayValue(){if(jr==="]")return Pa("punctuator",Dt());Or="value"},afterArrayValue(){switch(jr){case",":case"]":return Pa("punctuator",Dt())}throw Ma(Dt())},end(){throw Ma(Dt())}};function Pa(e,t){return{type:e,value:t,line:uy,column:rp}}function b1(e){for(const t of e){if(ig()!==t)throw Ma(Dt());Dt()}}function OLe(){switch(ig()){case"b":return Dt(),"\b";case"f":return Dt(),"\f";case"n":return Dt(),`
`;case"r":return Dt(),"\r";case"t":return Dt(),"	";case"v":return Dt(),"\v";case"0":if(Dt(),zu.isDigit(ig()))throw Ma(Dt());return"\0";case"x":return Dt(),xLe();case"u":return Dt(),TM();case`
`:case"\u2028":case"\u2029":return Dt(),"";case"\r":return Dt(),ig()===`
`&&Dt(),"";case"1":case"2":case"3":case"4":case"5":case"6":case"7":case"8":case"9":throw Ma(Dt());case void 0:throw Ma(Dt())}return Dt()}function xLe(){let e="",t=ig();if(!zu.isHexDigit(t)||(e+=Dt(),t=ig(),!zu.isHexDigit(t)))throw Ma(Dt());return e+=Dt(),String.fromCodePoint(parseInt(e,16))}function TM(){let e="",t=4;for(;t-- >0;){const n=ig();if(!zu.isHexDigit(n))throw Ma(Dt());e+=Dt()}return String.fromCodePoint(parseInt(e,16))}const SLe={start(){if(Wl.type==="eof")throw O1();SP()},beforePropertyName(){switch(Wl.type){case"identifier":case"string":nL=Wl.value,lc="afterPropertyName";return;case"punctuator":gE();return;case"eof":throw O1()}},afterPropertyName(){if(Wl.type==="eof")throw O1();lc="beforePropertyValue"},beforePropertyValue(){if(Wl.type==="eof")throw O1();SP()},beforeArrayValue(){if(Wl.type==="eof")throw O1();if(Wl.type==="punctuator"&&Wl.value==="]"){gE();return}SP()},afterPropertyValue(){if(Wl.type==="eof")throw O1();switch(Wl.value){case",":lc="beforePropertyName";return;case"}":gE()}},afterArrayValue(){if(Wl.type==="eof")throw O1();switch(Wl.value){case",":lc="beforeArrayValue";return;case"]":gE()}},end(){}};function SP(){let e;switch(Wl.type){case"punctuator":switch(Wl.value){case"{":e={};break;case"[":e=[];break}break;case"null":case"boolean":case"numeric":case"string":e=Wl.value;break}if(X2===void 0)X2=e;else{const t=Xm[Xm.length-1];Array.isArray(t)?t.push(e):Object.defineProperty(t,nL,{value:e,writable:!0,enumerable:!0,configurable:!0})}if(e!==null&&typeof e=="object")Xm.push(e),Array.isArray(e)?lc="beforeArrayValue":lc="beforePropertyName";else{const t=Xm[Xm.length-1];t==null?lc="end":Array.isArray(t)?lc="afterArrayValue":lc="afterPropertyValue"}}function gE(){Xm.pop();const e=Xm[Xm.length-1];e==null?lc="end":Array.isArray(e)?lc="afterArrayValue":lc="afterPropertyValue"}function Ma(e){return T$(e===void 0?`JSON5: invalid end of input at ${uy}:${rp}`:`JSON5: invalid character '${Pme(e)}' at ${uy}:${rp}`)}function O1(){return T$(`JSON5: invalid end of input at ${uy}:${rp}`)}function kX(){return rp-=5,T$(`JSON5: invalid identifier character at ${uy}:${rp}`)}function _Le(e){console.warn(`JSON5: '${Pme(e)}' in strings is not valid ECMAScript; consider escaping`)}function Pme(e){const t={"'":"\\'",'"':'\\"',"\\":"\\\\","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","	":"\\t","\v":"\\v","\0":"\\0","\u2028":"\\u2028","\u2029":"\\u2029"};if(t[e])return t[e];if(e<" "){const n=e.charCodeAt(0).toString(16);return"\\x"+("00"+n).substring(n.length)}return e}function T$(e){const t=new SyntaxError(e);return t.lineNumber=uy,t.columnNumber=rp,t}var ELe=function(t,n,r){const i=[];let a="",u,l,o="",s;if(n!=null&&typeof n=="object"&&!Array.isArray(n)&&(r=n.space,s=n.quote,n=n.replacer),typeof n=="function")l=n;else if(Array.isArray(n)){u=[];for(const v of n){let _;typeof v=="string"?_=v:(typeof v=="number"||v instanceof String||v instanceof Number)&&(_=String(v)),_!==void 0&&u.indexOf(_)<0&&u.push(_)}}return r instanceof Number?r=Number(r):r instanceof String&&(r=String(r)),typeof r=="number"?r>0&&(r=Math.min(10,Math.floor(r)),o="          ".substr(0,r)):typeof r=="string"&&(o=r.substr(0,10)),c("",{"":t});function c(v,_){let S=_[v];switch(S!=null&&(typeof S.toJSON5=="function"?S=S.toJSON5(v):typeof S.toJSON=="function"&&(S=S.toJSON(v))),l&&(S=l.call(_,v,S)),S instanceof Number?S=Number(S):S instanceof String?S=String(S):S instanceof Boolean&&(S=S.valueOf()),S){case null:return"null";case!0:return"true";case!1:return"false"}if(typeof S=="string")return d(S);if(typeof S=="number")return String(S);if(typeof S=="object")return Array.isArray(S)?y(S):h(S)}function d(v){const _={"'":.1,'"':.2},S={"'":"\\'",'"':'\\"',"\\":"\\\\","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","	":"\\t","\v":"\\v","\0":"\\0","\u2028":"\\u2028","\u2029":"\\u2029"};let E="";for(let T=0;T<v.length;T++){const R=v[T];switch(R){case"'":case'"':_[R]++,E+=R;continue;case"\0":if(zu.isDigit(v[T+1])){E+="\\x00";continue}}if(S[R]){E+=S[R];continue}if(R<" "){let $=R.charCodeAt(0).toString(16);E+="\\x"+("00"+$).substring($.length);continue}E+=R}const C=s||Object.keys(_).reduce((T,R)=>_[T]<_[R]?T:R);return E=E.replace(new RegExp(C,"g"),S[C]),C+E+C}function h(v){if(i.indexOf(v)>=0)throw TypeError("Converting circular structure to JSON5");i.push(v);let _=a;a=a+o;let S=u||Object.keys(v),E=[];for(const T of S){const R=c(T,v);if(R!==void 0){let $=m(T)+":";o!==""&&($+=" "),$+=R,E.push($)}}let C;if(E.length===0)C="{}";else{let T;if(o==="")T=E.join(","),C="{"+T+"}";else{let R=`,
`+a;T=E.join(R),C=`{
`+a+T+`,
`+_+"}"}}return i.pop(),a=_,C}function m(v){if(v.length===0)return d(v);const _=String.fromCodePoint(v.codePointAt(0));if(!zu.isIdStartChar(_))return d(v);for(let S=_.length;S<v.length;S++)if(!zu.isIdContinueChar(String.fromCodePoint(v.codePointAt(S))))return d(v);return v}function y(v){if(i.indexOf(v)>=0)throw TypeError("Converting circular structure to JSON5");i.push(v);let _=a;a=a+o;let S=[];for(let C=0;C<v.length;C++){const T=c(String(C),v);S.push(T!==void 0?T:"null")}let E;if(S.length===0)E="[]";else if(o==="")E="["+S.join(",")+"]";else{let C=`,
`+a,T=S.join(C);E=`[
`+a+T+`,
`+_+"]"}return i.pop(),a=_,E}};const DLe={parse:yLe,stringify:ELe};var Wat=DLe;const rL=Symbol.for("yaml.alias"),kM=Symbol.for("yaml.document"),Zv=Symbol.for("yaml.map"),Mme=Symbol.for("yaml.pair"),M0=Symbol.for("yaml.scalar"),u4=Symbol.for("yaml.seq"),Jd=Symbol.for("yaml.node.type"),xy=e=>!!e&&typeof e=="object"&&e[Jd]===rL,Tb=e=>!!e&&typeof e=="object"&&e[Jd]===kM,l4=e=>!!e&&typeof e=="object"&&e[Jd]===Zv,Za=e=>!!e&&typeof e=="object"&&e[Jd]===Mme,oa=e=>!!e&&typeof e=="object"&&e[Jd]===M0,o4=e=>!!e&&typeof e=="object"&&e[Jd]===u4;function ou(e){if(e&&typeof e=="object")switch(e[Jd]){case Zv:case u4:return!0}return!1}function cu(e){if(e&&typeof e=="object")switch(e[Jd]){case rL:case Zv:case M0:case u4:return!0}return!1}const Fme=e=>(oa(e)||ou(e))&&!!e.anchor,nf=Symbol("break visit"),Nme=Symbol("skip children"),T0=Symbol("remove node");function kb(e,t){const n=Ime(t);Tb(e)?ZO(null,e.contents,n,Object.freeze([e]))===T0&&(e.contents=null):ZO(null,e,n,Object.freeze([]))}kb.BREAK=nf;kb.SKIP=Nme;kb.REMOVE=T0;function ZO(e,t,n,r){const i=Lme(e,t,n,r);if(cu(i)||Za(i))return Bme(e,r,i),ZO(e,i,n,r);if(typeof i!="symbol"){if(ou(t)){r=Object.freeze(r.concat(t));for(let a=0;a<t.items.length;++a){const u=ZO(a,t.items[a],n,r);if(typeof u=="number")a=u-1;else{if(u===nf)return nf;u===T0&&(t.items.splice(a,1),a-=1)}}}else if(Za(t)){r=Object.freeze(r.concat(t));const a=ZO("key",t.key,n,r);if(a===nf)return nf;a===T0&&(t.key=null);const u=ZO("value",t.value,n,r);if(u===nf)return nf;u===T0&&(t.value=null)}}return i}async function Dw(e,t){const n=Ime(t);Tb(e)?await HO(null,e.contents,n,Object.freeze([e]))===T0&&(e.contents=null):await HO(null,e,n,Object.freeze([]))}Dw.BREAK=nf;Dw.SKIP=Nme;Dw.REMOVE=T0;async function HO(e,t,n,r){const i=await Lme(e,t,n,r);if(cu(i)||Za(i))return Bme(e,r,i),HO(e,i,n,r);if(typeof i!="symbol"){if(ou(t)){r=Object.freeze(r.concat(t));for(let a=0;a<t.items.length;++a){const u=await HO(a,t.items[a],n,r);if(typeof u=="number")a=u-1;else{if(u===nf)return nf;u===T0&&(t.items.splice(a,1),a-=1)}}}else if(Za(t)){r=Object.freeze(r.concat(t));const a=await HO("key",t.key,n,r);if(a===nf)return nf;a===T0&&(t.key=null);const u=await HO("value",t.value,n,r);if(u===nf)return nf;u===T0&&(t.value=null)}}return i}function Ime(e){return typeof e=="object"&&(e.Collection||e.Node||e.Value)?Object.assign({Alias:e.Node,Map:e.Node,Scalar:e.Node,Seq:e.Node},e.Value&&{Map:e.Value,Scalar:e.Value,Seq:e.Value},e.Collection&&{Map:e.Collection,Seq:e.Collection},e):e}function Lme(e,t,n,r){var i,a,u,l,o;if(typeof n=="function")return n(e,t,r);if(l4(t))return(i=n.Map)==null?void 0:i.call(n,e,t,r);if(o4(t))return(a=n.Seq)==null?void 0:a.call(n,e,t,r);if(Za(t))return(u=n.Pair)==null?void 0:u.call(n,e,t,r);if(oa(t))return(l=n.Scalar)==null?void 0:l.call(n,e,t,r);if(xy(t))return(o=n.Alias)==null?void 0:o.call(n,e,t,r)}function Bme(e,t,n){const r=t[t.length-1];if(ou(r))r.items[e]=n;else if(Za(r))e==="key"?r.key=n:r.value=n;else if(Tb(r))r.contents=n;else{const i=xy(r)?"alias":"scalar";throw new Error(`Cannot replace node with ${i} parent`)}}const $Le={"!":"%21",",":"%2C","[":"%5B","]":"%5D","{":"%7B","}":"%7D"},CLe=e=>e.replace(/[!,[\]{}]/g,t=>$Le[t]);class ic{constructor(t,n){this.docStart=null,this.docEnd=!1,this.yaml=Object.assign({},ic.defaultYaml,t),this.tags=Object.assign({},ic.defaultTags,n)}clone(){const t=new ic(this.yaml,this.tags);return t.docStart=this.docStart,t}atDocument(){const t=new ic(this.yaml,this.tags);switch(this.yaml.version){case"1.1":this.atNextDocument=!0;break;case"1.2":this.atNextDocument=!1,this.yaml={explicit:ic.defaultYaml.explicit,version:"1.2"},this.tags=Object.assign({},ic.defaultTags);break}return t}add(t,n){this.atNextDocument&&(this.yaml={explicit:ic.defaultYaml.explicit,version:"1.1"},this.tags=Object.assign({},ic.defaultTags),this.atNextDocument=!1);const r=t.trim().split(/[ \t]+/),i=r.shift();switch(i){case"%TAG":{if(r.length!==2&&(n(0,"%TAG directive should contain exactly two parts"),r.length<2))return!1;const[a,u]=r;return this.tags[a]=u,!0}case"%YAML":{if(this.yaml.explicit=!0,r.length!==1)return n(0,"%YAML directive should contain exactly one part"),!1;const[a]=r;if(a==="1.1"||a==="1.2")return this.yaml.version=a,!0;{const u=/^\d+\.\d+$/.test(a);return n(6,`Unsupported YAML version ${a}`,u),!1}}default:return n(0,`Unknown directive ${i}`,!0),!1}}tagName(t,n){if(t==="!")return"!";if(t[0]!=="!")return n(`Not a valid tag: ${t}`),null;if(t[1]==="<"){const u=t.slice(2,-1);return u==="!"||u==="!!"?(n(`Verbatim tags aren't resolved, so ${t} is invalid.`),null):(t[t.length-1]!==">"&&n("Verbatim tags must end with a >"),u)}const[,r,i]=t.match(/^(.*!)([^!]*)$/s);i||n(`The ${t} tag has no suffix`);const a=this.tags[r];if(a)try{return a+decodeURIComponent(i)}catch(u){return n(String(u)),null}return r==="!"?t:(n(`Could not resolve tag: ${t}`),null)}tagString(t){for(const[n,r]of Object.entries(this.tags))if(t.startsWith(r))return n+CLe(t.substring(r.length));return t[0]==="!"?t:`!<${t}>`}toString(t){const n=this.yaml.explicit?[`%YAML ${this.yaml.version||"1.2"}`]:[],r=Object.entries(this.tags);let i;if(t&&r.length>0&&cu(t.contents)){const a={};kb(t.contents,(u,l)=>{cu(l)&&l.tag&&(a[l.tag]=!0)}),i=Object.keys(a)}else i=[];for(const[a,u]of r)a==="!!"&&u==="tag:yaml.org,2002:"||(!t||i.some(l=>l.startsWith(u)))&&n.push(`%TAG ${a} ${u}`);return n.join(`
`)}}ic.defaultYaml={explicit:!1,version:"1.2"};ic.defaultTags={"!!":"tag:yaml.org,2002:"};function Qme(e){if(/[\x00-\x19\s,[\]{}]/.test(e)){const n=`Anchor must not contain whitespace or control characters: ${JSON.stringify(e)}`;throw new Error(n)}return!0}function zme(e){const t=new Set;return kb(e,{Value(n,r){r.anchor&&t.add(r.anchor)}}),t}function qme(e,t){for(let n=1;;++n){const r=`${e}${n}`;if(!t.has(r))return r}}function wLe(e,t){const n=[],r=new Map;let i=null;return{onAnchor:a=>{n.push(a),i??(i=zme(e));const u=qme(t,i);return i.add(u),u},setAnchors:()=>{for(const a of n){const u=r.get(a);if(typeof u=="object"&&u.anchor&&(oa(u.node)||ou(u.node)))u.node.anchor=u.anchor;else{const l=new Error("Failed to resolve repeated object (this should not happen)");throw l.source=a,l}}},sourceObjects:r}}function XO(e,t,n,r){if(r&&typeof r=="object")if(Array.isArray(r))for(let i=0,a=r.length;i<a;++i){const u=r[i],l=XO(e,r,String(i),u);l===void 0?delete r[i]:l!==u&&(r[i]=l)}else if(r instanceof Map)for(const i of Array.from(r.keys())){const a=r.get(i),u=XO(e,r,i,a);u===void 0?r.delete(i):u!==a&&r.set(i,u)}else if(r instanceof Set)for(const i of Array.from(r)){const a=XO(e,r,i,i);a===void 0?r.delete(i):a!==i&&(r.delete(i),r.add(a))}else for(const[i,a]of Object.entries(r)){const u=XO(e,r,i,a);u===void 0?delete r[i]:u!==a&&(r[i]=u)}return e.call(t,n,r)}function Kd(e,t,n){if(Array.isArray(e))return e.map((r,i)=>Kd(r,String(i),n));if(e&&typeof e.toJSON=="function"){if(!n||!Fme(e))return e.toJSON(t,n);const r={aliasCount:0,count:1,res:void 0};n.anchors.set(e,r),n.onCreate=a=>{r.res=a,delete n.onCreate};const i=e.toJSON(t,n);return n.onCreate&&n.onCreate(i),i}return typeof e=="bigint"&&!(n!=null&&n.keep)?Number(e):e}class iL{constructor(t){Object.defineProperty(this,Jd,{value:t})}clone(){const t=Object.create(Object.getPrototypeOf(this),Object.getOwnPropertyDescriptors(this));return this.range&&(t.range=this.range.slice()),t}toJS(t,{mapAsMap:n,maxAliasCount:r,onAnchor:i,reviver:a}={}){if(!Tb(t))throw new TypeError("A document argument is required");const u={anchors:new Map,doc:t,keep:!0,mapAsMap:n===!0,mapKeyWarned:!1,maxAliasCount:typeof r=="number"?r:100},l=Kd(this,"",u);if(typeof i=="function")for(const{count:o,res:s}of u.anchors.values())i(s,o);return typeof a=="function"?XO(a,{"":l},"",l):l}}class $w extends iL{constructor(t){super(rL),this.source=t,Object.defineProperty(this,"tag",{set(){throw new Error("Alias nodes cannot have tags")}})}resolve(t,n){let r;n!=null&&n.aliasResolveCache?r=n.aliasResolveCache:(r=[],kb(t,{Node:(a,u)=>{(xy(u)||Fme(u))&&r.push(u)}}),n&&(n.aliasResolveCache=r));let i;for(const a of r){if(a===this)break;a.anchor===this.source&&(i=a)}return i}toJSON(t,n){if(!n)return{source:this.source};const{anchors:r,doc:i,maxAliasCount:a}=n,u=this.resolve(i,n);if(!u){const o=`Unresolved alias (the anchor must be set before the alias): ${this.source}`;throw new ReferenceError(o)}let l=r.get(u);if(l||(Kd(u,null,n),l=r.get(u)),!l||l.res===void 0){const o="This should not happen: Alias anchor was not resolved?";throw new ReferenceError(o)}if(a>=0&&(l.count+=1,l.aliasCount===0&&(l.aliasCount=cD(i,u,r)),l.count*l.aliasCount>a)){const o="Excessive alias count indicates a resource exhaustion attack";throw new ReferenceError(o)}return l.res}toString(t,n,r){const i=`*${this.source}`;if(t){if(Qme(this.source),t.options.verifyAliasOrder&&!t.anchors.has(this.source)){const a=`Unresolved alias (the anchor must be set before the alias): ${this.source}`;throw new Error(a)}if(t.implicitKey)return`${i} `}return i}}function cD(e,t,n){if(xy(t)){const r=t.resolve(e),i=n&&r&&n.get(r);return i?i.count*i.aliasCount:0}else if(ou(t)){let r=0;for(const i of t.items){const a=cD(e,i,n);a>r&&(r=a)}return r}else if(Za(t)){const r=cD(e,t.key,n),i=cD(e,t.value,n);return Math.max(r,i)}return 1}const Vme=e=>!e||typeof e!="function"&&typeof e!="object";class ar extends iL{constructor(t){super(M0),this.value=t}toJSON(t,n){return n!=null&&n.keep?this.value:Kd(this.value,t,n)}toString(){return String(this.value)}}ar.BLOCK_FOLDED="BLOCK_FOLDED";ar.BLOCK_LITERAL="BLOCK_LITERAL";ar.PLAIN="PLAIN";ar.QUOTE_DOUBLE="QUOTE_DOUBLE";ar.QUOTE_SINGLE="QUOTE_SINGLE";const RLe="tag:yaml.org,2002:";function ALe(e,t,n){if(t){const r=n.filter(a=>a.tag===t),i=r.find(a=>!a.format)??r[0];if(!i)throw new Error(`Tag ${t} not found`);return i}return n.find(r=>{var i;return((i=r.identify)==null?void 0:i.call(r,e))&&!r.format})}function Bx(e,t,n){var d,h,m;if(Tb(e)&&(e=e.contents),cu(e))return e;if(Za(e)){const y=(h=(d=n.schema[Zv]).createNode)==null?void 0:h.call(d,n.schema,null,n);return y.items.push(e),y}(e instanceof String||e instanceof Number||e instanceof Boolean||typeof BigInt<"u"&&e instanceof BigInt)&&(e=e.valueOf());const{aliasDuplicateObjects:r,onAnchor:i,onTagObj:a,schema:u,sourceObjects:l}=n;let o;if(r&&e&&typeof e=="object"){if(o=l.get(e),o)return o.anchor??(o.anchor=i(e)),new $w(o.anchor);o={anchor:null,node:null},l.set(e,o)}t!=null&&t.startsWith("!!")&&(t=RLe+t.slice(2));let s=ALe(e,t,u.tags);if(!s){if(e&&typeof e.toJSON=="function"&&(e=e.toJSON()),!e||typeof e!="object"){const y=new ar(e);return o&&(o.node=y),y}s=e instanceof Map?u[Zv]:Symbol.iterator in Object(e)?u[u4]:u[Zv]}a&&(a(s),delete n.onTagObj);const c=s!=null&&s.createNode?s.createNode(n.schema,e,n):typeof((m=s==null?void 0:s.nodeClass)==null?void 0:m.from)=="function"?s.nodeClass.from(n.schema,e,n):new ar(e);return t?c.tag=t:s.default||(c.tag=s.tag),o&&(o.node=c),c}function k$(e,t,n){let r=n;for(let i=t.length-1;i>=0;--i){const a=t[i];if(typeof a=="number"&&Number.isInteger(a)&&a>=0){const u=[];u[a]=r,r=u}else r=new Map([[a,r]])}return Bx(r,void 0,{aliasDuplicateObjects:!1,keepUndefined:!1,onAnchor:()=>{throw new Error("This should not happen, please report a bug.")},schema:e,sourceObjects:new Map})}const I2=e=>e==null||typeof e=="object"&&!!e[Symbol.iterator]().next().done;class Ume extends iL{constructor(t,n){super(t),Object.defineProperty(this,"schema",{value:n,configurable:!0,enumerable:!1,writable:!0})}clone(t){const n=Object.create(Object.getPrototypeOf(this),Object.getOwnPropertyDescriptors(this));return t&&(n.schema=t),n.items=n.items.map(r=>cu(r)||Za(r)?r.clone(t):r),this.range&&(n.range=this.range.slice()),n}addIn(t,n){if(I2(t))this.add(n);else{const[r,...i]=t,a=this.get(r,!0);if(ou(a))a.addIn(i,n);else if(a===void 0&&this.schema)this.set(r,k$(this.schema,i,n));else throw new Error(`Expected YAML collection at ${r}. Remaining path: ${i}`)}}deleteIn(t){const[n,...r]=t;if(r.length===0)return this.delete(n);const i=this.get(n,!0);if(ou(i))return i.deleteIn(r);throw new Error(`Expected YAML collection at ${n}. Remaining path: ${r}`)}getIn(t,n){const[r,...i]=t,a=this.get(r,!0);return i.length===0?!n&&oa(a)?a.value:a:ou(a)?a.getIn(i,n):void 0}hasAllNullValues(t){return this.items.every(n=>{if(!Za(n))return!1;const r=n.value;return r==null||t&&oa(r)&&r.value==null&&!r.commentBefore&&!r.comment&&!r.tag})}hasIn(t){const[n,...r]=t;if(r.length===0)return this.has(n);const i=this.get(n,!0);return ou(i)?i.hasIn(r):!1}setIn(t,n){const[r,...i]=t;if(i.length===0)this.set(r,n);else{const a=this.get(r,!0);if(ou(a))a.setIn(i,n);else if(a===void 0&&this.schema)this.set(r,k$(this.schema,i,n));else throw new Error(`Expected YAML collection at ${r}. Remaining path: ${i}`)}}}const TLe=e=>e.replace(/^(?!$)(?: $)?/gm,"#");function Jm(e,t){return/^\n+$/.test(e)?e.substring(1):t?e.replace(/^(?! *$)/gm,t):e}const z1=(e,t,n)=>e.endsWith(`
`)?Jm(n,t):n.includes(`
`)?`
`+Jm(n,t):(e.endsWith(" ")?"":" ")+n,jme="flow",PM="block",fD="quoted";function Cw(e,t,n="flow",{indentAtStart:r,lineWidth:i=80,minContentWidth:a=20,onFold:u,onOverflow:l}={}){if(!i||i<0)return e;i<a&&(a=0);const o=Math.max(1+a,1+i-t.length);if(e.length<=o)return e;const s=[],c={};let d=i-t.length;typeof r=="number"&&(r>i-Math.max(2,a)?s.push(0):d=i-r);let h,m,y=!1,v=-1,_=-1,S=-1;n===PM&&(v=PX(e,v,t.length),v!==-1&&(d=v+o));for(let C;C=e[v+=1];){if(n===fD&&C==="\\"){switch(_=v,e[v+1]){case"x":v+=3;break;case"u":v+=5;break;case"U":v+=9;break;default:v+=1}S=v}if(C===`
`)n===PM&&(v=PX(e,v,t.length)),d=v+t.length+o,h=void 0;else{if(C===" "&&m&&m!==" "&&m!==`
`&&m!=="	"){const T=e[v+1];T&&T!==" "&&T!==`
`&&T!=="	"&&(h=v)}if(v>=d)if(h)s.push(h),d=h+o,h=void 0;else if(n===fD){for(;m===" "||m==="	";)m=C,C=e[v+=1],y=!0;const T=v>S+1?v-2:_-1;if(c[T])return e;s.push(T),c[T]=!0,d=T+o,h=void 0}else y=!0}m=C}if(y&&l&&l(),s.length===0)return e;u&&u();let E=e.slice(0,s[0]);for(let C=0;C<s.length;++C){const T=s[C],R=s[C+1]||e.length;T===0?E=`
${t}${e.slice(0,R)}`:(n===fD&&c[T]&&(E+=`${e[T]}\\`),E+=`
${t}${e.slice(T+1,R)}`)}return E}function PX(e,t,n){let r=t,i=t+1,a=e[i];for(;a===" "||a==="	";)if(t<i+n)a=e[++t];else{do a=e[++t];while(a&&a!==`
`);r=t,i=t+1,a=e[i]}return r}const ww=(e,t)=>({indentAtStart:t?e.indent.length:e.indentAtStart,lineWidth:e.options.lineWidth,minContentWidth:e.options.minContentWidth}),Rw=e=>/^(%|---|\.\.\.)/m.test(e);function kLe(e,t,n){if(!t||t<0)return!1;const r=t-n,i=e.length;if(i<=r)return!1;for(let a=0,u=0;a<i;++a)if(e[a]===`
`){if(a-u>r)return!0;if(u=a+1,i-u<=r)return!1}return!0}function Y2(e,t){const n=JSON.stringify(e);if(t.options.doubleQuotedAsJSON)return n;const{implicitKey:r}=t,i=t.options.doubleQuotedMinMultiLineLength,a=t.indent||(Rw(e)?"  ":"");let u="",l=0;for(let o=0,s=n[o];s;s=n[++o])if(s===" "&&n[o+1]==="\\"&&n[o+2]==="n"&&(u+=n.slice(l,o)+"\\ ",o+=1,l=o,s="\\"),s==="\\")switch(n[o+1]){case"u":{u+=n.slice(l,o);const c=n.substr(o+2,4);switch(c){case"0000":u+="\\0";break;case"0007":u+="\\a";break;case"000b":u+="\\v";break;case"001b":u+="\\e";break;case"0085":u+="\\N";break;case"00a0":u+="\\_";break;case"2028":u+="\\L";break;case"2029":u+="\\P";break;default:c.substr(0,2)==="00"?u+="\\x"+c.substr(2):u+=n.substr(o,6)}o+=5,l=o+1}break;case"n":if(r||n[o+2]==='"'||n.length<i)o+=1;else{for(u+=n.slice(l,o)+`

`;n[o+2]==="\\"&&n[o+3]==="n"&&n[o+4]!=='"';)u+=`
`,o+=2;u+=a,n[o+2]===" "&&(u+="\\"),o+=1,l=o+1}break;default:o+=1}return u=l?u+n.slice(l):n,r?u:Cw(u,a,fD,ww(t,!1))}function MM(e,t){if(t.options.singleQuote===!1||t.implicitKey&&e.includes(`
`)||/[ \t]\n|\n[ \t]/.test(e))return Y2(e,t);const n=t.indent||(Rw(e)?"  ":""),r="'"+e.replace(/'/g,"''").replace(/\n+/g,`$&
${n}`)+"'";return t.implicitKey?r:Cw(r,n,jme,ww(t,!1))}function YO(e,t){const{singleQuote:n}=t.options;let r;if(n===!1)r=Y2;else{const i=e.includes('"'),a=e.includes("'");i&&!a?r=MM:a&&!i?r=Y2:r=n?MM:Y2}return r(e,t)}let FM;try{FM=new RegExp(`(^|(?<!
))
+(?!
|$)`,"g")}catch{FM=/\n+(?!\n|$)/g}function dD({comment:e,type:t,value:n},r,i,a){const{blockQuote:u,commentString:l,lineWidth:o}=r.options;if(!u||/\n[\t ]+$/.test(n)||/^\s*$/.test(n))return YO(n,r);const s=r.indent||(r.forceBlockIndent||Rw(n)?"  ":""),c=u==="literal"?!0:u==="folded"||t===ar.BLOCK_FOLDED?!1:t===ar.BLOCK_LITERAL?!0:!kLe(n,o,s.length);if(!n)return c?`|
`:`>
`;let d,h;for(h=n.length;h>0;--h){const R=n[h-1];if(R!==`
`&&R!=="	"&&R!==" ")break}let m=n.substring(h);const y=m.indexOf(`
`);y===-1?d="-":n===m||y!==m.length-1?(d="+",a&&a()):d="",m&&(n=n.slice(0,-m.length),m[m.length-1]===`
`&&(m=m.slice(0,-1)),m=m.replace(FM,`$&${s}`));let v=!1,_,S=-1;for(_=0;_<n.length;++_){const R=n[_];if(R===" ")v=!0;else if(R===`
`)S=_;else break}let E=n.substring(0,S<_?S+1:_);E&&(n=n.substring(E.length),E=E.replace(/\n+/g,`$&${s}`));let T=(v?s?"2":"1":"")+d;if(e&&(T+=" "+l(e.replace(/ ?[\r\n]+/g," ")),i&&i()),!c){const R=n.replace(/\n+/g,`
$&`).replace(/(?:^|\n)([\t ].*)(?:([\n\t ]*)\n(?![\n\t ]))?/g,"$1$2").replace(/\n+/g,`$&${s}`);let $=!1;const k=ww(r,!0);u!=="folded"&&t!==ar.BLOCK_FOLDED&&(k.onOverflow=()=>{$=!0});const F=Cw(`${E}${R}${m}`,s,PM,k);if(!$)return`>${T}
${s}${F}`}return n=n.replace(/\n+/g,`$&${s}`),`|${T}
${s}${E}${n}${m}`}function PLe(e,t,n,r){const{type:i,value:a}=e,{actualString:u,implicitKey:l,indent:o,indentStep:s,inFlow:c}=t;if(l&&a.includes(`
`)||c&&/[[\]{},]/.test(a))return YO(a,t);if(/^[\n\t ,[\]{}#&*!|>'"%@`]|^[?-]$|^[?-][ \t]|[\n:][ \t]|[ \t]\n|[\n\t ]#|[\n\t :]$/.test(a))return l||c||!a.includes(`
`)?YO(a,t):dD(e,t,n,r);if(!l&&!c&&i!==ar.PLAIN&&a.includes(`
`))return dD(e,t,n,r);if(Rw(a)){if(o==="")return t.forceBlockIndent=!0,dD(e,t,n,r);if(l&&o===s)return YO(a,t)}const d=a.replace(/\n+/g,`$&
${o}`);if(u){const h=v=>{var _;return v.default&&v.tag!=="tag:yaml.org,2002:str"&&((_=v.test)==null?void 0:_.test(d))},{compat:m,tags:y}=t.doc.schema;if(y.some(h)||m!=null&&m.some(h))return YO(a,t)}return l?d:Cw(d,o,jme,ww(t,!1))}function RS(e,t,n,r){const{implicitKey:i,inFlow:a}=t,u=typeof e.value=="string"?e:Object.assign({},e,{value:String(e.value)});let{type:l}=e;l!==ar.QUOTE_DOUBLE&&/[\x00-\x08\x0b-\x1f\x7f-\x9f\u{D800}-\u{DFFF}]/u.test(u.value)&&(l=ar.QUOTE_DOUBLE);const o=c=>{switch(c){case ar.BLOCK_FOLDED:case ar.BLOCK_LITERAL:return i||a?YO(u.value,t):dD(u,t,n,r);case ar.QUOTE_DOUBLE:return Y2(u.value,t);case ar.QUOTE_SINGLE:return MM(u.value,t);case ar.PLAIN:return PLe(u,t,n,r);default:return null}};let s=o(l);if(s===null){const{defaultKeyType:c,defaultStringType:d}=t.options,h=i&&c||d;if(s=o(h),s===null)throw new Error(`Unsupported default string type ${h}`)}return s}function Zme(e,t){const n=Object.assign({blockQuote:!0,commentString:TLe,defaultKeyType:null,defaultStringType:"PLAIN",directives:null,doubleQuotedAsJSON:!1,doubleQuotedMinMultiLineLength:40,falseStr:"false",flowCollectionPadding:!0,indentSeq:!0,lineWidth:80,minContentWidth:20,nullStr:"null",simpleKeys:!1,singleQuote:null,trueStr:"true",verifyAliasOrder:!0},e.schema.toStringOptions,t);let r;switch(n.collectionStyle){case"block":r=!1;break;case"flow":r=!0;break;default:r=null}return{anchors:new Set,doc:e,flowCollectionPadding:n.flowCollectionPadding?" ":"",indent:"",indentStep:typeof n.indent=="number"?" ".repeat(n.indent):"  ",inFlow:r,options:n}}function MLe(e,t){var i;if(t.tag){const a=e.filter(u=>u.tag===t.tag);if(a.length>0)return a.find(u=>u.format===t.format)??a[0]}let n,r;if(oa(t)){r=t.value;let a=e.filter(u=>{var l;return(l=u.identify)==null?void 0:l.call(u,r)});if(a.length>1){const u=a.filter(l=>l.test);u.length>0&&(a=u)}n=a.find(u=>u.format===t.format)??a.find(u=>!u.format)}else r=t,n=e.find(a=>a.nodeClass&&r instanceof a.nodeClass);if(!n){const a=((i=r==null?void 0:r.constructor)==null?void 0:i.name)??(r===null?"null":typeof r);throw new Error(`Tag not resolved for ${a} value`)}return n}function FLe(e,t,{anchors:n,doc:r}){if(!r.directives)return"";const i=[],a=(oa(e)||ou(e))&&e.anchor;a&&Qme(a)&&(n.add(a),i.push(`&${a}`));const u=e.tag??(t.default?null:t.tag);return u&&i.push(r.directives.tagString(u)),i.join(" ")}function F3(e,t,n,r){var o;if(Za(e))return e.toString(t,n,r);if(xy(e)){if(t.doc.directives)return e.toString(t);if((o=t.resolvedAliases)!=null&&o.has(e))throw new TypeError("Cannot stringify circular structure without alias nodes");t.resolvedAliases?t.resolvedAliases.add(e):t.resolvedAliases=new Set([e]),e=e.resolve(t.doc)}let i;const a=cu(e)?e:t.doc.createNode(e,{onTagObj:s=>i=s});i??(i=MLe(t.doc.schema.tags,a));const u=FLe(a,i,t);u.length>0&&(t.indentAtStart=(t.indentAtStart??0)+u.length+1);const l=typeof i.stringify=="function"?i.stringify(a,t,n,r):oa(a)?RS(a,t,n,r):a.toString(t,n,r);return u?oa(a)||l[0]==="{"||l[0]==="["?`${u} ${l}`:`${u}
${t.indent}${l}`:l}function NLe({key:e,value:t},n,r,i){const{allNullValues:a,doc:u,indent:l,indentStep:o,options:{commentString:s,indentSeq:c,simpleKeys:d}}=n;let h=cu(e)&&e.comment||null;if(d){if(h)throw new Error("With simple keys, key nodes cannot have comments");if(ou(e)||!cu(e)&&typeof e=="object"){const k="With simple keys, collection cannot be used as a key value";throw new Error(k)}}let m=!d&&(!e||h&&t==null&&!n.inFlow||ou(e)||(oa(e)?e.type===ar.BLOCK_FOLDED||e.type===ar.BLOCK_LITERAL:typeof e=="object"));n=Object.assign({},n,{allNullValues:!1,implicitKey:!m&&(d||!a),indent:l+o});let y=!1,v=!1,_=F3(e,n,()=>y=!0,()=>v=!0);if(!m&&!n.inFlow&&_.length>1024){if(d)throw new Error("With simple keys, single line scalar must not span more than 1024 characters");m=!0}if(n.inFlow){if(a||t==null)return y&&r&&r(),_===""?"?":m?`? ${_}`:_}else if(a&&!d||t==null&&m)return _=`? ${_}`,h&&!y?_+=z1(_,n.indent,s(h)):v&&i&&i(),_;y&&(h=null),m?(h&&(_+=z1(_,n.indent,s(h))),_=`? ${_}
${l}:`):(_=`${_}:`,h&&(_+=z1(_,n.indent,s(h))));let S,E,C;cu(t)?(S=!!t.spaceBefore,E=t.commentBefore,C=t.comment):(S=!1,E=null,C=null,t&&typeof t=="object"&&(t=u.createNode(t))),n.implicitKey=!1,!m&&!h&&oa(t)&&(n.indentAtStart=_.length+1),v=!1,!c&&o.length>=2&&!n.inFlow&&!m&&o4(t)&&!t.flow&&!t.tag&&!t.anchor&&(n.indent=n.indent.substring(2));let T=!1;const R=F3(t,n,()=>T=!0,()=>v=!0);let $=" ";if(h||S||E){if($=S?`
`:"",E){const k=s(E);$+=`
${Jm(k,n.indent)}`}R===""&&!n.inFlow?$===`
`&&($=`

`):$+=`
${n.indent}`}else if(!m&&ou(t)){const k=R[0],F=R.indexOf(`
`),L=F!==-1,j=n.inFlow??t.flow??t.items.length===0;if(L||!j){let V=!1;if(L&&(k==="&"||k==="!")){let q=R.indexOf(" ");k==="&"&&q!==-1&&q<F&&R[q+1]==="!"&&(q=R.indexOf(" ",q+1)),(q===-1||F<q)&&(V=!0)}V||($=`
${n.indent}`)}}else(R===""||R[0]===`
`)&&($="");return _+=$+R,n.inFlow?T&&r&&r():C&&!T?_+=z1(_,n.indent,s(C)):v&&i&&i(),_}function Hme(e,t){(e==="debug"||e==="warn")&&console.warn(t)}const vE="<<",ag={identify:e=>e===vE||typeof e=="symbol"&&e.description===vE,default:"key",tag:"tag:yaml.org,2002:merge",test:/^<<$/,resolve:()=>Object.assign(new ar(Symbol(vE)),{addToJSMap:Xme}),stringify:()=>vE},ILe=(e,t)=>(ag.identify(t)||oa(t)&&(!t.type||t.type===ar.PLAIN)&&ag.identify(t.value))&&(e==null?void 0:e.doc.schema.tags.some(n=>n.tag===ag.tag&&n.default));function Xme(e,t,n){if(n=e&&xy(n)?n.resolve(e.doc):n,o4(n))for(const r of n.items)_P(e,t,r);else if(Array.isArray(n))for(const r of n)_P(e,t,r);else _P(e,t,n)}function _P(e,t,n){const r=e&&xy(n)?n.resolve(e.doc):n;if(!l4(r))throw new Error("Merge sources must be maps or map aliases");const i=r.toJSON(null,e,Map);for(const[a,u]of i)t instanceof Map?t.has(a)||t.set(a,u):t instanceof Set?t.add(a):Object.prototype.hasOwnProperty.call(t,a)||Object.defineProperty(t,a,{value:u,writable:!0,enumerable:!0,configurable:!0});return t}function Yme(e,t,{key:n,value:r}){if(cu(n)&&n.addToJSMap)n.addToJSMap(e,t,r);else if(ILe(e,n))Xme(e,t,r);else{const i=Kd(n,"",e);if(t instanceof Map)t.set(i,Kd(r,i,e));else if(t instanceof Set)t.add(i);else{const a=LLe(n,i,e),u=Kd(r,a,e);a in t?Object.defineProperty(t,a,{value:u,writable:!0,enumerable:!0,configurable:!0}):t[a]=u}}return t}function LLe(e,t,n){if(t===null)return"";if(typeof t!="object")return String(t);if(cu(e)&&(n!=null&&n.doc)){const r=Zme(n.doc,{});r.anchors=new Set;for(const a of n.anchors.keys())r.anchors.add(a.anchor);r.inFlow=!0,r.inStringifyKey=!0;const i=e.toString(r);if(!n.mapKeyWarned){let a=JSON.stringify(i);a.length>40&&(a=a.substring(0,36)+'..."'),Hme(n.doc.options.logLevel,`Keys with collection values will be stringified due to JS Object restrictions: ${a}. Set mapAsMap: true to use object keys.`),n.mapKeyWarned=!0}return i}return JSON.stringify(t)}function aL(e,t,n){const r=Bx(e,void 0,n),i=Bx(t,void 0,n);return new gs(r,i)}class gs{constructor(t,n=null){Object.defineProperty(this,Jd,{value:Mme}),this.key=t,this.value=n}clone(t){let{key:n,value:r}=this;return cu(n)&&(n=n.clone(t)),cu(r)&&(r=r.clone(t)),new gs(n,r)}toJSON(t,n){const r=n!=null&&n.mapAsMap?new Map:{};return Yme(n,r,this)}toString(t,n,r){return t!=null&&t.doc?NLe(this,t,n,r):JSON.stringify(this)}}function Gme(e,t,n){return(t.inFlow??e.flow?QLe:BLe)(e,t,n)}function BLe({comment:e,items:t},n,{blockItemPrefix:r,flowChars:i,itemIndent:a,onChompKeep:u,onComment:l}){const{indent:o,options:{commentString:s}}=n,c=Object.assign({},n,{indent:a,type:null});let d=!1;const h=[];for(let y=0;y<t.length;++y){const v=t[y];let _=null;if(cu(v))!d&&v.spaceBefore&&h.push(""),P$(n,h,v.commentBefore,d),v.comment&&(_=v.comment);else if(Za(v)){const E=cu(v.key)?v.key:null;E&&(!d&&E.spaceBefore&&h.push(""),P$(n,h,E.commentBefore,d))}d=!1;let S=F3(v,c,()=>_=null,()=>d=!0);_&&(S+=z1(S,a,s(_))),d&&_&&(d=!1),h.push(r+S)}let m;if(h.length===0)m=i.start+i.end;else{m=h[0];for(let y=1;y<h.length;++y){const v=h[y];m+=v?`
${o}${v}`:`
`}}return e?(m+=`
`+Jm(s(e),o),l&&l()):d&&u&&u(),m}function QLe({items:e},t,{flowChars:n,itemIndent:r}){const{indent:i,indentStep:a,flowCollectionPadding:u,options:{commentString:l}}=t;r+=a;const o=Object.assign({},t,{indent:r,inFlow:!0,type:null});let s=!1,c=0;const d=[];for(let y=0;y<e.length;++y){const v=e[y];let _=null;if(cu(v))v.spaceBefore&&d.push(""),P$(t,d,v.commentBefore,!1),v.comment&&(_=v.comment);else if(Za(v)){const E=cu(v.key)?v.key:null;E&&(E.spaceBefore&&d.push(""),P$(t,d,E.commentBefore,!1),E.comment&&(s=!0));const C=cu(v.value)?v.value:null;C?(C.comment&&(_=C.comment),C.commentBefore&&(s=!0)):v.value==null&&(E!=null&&E.comment)&&(_=E.comment)}_&&(s=!0);let S=F3(v,o,()=>_=null);y<e.length-1&&(S+=","),_&&(S+=z1(S,r,l(_))),!s&&(d.length>c||S.includes(`
`))&&(s=!0),d.push(S),c=d.length}const{start:h,end:m}=n;if(d.length===0)return h+m;if(!s){const y=d.reduce((v,_)=>v+_.length+2,2);s=t.options.lineWidth>0&&y>t.options.lineWidth}if(s){let y=h;for(const v of d)y+=v?`
${a}${i}${v}`:`
`;return`${y}
${i}${m}`}else return`${h}${u}${d.join(" ")}${u}${m}`}function P$({indent:e,options:{commentString:t}},n,r,i){if(r&&i&&(r=r.replace(/^\n+/,"")),r){const a=Jm(t(r),e);n.push(a.trimStart())}}function q1(e,t){const n=oa(t)?t.value:t;for(const r of e)if(Za(r)&&(r.key===t||r.key===n||oa(r.key)&&r.key.value===n))return r}class zf extends Ume{static get tagName(){return"tag:yaml.org,2002:map"}constructor(t){super(Zv,t),this.items=[]}static from(t,n,r){const{keepUndefined:i,replacer:a}=r,u=new this(t),l=(o,s)=>{if(typeof a=="function")s=a.call(n,o,s);else if(Array.isArray(a)&&!a.includes(o))return;(s!==void 0||i)&&u.items.push(aL(o,s,r))};if(n instanceof Map)for(const[o,s]of n)l(o,s);else if(n&&typeof n=="object")for(const o of Object.keys(n))l(o,n[o]);return typeof t.sortMapEntries=="function"&&u.items.sort(t.sortMapEntries),u}add(t,n){var u;let r;Za(t)?r=t:!t||typeof t!="object"||!("key"in t)?r=new gs(t,t==null?void 0:t.value):r=new gs(t.key,t.value);const i=q1(this.items,r.key),a=(u=this.schema)==null?void 0:u.sortMapEntries;if(i){if(!n)throw new Error(`Key ${r.key} already set`);oa(i.value)&&Vme(r.value)?i.value.value=r.value:i.value=r.value}else if(a){const l=this.items.findIndex(o=>a(r,o)<0);l===-1?this.items.push(r):this.items.splice(l,0,r)}else this.items.push(r)}delete(t){const n=q1(this.items,t);return n?this.items.splice(this.items.indexOf(n),1).length>0:!1}get(t,n){const r=q1(this.items,t),i=r==null?void 0:r.value;return(!n&&oa(i)?i.value:i)??void 0}has(t){return!!q1(this.items,t)}set(t,n){this.add(new gs(t,n),!0)}toJSON(t,n,r){const i=r?new r:n!=null&&n.mapAsMap?new Map:{};n!=null&&n.onCreate&&n.onCreate(i);for(const a of this.items)Yme(n,i,a);return i}toString(t,n,r){if(!t)return JSON.stringify(this);for(const i of this.items)if(!Za(i))throw new Error(`Map items must all be pairs; found ${JSON.stringify(i)} instead`);return!t.allNullValues&&this.hasAllNullValues(!1)&&(t=Object.assign({},t,{allNullValues:!0})),Gme(this,t,{blockItemPrefix:"",flowChars:{start:"{",end:"}"},itemIndent:t.indent||"",onChompKeep:r,onComment:n})}}const s4={collection:"map",default:!0,nodeClass:zf,tag:"tag:yaml.org,2002:map",resolve(e,t){return l4(e)||t("Expected a mapping for this tag"),e},createNode:(e,t,n)=>zf.from(e,t,n)};class ly extends Ume{static get tagName(){return"tag:yaml.org,2002:seq"}constructor(t){super(u4,t),this.items=[]}add(t){this.items.push(t)}delete(t){const n=yE(t);return typeof n!="number"?!1:this.items.splice(n,1).length>0}get(t,n){const r=yE(t);if(typeof r!="number")return;const i=this.items[r];return!n&&oa(i)?i.value:i}has(t){const n=yE(t);return typeof n=="number"&&n<this.items.length}set(t,n){const r=yE(t);if(typeof r!="number")throw new Error(`Expected a valid index, not ${t}.`);const i=this.items[r];oa(i)&&Vme(n)?i.value=n:this.items[r]=n}toJSON(t,n){const r=[];n!=null&&n.onCreate&&n.onCreate(r);let i=0;for(const a of this.items)r.push(Kd(a,String(i++),n));return r}toString(t,n,r){return t?Gme(this,t,{blockItemPrefix:"- ",flowChars:{start:"[",end:"]"},itemIndent:(t.indent||"")+"  ",onChompKeep:r,onComment:n}):JSON.stringify(this)}static from(t,n,r){const{replacer:i}=r,a=new this(t);if(n&&Symbol.iterator in Object(n)){let u=0;for(let l of n){if(typeof i=="function"){const o=n instanceof Set?l:String(u++);l=i.call(n,o,l)}a.items.push(Bx(l,void 0,r))}}return a}}function yE(e){let t=oa(e)?e.value:e;return t&&typeof t=="string"&&(t=Number(t)),typeof t=="number"&&Number.isInteger(t)&&t>=0?t:null}const c4={collection:"seq",default:!0,nodeClass:ly,tag:"tag:yaml.org,2002:seq",resolve(e,t){return o4(e)||t("Expected a sequence for this tag"),e},createNode:(e,t,n)=>ly.from(e,t,n)},Aw={identify:e=>typeof e=="string",default:!0,tag:"tag:yaml.org,2002:str",resolve:e=>e,stringify(e,t,n,r){return t=Object.assign({actualString:!0},t),RS(e,t,n,r)}},Tw={identify:e=>e==null,createNode:()=>new ar(null),default:!0,tag:"tag:yaml.org,2002:null",test:/^(?:~|[Nn]ull|NULL)?$/,resolve:()=>new ar(null),stringify:({source:e},t)=>typeof e=="string"&&Tw.test.test(e)?e:t.options.nullStr},uL={identify:e=>typeof e=="boolean",default:!0,tag:"tag:yaml.org,2002:bool",test:/^(?:[Tt]rue|TRUE|[Ff]alse|FALSE)$/,resolve:e=>new ar(e[0]==="t"||e[0]==="T"),stringify({source:e,value:t},n){if(e&&uL.test.test(e)){const r=e[0]==="t"||e[0]==="T";if(t===r)return e}return t?n.options.trueStr:n.options.falseStr}};function yp({format:e,minFractionDigits:t,tag:n,value:r}){if(typeof r=="bigint")return String(r);const i=typeof r=="number"?r:Number(r);if(!isFinite(i))return isNaN(i)?".nan":i<0?"-.inf":".inf";let a=JSON.stringify(r);if(!e&&t&&(!n||n==="tag:yaml.org,2002:float")&&/^\d/.test(a)){let u=a.indexOf(".");u<0&&(u=a.length,a+=".");let l=t-(a.length-u-1);for(;l-- >0;)a+="0"}return a}const Kme={identify:e=>typeof e=="number",default:!0,tag:"tag:yaml.org,2002:float",test:/^(?:[-+]?\.(?:inf|Inf|INF)|\.nan|\.NaN|\.NAN)$/,resolve:e=>e.slice(-3).toLowerCase()==="nan"?NaN:e[0]==="-"?Number.NEGATIVE_INFINITY:Number.POSITIVE_INFINITY,stringify:yp},Wme={identify:e=>typeof e=="number",default:!0,tag:"tag:yaml.org,2002:float",format:"EXP",test:/^[-+]?(?:\.[0-9]+|[0-9]+(?:\.[0-9]*)?)[eE][-+]?[0-9]+$/,resolve:e=>parseFloat(e),stringify(e){const t=Number(e.value);return isFinite(t)?t.toExponential():yp(e)}},Jme={identify:e=>typeof e=="number",default:!0,tag:"tag:yaml.org,2002:float",test:/^[-+]?(?:\.[0-9]+|[0-9]+\.[0-9]*)$/,resolve(e){const t=new ar(parseFloat(e)),n=e.indexOf(".");return n!==-1&&e[e.length-1]==="0"&&(t.minFractionDigits=e.length-n-1),t},stringify:yp},kw=e=>typeof e=="bigint"||Number.isInteger(e),lL=(e,t,n,{intAsBigInt:r})=>r?BigInt(e):parseInt(e.substring(t),n);function ege(e,t,n){const{value:r}=e;return kw(r)&&r>=0?n+r.toString(t):yp(e)}const tge={identify:e=>kw(e)&&e>=0,default:!0,tag:"tag:yaml.org,2002:int",format:"OCT",test:/^0o[0-7]+$/,resolve:(e,t,n)=>lL(e,2,8,n),stringify:e=>ege(e,8,"0o")},nge={identify:kw,default:!0,tag:"tag:yaml.org,2002:int",test:/^[-+]?[0-9]+$/,resolve:(e,t,n)=>lL(e,0,10,n),stringify:yp},rge={identify:e=>kw(e)&&e>=0,default:!0,tag:"tag:yaml.org,2002:int",format:"HEX",test:/^0x[0-9a-fA-F]+$/,resolve:(e,t,n)=>lL(e,2,16,n),stringify:e=>ege(e,16,"0x")},zLe=[s4,c4,Aw,Tw,uL,tge,nge,rge,Kme,Wme,Jme];function MX(e){return typeof e=="bigint"||Number.isInteger(e)}const bE=({value:e})=>JSON.stringify(e),qLe=[{identify:e=>typeof e=="string",default:!0,tag:"tag:yaml.org,2002:str",resolve:e=>e,stringify:bE},{identify:e=>e==null,createNode:()=>new ar(null),default:!0,tag:"tag:yaml.org,2002:null",test:/^null$/,resolve:()=>null,stringify:bE},{identify:e=>typeof e=="boolean",default:!0,tag:"tag:yaml.org,2002:bool",test:/^true$|^false$/,resolve:e=>e==="true",stringify:bE},{identify:MX,default:!0,tag:"tag:yaml.org,2002:int",test:/^-?(?:0|[1-9][0-9]*)$/,resolve:(e,t,{intAsBigInt:n})=>n?BigInt(e):parseInt(e,10),stringify:({value:e})=>MX(e)?e.toString():JSON.stringify(e)},{identify:e=>typeof e=="number",default:!0,tag:"tag:yaml.org,2002:float",test:/^-?(?:0|[1-9][0-9]*)(?:\.[0-9]*)?(?:[eE][-+]?[0-9]+)?$/,resolve:e=>parseFloat(e),stringify:bE}],VLe={default:!0,tag:"",test:/^/,resolve(e,t){return t(`Unresolved plain scalar ${JSON.stringify(e)}`),e}},ULe=[s4,c4].concat(qLe,VLe),oL={identify:e=>e instanceof Uint8Array,default:!1,tag:"tag:yaml.org,2002:binary",resolve(e,t){if(typeof atob=="function"){const n=atob(e.replace(/[\n\r]/g,"")),r=new Uint8Array(n.length);for(let i=0;i<n.length;++i)r[i]=n.charCodeAt(i);return r}else return t("This environment does not support reading binary tags; either Buffer or atob is required"),e},stringify({comment:e,type:t,value:n},r,i,a){if(!n)return"";const u=n;let l;if(typeof btoa=="function"){let o="";for(let s=0;s<u.length;++s)o+=String.fromCharCode(u[s]);l=btoa(o)}else throw new Error("This environment does not support writing binary tags; either Buffer or btoa is required");if(t??(t=ar.BLOCK_LITERAL),t!==ar.QUOTE_DOUBLE){const o=Math.max(r.options.lineWidth-r.indent.length,r.options.minContentWidth),s=Math.ceil(l.length/o),c=new Array(s);for(let d=0,h=0;d<s;++d,h+=o)c[d]=l.substr(h,o);l=c.join(t===ar.BLOCK_LITERAL?`
`:" ")}return RS({comment:e,type:t,value:l},r,i,a)}};function ige(e,t){if(o4(e))for(let n=0;n<e.items.length;++n){let r=e.items[n];if(!Za(r)){if(l4(r)){r.items.length>1&&t("Each pair must have its own sequence indicator");const i=r.items[0]||new gs(new ar(null));if(r.commentBefore&&(i.key.commentBefore=i.key.commentBefore?`${r.commentBefore}
${i.key.commentBefore}`:r.commentBefore),r.comment){const a=i.value??i.key;a.comment=a.comment?`${r.comment}
${a.comment}`:r.comment}r=i}e.items[n]=Za(r)?r:new gs(r)}}else t("Expected a sequence for this tag");return e}function age(e,t,n){const{replacer:r}=n,i=new ly(e);i.tag="tag:yaml.org,2002:pairs";let a=0;if(t&&Symbol.iterator in Object(t))for(let u of t){typeof r=="function"&&(u=r.call(t,String(a++),u));let l,o;if(Array.isArray(u))if(u.length===2)l=u[0],o=u[1];else throw new TypeError(`Expected [key, value] tuple: ${u}`);else if(u&&u instanceof Object){const s=Object.keys(u);if(s.length===1)l=s[0],o=u[l];else throw new TypeError(`Expected tuple with one key, not ${s.length} keys`)}else l=u;i.items.push(aL(l,o,n))}return i}const sL={collection:"seq",default:!1,tag:"tag:yaml.org,2002:pairs",resolve:ige,createNode:age};class v3 extends ly{constructor(){super(),this.add=zf.prototype.add.bind(this),this.delete=zf.prototype.delete.bind(this),this.get=zf.prototype.get.bind(this),this.has=zf.prototype.has.bind(this),this.set=zf.prototype.set.bind(this),this.tag=v3.tag}toJSON(t,n){if(!n)return super.toJSON(t);const r=new Map;n!=null&&n.onCreate&&n.onCreate(r);for(const i of this.items){let a,u;if(Za(i)?(a=Kd(i.key,"",n),u=Kd(i.value,a,n)):a=Kd(i,"",n),r.has(a))throw new Error("Ordered maps must not include duplicate keys");r.set(a,u)}return r}static from(t,n,r){const i=age(t,n,r),a=new this;return a.items=i.items,a}}v3.tag="tag:yaml.org,2002:omap";const cL={collection:"seq",identify:e=>e instanceof Map,nodeClass:v3,default:!1,tag:"tag:yaml.org,2002:omap",resolve(e,t){const n=ige(e,t),r=[];for(const{key:i}of n.items)oa(i)&&(r.includes(i.value)?t(`Ordered maps must not include duplicate keys: ${i.value}`):r.push(i.value));return Object.assign(new v3,n)},createNode:(e,t,n)=>v3.from(e,t,n)};function uge({value:e,source:t},n){return t&&(e?lge:oge).test.test(t)?t:e?n.options.trueStr:n.options.falseStr}const lge={identify:e=>e===!0,default:!0,tag:"tag:yaml.org,2002:bool",test:/^(?:Y|y|[Yy]es|YES|[Tt]rue|TRUE|[Oo]n|ON)$/,resolve:()=>new ar(!0),stringify:uge},oge={identify:e=>e===!1,default:!0,tag:"tag:yaml.org,2002:bool",test:/^(?:N|n|[Nn]o|NO|[Ff]alse|FALSE|[Oo]ff|OFF)$/,resolve:()=>new ar(!1),stringify:uge},jLe={identify:e=>typeof e=="number",default:!0,tag:"tag:yaml.org,2002:float",test:/^(?:[-+]?\.(?:inf|Inf|INF)|\.nan|\.NaN|\.NAN)$/,resolve:e=>e.slice(-3).toLowerCase()==="nan"?NaN:e[0]==="-"?Number.NEGATIVE_INFINITY:Number.POSITIVE_INFINITY,stringify:yp},ZLe={identify:e=>typeof e=="number",default:!0,tag:"tag:yaml.org,2002:float",format:"EXP",test:/^[-+]?(?:[0-9][0-9_]*)?(?:\.[0-9_]*)?[eE][-+]?[0-9]+$/,resolve:e=>parseFloat(e.replace(/_/g,"")),stringify(e){const t=Number(e.value);return isFinite(t)?t.toExponential():yp(e)}},HLe={identify:e=>typeof e=="number",default:!0,tag:"tag:yaml.org,2002:float",test:/^[-+]?(?:[0-9][0-9_]*)?\.[0-9_]*$/,resolve(e){const t=new ar(parseFloat(e.replace(/_/g,""))),n=e.indexOf(".");if(n!==-1){const r=e.substring(n+1).replace(/_/g,"");r[r.length-1]==="0"&&(t.minFractionDigits=r.length)}return t},stringify:yp},AS=e=>typeof e=="bigint"||Number.isInteger(e);function Pw(e,t,n,{intAsBigInt:r}){const i=e[0];if((i==="-"||i==="+")&&(t+=1),e=e.substring(t).replace(/_/g,""),r){switch(n){case 2:e=`0b${e}`;break;case 8:e=`0o${e}`;break;case 16:e=`0x${e}`;break}const u=BigInt(e);return i==="-"?BigInt(-1)*u:u}const a=parseInt(e,n);return i==="-"?-1*a:a}function fL(e,t,n){const{value:r}=e;if(AS(r)){const i=r.toString(t);return r<0?"-"+n+i.substr(1):n+i}return yp(e)}const XLe={identify:AS,default:!0,tag:"tag:yaml.org,2002:int",format:"BIN",test:/^[-+]?0b[0-1_]+$/,resolve:(e,t,n)=>Pw(e,2,2,n),stringify:e=>fL(e,2,"0b")},YLe={identify:AS,default:!0,tag:"tag:yaml.org,2002:int",format:"OCT",test:/^[-+]?0[0-7_]+$/,resolve:(e,t,n)=>Pw(e,1,8,n),stringify:e=>fL(e,8,"0")},GLe={identify:AS,default:!0,tag:"tag:yaml.org,2002:int",test:/^[-+]?[0-9][0-9_]*$/,resolve:(e,t,n)=>Pw(e,0,10,n),stringify:yp},KLe={identify:AS,default:!0,tag:"tag:yaml.org,2002:int",format:"HEX",test:/^[-+]?0x[0-9a-fA-F_]+$/,resolve:(e,t,n)=>Pw(e,2,16,n),stringify:e=>fL(e,16,"0x")};class y3 extends zf{constructor(t){super(t),this.tag=y3.tag}add(t){let n;Za(t)?n=t:t&&typeof t=="object"&&"key"in t&&"value"in t&&t.value===null?n=new gs(t.key,null):n=new gs(t,null),q1(this.items,n.key)||this.items.push(n)}get(t,n){const r=q1(this.items,t);return!n&&Za(r)?oa(r.key)?r.key.value:r.key:r}set(t,n){if(typeof n!="boolean")throw new Error(`Expected boolean value for set(key, value) in a YAML set, not ${typeof n}`);const r=q1(this.items,t);r&&!n?this.items.splice(this.items.indexOf(r),1):!r&&n&&this.items.push(new gs(t))}toJSON(t,n){return super.toJSON(t,n,Set)}toString(t,n,r){if(!t)return JSON.stringify(this);if(this.hasAllNullValues(!0))return super.toString(Object.assign({},t,{allNullValues:!0}),n,r);throw new Error("Set items must all have null values")}static from(t,n,r){const{replacer:i}=r,a=new this(t);if(n&&Symbol.iterator in Object(n))for(let u of n)typeof i=="function"&&(u=i.call(n,u,u)),a.items.push(aL(u,null,r));return a}}y3.tag="tag:yaml.org,2002:set";const dL={collection:"map",identify:e=>e instanceof Set,nodeClass:y3,default:!1,tag:"tag:yaml.org,2002:set",createNode:(e,t,n)=>y3.from(e,t,n),resolve(e,t){if(l4(e)){if(e.hasAllNullValues(!0))return Object.assign(new y3,e);t("Set items must all have null values")}else t("Expected a mapping for this tag");return e}};function hL(e,t){const n=e[0],r=n==="-"||n==="+"?e.substring(1):e,i=u=>t?BigInt(u):Number(u),a=r.replace(/_/g,"").split(":").reduce((u,l)=>u*i(60)+i(l),i(0));return n==="-"?i(-1)*a:a}function sge(e){let{value:t}=e,n=u=>u;if(typeof t=="bigint")n=u=>BigInt(u);else if(isNaN(t)||!isFinite(t))return yp(e);let r="";t<0&&(r="-",t*=n(-1));const i=n(60),a=[t%i];return t<60?a.unshift(0):(t=(t-a[0])/i,a.unshift(t%i),t>=60&&(t=(t-a[0])/i,a.unshift(t))),r+a.map(u=>String(u).padStart(2,"0")).join(":").replace(/000000\d*$/,"")}const cge={identify:e=>typeof e=="bigint"||Number.isInteger(e),default:!0,tag:"tag:yaml.org,2002:int",format:"TIME",test:/^[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+$/,resolve:(e,t,{intAsBigInt:n})=>hL(e,n),stringify:sge},fge={identify:e=>typeof e=="number",default:!0,tag:"tag:yaml.org,2002:float",format:"TIME",test:/^[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\.[0-9_]*$/,resolve:e=>hL(e,!1),stringify:sge},Mw={identify:e=>e instanceof Date,default:!0,tag:"tag:yaml.org,2002:timestamp",test:RegExp("^([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})(?:(?:t|T|[ \\t]+)([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2}(\\.[0-9]+)?)(?:[ \\t]*(Z|[-+][012]?[0-9](?::[0-9]{2})?))?)?$"),resolve(e){const t=e.match(Mw.test);if(!t)throw new Error("!!timestamp expects a date, starting with yyyy-mm-dd");const[,n,r,i,a,u,l]=t.map(Number),o=t[7]?Number((t[7]+"00").substr(1,3)):0;let s=Date.UTC(n,r-1,i,a||0,u||0,l||0,o);const c=t[8];if(c&&c!=="Z"){let d=hL(c,!1);Math.abs(d)<30&&(d*=60),s-=6e4*d}return new Date(s)},stringify:({value:e})=>(e==null?void 0:e.toISOString().replace(/(T00:00:00)?\.000Z$/,""))??""},FX=[s4,c4,Aw,Tw,lge,oge,XLe,YLe,GLe,KLe,jLe,ZLe,HLe,oL,ag,cL,sL,dL,cge,fge,Mw],NX=new Map([["core",zLe],["failsafe",[s4,c4,Aw]],["json",ULe],["yaml11",FX],["yaml-1.1",FX]]),IX={binary:oL,bool:uL,float:Jme,floatExp:Wme,floatNaN:Kme,floatTime:fge,int:nge,intHex:rge,intOct:tge,intTime:cge,map:s4,merge:ag,null:Tw,omap:cL,pairs:sL,seq:c4,set:dL,timestamp:Mw},WLe={"tag:yaml.org,2002:binary":oL,"tag:yaml.org,2002:merge":ag,"tag:yaml.org,2002:omap":cL,"tag:yaml.org,2002:pairs":sL,"tag:yaml.org,2002:set":dL,"tag:yaml.org,2002:timestamp":Mw};function EP(e,t,n){const r=NX.get(t);if(r&&!e)return n&&!r.includes(ag)?r.concat(ag):r.slice();let i=r;if(!i)if(Array.isArray(e))i=[];else{const a=Array.from(NX.keys()).filter(u=>u!=="yaml11").map(u=>JSON.stringify(u)).join(", ");throw new Error(`Unknown schema "${t}"; use one of ${a} or define customTags array`)}if(Array.isArray(e))for(const a of e)i=i.concat(a);else typeof e=="function"&&(i=e(i.slice()));return n&&(i=i.concat(ag)),i.reduce((a,u)=>{const l=typeof u=="string"?IX[u]:u;if(!l){const o=JSON.stringify(u),s=Object.keys(IX).map(c=>JSON.stringify(c)).join(", ");throw new Error(`Unknown custom tag ${o}; use one of ${s}`)}return a.includes(l)||a.push(l),a},[])}const JLe=(e,t)=>e.key<t.key?-1:e.key>t.key?1:0;class Fw{constructor({compat:t,customTags:n,merge:r,resolveKnownTags:i,schema:a,sortMapEntries:u,toStringDefaults:l}){this.compat=Array.isArray(t)?EP(t,"compat"):t?EP(null,t):null,this.name=typeof a=="string"&&a||"core",this.knownTags=i?WLe:{},this.tags=EP(n,this.name,r),this.toStringOptions=l??null,Object.defineProperty(this,Zv,{value:s4}),Object.defineProperty(this,M0,{value:Aw}),Object.defineProperty(this,u4,{value:c4}),this.sortMapEntries=typeof u=="function"?u:u===!0?JLe:null}clone(){const t=Object.create(Fw.prototype,Object.getOwnPropertyDescriptors(this));return t.tags=this.tags.slice(),t}}function eBe(e,t){var o;const n=[];let r=t.directives===!0;if(t.directives!==!1&&e.directives){const s=e.directives.toString(e);s?(n.push(s),r=!0):e.directives.docStart&&(r=!0)}r&&n.push("---");const i=Zme(e,t),{commentString:a}=i.options;if(e.commentBefore){n.length!==1&&n.unshift("");const s=a(e.commentBefore);n.unshift(Jm(s,""))}let u=!1,l=null;if(e.contents){if(cu(e.contents)){if(e.contents.spaceBefore&&r&&n.push(""),e.contents.commentBefore){const d=a(e.contents.commentBefore);n.push(Jm(d,""))}i.forceBlockIndent=!!e.comment,l=e.contents.comment}const s=l?void 0:()=>u=!0;let c=F3(e.contents,i,()=>l=null,s);l&&(c+=z1(c,"",a(l))),(c[0]==="|"||c[0]===">")&&n[n.length-1]==="---"?n[n.length-1]=`--- ${c}`:n.push(c)}else n.push(F3(e.contents,i));if((o=e.directives)!=null&&o.docEnd)if(e.comment){const s=a(e.comment);s.includes(`
`)?(n.push("..."),n.push(Jm(s,""))):n.push(`... ${s}`)}else n.push("...");else{let s=e.comment;s&&u&&(s=s.replace(/^\n+/,"")),s&&((!u||l)&&n[n.length-1]!==""&&n.push(""),n.push(Jm(a(s),"")))}return n.join(`
`)+`
`}let Nw=class dge{constructor(t,n,r){this.commentBefore=null,this.comment=null,this.errors=[],this.warnings=[],Object.defineProperty(this,Jd,{value:kM});let i=null;typeof n=="function"||Array.isArray(n)?i=n:r===void 0&&n&&(r=n,n=void 0);const a=Object.assign({intAsBigInt:!1,keepSourceTokens:!1,logLevel:"warn",prettyErrors:!0,strict:!0,stringKeys:!1,uniqueKeys:!0,version:"1.2"},r);this.options=a;let{version:u}=a;r!=null&&r._directives?(this.directives=r._directives.atDocument(),this.directives.yaml.explicit&&(u=this.directives.yaml.version)):this.directives=new ic({version:u}),this.setSchema(u,r),this.contents=t===void 0?null:this.createNode(t,i,r)}clone(){const t=Object.create(dge.prototype,{[Jd]:{value:kM}});return t.commentBefore=this.commentBefore,t.comment=this.comment,t.errors=this.errors.slice(),t.warnings=this.warnings.slice(),t.options=Object.assign({},this.options),this.directives&&(t.directives=this.directives.clone()),t.schema=this.schema.clone(),t.contents=cu(this.contents)?this.contents.clone(t.schema):this.contents,this.range&&(t.range=this.range.slice()),t}add(t){EO(this.contents)&&this.contents.add(t)}addIn(t,n){EO(this.contents)&&this.contents.addIn(t,n)}createAlias(t,n){if(!t.anchor){const r=zme(this);t.anchor=!n||r.has(n)?qme(n||"a",r):n}return new $w(t.anchor)}createNode(t,n,r){let i;if(typeof n=="function")t=n.call({"":t},"",t),i=n;else if(Array.isArray(n)){const _=E=>typeof E=="number"||E instanceof String||E instanceof Number,S=n.filter(_).map(String);S.length>0&&(n=n.concat(S)),i=n}else r===void 0&&n&&(r=n,n=void 0);const{aliasDuplicateObjects:a,anchorPrefix:u,flow:l,keepUndefined:o,onTagObj:s,tag:c}=r??{},{onAnchor:d,setAnchors:h,sourceObjects:m}=wLe(this,u||"a"),y={aliasDuplicateObjects:a??!0,keepUndefined:o??!1,onAnchor:d,onTagObj:s,replacer:i,schema:this.schema,sourceObjects:m},v=Bx(t,c,y);return l&&ou(v)&&(v.flow=!0),h(),v}createPair(t,n,r={}){const i=this.createNode(t,null,r),a=this.createNode(n,null,r);return new gs(i,a)}delete(t){return EO(this.contents)?this.contents.delete(t):!1}deleteIn(t){return I2(t)?this.contents==null?!1:(this.contents=null,!0):EO(this.contents)?this.contents.deleteIn(t):!1}get(t,n){return ou(this.contents)?this.contents.get(t,n):void 0}getIn(t,n){return I2(t)?!n&&oa(this.contents)?this.contents.value:this.contents:ou(this.contents)?this.contents.getIn(t,n):void 0}has(t){return ou(this.contents)?this.contents.has(t):!1}hasIn(t){return I2(t)?this.contents!==void 0:ou(this.contents)?this.contents.hasIn(t):!1}set(t,n){this.contents==null?this.contents=k$(this.schema,[t],n):EO(this.contents)&&this.contents.set(t,n)}setIn(t,n){I2(t)?this.contents=n:this.contents==null?this.contents=k$(this.schema,Array.from(t),n):EO(this.contents)&&this.contents.setIn(t,n)}setSchema(t,n={}){typeof t=="number"&&(t=String(t));let r;switch(t){case"1.1":this.directives?this.directives.yaml.version="1.1":this.directives=new ic({version:"1.1"}),r={resolveKnownTags:!1,schema:"yaml-1.1"};break;case"1.2":case"next":this.directives?this.directives.yaml.version=t:this.directives=new ic({version:t}),r={resolveKnownTags:!0,schema:"core"};break;case null:this.directives&&delete this.directives,r=null;break;default:{const i=JSON.stringify(t);throw new Error(`Expected '1.1', '1.2' or null as first argument, but found: ${i}`)}}if(n.schema instanceof Object)this.schema=n.schema;else if(r)this.schema=new Fw(Object.assign(r,n));else throw new Error("With a null YAML version, the { schema: Schema } option is required")}toJS({json:t,jsonArg:n,mapAsMap:r,maxAliasCount:i,onAnchor:a,reviver:u}={}){const l={anchors:new Map,doc:this,keep:!t,mapAsMap:r===!0,mapKeyWarned:!1,maxAliasCount:typeof i=="number"?i:100},o=Kd(this.contents,n??"",l);if(typeof a=="function")for(const{count:s,res:c}of l.anchors.values())a(c,s);return typeof u=="function"?XO(u,{"":o},"",o):o}toJSON(t,n){return this.toJS({json:!0,jsonArg:t,mapAsMap:!1,onAnchor:n})}toString(t={}){if(this.errors.length>0)throw new Error("Document with errors cannot be stringified");if("indent"in t&&(!Number.isInteger(t.indent)||Number(t.indent)<=0)){const n=JSON.stringify(t.indent);throw new Error(`"indent" option must be a positive integer, not ${n}`)}return eBe(this,t)}};function EO(e){if(ou(e))return!0;throw new Error("Expected a YAML collection as document contents")}class pL extends Error{constructor(t,n,r,i){super(),this.name=t,this.code=r,this.message=i,this.pos=n}}class V1 extends pL{constructor(t,n,r){super("YAMLParseError",t,n,r)}}class hge extends pL{constructor(t,n,r){super("YAMLWarning",t,n,r)}}const M$=(e,t)=>n=>{if(n.pos[0]===-1)return;n.linePos=n.pos.map(l=>t.linePos(l));const{line:r,col:i}=n.linePos[0];n.message+=` at line ${r}, column ${i}`;let a=i-1,u=e.substring(t.lineStarts[r-1],t.lineStarts[r]).replace(/[\n\r]+$/,"");if(a>=60&&u.length>80){const l=Math.min(a-39,u.length-79);u="…"+u.substring(l),a-=l-1}if(u.length>80&&(u=u.substring(0,79)+"…"),r>1&&/^ *$/.test(u.substring(0,a))){let l=e.substring(t.lineStarts[r-2],t.lineStarts[r-1]);l.length>80&&(l=l.substring(0,79)+`…
`),u=l+u}if(/[^ ]/.test(u)){let l=1;const o=n.linePos[1];o&&o.line===r&&o.col>i&&(l=Math.max(1,Math.min(o.col-i,80-a)));const s=" ".repeat(a)+"^".repeat(l);n.message+=`:

${u}
${s}
`}};function N3(e,{flow:t,indicator:n,next:r,offset:i,onError:a,parentIndent:u,startOnNewline:l}){let o=!1,s=l,c=l,d="",h="",m=!1,y=!1,v=null,_=null,S=null,E=null,C=null,T=null,R=null;for(const F of e)switch(y&&(F.type!=="space"&&F.type!=="newline"&&F.type!=="comma"&&a(F.offset,"MISSING_CHAR","Tags and anchors must be separated from the next token by white space"),y=!1),v&&(s&&F.type!=="comment"&&F.type!=="newline"&&a(v,"TAB_AS_INDENT","Tabs are not allowed as indentation"),v=null),F.type){case"space":!t&&(n!=="doc-start"||(r==null?void 0:r.type)!=="flow-collection")&&F.source.includes("	")&&(v=F),c=!0;break;case"comment":{c||a(F,"MISSING_CHAR","Comments must be separated from other tokens by white space characters");const L=F.source.substring(1)||" ";d?d+=h+L:d=L,h="",s=!1;break}case"newline":s?d?d+=F.source:(!T||n!=="seq-item-ind")&&(o=!0):h+=F.source,s=!0,m=!0,(_||S)&&(E=F),c=!0;break;case"anchor":_&&a(F,"MULTIPLE_ANCHORS","A node can have at most one anchor"),F.source.endsWith(":")&&a(F.offset+F.source.length-1,"BAD_ALIAS","Anchor ending in : is ambiguous",!0),_=F,R??(R=F.offset),s=!1,c=!1,y=!0;break;case"tag":{S&&a(F,"MULTIPLE_TAGS","A node can have at most one tag"),S=F,R??(R=F.offset),s=!1,c=!1,y=!0;break}case n:(_||S)&&a(F,"BAD_PROP_ORDER",`Anchors and tags must be after the ${F.source} indicator`),T&&a(F,"UNEXPECTED_TOKEN",`Unexpected ${F.source} in ${t??"collection"}`),T=F,s=n==="seq-item-ind"||n==="explicit-key-ind",c=!1;break;case"comma":if(t){C&&a(F,"UNEXPECTED_TOKEN",`Unexpected , in ${t}`),C=F,s=!1,c=!1;break}default:a(F,"UNEXPECTED_TOKEN",`Unexpected ${F.type} token`),s=!1,c=!1}const $=e[e.length-1],k=$?$.offset+$.source.length:i;return y&&r&&r.type!=="space"&&r.type!=="newline"&&r.type!=="comma"&&(r.type!=="scalar"||r.source!=="")&&a(r.offset,"MISSING_CHAR","Tags and anchors must be separated from the next token by white space"),v&&(s&&v.indent<=u||(r==null?void 0:r.type)==="block-map"||(r==null?void 0:r.type)==="block-seq")&&a(v,"TAB_AS_INDENT","Tabs are not allowed as indentation"),{comma:C,found:T,spaceBefore:o,comment:d,hasNewline:m,anchor:_,tag:S,newlineAfterProp:E,end:k,start:R??k}}function Qx(e){if(!e)return null;switch(e.type){case"alias":case"scalar":case"double-quoted-scalar":case"single-quoted-scalar":if(e.source.includes(`
`))return!0;if(e.end){for(const t of e.end)if(t.type==="newline")return!0}return!1;case"flow-collection":for(const t of e.items){for(const n of t.start)if(n.type==="newline")return!0;if(t.sep){for(const n of t.sep)if(n.type==="newline")return!0}if(Qx(t.key)||Qx(t.value))return!0}return!1;default:return!0}}function NM(e,t,n){if((t==null?void 0:t.type)==="flow-collection"){const r=t.end[0];r.indent===e&&(r.source==="]"||r.source==="}")&&Qx(t)&&n(r,"BAD_INDENT","Flow end indicator should be more indented than parent",!0)}}function pge(e,t,n){const{uniqueKeys:r}=e.options;if(r===!1)return!1;const i=typeof r=="function"?r:(a,u)=>a===u||oa(a)&&oa(u)&&a.value===u.value;return t.some(a=>i(a.key,n))}const LX="All mapping items must start at the same column";function tBe({composeNode:e,composeEmptyNode:t},n,r,i,a){var c;const u=(a==null?void 0:a.nodeClass)??zf,l=new u(n.schema);n.atRoot&&(n.atRoot=!1);let o=r.offset,s=null;for(const d of r.items){const{start:h,key:m,sep:y,value:v}=d,_=N3(h,{indicator:"explicit-key-ind",next:m??(y==null?void 0:y[0]),offset:o,onError:i,parentIndent:r.indent,startOnNewline:!0}),S=!_.found;if(S){if(m&&(m.type==="block-seq"?i(o,"BLOCK_AS_IMPLICIT_KEY","A block sequence may not be used as an implicit map key"):"indent"in m&&m.indent!==r.indent&&i(o,"BAD_INDENT",LX)),!_.anchor&&!_.tag&&!y){s=_.end,_.comment&&(l.comment?l.comment+=`
`+_.comment:l.comment=_.comment);continue}(_.newlineAfterProp||Qx(m))&&i(m??h[h.length-1],"MULTILINE_IMPLICIT_KEY","Implicit keys need to be on a single line")}else((c=_.found)==null?void 0:c.indent)!==r.indent&&i(o,"BAD_INDENT",LX);n.atKey=!0;const E=_.end,C=m?e(n,m,_,i):t(n,E,h,null,_,i);n.schema.compat&&NM(r.indent,m,i),n.atKey=!1,pge(n,l.items,C)&&i(E,"DUPLICATE_KEY","Map keys must be unique");const T=N3(y??[],{indicator:"map-value-ind",next:v,offset:C.range[2],onError:i,parentIndent:r.indent,startOnNewline:!m||m.type==="block-scalar"});if(o=T.end,T.found){S&&((v==null?void 0:v.type)==="block-map"&&!T.hasNewline&&i(o,"BLOCK_AS_IMPLICIT_KEY","Nested mappings are not allowed in compact mappings"),n.options.strict&&_.start<T.found.offset-1024&&i(C.range,"KEY_OVER_1024_CHARS","The : indicator must be at most 1024 chars after the start of an implicit block mapping key"));const R=v?e(n,v,T,i):t(n,o,y,null,T,i);n.schema.compat&&NM(r.indent,v,i),o=R.range[2];const $=new gs(C,R);n.options.keepSourceTokens&&($.srcToken=d),l.items.push($)}else{S&&i(C.range,"MISSING_CHAR","Implicit map keys need to be followed by map values"),T.comment&&(C.comment?C.comment+=`
`+T.comment:C.comment=T.comment);const R=new gs(C);n.options.keepSourceTokens&&(R.srcToken=d),l.items.push(R)}}return s&&s<o&&i(s,"IMPOSSIBLE","Map comment with trailing content"),l.range=[r.offset,o,s??o],l}function nBe({composeNode:e,composeEmptyNode:t},n,r,i,a){const u=(a==null?void 0:a.nodeClass)??ly,l=new u(n.schema);n.atRoot&&(n.atRoot=!1),n.atKey&&(n.atKey=!1);let o=r.offset,s=null;for(const{start:c,value:d}of r.items){const h=N3(c,{indicator:"seq-item-ind",next:d,offset:o,onError:i,parentIndent:r.indent,startOnNewline:!0});if(!h.found)if(h.anchor||h.tag||d)d&&d.type==="block-seq"?i(h.end,"BAD_INDENT","All sequence items must start at the same column"):i(o,"MISSING_CHAR","Sequence item without - indicator");else{s=h.end,h.comment&&(l.comment=h.comment);continue}const m=d?e(n,d,h,i):t(n,h.end,c,null,h,i);n.schema.compat&&NM(r.indent,d,i),o=m.range[2],l.items.push(m)}return l.range=[r.offset,o,s??o],l}function TS(e,t,n,r){let i="";if(e){let a=!1,u="";for(const l of e){const{source:o,type:s}=l;switch(s){case"space":a=!0;break;case"comment":{n&&!a&&r(l,"MISSING_CHAR","Comments must be separated from other tokens by white space characters");const c=o.substring(1)||" ";i?i+=u+c:i=c,u="";break}case"newline":i&&(u+=o),a=!0;break;default:r(l,"UNEXPECTED_TOKEN",`Unexpected ${s} at node end`)}t+=o.length}}return{comment:i,offset:t}}const DP="Block collections are not allowed within flow collections",$P=e=>e&&(e.type==="block-map"||e.type==="block-seq");function rBe({composeNode:e,composeEmptyNode:t},n,r,i,a){const u=r.start.source==="{",l=u?"flow map":"flow sequence",o=(a==null?void 0:a.nodeClass)??(u?zf:ly),s=new o(n.schema);s.flow=!0;const c=n.atRoot;c&&(n.atRoot=!1),n.atKey&&(n.atKey=!1);let d=r.offset+r.start.source.length;for(let _=0;_<r.items.length;++_){const S=r.items[_],{start:E,key:C,sep:T,value:R}=S,$=N3(E,{flow:l,indicator:"explicit-key-ind",next:C??(T==null?void 0:T[0]),offset:d,onError:i,parentIndent:r.indent,startOnNewline:!1});if(!$.found){if(!$.anchor&&!$.tag&&!T&&!R){_===0&&$.comma?i($.comma,"UNEXPECTED_TOKEN",`Unexpected , in ${l}`):_<r.items.length-1&&i($.start,"UNEXPECTED_TOKEN",`Unexpected empty item in ${l}`),$.comment&&(s.comment?s.comment+=`
`+$.comment:s.comment=$.comment),d=$.end;continue}!u&&n.options.strict&&Qx(C)&&i(C,"MULTILINE_IMPLICIT_KEY","Implicit keys of flow sequence pairs need to be on a single line")}if(_===0)$.comma&&i($.comma,"UNEXPECTED_TOKEN",`Unexpected , in ${l}`);else if($.comma||i($.start,"MISSING_CHAR",`Missing , between ${l} items`),$.comment){let k="";e:for(const F of E)switch(F.type){case"comma":case"space":break;case"comment":k=F.source.substring(1);break e;default:break e}if(k){let F=s.items[s.items.length-1];Za(F)&&(F=F.value??F.key),F.comment?F.comment+=`
`+k:F.comment=k,$.comment=$.comment.substring(k.length+1)}}if(!u&&!T&&!$.found){const k=R?e(n,R,$,i):t(n,$.end,T,null,$,i);s.items.push(k),d=k.range[2],$P(R)&&i(k.range,"BLOCK_IN_FLOW",DP)}else{n.atKey=!0;const k=$.end,F=C?e(n,C,$,i):t(n,k,E,null,$,i);$P(C)&&i(F.range,"BLOCK_IN_FLOW",DP),n.atKey=!1;const L=N3(T??[],{flow:l,indicator:"map-value-ind",next:R,offset:F.range[2],onError:i,parentIndent:r.indent,startOnNewline:!1});if(L.found){if(!u&&!$.found&&n.options.strict){if(T)for(const q of T){if(q===L.found)break;if(q.type==="newline"){i(q,"MULTILINE_IMPLICIT_KEY","Implicit keys of flow sequence pairs need to be on a single line");break}}$.start<L.found.offset-1024&&i(L.found,"KEY_OVER_1024_CHARS","The : indicator must be at most 1024 chars after the start of an implicit flow sequence key")}}else R&&("source"in R&&R.source&&R.source[0]===":"?i(R,"MISSING_CHAR",`Missing space after : in ${l}`):i(L.start,"MISSING_CHAR",`Missing , or : between ${l} items`));const j=R?e(n,R,L,i):L.found?t(n,L.end,T,null,L,i):null;j?$P(R)&&i(j.range,"BLOCK_IN_FLOW",DP):L.comment&&(F.comment?F.comment+=`
`+L.comment:F.comment=L.comment);const V=new gs(F,j);if(n.options.keepSourceTokens&&(V.srcToken=S),u){const q=s;pge(n,q.items,F)&&i(k,"DUPLICATE_KEY","Map keys must be unique"),q.items.push(V)}else{const q=new zf(n.schema);q.flow=!0,q.items.push(V);const N=(j??F).range;q.range=[F.range[0],N[1],N[2]],s.items.push(q)}d=j?j.range[2]:L.end}}const h=u?"}":"]",[m,...y]=r.end;let v=d;if(m&&m.source===h)v=m.offset+m.source.length;else{const _=l[0].toUpperCase()+l.substring(1),S=c?`${_} must end with a ${h}`:`${_} in block collection must be sufficiently indented and end with a ${h}`;i(d,c?"MISSING_CHAR":"BAD_INDENT",S),m&&m.source.length!==1&&y.unshift(m)}if(y.length>0){const _=TS(y,v,n.options.strict,i);_.comment&&(s.comment?s.comment+=`
`+_.comment:s.comment=_.comment),s.range=[r.offset,v,_.offset]}else s.range=[r.offset,v,v];return s}function CP(e,t,n,r,i,a){const u=n.type==="block-map"?tBe(e,t,n,r,a):n.type==="block-seq"?nBe(e,t,n,r,a):rBe(e,t,n,r,a),l=u.constructor;return i==="!"||i===l.tagName?(u.tag=l.tagName,u):(i&&(u.tag=i),u)}function iBe(e,t,n,r,i){var h;const a=r.tag,u=a?t.directives.tagName(a.source,m=>i(a,"TAG_RESOLVE_FAILED",m)):null;if(n.type==="block-seq"){const{anchor:m,newlineAfterProp:y}=r,v=m&&a?m.offset>a.offset?m:a:m??a;v&&(!y||y.offset<v.offset)&&i(v,"MISSING_CHAR","Missing newline after block sequence props")}const l=n.type==="block-map"?"map":n.type==="block-seq"?"seq":n.start.source==="{"?"map":"seq";if(!a||!u||u==="!"||u===zf.tagName&&l==="map"||u===ly.tagName&&l==="seq")return CP(e,t,n,i,u);let o=t.schema.tags.find(m=>m.tag===u&&m.collection===l);if(!o){const m=t.schema.knownTags[u];if(m&&m.collection===l)t.schema.tags.push(Object.assign({},m,{default:!1})),o=m;else return m?i(a,"BAD_COLLECTION_TYPE",`${m.tag} used for ${l} collection, but expects ${m.collection??"scalar"}`,!0):i(a,"TAG_RESOLVE_FAILED",`Unresolved tag: ${u}`,!0),CP(e,t,n,i,u)}const s=CP(e,t,n,i,u,o),c=((h=o.resolve)==null?void 0:h.call(o,s,m=>i(a,"TAG_RESOLVE_FAILED",m),t.options))??s,d=cu(c)?c:new ar(c);return d.range=s.range,d.tag=u,o!=null&&o.format&&(d.format=o.format),d}function mge(e,t,n){const r=t.offset,i=aBe(t,e.options.strict,n);if(!i)return{value:"",type:null,comment:"",range:[r,r,r]};const a=i.mode===">"?ar.BLOCK_FOLDED:ar.BLOCK_LITERAL,u=t.source?uBe(t.source):[];let l=u.length;for(let v=u.length-1;v>=0;--v){const _=u[v][1];if(_===""||_==="\r")l=v;else break}if(l===0){const v=i.chomp==="+"&&u.length>0?`
`.repeat(Math.max(1,u.length-1)):"";let _=r+i.length;return t.source&&(_+=t.source.length),{value:v,type:a,comment:i.comment,range:[r,_,_]}}let o=t.indent+i.indent,s=t.offset+i.length,c=0;for(let v=0;v<l;++v){const[_,S]=u[v];if(S===""||S==="\r")i.indent===0&&_.length>o&&(o=_.length);else{_.length<o&&n(s+_.length,"MISSING_CHAR","Block scalars with more-indented leading empty lines must use an explicit indentation indicator"),i.indent===0&&(o=_.length),c=v,o===0&&!e.atRoot&&n(s,"BAD_INDENT","Block scalar values in collections must be indented");break}s+=_.length+S.length+1}for(let v=u.length-1;v>=l;--v)u[v][0].length>o&&(l=v+1);let d="",h="",m=!1;for(let v=0;v<c;++v)d+=u[v][0].slice(o)+`
`;for(let v=c;v<l;++v){let[_,S]=u[v];s+=_.length+S.length+1;const E=S[S.length-1]==="\r";if(E&&(S=S.slice(0,-1)),S&&_.length<o){const T=`Block scalar lines must not be less indented than their ${i.indent?"explicit indentation indicator":"first line"}`;n(s-S.length-(E?2:1),"BAD_INDENT",T),_=""}a===ar.BLOCK_LITERAL?(d+=h+_.slice(o)+S,h=`
`):_.length>o||S[0]==="	"?(h===" "?h=`
`:!m&&h===`
`&&(h=`

`),d+=h+_.slice(o)+S,h=`
`,m=!0):S===""?h===`
`?d+=`
`:h=`
`:(d+=h+S,h=" ",m=!1)}switch(i.chomp){case"-":break;case"+":for(let v=l;v<u.length;++v)d+=`
`+u[v][0].slice(o);d[d.length-1]!==`
`&&(d+=`
`);break;default:d+=`
`}const y=r+i.length+t.source.length;return{value:d,type:a,comment:i.comment,range:[r,y,y]}}function aBe({offset:e,props:t},n,r){if(t[0].type!=="block-scalar-header")return r(t[0],"IMPOSSIBLE","Block scalar header not found"),null;const{source:i}=t[0],a=i[0];let u=0,l="",o=-1;for(let h=1;h<i.length;++h){const m=i[h];if(!l&&(m==="-"||m==="+"))l=m;else{const y=Number(m);!u&&y?u=y:o===-1&&(o=e+h)}}o!==-1&&r(o,"UNEXPECTED_TOKEN",`Block scalar header includes extra characters: ${i}`);let s=!1,c="",d=i.length;for(let h=1;h<t.length;++h){const m=t[h];switch(m.type){case"space":s=!0;case"newline":d+=m.source.length;break;case"comment":n&&!s&&r(m,"MISSING_CHAR","Comments must be separated from other tokens by white space characters"),d+=m.source.length,c=m.source.substring(1);break;case"error":r(m,"UNEXPECTED_TOKEN",m.message),d+=m.source.length;break;default:{const y=`Unexpected token in block scalar header: ${m.type}`;r(m,"UNEXPECTED_TOKEN",y);const v=m.source;v&&typeof v=="string"&&(d+=v.length)}}}return{mode:a,indent:u,chomp:l,comment:c,length:d}}function uBe(e){const t=e.split(/\n( *)/),n=t[0],r=n.match(/^( *)/),a=[r!=null&&r[1]?[r[1],n.slice(r[1].length)]:["",n]];for(let u=1;u<t.length;u+=2)a.push([t[u],t[u+1]]);return a}function gge(e,t,n){const{offset:r,type:i,source:a,end:u}=e;let l,o;const s=(h,m,y)=>n(r+h,m,y);switch(i){case"scalar":l=ar.PLAIN,o=lBe(a,s);break;case"single-quoted-scalar":l=ar.QUOTE_SINGLE,o=oBe(a,s);break;case"double-quoted-scalar":l=ar.QUOTE_DOUBLE,o=sBe(a,s);break;default:return n(e,"UNEXPECTED_TOKEN",`Expected a flow scalar value, but found: ${i}`),{value:"",type:null,comment:"",range:[r,r+a.length,r+a.length]}}const c=r+a.length,d=TS(u,c,t,n);return{value:o,type:l,comment:d.comment,range:[r,c,d.offset]}}function lBe(e,t){let n="";switch(e[0]){case"	":n="a tab character";break;case",":n="flow indicator character ,";break;case"%":n="directive indicator character %";break;case"|":case">":{n=`block scalar indicator ${e[0]}`;break}case"@":case"`":{n=`reserved character ${e[0]}`;break}}return n&&t(0,"BAD_SCALAR_START",`Plain value cannot start with ${n}`),vge(e)}function oBe(e,t){return(e[e.length-1]!=="'"||e.length===1)&&t(e.length,"MISSING_CHAR","Missing closing 'quote"),vge(e.slice(1,-1)).replace(/''/g,"'")}function vge(e){let t,n;try{t=new RegExp(`(.*?)(?<![ 	])[ 	]*\r?
`,"sy"),n=new RegExp(`[ 	]*(.*?)(?:(?<![ 	])[ 	]*)?\r?
`,"sy")}catch{t=/(.*?)[ \t]*\r?\n/sy,n=/[ \t]*(.*?)[ \t]*\r?\n/sy}let r=t.exec(e);if(!r)return e;let i=r[1],a=" ",u=t.lastIndex;for(n.lastIndex=u;r=n.exec(e);)r[1]===""?a===`
`?i+=a:a=`
`:(i+=a+r[1],a=" "),u=n.lastIndex;const l=/[ \t]*(.*)/sy;return l.lastIndex=u,r=l.exec(e),i+a+((r==null?void 0:r[1])??"")}function sBe(e,t){let n="";for(let r=1;r<e.length-1;++r){const i=e[r];if(!(i==="\r"&&e[r+1]===`
`))if(i===`
`){const{fold:a,offset:u}=cBe(e,r);n+=a,r=u}else if(i==="\\"){let a=e[++r];const u=fBe[a];if(u)n+=u;else if(a===`
`)for(a=e[r+1];a===" "||a==="	";)a=e[++r+1];else if(a==="\r"&&e[r+1]===`
`)for(a=e[++r+1];a===" "||a==="	";)a=e[++r+1];else if(a==="x"||a==="u"||a==="U"){const l={x:2,u:4,U:8}[a];n+=dBe(e,r+1,l,t),r+=l}else{const l=e.substr(r-1,2);t(r-1,"BAD_DQ_ESCAPE",`Invalid escape sequence ${l}`),n+=l}}else if(i===" "||i==="	"){const a=r;let u=e[r+1];for(;u===" "||u==="	";)u=e[++r+1];u!==`
`&&!(u==="\r"&&e[r+2]===`
`)&&(n+=r>a?e.slice(a,r+1):i)}else n+=i}return(e[e.length-1]!=='"'||e.length===1)&&t(e.length,"MISSING_CHAR",'Missing closing "quote'),n}function cBe(e,t){let n="",r=e[t+1];for(;(r===" "||r==="	"||r===`
`||r==="\r")&&!(r==="\r"&&e[t+2]!==`
`);)r===`
`&&(n+=`
`),t+=1,r=e[t+1];return n||(n=" "),{fold:n,offset:t}}const fBe={0:"\0",a:"\x07",b:"\b",e:"\x1B",f:"\f",n:`
`,r:"\r",t:"	",v:"\v",N:"",_:" ",L:"\u2028",P:"\u2029"," ":" ",'"':'"',"/":"/","\\":"\\","	":"	"};function dBe(e,t,n,r){const i=e.substr(t,n),u=i.length===n&&/^[0-9a-fA-F]+$/.test(i)?parseInt(i,16):NaN;if(isNaN(u)){const l=e.substr(t-2,n+2);return r(t-2,"BAD_DQ_ESCAPE",`Invalid escape sequence ${l}`),l}return String.fromCodePoint(u)}function yge(e,t,n,r){const{value:i,type:a,comment:u,range:l}=t.type==="block-scalar"?mge(e,t,r):gge(t,e.options.strict,r),o=n?e.directives.tagName(n.source,d=>r(n,"TAG_RESOLVE_FAILED",d)):null;let s;e.options.stringKeys&&e.atKey?s=e.schema[M0]:o?s=hBe(e.schema,i,o,n,r):t.type==="scalar"?s=pBe(e,i,t,r):s=e.schema[M0];let c;try{const d=s.resolve(i,h=>r(n??t,"TAG_RESOLVE_FAILED",h),e.options);c=oa(d)?d:new ar(d)}catch(d){const h=d instanceof Error?d.message:String(d);r(n??t,"TAG_RESOLVE_FAILED",h),c=new ar(i)}return c.range=l,c.source=i,a&&(c.type=a),o&&(c.tag=o),s.format&&(c.format=s.format),u&&(c.comment=u),c}function hBe(e,t,n,r,i){var l;if(n==="!")return e[M0];const a=[];for(const o of e.tags)if(!o.collection&&o.tag===n)if(o.default&&o.test)a.push(o);else return o;for(const o of a)if((l=o.test)!=null&&l.test(t))return o;const u=e.knownTags[n];return u&&!u.collection?(e.tags.push(Object.assign({},u,{default:!1,test:void 0})),u):(i(r,"TAG_RESOLVE_FAILED",`Unresolved tag: ${n}`,n!=="tag:yaml.org,2002:str"),e[M0])}function pBe({atKey:e,directives:t,schema:n},r,i,a){const u=n.tags.find(l=>{var o;return(l.default===!0||e&&l.default==="key")&&((o=l.test)==null?void 0:o.test(r))})||n[M0];if(n.compat){const l=n.compat.find(o=>{var s;return o.default&&((s=o.test)==null?void 0:s.test(r))})??n[M0];if(u.tag!==l.tag){const o=t.tagString(u.tag),s=t.tagString(l.tag),c=`Value may be parsed as either ${o} or ${s}`;a(i,"TAG_RESOLVE_FAILED",c,!0)}}return u}function mBe(e,t,n){if(t){n??(n=t.length);for(let r=n-1;r>=0;--r){let i=t[r];switch(i.type){case"space":case"comment":case"newline":e-=i.source.length;continue}for(i=t[++r];(i==null?void 0:i.type)==="space";)e+=i.source.length,i=t[++r];break}}return e}const gBe={composeNode:bge,composeEmptyNode:mL};function bge(e,t,n,r){const i=e.atKey,{spaceBefore:a,comment:u,anchor:l,tag:o}=n;let s,c=!0;switch(t.type){case"alias":s=vBe(e,t,r),(l||o)&&r(t,"ALIAS_PROPS","An alias node must not specify any properties");break;case"scalar":case"single-quoted-scalar":case"double-quoted-scalar":case"block-scalar":s=yge(e,t,o,r),l&&(s.anchor=l.source.substring(1));break;case"block-map":case"block-seq":case"flow-collection":s=iBe(gBe,e,t,n,r),l&&(s.anchor=l.source.substring(1));break;default:{const d=t.type==="error"?t.message:`Unsupported token (type: ${t.type})`;r(t,"UNEXPECTED_TOKEN",d),s=mL(e,t.offset,void 0,null,n,r),c=!1}}return l&&s.anchor===""&&r(l,"BAD_ALIAS","Anchor cannot be an empty string"),i&&e.options.stringKeys&&(!oa(s)||typeof s.value!="string"||s.tag&&s.tag!=="tag:yaml.org,2002:str")&&r(o??t,"NON_STRING_KEY","With stringKeys, all keys must be strings"),a&&(s.spaceBefore=!0),u&&(t.type==="scalar"&&t.source===""?s.comment=u:s.commentBefore=u),e.options.keepSourceTokens&&c&&(s.srcToken=t),s}function mL(e,t,n,r,{spaceBefore:i,comment:a,anchor:u,tag:l,end:o},s){const c={type:"scalar",offset:mBe(t,n,r),indent:-1,source:""},d=yge(e,c,l,s);return u&&(d.anchor=u.source.substring(1),d.anchor===""&&s(u,"BAD_ALIAS","Anchor cannot be an empty string")),i&&(d.spaceBefore=!0),a&&(d.comment=a,d.range[2]=o),d}function vBe({options:e},{offset:t,source:n,end:r},i){const a=new $w(n.substring(1));a.source===""&&i(t,"BAD_ALIAS","Alias cannot be an empty string"),a.source.endsWith(":")&&i(t+n.length-1,"BAD_ALIAS","Alias ending in : is ambiguous",!0);const u=t+n.length,l=TS(r,u,e.strict,i);return a.range=[t,u,l.offset],l.comment&&(a.comment=l.comment),a}function yBe(e,t,{offset:n,start:r,value:i,end:a},u){const l=Object.assign({_directives:t},e),o=new Nw(void 0,l),s={atKey:!1,atRoot:!0,directives:o.directives,options:o.options,schema:o.schema},c=N3(r,{indicator:"doc-start",next:i??(a==null?void 0:a[0]),offset:n,onError:u,parentIndent:0,startOnNewline:!0});c.found&&(o.directives.docStart=!0,i&&(i.type==="block-map"||i.type==="block-seq")&&!c.hasNewline&&u(c.end,"MISSING_CHAR","Block collection cannot start on same line with directives-end marker")),o.contents=i?bge(s,i,c,u):mL(s,c.end,r,null,c,u);const d=o.contents.range[2],h=TS(a,d,!1,u);return h.comment&&(o.comment=h.comment),o.range=[n,d,h.offset],o}function c2(e){if(typeof e=="number")return[e,e+1];if(Array.isArray(e))return e.length===2?e:[e[0],e[1]];const{offset:t,source:n}=e;return[t,t+(typeof n=="string"?n.length:1)]}function BX(e){var i;let t="",n=!1,r=!1;for(let a=0;a<e.length;++a){const u=e[a];switch(u[0]){case"#":t+=(t===""?"":r?`

`:`
`)+(u.substring(1)||" "),n=!0,r=!1;break;case"%":((i=e[a+1])==null?void 0:i[0])!=="#"&&(a+=1),n=!1;break;default:n||(r=!0),n=!1}}return{comment:t,afterEmptyLine:r}}class gL{constructor(t={}){this.doc=null,this.atDirectives=!1,this.prelude=[],this.errors=[],this.warnings=[],this.onError=(n,r,i,a)=>{const u=c2(n);a?this.warnings.push(new hge(u,r,i)):this.errors.push(new V1(u,r,i))},this.directives=new ic({version:t.version||"1.2"}),this.options=t}decorate(t,n){const{comment:r,afterEmptyLine:i}=BX(this.prelude);if(r){const a=t.contents;if(n)t.comment=t.comment?`${t.comment}
${r}`:r;else if(i||t.directives.docStart||!a)t.commentBefore=r;else if(ou(a)&&!a.flow&&a.items.length>0){let u=a.items[0];Za(u)&&(u=u.key);const l=u.commentBefore;u.commentBefore=l?`${r}
${l}`:r}else{const u=a.commentBefore;a.commentBefore=u?`${r}
${u}`:r}}n?(Array.prototype.push.apply(t.errors,this.errors),Array.prototype.push.apply(t.warnings,this.warnings)):(t.errors=this.errors,t.warnings=this.warnings),this.prelude=[],this.errors=[],this.warnings=[]}streamInfo(){return{comment:BX(this.prelude).comment,directives:this.directives,errors:this.errors,warnings:this.warnings}}*compose(t,n=!1,r=-1){for(const i of t)yield*this.next(i);yield*this.end(n,r)}*next(t){switch(t.type){case"directive":this.directives.add(t.source,(n,r,i)=>{const a=c2(t);a[0]+=n,this.onError(a,"BAD_DIRECTIVE",r,i)}),this.prelude.push(t.source),this.atDirectives=!0;break;case"document":{const n=yBe(this.options,this.directives,t,this.onError);this.atDirectives&&!n.directives.docStart&&this.onError(t,"MISSING_CHAR","Missing directives-end/doc-start indicator line"),this.decorate(n,!1),this.doc&&(yield this.doc),this.doc=n,this.atDirectives=!1;break}case"byte-order-mark":case"space":break;case"comment":case"newline":this.prelude.push(t.source);break;case"error":{const n=t.source?`${t.message}: ${JSON.stringify(t.source)}`:t.message,r=new V1(c2(t),"UNEXPECTED_TOKEN",n);this.atDirectives||!this.doc?this.errors.push(r):this.doc.errors.push(r);break}case"doc-end":{if(!this.doc){const r="Unexpected doc-end without preceding document";this.errors.push(new V1(c2(t),"UNEXPECTED_TOKEN",r));break}this.doc.directives.docEnd=!0;const n=TS(t.end,t.offset+t.source.length,this.doc.options.strict,this.onError);if(this.decorate(this.doc,!0),n.comment){const r=this.doc.comment;this.doc.comment=r?`${r}
${n.comment}`:n.comment}this.doc.range[2]=n.offset;break}default:this.errors.push(new V1(c2(t),"UNEXPECTED_TOKEN",`Unsupported token ${t.type}`))}}*end(t=!1,n=-1){if(this.doc)this.decorate(this.doc,!0),yield this.doc,this.doc=null;else if(t){const r=Object.assign({_directives:this.directives},this.options),i=new Nw(void 0,r);this.atDirectives&&this.onError(n,"MISSING_CHAR","Missing directives-end indicator line"),i.range=[0,n,n],this.decorate(i,!1),yield i}}}function bBe(e,t=!0,n){if(e){const r=(i,a,u)=>{const l=typeof i=="number"?i:Array.isArray(i)?i[0]:i.offset;if(n)n(l,a,u);else throw new V1([l,l+1],a,u)};switch(e.type){case"scalar":case"single-quoted-scalar":case"double-quoted-scalar":return gge(e,t,r);case"block-scalar":return mge({options:{strict:t}},e,r)}}return null}function OBe(e,t){const{implicitKey:n=!1,indent:r,inFlow:i=!1,offset:a=-1,type:u="PLAIN"}=t,l=RS({type:u,value:e},{implicitKey:n,indent:r>0?" ".repeat(r):"",inFlow:i,options:{blockQuote:!0,lineWidth:-1}}),o=t.end??[{type:"newline",offset:-1,indent:r,source:`
`}];switch(l[0]){case"|":case">":{const s=l.indexOf(`
`),c=l.substring(0,s),d=l.substring(s+1)+`
`,h=[{type:"block-scalar-header",offset:a,indent:r,source:c}];return Oge(h,o)||h.push({type:"newline",offset:-1,indent:r,source:`
`}),{type:"block-scalar",offset:a,indent:r,props:h,source:d}}case'"':return{type:"double-quoted-scalar",offset:a,indent:r,source:l,end:o};case"'":return{type:"single-quoted-scalar",offset:a,indent:r,source:l,end:o};default:return{type:"scalar",offset:a,indent:r,source:l,end:o}}}function xBe(e,t,n={}){let{afterKey:r=!1,implicitKey:i=!1,inFlow:a=!1,type:u}=n,l="indent"in e?e.indent:null;if(r&&typeof l=="number"&&(l+=2),!u)switch(e.type){case"single-quoted-scalar":u="QUOTE_SINGLE";break;case"double-quoted-scalar":u="QUOTE_DOUBLE";break;case"block-scalar":{const s=e.props[0];if(s.type!=="block-scalar-header")throw new Error("Invalid block scalar header");u=s.source[0]===">"?"BLOCK_FOLDED":"BLOCK_LITERAL";break}default:u="PLAIN"}const o=RS({type:u,value:t},{implicitKey:i||l===null,indent:l!==null&&l>0?" ".repeat(l):"",inFlow:a,options:{blockQuote:!0,lineWidth:-1}});switch(o[0]){case"|":case">":SBe(e,o);break;case'"':wP(e,o,"double-quoted-scalar");break;case"'":wP(e,o,"single-quoted-scalar");break;default:wP(e,o,"scalar")}}function SBe(e,t){const n=t.indexOf(`
`),r=t.substring(0,n),i=t.substring(n+1)+`
`;if(e.type==="block-scalar"){const a=e.props[0];if(a.type!=="block-scalar-header")throw new Error("Invalid block scalar header");a.source=r,e.source=i}else{const{offset:a}=e,u="indent"in e?e.indent:-1,l=[{type:"block-scalar-header",offset:a,indent:u,source:r}];Oge(l,"end"in e?e.end:void 0)||l.push({type:"newline",offset:-1,indent:u,source:`
`});for(const o of Object.keys(e))o!=="type"&&o!=="offset"&&delete e[o];Object.assign(e,{type:"block-scalar",indent:u,props:l,source:i})}}function Oge(e,t){if(t)for(const n of t)switch(n.type){case"space":case"comment":e.push(n);break;case"newline":return e.push(n),!0}return!1}function wP(e,t,n){switch(e.type){case"scalar":case"double-quoted-scalar":case"single-quoted-scalar":e.type=n,e.source=t;break;case"block-scalar":{const r=e.props.slice(1);let i=t.length;e.props[0].type==="block-scalar-header"&&(i-=e.props[0].source.length);for(const a of r)a.offset+=i;delete e.props,Object.assign(e,{type:n,source:t,end:r});break}case"block-map":case"block-seq":{const i={type:"newline",offset:e.offset+t.length,indent:e.indent,source:`
`};delete e.items,Object.assign(e,{type:n,source:t,end:[i]});break}default:{const r="indent"in e?e.indent:-1,i="end"in e&&Array.isArray(e.end)?e.end.filter(a=>a.type==="space"||a.type==="comment"||a.type==="newline"):[];for(const a of Object.keys(e))a!=="type"&&a!=="offset"&&delete e[a];Object.assign(e,{type:n,indent:r,source:t,end:i})}}}const _Be=e=>"type"in e?F$(e):hD(e);function F$(e){switch(e.type){case"block-scalar":{let t="";for(const n of e.props)t+=F$(n);return t+e.source}case"block-map":case"block-seq":{let t="";for(const n of e.items)t+=hD(n);return t}case"flow-collection":{let t=e.start.source;for(const n of e.items)t+=hD(n);for(const n of e.end)t+=n.source;return t}case"document":{let t=hD(e);if(e.end)for(const n of e.end)t+=n.source;return t}default:{let t=e.source;if("end"in e&&e.end)for(const n of e.end)t+=n.source;return t}}}function hD({start:e,key:t,sep:n,value:r}){let i="";for(const a of e)i+=a.source;if(t&&(i+=F$(t)),n)for(const a of n)i+=a.source;return r&&(i+=F$(r)),i}const IM=Symbol("break visit"),EBe=Symbol("skip children"),xge=Symbol("remove item");function pb(e,t){"type"in e&&e.type==="document"&&(e={start:e.start,value:e.value}),Sge(Object.freeze([]),e,t)}pb.BREAK=IM;pb.SKIP=EBe;pb.REMOVE=xge;pb.itemAtPath=(e,t)=>{let n=e;for(const[r,i]of t){const a=n==null?void 0:n[r];if(a&&"items"in a)n=a.items[i];else return}return n};pb.parentCollection=(e,t)=>{const n=pb.itemAtPath(e,t.slice(0,-1)),r=t[t.length-1][0],i=n==null?void 0:n[r];if(i&&"items"in i)return i;throw new Error("Parent collection not found")};function Sge(e,t,n){let r=n(t,e);if(typeof r=="symbol")return r;for(const i of["key","value"]){const a=t[i];if(a&&"items"in a){for(let u=0;u<a.items.length;++u){const l=Sge(Object.freeze(e.concat([[i,u]])),a.items[u],n);if(typeof l=="number")u=l-1;else{if(l===IM)return IM;l===xge&&(a.items.splice(u,1),u-=1)}}typeof r=="function"&&i==="key"&&(r=r(t,e))}}return typeof r=="function"?r(t,e):r}const Iw="\uFEFF",Lw="",Bw="",zx="",DBe=e=>!!e&&"items"in e,$Be=e=>!!e&&(e.type==="scalar"||e.type==="single-quoted-scalar"||e.type==="double-quoted-scalar"||e.type==="block-scalar");function CBe(e){switch(e){case Iw:return"<BOM>";case Lw:return"<DOC>";case Bw:return"<FLOW_END>";case zx:return"<SCALAR>";default:return JSON.stringify(e)}}function _ge(e){switch(e){case Iw:return"byte-order-mark";case Lw:return"doc-mode";case Bw:return"flow-error-end";case zx:return"scalar";case"---":return"doc-start";case"...":return"doc-end";case"":case`
`:case`\r
`:return"newline";case"-":return"seq-item-ind";case"?":return"explicit-key-ind";case":":return"map-value-ind";case"{":return"flow-map-start";case"}":return"flow-map-end";case"[":return"flow-seq-start";case"]":return"flow-seq-end";case",":return"comma"}switch(e[0]){case" ":case"	":return"space";case"#":return"comment";case"%":return"directive-line";case"*":return"alias";case"&":return"anchor";case"!":return"tag";case"'":return"single-quoted-scalar";case'"':return"double-quoted-scalar";case"|":case">":return"block-scalar-header"}return null}const wBe=Object.freeze(Object.defineProperty({__proto__:null,BOM:Iw,DOCUMENT:Lw,FLOW_END:Bw,SCALAR:zx,createScalarToken:OBe,isCollection:DBe,isScalar:$Be,prettyToken:CBe,resolveAsScalar:bBe,setScalarValue:xBe,stringify:_Be,tokenType:_ge,visit:pb},Symbol.toStringTag,{value:"Module"}));function Zh(e){switch(e){case void 0:case" ":case`
`:case"\r":case"	":return!0;default:return!1}}const QX=new Set("0123456789ABCDEFabcdef"),RBe=new Set("0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz-#;/?:@&=+$_.!~*'()"),OE=new Set(",[]{}"),ABe=new Set(` ,[]{}
\r	`),RP=e=>!e||ABe.has(e);class Ege{constructor(){this.atEnd=!1,this.blockScalarIndent=-1,this.blockScalarKeep=!1,this.buffer="",this.flowKey=!1,this.flowLevel=0,this.indentNext=0,this.indentValue=0,this.lineEndPos=null,this.next=null,this.pos=0}*lex(t,n=!1){if(t){if(typeof t!="string")throw TypeError("source is not a string");this.buffer=this.buffer?this.buffer+t:t,this.lineEndPos=null}this.atEnd=!n;let r=this.next??"stream";for(;r&&(n||this.hasChars(1));)r=yield*this.parseNext(r)}atLineEnd(){let t=this.pos,n=this.buffer[t];for(;n===" "||n==="	";)n=this.buffer[++t];return!n||n==="#"||n===`
`?!0:n==="\r"?this.buffer[t+1]===`
`:!1}charAt(t){return this.buffer[this.pos+t]}continueScalar(t){let n=this.buffer[t];if(this.indentNext>0){let r=0;for(;n===" ";)n=this.buffer[++r+t];if(n==="\r"){const i=this.buffer[r+t+1];if(i===`
`||!i&&!this.atEnd)return t+r+1}return n===`
`||r>=this.indentNext||!n&&!this.atEnd?t+r:-1}if(n==="-"||n==="."){const r=this.buffer.substr(t,3);if((r==="---"||r==="...")&&Zh(this.buffer[t+3]))return-1}return t}getLine(){let t=this.lineEndPos;return(typeof t!="number"||t!==-1&&t<this.pos)&&(t=this.buffer.indexOf(`
`,this.pos),this.lineEndPos=t),t===-1?this.atEnd?this.buffer.substring(this.pos):null:(this.buffer[t-1]==="\r"&&(t-=1),this.buffer.substring(this.pos,t))}hasChars(t){return this.pos+t<=this.buffer.length}setNext(t){return this.buffer=this.buffer.substring(this.pos),this.pos=0,this.lineEndPos=null,this.next=t,null}peek(t){return this.buffer.substr(this.pos,t)}*parseNext(t){switch(t){case"stream":return yield*this.parseStream();case"line-start":return yield*this.parseLineStart();case"block-start":return yield*this.parseBlockStart();case"doc":return yield*this.parseDocument();case"flow":return yield*this.parseFlowCollection();case"quoted-scalar":return yield*this.parseQuotedScalar();case"block-scalar":return yield*this.parseBlockScalar();case"plain-scalar":return yield*this.parsePlainScalar()}}*parseStream(){let t=this.getLine();if(t===null)return this.setNext("stream");if(t[0]===Iw&&(yield*this.pushCount(1),t=t.substring(1)),t[0]==="%"){let n=t.length,r=t.indexOf("#");for(;r!==-1;){const a=t[r-1];if(a===" "||a==="	"){n=r-1;break}else r=t.indexOf("#",r+1)}for(;;){const a=t[n-1];if(a===" "||a==="	")n-=1;else break}const i=(yield*this.pushCount(n))+(yield*this.pushSpaces(!0));return yield*this.pushCount(t.length-i),this.pushNewline(),"stream"}if(this.atLineEnd()){const n=yield*this.pushSpaces(!0);return yield*this.pushCount(t.length-n),yield*this.pushNewline(),"stream"}return yield Lw,yield*this.parseLineStart()}*parseLineStart(){const t=this.charAt(0);if(!t&&!this.atEnd)return this.setNext("line-start");if(t==="-"||t==="."){if(!this.atEnd&&!this.hasChars(4))return this.setNext("line-start");const n=this.peek(3);if((n==="---"||n==="...")&&Zh(this.charAt(3)))return yield*this.pushCount(3),this.indentValue=0,this.indentNext=0,n==="---"?"doc":"stream"}return this.indentValue=yield*this.pushSpaces(!1),this.indentNext>this.indentValue&&!Zh(this.charAt(1))&&(this.indentNext=this.indentValue),yield*this.parseBlockStart()}*parseBlockStart(){const[t,n]=this.peek(2);if(!n&&!this.atEnd)return this.setNext("block-start");if((t==="-"||t==="?"||t===":")&&Zh(n)){const r=(yield*this.pushCount(1))+(yield*this.pushSpaces(!0));return this.indentNext=this.indentValue+1,this.indentValue+=r,yield*this.parseBlockStart()}return"doc"}*parseDocument(){yield*this.pushSpaces(!0);const t=this.getLine();if(t===null)return this.setNext("doc");let n=yield*this.pushIndicators();switch(t[n]){case"#":yield*this.pushCount(t.length-n);case void 0:return yield*this.pushNewline(),yield*this.parseLineStart();case"{":case"[":return yield*this.pushCount(1),this.flowKey=!1,this.flowLevel=1,"flow";case"}":case"]":return yield*this.pushCount(1),"doc";case"*":return yield*this.pushUntil(RP),"doc";case'"':case"'":return yield*this.parseQuotedScalar();case"|":case">":return n+=yield*this.parseBlockScalarHeader(),n+=yield*this.pushSpaces(!0),yield*this.pushCount(t.length-n),yield*this.pushNewline(),yield*this.parseBlockScalar();default:return yield*this.parsePlainScalar()}}*parseFlowCollection(){let t,n,r=-1;do t=yield*this.pushNewline(),t>0?(n=yield*this.pushSpaces(!1),this.indentValue=r=n):n=0,n+=yield*this.pushSpaces(!0);while(t+n>0);const i=this.getLine();if(i===null)return this.setNext("flow");if((r!==-1&&r<this.indentNext&&i[0]!=="#"||r===0&&(i.startsWith("---")||i.startsWith("..."))&&Zh(i[3]))&&!(r===this.indentNext-1&&this.flowLevel===1&&(i[0]==="]"||i[0]==="}")))return this.flowLevel=0,yield Bw,yield*this.parseLineStart();let a=0;for(;i[a]===",";)a+=yield*this.pushCount(1),a+=yield*this.pushSpaces(!0),this.flowKey=!1;switch(a+=yield*this.pushIndicators(),i[a]){case void 0:return"flow";case"#":return yield*this.pushCount(i.length-a),"flow";case"{":case"[":return yield*this.pushCount(1),this.flowKey=!1,this.flowLevel+=1,"flow";case"}":case"]":return yield*this.pushCount(1),this.flowKey=!0,this.flowLevel-=1,this.flowLevel?"flow":"doc";case"*":return yield*this.pushUntil(RP),"flow";case'"':case"'":return this.flowKey=!0,yield*this.parseQuotedScalar();case":":{const u=this.charAt(1);if(this.flowKey||Zh(u)||u===",")return this.flowKey=!1,yield*this.pushCount(1),yield*this.pushSpaces(!0),"flow"}default:return this.flowKey=!1,yield*this.parsePlainScalar()}}*parseQuotedScalar(){const t=this.charAt(0);let n=this.buffer.indexOf(t,this.pos+1);if(t==="'")for(;n!==-1&&this.buffer[n+1]==="'";)n=this.buffer.indexOf("'",n+2);else for(;n!==-1;){let a=0;for(;this.buffer[n-1-a]==="\\";)a+=1;if(a%2===0)break;n=this.buffer.indexOf('"',n+1)}const r=this.buffer.substring(0,n);let i=r.indexOf(`
`,this.pos);if(i!==-1){for(;i!==-1;){const a=this.continueScalar(i+1);if(a===-1)break;i=r.indexOf(`
`,a)}i!==-1&&(n=i-(r[i-1]==="\r"?2:1))}if(n===-1){if(!this.atEnd)return this.setNext("quoted-scalar");n=this.buffer.length}return yield*this.pushToIndex(n+1,!1),this.flowLevel?"flow":"doc"}*parseBlockScalarHeader(){this.blockScalarIndent=-1,this.blockScalarKeep=!1;let t=this.pos;for(;;){const n=this.buffer[++t];if(n==="+")this.blockScalarKeep=!0;else if(n>"0"&&n<="9")this.blockScalarIndent=Number(n)-1;else if(n!=="-")break}return yield*this.pushUntil(n=>Zh(n)||n==="#")}*parseBlockScalar(){let t=this.pos-1,n=0,r;e:for(let a=this.pos;r=this.buffer[a];++a)switch(r){case" ":n+=1;break;case`
`:t=a,n=0;break;case"\r":{const u=this.buffer[a+1];if(!u&&!this.atEnd)return this.setNext("block-scalar");if(u===`
`)break}default:break e}if(!r&&!this.atEnd)return this.setNext("block-scalar");if(n>=this.indentNext){this.blockScalarIndent===-1?this.indentNext=n:this.indentNext=this.blockScalarIndent+(this.indentNext===0?1:this.indentNext);do{const a=this.continueScalar(t+1);if(a===-1)break;t=this.buffer.indexOf(`
`,a)}while(t!==-1);if(t===-1){if(!this.atEnd)return this.setNext("block-scalar");t=this.buffer.length}}let i=t+1;for(r=this.buffer[i];r===" ";)r=this.buffer[++i];if(r==="	"){for(;r==="	"||r===" "||r==="\r"||r===`
`;)r=this.buffer[++i];t=i-1}else if(!this.blockScalarKeep)do{let a=t-1,u=this.buffer[a];u==="\r"&&(u=this.buffer[--a]);const l=a;for(;u===" ";)u=this.buffer[--a];if(u===`
`&&a>=this.pos&&a+1+n>l)t=a;else break}while(!0);return yield zx,yield*this.pushToIndex(t+1,!0),yield*this.parseLineStart()}*parsePlainScalar(){const t=this.flowLevel>0;let n=this.pos-1,r=this.pos-1,i;for(;i=this.buffer[++r];)if(i===":"){const a=this.buffer[r+1];if(Zh(a)||t&&OE.has(a))break;n=r}else if(Zh(i)){let a=this.buffer[r+1];if(i==="\r"&&(a===`
`?(r+=1,i=`
`,a=this.buffer[r+1]):n=r),a==="#"||t&&OE.has(a))break;if(i===`
`){const u=this.continueScalar(r+1);if(u===-1)break;r=Math.max(r,u-2)}}else{if(t&&OE.has(i))break;n=r}return!i&&!this.atEnd?this.setNext("plain-scalar"):(yield zx,yield*this.pushToIndex(n+1,!0),t?"flow":"doc")}*pushCount(t){return t>0?(yield this.buffer.substr(this.pos,t),this.pos+=t,t):0}*pushToIndex(t,n){const r=this.buffer.slice(this.pos,t);return r?(yield r,this.pos+=r.length,r.length):(n&&(yield""),0)}*pushIndicators(){switch(this.charAt(0)){case"!":return(yield*this.pushTag())+(yield*this.pushSpaces(!0))+(yield*this.pushIndicators());case"&":return(yield*this.pushUntil(RP))+(yield*this.pushSpaces(!0))+(yield*this.pushIndicators());case"-":case"?":case":":{const t=this.flowLevel>0,n=this.charAt(1);if(Zh(n)||t&&OE.has(n))return t?this.flowKey&&(this.flowKey=!1):this.indentNext=this.indentValue+1,(yield*this.pushCount(1))+(yield*this.pushSpaces(!0))+(yield*this.pushIndicators())}}return 0}*pushTag(){if(this.charAt(1)==="<"){let t=this.pos+2,n=this.buffer[t];for(;!Zh(n)&&n!==">";)n=this.buffer[++t];return yield*this.pushToIndex(n===">"?t+1:t,!1)}else{let t=this.pos+1,n=this.buffer[t];for(;n;)if(RBe.has(n))n=this.buffer[++t];else if(n==="%"&&QX.has(this.buffer[t+1])&&QX.has(this.buffer[t+2]))n=this.buffer[t+=3];else break;return yield*this.pushToIndex(t,!1)}}*pushNewline(){const t=this.buffer[this.pos];return t===`
`?yield*this.pushCount(1):t==="\r"&&this.charAt(1)===`
`?yield*this.pushCount(2):0}*pushSpaces(t){let n=this.pos-1,r;do r=this.buffer[++n];while(r===" "||t&&r==="	");const i=n-this.pos;return i>0&&(yield this.buffer.substr(this.pos,i),this.pos=n),i}*pushUntil(t){let n=this.pos,r=this.buffer[n];for(;!t(r);)r=this.buffer[++n];return yield*this.pushToIndex(n,!1)}}class Dge{constructor(){this.lineStarts=[],this.addNewLine=t=>this.lineStarts.push(t),this.linePos=t=>{let n=0,r=this.lineStarts.length;for(;n<r;){const a=n+r>>1;this.lineStarts[a]<t?n=a+1:r=a}if(this.lineStarts[n]===t)return{line:n+1,col:1};if(n===0)return{line:0,col:t};const i=this.lineStarts[n-1];return{line:n,col:t-i+1}}}}function Dv(e,t){for(let n=0;n<e.length;++n)if(e[n].type===t)return!0;return!1}function zX(e){for(let t=0;t<e.length;++t)switch(e[t].type){case"space":case"comment":case"newline":break;default:return t}return-1}function $ge(e){switch(e==null?void 0:e.type){case"alias":case"scalar":case"single-quoted-scalar":case"double-quoted-scalar":case"flow-collection":return!0;default:return!1}}function xE(e){switch(e.type){case"document":return e.start;case"block-map":{const t=e.items[e.items.length-1];return t.sep??t.start}case"block-seq":return e.items[e.items.length-1].start;default:return[]}}function DO(e){var n;if(e.length===0)return[];let t=e.length;e:for(;--t>=0;)switch(e[t].type){case"doc-start":case"explicit-key-ind":case"map-value-ind":case"seq-item-ind":case"newline":break e}for(;((n=e[++t])==null?void 0:n.type)==="space";);return e.splice(t,e.length)}function qX(e){if(e.start.type==="flow-seq-start")for(const t of e.items)t.sep&&!t.value&&!Dv(t.start,"explicit-key-ind")&&!Dv(t.sep,"map-value-ind")&&(t.key&&(t.value=t.key),delete t.key,$ge(t.value)?t.value.end?Array.prototype.push.apply(t.value.end,t.sep):t.value.end=t.sep:Array.prototype.push.apply(t.start,t.sep),delete t.sep)}class vL{constructor(t){this.atNewLine=!0,this.atScalar=!1,this.indent=0,this.offset=0,this.onKeyLine=!1,this.stack=[],this.source="",this.type="",this.lexer=new Ege,this.onNewLine=t}*parse(t,n=!1){this.onNewLine&&this.offset===0&&this.onNewLine(0);for(const r of this.lexer.lex(t,n))yield*this.next(r);n||(yield*this.end())}*next(t){if(this.source=t,this.atScalar){this.atScalar=!1,yield*this.step(),this.offset+=t.length;return}const n=_ge(t);if(n)if(n==="scalar")this.atNewLine=!1,this.atScalar=!0,this.type="scalar";else{switch(this.type=n,yield*this.step(),n){case"newline":this.atNewLine=!0,this.indent=0,this.onNewLine&&this.onNewLine(this.offset+t.length);break;case"space":this.atNewLine&&t[0]===" "&&(this.indent+=t.length);break;case"explicit-key-ind":case"map-value-ind":case"seq-item-ind":this.atNewLine&&(this.indent+=t.length);break;case"doc-mode":case"flow-error-end":return;default:this.atNewLine=!1}this.offset+=t.length}else{const r=`Not a YAML token: ${t}`;yield*this.pop({type:"error",offset:this.offset,message:r,source:t}),this.offset+=t.length}}*end(){for(;this.stack.length>0;)yield*this.pop()}get sourceToken(){return{type:this.type,offset:this.offset,indent:this.indent,source:this.source}}*step(){const t=this.peek(1);if(this.type==="doc-end"&&(!t||t.type!=="doc-end")){for(;this.stack.length>0;)yield*this.pop();this.stack.push({type:"doc-end",offset:this.offset,source:this.source});return}if(!t)return yield*this.stream();switch(t.type){case"document":return yield*this.document(t);case"alias":case"scalar":case"single-quoted-scalar":case"double-quoted-scalar":return yield*this.scalar(t);case"block-scalar":return yield*this.blockScalar(t);case"block-map":return yield*this.blockMap(t);case"block-seq":return yield*this.blockSequence(t);case"flow-collection":return yield*this.flowCollection(t);case"doc-end":return yield*this.documentEnd(t)}yield*this.pop()}peek(t){return this.stack[this.stack.length-t]}*pop(t){const n=t??this.stack.pop();if(!n)yield{type:"error",offset:this.offset,source:"",message:"Tried to pop an empty stack"};else if(this.stack.length===0)yield n;else{const r=this.peek(1);switch(n.type==="block-scalar"?n.indent="indent"in r?r.indent:0:n.type==="flow-collection"&&r.type==="document"&&(n.indent=0),n.type==="flow-collection"&&qX(n),r.type){case"document":r.value=n;break;case"block-scalar":r.props.push(n);break;case"block-map":{const i=r.items[r.items.length-1];if(i.value){r.items.push({start:[],key:n,sep:[]}),this.onKeyLine=!0;return}else if(i.sep)i.value=n;else{Object.assign(i,{key:n,sep:[]}),this.onKeyLine=!i.explicitKey;return}break}case"block-seq":{const i=r.items[r.items.length-1];i.value?r.items.push({start:[],value:n}):i.value=n;break}case"flow-collection":{const i=r.items[r.items.length-1];!i||i.value?r.items.push({start:[],key:n,sep:[]}):i.sep?i.value=n:Object.assign(i,{key:n,sep:[]});return}default:yield*this.pop(),yield*this.pop(n)}if((r.type==="document"||r.type==="block-map"||r.type==="block-seq")&&(n.type==="block-map"||n.type==="block-seq")){const i=n.items[n.items.length-1];i&&!i.sep&&!i.value&&i.start.length>0&&zX(i.start)===-1&&(n.indent===0||i.start.every(a=>a.type!=="comment"||a.indent<n.indent))&&(r.type==="document"?r.end=i.start:r.items.push({start:i.start}),n.items.splice(-1,1))}}}*stream(){switch(this.type){case"directive-line":yield{type:"directive",offset:this.offset,source:this.source};return;case"byte-order-mark":case"space":case"comment":case"newline":yield this.sourceToken;return;case"doc-mode":case"doc-start":{const t={type:"document",offset:this.offset,start:[]};this.type==="doc-start"&&t.start.push(this.sourceToken),this.stack.push(t);return}}yield{type:"error",offset:this.offset,message:`Unexpected ${this.type} token in YAML stream`,source:this.source}}*document(t){if(t.value)return yield*this.lineEnd(t);switch(this.type){case"doc-start":{zX(t.start)!==-1?(yield*this.pop(),yield*this.step()):t.start.push(this.sourceToken);return}case"anchor":case"tag":case"space":case"comment":case"newline":t.start.push(this.sourceToken);return}const n=this.startBlockValue(t);n?this.stack.push(n):yield{type:"error",offset:this.offset,message:`Unexpected ${this.type} token in YAML document`,source:this.source}}*scalar(t){if(this.type==="map-value-ind"){const n=xE(this.peek(2)),r=DO(n);let i;t.end?(i=t.end,i.push(this.sourceToken),delete t.end):i=[this.sourceToken];const a={type:"block-map",offset:t.offset,indent:t.indent,items:[{start:r,key:t,sep:i}]};this.onKeyLine=!0,this.stack[this.stack.length-1]=a}else yield*this.lineEnd(t)}*blockScalar(t){switch(this.type){case"space":case"comment":case"newline":t.props.push(this.sourceToken);return;case"scalar":if(t.source=this.source,this.atNewLine=!0,this.indent=0,this.onNewLine){let n=this.source.indexOf(`
`)+1;for(;n!==0;)this.onNewLine(this.offset+n),n=this.source.indexOf(`
`,n)+1}yield*this.pop();break;default:yield*this.pop(),yield*this.step()}}*blockMap(t){var r;const n=t.items[t.items.length-1];switch(this.type){case"newline":if(this.onKeyLine=!1,n.value){const i="end"in n.value?n.value.end:void 0,a=Array.isArray(i)?i[i.length-1]:void 0;(a==null?void 0:a.type)==="comment"?i==null||i.push(this.sourceToken):t.items.push({start:[this.sourceToken]})}else n.sep?n.sep.push(this.sourceToken):n.start.push(this.sourceToken);return;case"space":case"comment":if(n.value)t.items.push({start:[this.sourceToken]});else if(n.sep)n.sep.push(this.sourceToken);else{if(this.atIndentedComment(n.start,t.indent)){const i=t.items[t.items.length-2],a=(r=i==null?void 0:i.value)==null?void 0:r.end;if(Array.isArray(a)){Array.prototype.push.apply(a,n.start),a.push(this.sourceToken),t.items.pop();return}}n.start.push(this.sourceToken)}return}if(this.indent>=t.indent){const i=!this.onKeyLine&&this.indent===t.indent,a=i&&(n.sep||n.explicitKey)&&this.type!=="seq-item-ind";let u=[];if(a&&n.sep&&!n.value){const l=[];for(let o=0;o<n.sep.length;++o){const s=n.sep[o];switch(s.type){case"newline":l.push(o);break;case"space":break;case"comment":s.indent>t.indent&&(l.length=0);break;default:l.length=0}}l.length>=2&&(u=n.sep.splice(l[1]))}switch(this.type){case"anchor":case"tag":a||n.value?(u.push(this.sourceToken),t.items.push({start:u}),this.onKeyLine=!0):n.sep?n.sep.push(this.sourceToken):n.start.push(this.sourceToken);return;case"explicit-key-ind":!n.sep&&!n.explicitKey?(n.start.push(this.sourceToken),n.explicitKey=!0):a||n.value?(u.push(this.sourceToken),t.items.push({start:u,explicitKey:!0})):this.stack.push({type:"block-map",offset:this.offset,indent:this.indent,items:[{start:[this.sourceToken],explicitKey:!0}]}),this.onKeyLine=!0;return;case"map-value-ind":if(n.explicitKey)if(n.sep)if(n.value)t.items.push({start:[],key:null,sep:[this.sourceToken]});else if(Dv(n.sep,"map-value-ind"))this.stack.push({type:"block-map",offset:this.offset,indent:this.indent,items:[{start:u,key:null,sep:[this.sourceToken]}]});else if($ge(n.key)&&!Dv(n.sep,"newline")){const l=DO(n.start),o=n.key,s=n.sep;s.push(this.sourceToken),delete n.key,delete n.sep,this.stack.push({type:"block-map",offset:this.offset,indent:this.indent,items:[{start:l,key:o,sep:s}]})}else u.length>0?n.sep=n.sep.concat(u,this.sourceToken):n.sep.push(this.sourceToken);else if(Dv(n.start,"newline"))Object.assign(n,{key:null,sep:[this.sourceToken]});else{const l=DO(n.start);this.stack.push({type:"block-map",offset:this.offset,indent:this.indent,items:[{start:l,key:null,sep:[this.sourceToken]}]})}else n.sep?n.value||a?t.items.push({start:u,key:null,sep:[this.sourceToken]}):Dv(n.sep,"map-value-ind")?this.stack.push({type:"block-map",offset:this.offset,indent:this.indent,items:[{start:[],key:null,sep:[this.sourceToken]}]}):n.sep.push(this.sourceToken):Object.assign(n,{key:null,sep:[this.sourceToken]});this.onKeyLine=!0;return;case"alias":case"scalar":case"single-quoted-scalar":case"double-quoted-scalar":{const l=this.flowScalar(this.type);a||n.value?(t.items.push({start:u,key:l,sep:[]}),this.onKeyLine=!0):n.sep?this.stack.push(l):(Object.assign(n,{key:l,sep:[]}),this.onKeyLine=!0);return}default:{const l=this.startBlockValue(t);if(l){if(l.type==="block-seq"){if(!n.explicitKey&&n.sep&&!Dv(n.sep,"newline")){yield*this.pop({type:"error",offset:this.offset,message:"Unexpected block-seq-ind on same line with key",source:this.source});return}}else i&&t.items.push({start:u});this.stack.push(l);return}}}}yield*this.pop(),yield*this.step()}*blockSequence(t){var r;const n=t.items[t.items.length-1];switch(this.type){case"newline":if(n.value){const i="end"in n.value?n.value.end:void 0,a=Array.isArray(i)?i[i.length-1]:void 0;(a==null?void 0:a.type)==="comment"?i==null||i.push(this.sourceToken):t.items.push({start:[this.sourceToken]})}else n.start.push(this.sourceToken);return;case"space":case"comment":if(n.value)t.items.push({start:[this.sourceToken]});else{if(this.atIndentedComment(n.start,t.indent)){const i=t.items[t.items.length-2],a=(r=i==null?void 0:i.value)==null?void 0:r.end;if(Array.isArray(a)){Array.prototype.push.apply(a,n.start),a.push(this.sourceToken),t.items.pop();return}}n.start.push(this.sourceToken)}return;case"anchor":case"tag":if(n.value||this.indent<=t.indent)break;n.start.push(this.sourceToken);return;case"seq-item-ind":if(this.indent!==t.indent)break;n.value||Dv(n.start,"seq-item-ind")?t.items.push({start:[this.sourceToken]}):n.start.push(this.sourceToken);return}if(this.indent>t.indent){const i=this.startBlockValue(t);if(i){this.stack.push(i);return}}yield*this.pop(),yield*this.step()}*flowCollection(t){const n=t.items[t.items.length-1];if(this.type==="flow-error-end"){let r;do yield*this.pop(),r=this.peek(1);while(r&&r.type==="flow-collection")}else if(t.end.length===0){switch(this.type){case"comma":case"explicit-key-ind":!n||n.sep?t.items.push({start:[this.sourceToken]}):n.start.push(this.sourceToken);return;case"map-value-ind":!n||n.value?t.items.push({start:[],key:null,sep:[this.sourceToken]}):n.sep?n.sep.push(this.sourceToken):Object.assign(n,{key:null,sep:[this.sourceToken]});return;case"space":case"comment":case"newline":case"anchor":case"tag":!n||n.value?t.items.push({start:[this.sourceToken]}):n.sep?n.sep.push(this.sourceToken):n.start.push(this.sourceToken);return;case"alias":case"scalar":case"single-quoted-scalar":case"double-quoted-scalar":{const i=this.flowScalar(this.type);!n||n.value?t.items.push({start:[],key:i,sep:[]}):n.sep?this.stack.push(i):Object.assign(n,{key:i,sep:[]});return}case"flow-map-end":case"flow-seq-end":t.end.push(this.sourceToken);return}const r=this.startBlockValue(t);r?this.stack.push(r):(yield*this.pop(),yield*this.step())}else{const r=this.peek(2);if(r.type==="block-map"&&(this.type==="map-value-ind"&&r.indent===t.indent||this.type==="newline"&&!r.items[r.items.length-1].sep))yield*this.pop(),yield*this.step();else if(this.type==="map-value-ind"&&r.type!=="flow-collection"){const i=xE(r),a=DO(i);qX(t);const u=t.end.splice(1,t.end.length);u.push(this.sourceToken);const l={type:"block-map",offset:t.offset,indent:t.indent,items:[{start:a,key:t,sep:u}]};this.onKeyLine=!0,this.stack[this.stack.length-1]=l}else yield*this.lineEnd(t)}}flowScalar(t){if(this.onNewLine){let n=this.source.indexOf(`
`)+1;for(;n!==0;)this.onNewLine(this.offset+n),n=this.source.indexOf(`
`,n)+1}return{type:t,offset:this.offset,indent:this.indent,source:this.source}}startBlockValue(t){switch(this.type){case"alias":case"scalar":case"single-quoted-scalar":case"double-quoted-scalar":return this.flowScalar(this.type);case"block-scalar-header":return{type:"block-scalar",offset:this.offset,indent:this.indent,props:[this.sourceToken],source:""};case"flow-map-start":case"flow-seq-start":return{type:"flow-collection",offset:this.offset,indent:this.indent,start:this.sourceToken,items:[],end:[]};case"seq-item-ind":return{type:"block-seq",offset:this.offset,indent:this.indent,items:[{start:[this.sourceToken]}]};case"explicit-key-ind":{this.onKeyLine=!0;const n=xE(t),r=DO(n);return r.push(this.sourceToken),{type:"block-map",offset:this.offset,indent:this.indent,items:[{start:r,explicitKey:!0}]}}case"map-value-ind":{this.onKeyLine=!0;const n=xE(t),r=DO(n);return{type:"block-map",offset:this.offset,indent:this.indent,items:[{start:r,key:null,sep:[this.sourceToken]}]}}}return null}atIndentedComment(t,n){return this.type!=="comment"||this.indent<=n?!1:t.every(r=>r.type==="newline"||r.type==="space")}*documentEnd(t){this.type!=="doc-mode"&&(t.end?t.end.push(this.sourceToken):t.end=[this.sourceToken],this.type==="newline"&&(yield*this.pop()))}*lineEnd(t){switch(this.type){case"comma":case"doc-start":case"doc-end":case"flow-seq-end":case"flow-map-end":case"map-value-ind":yield*this.pop(),yield*this.step();break;case"newline":this.onKeyLine=!1;case"space":case"comment":default:t.end?t.end.push(this.sourceToken):t.end=[this.sourceToken],this.type==="newline"&&(yield*this.pop())}}}function Cge(e){const t=e.prettyErrors!==!1;return{lineCounter:e.lineCounter||t&&new Dge||null,prettyErrors:t}}function TBe(e,t={}){const{lineCounter:n,prettyErrors:r}=Cge(t),i=new vL(n==null?void 0:n.addNewLine),a=new gL(t),u=Array.from(a.compose(i.parse(e)));if(r&&n)for(const l of u)l.errors.forEach(M$(e,n)),l.warnings.forEach(M$(e,n));return u.length>0?u:Object.assign([],{empty:!0},a.streamInfo())}function wge(e,t={}){const{lineCounter:n,prettyErrors:r}=Cge(t),i=new vL(n==null?void 0:n.addNewLine),a=new gL(t);let u=null;for(const l of a.compose(i.parse(e),!0,e.length))if(!u)u=l;else if(u.options.logLevel!=="silent"){u.errors.push(new V1(l.range.slice(0,2),"MULTIPLE_DOCS","Source contains multiple documents; please use YAML.parseAllDocuments()"));break}return r&&n&&(u.errors.forEach(M$(e,n)),u.warnings.forEach(M$(e,n))),u}function kBe(e,t,n){let r;typeof t=="function"?r=t:n===void 0&&t&&typeof t=="object"&&(n=t);const i=wge(e,n);if(!i)return null;if(i.warnings.forEach(a=>Hme(i.options.logLevel,a)),i.errors.length>0){if(i.options.logLevel!=="silent")throw i.errors[0];i.errors=[]}return i.toJS(Object.assign({reviver:r},n))}function PBe(e,t,n){let r=null;if(typeof t=="function"||Array.isArray(t)?r=t:n===void 0&&t&&(n=t),typeof n=="string"&&(n=n.length),typeof n=="number"){const i=Math.round(n);n=i<1?void 0:i>8?{indent:8}:{indent:i}}if(e===void 0){const{keepUndefined:i}=n??t??{};if(!i)return}return Tb(e)&&!r?e.toString(n):new Nw(e,r,n).toString(n)}const Jat=Object.freeze(Object.defineProperty({__proto__:null,Alias:$w,CST:wBe,Composer:gL,Document:Nw,Lexer:Ege,LineCounter:Dge,Pair:gs,Parser:vL,Scalar:ar,Schema:Fw,YAMLError:pL,YAMLMap:zf,YAMLParseError:V1,YAMLSeq:ly,YAMLWarning:hge,isAlias:xy,isCollection:ou,isDocument:Tb,isMap:l4,isNode:cu,isPair:Za,isScalar:oa,isSeq:o4,parse:kBe,parseAllDocuments:TBe,parseDocument:wge,stringify:PBe,visit:kb,visitAsync:Dw},Symbol.toStringTag,{value:"Module"})),MBe=1,Rge=194,Age=195,FBe=196,VX=197,NBe=198,IBe=199,LBe=200,BBe=2,Tge=3,UX=201,QBe=24,zBe=25,qBe=49,VBe=50,UBe=55,jBe=56,ZBe=57,HBe=59,XBe=60,YBe=61,GBe=62,KBe=63,WBe=65,JBe=238,eQe=71,tQe=241,nQe=242,rQe=243,iQe=244,aQe=245,uQe=246,lQe=247,oQe=248,kge=72,sQe=249,cQe=250,fQe=251,dQe=252,hQe=253,pQe=254,mQe=255,gQe=256,vQe=73,yQe=77,bQe=263,OQe=112,xQe=130,SQe=151,_Qe=152,EQe=155,mb=10,qx=13,yL=32,Qw=9,bL=35,DQe=40,$Qe=46,LM=123,jX=125,Pge=39,Mge=34,ZX=92,CQe=111,wQe=120,RQe=78,AQe=117,TQe=85,kQe=new Set([zBe,qBe,VBe,bQe,WBe,xQe,jBe,ZBe,JBe,GBe,KBe,kge,vQe,yQe,XBe,YBe,SQe,_Qe,EQe,OQe]);function AP(e){return e==mb||e==qx}function TP(e){return e>=48&&e<=57||e>=65&&e<=70||e>=97&&e<=102}const PQe=new gg((e,t)=>{let n;if(e.next<0)e.acceptToken(IBe);else if(t.context.flags&pD)AP(e.next)&&e.acceptToken(NBe,1);else if(((n=e.peek(-1))<0||AP(n))&&t.canShift(VX)){let r=0;for(;e.next==yL||e.next==Qw;)e.advance(),r++;(e.next==mb||e.next==qx||e.next==bL)&&e.acceptToken(VX,-r)}else AP(e.next)&&e.acceptToken(FBe,1)},{contextual:!0}),MQe=new gg((e,t)=>{let n=t.context;if(n.flags)return;let r=e.peek(-1);if(r==mb||r==qx){let i=0,a=0;for(;;){if(e.next==yL)i++;else if(e.next==Qw)i+=8-i%8;else break;e.advance(),a++}i!=n.indent&&e.next!=mb&&e.next!=qx&&e.next!=bL&&(i<n.indent?e.acceptToken(Age,-a):e.acceptToken(Rge))}}),pD=1,Fge=2,Fm=4,Nm=8,Im=16,Lm=32;function mD(e,t,n){this.parent=e,this.indent=t,this.flags=n,this.hash=(e?e.hash+e.hash<<8:0)+t+(t<<4)+n+(n<<6)}const FQe=new mD(null,0,0);function NQe(e){let t=0;for(let n=0;n<e.length;n++)t+=e.charCodeAt(n)==Qw?8-t%8:1;return t}const HX=new Map([[tQe,0],[nQe,Fm],[rQe,Nm],[iQe,Nm|Fm],[aQe,Im],[uQe,Im|Fm],[lQe,Im|Nm],[oQe,Im|Nm|Fm],[sQe,Lm],[cQe,Lm|Fm],[fQe,Lm|Nm],[dQe,Lm|Nm|Fm],[hQe,Lm|Im],[pQe,Lm|Im|Fm],[mQe,Lm|Im|Nm],[gQe,Lm|Im|Nm|Fm]].map(([e,t])=>[e,t|Fge])),IQe=new Ree({start:FQe,reduce(e,t,n,r){return e.flags&pD&&kQe.has(t)||(t==eQe||t==kge)&&e.flags&Fge?e.parent:e},shift(e,t,n,r){return t==Rge?new mD(e,NQe(r.read(r.pos,n.pos)),0):t==Age?e.parent:t==QBe||t==UBe||t==HBe||t==Tge?new mD(e,0,pD):HX.has(t)?new mD(e,0,HX.get(t)|e.flags&pD):e},hash(e){return e.hash}}),LQe=new gg(e=>{for(let t=0;t<5;t++){if(e.next!="print".charCodeAt(t))return;e.advance()}if(!/\w/.test(String.fromCharCode(e.next)))for(let t=0;;t++){let n=e.peek(t);if(!(n==yL||n==Qw)){n!=DQe&&n!=$Qe&&n!=mb&&n!=qx&&n!=bL&&e.acceptToken(MBe);return}}}),BQe=new gg((e,t)=>{let{flags:n}=t.context,r=n&Fm?Mge:Pge,i=(n&Nm)>0,a=!(n&Im),u=(n&Lm)>0,l=e.pos;for(;!(e.next<0);)if(u&&e.next==LM)if(e.peek(1)==LM)e.advance(2);else{if(e.pos==l){e.acceptToken(Tge,1);return}break}else if(a&&e.next==ZX){if(e.pos==l){e.advance();let o=e.next;o>=0&&(e.advance(),QQe(e,o)),e.acceptToken(BBe);return}break}else if(e.next==ZX&&!a&&e.peek(1)>-1)e.advance(2);else if(e.next==r&&(!i||e.peek(1)==r&&e.peek(2)==r)){if(e.pos==l){e.acceptToken(UX,i?3:1);return}break}else if(e.next==mb){if(i)e.advance();else if(e.pos==l){e.acceptToken(UX);return}break}else e.advance();e.pos>l&&e.acceptToken(LBe)});function QQe(e,t){if(t==CQe)for(let n=0;n<2&&e.next>=48&&e.next<=55;n++)e.advance();else if(t==wQe)for(let n=0;n<2&&TP(e.next);n++)e.advance();else if(t==AQe)for(let n=0;n<4&&TP(e.next);n++)e.advance();else if(t==TQe)for(let n=0;n<8&&TP(e.next);n++)e.advance();else if(t==RQe&&e.next==LM){for(e.advance();e.next>=0&&e.next!=jX&&e.next!=Pge&&e.next!=Mge&&e.next!=mb;)e.advance();e.next==jX&&e.advance()}}const zQe=nN({'async "*" "**" FormatConversion FormatSpec':ot.modifier,"for while if elif else try except finally return raise break continue with pass assert await yield match case":ot.controlKeyword,"in not and or is del":ot.operatorKeyword,"from def class global nonlocal lambda":ot.definitionKeyword,import:ot.moduleKeyword,"with as print":ot.keyword,Boolean:ot.bool,None:ot.null,VariableName:ot.variableName,"CallExpression/VariableName":ot.function(ot.variableName),"FunctionDefinition/VariableName":ot.function(ot.definition(ot.variableName)),"ClassDefinition/VariableName":ot.definition(ot.className),PropertyName:ot.propertyName,"CallExpression/MemberExpression/PropertyName":ot.function(ot.propertyName),Comment:ot.lineComment,Number:ot.number,String:ot.string,FormatString:ot.special(ot.string),Escape:ot.escape,UpdateOp:ot.updateOperator,"ArithOp!":ot.arithmeticOperator,BitOp:ot.bitwiseOperator,CompareOp:ot.compareOperator,AssignOp:ot.definitionOperator,Ellipsis:ot.punctuation,At:ot.meta,"( )":ot.paren,"[ ]":ot.squareBracket,"{ }":ot.brace,".":ot.derefOperator,", ;":ot.separator}),qQe={__proto__:null,await:44,or:54,and:56,in:60,not:62,is:64,if:70,else:72,lambda:76,yield:94,from:96,async:102,for:104,None:162,True:164,False:164,del:178,pass:182,break:186,continue:190,return:194,raise:202,import:206,as:208,global:212,nonlocal:214,assert:218,type:223,elif:236,while:240,try:246,except:248,finally:250,with:254,def:258,class:268,match:279,case:285},eut=$3.deserialize({version:14,states:"##jO`QeOOP$}OSOOO&WQtO'#HUOOQS'#Co'#CoOOQS'#Cp'#CpO'vQdO'#CnO*UQtO'#HTOOQS'#HU'#HUOOQS'#DU'#DUOOQS'#HT'#HTO*rQdO'#D_O+VQdO'#DfO+gQdO'#DjO+zOWO'#DuO,VOWO'#DvO.[QtO'#GuOOQS'#Gu'#GuO'vQdO'#GtO0ZQtO'#GtOOQS'#Eb'#EbO0rQdO'#EcOOQS'#Gs'#GsO0|QdO'#GrOOQV'#Gr'#GrO1XQdO'#FYOOQS'#G^'#G^O1^QdO'#FXOOQV'#IS'#ISOOQV'#Gq'#GqOOQV'#Fq'#FqQ`QeOOO'vQdO'#CqO1lQdO'#C}O1sQdO'#DRO2RQdO'#HYO2cQtO'#EVO'vQdO'#EWOOQS'#EY'#EYOOQS'#E['#E[OOQS'#E^'#E^O2wQdO'#E`O3_QdO'#EdO3rQdO'#EfO3zQtO'#EfO1XQdO'#EiO0rQdO'#ElO1XQdO'#EnO0rQdO'#EtO0rQdO'#EwO4VQdO'#EyO4^QdO'#FOO4iQdO'#EzO0rQdO'#FOO1XQdO'#FQO1XQdO'#FVO4nQdO'#F[P4uOdO'#GpPOOO)CBd)CBdOOQS'#Ce'#CeOOQS'#Cf'#CfOOQS'#Cg'#CgOOQS'#Ch'#ChOOQS'#Ci'#CiOOQS'#Cj'#CjOOQS'#Cl'#ClO'vQdO,59OO'vQdO,59OO'vQdO,59OO'vQdO,59OO'vQdO,59OO'vQdO,59OO5TQdO'#DoOOQS,5:Y,5:YO5hQdO'#HdOOQS,5:],5:]O5uQ!fO,5:]O5zQtO,59YO1lQdO,59bO1lQdO,59bO1lQdO,59bO8jQdO,59bO8oQdO,59bO8vQdO,59jO8}QdO'#HTO:TQdO'#HSOOQS'#HS'#HSOOQS'#D['#D[O:lQdO,59aO'vQdO,59aO:zQdO,59aOOQS,59y,59yO;PQdO,5:RO'vQdO,5:ROOQS,5:Q,5:QO;_QdO,5:QO;dQdO,5:XO'vQdO,5:XO'vQdO,5:VOOQS,5:U,5:UO;uQdO,5:UO;zQdO,5:WOOOW'#Fy'#FyO<POWO,5:aOOQS,5:a,5:aO<[QdO'#HwOOOW'#Dw'#DwOOOW'#Fz'#FzO<lOWO,5:bOOQS,5:b,5:bOOQS'#F}'#F}O<zQtO,5:iO?lQtO,5=`O@VQ#xO,5=`O@vQtO,5=`OOQS,5:},5:}OA_QeO'#GWOBqQdO,5;^OOQV,5=^,5=^OB|QtO'#IPOCkQdO,5;tOOQS-E:[-E:[OOQV,5;s,5;sO4dQdO'#FQOOQV-E9o-E9oOCsQtO,59]OEzQtO,59iOFeQdO'#HVOFpQdO'#HVO1XQdO'#HVOF{QdO'#DTOGTQdO,59mOGYQdO'#HZO'vQdO'#HZO0rQdO,5=tOOQS,5=t,5=tO0rQdO'#EROOQS'#ES'#ESOGwQdO'#GPOHXQdO,58|OHXQdO,58|O*xQdO,5:oOHgQtO'#H]OOQS,5:r,5:rOOQS,5:z,5:zOHzQdO,5;OOI]QdO'#IOO1XQdO'#H}OOQS,5;Q,5;QOOQS'#GT'#GTOIqQtO,5;QOJPQdO,5;QOJUQdO'#IQOOQS,5;T,5;TOJdQdO'#H|OOQS,5;W,5;WOJuQdO,5;YO4iQdO,5;`O4iQdO,5;cOJ}QtO'#ITO'vQdO'#ITOKXQdO,5;eO4VQdO,5;eO0rQdO,5;jO1XQdO,5;lOK^QeO'#EuOLjQgO,5;fO!!kQdO'#IUO4iQdO,5;jO!!vQdO,5;lO!#OQdO,5;qO!#ZQtO,5;vO'vQdO,5;vPOOO,5=[,5=[P!#bOSO,5=[P!#jOdO,5=[O!&bQtO1G.jO!&iQtO1G.jO!)YQtO1G.jO!)dQtO1G.jO!+}QtO1G.jO!,bQtO1G.jO!,uQdO'#HcO!-TQtO'#GuO0rQdO'#HcO!-_QdO'#HbOOQS,5:Z,5:ZO!-gQdO,5:ZO!-lQdO'#HeO!-wQdO'#HeO!.[QdO,5>OOOQS'#Ds'#DsOOQS1G/w1G/wOOQS1G.|1G.|O!/[QtO1G.|O!/cQtO1G.|O1lQdO1G.|O!0OQdO1G/UOOQS'#DZ'#DZO0rQdO,59tOOQS1G.{1G.{O!0VQdO1G/eO!0gQdO1G/eO!0oQdO1G/fO'vQdO'#H[O!0tQdO'#H[O!0yQtO1G.{O!1ZQdO,59iO!2aQdO,5=zO!2qQdO,5=zO!2yQdO1G/mO!3OQtO1G/mOOQS1G/l1G/lO!3`QdO,5=uO!4VQdO,5=uO0rQdO1G/qO!4tQdO1G/sO!4yQtO1G/sO!5ZQtO1G/qOOQS1G/p1G/pOOQS1G/r1G/rOOOW-E9w-E9wOOQS1G/{1G/{O!5kQdO'#HxO0rQdO'#HxO!5|QdO,5>cOOOW-E9x-E9xOOQS1G/|1G/|OOQS-E9{-E9{O!6[Q#xO1G2zO!6{QtO1G2zO'vQdO,5<jOOQS,5<j,5<jOOQS-E9|-E9|OOQS,5<r,5<rOOQS-E:U-E:UOOQV1G0x1G0xO1XQdO'#GRO!7dQtO,5>kOOQS1G1`1G1`O!8RQdO1G1`OOQS'#DV'#DVO0rQdO,5=qOOQS,5=q,5=qO!8WQdO'#FrO!8cQdO,59oO!8kQdO1G/XO!8uQtO,5=uOOQS1G3`1G3`OOQS,5:m,5:mO!9fQdO'#GtOOQS,5<k,5<kOOQS-E9}-E9}O!9wQdO1G.hOOQS1G0Z1G0ZO!:VQdO,5=wO!:gQdO,5=wO0rQdO1G0jO0rQdO1G0jO!:xQdO,5>jO!;ZQdO,5>jO1XQdO,5>jO!;lQdO,5>iOOQS-E:R-E:RO!;qQdO1G0lO!;|QdO1G0lO!<RQdO,5>lO!<aQdO,5>lO!<oQdO,5>hO!=VQdO,5>hO!=hQdO'#EpO0rQdO1G0tO!=sQdO1G0tO!=xQgO1G0zO!AvQgO1G0}O!EqQdO,5>oO!E{QdO,5>oO!FTQtO,5>oO0rQdO1G1PO!F_QdO1G1PO4iQdO1G1UO!!vQdO1G1WOOQV,5;a,5;aO!FdQfO,5;aO!FiQgO1G1QO!JjQdO'#GZO4iQdO1G1QO4iQdO1G1QO!JzQdO,5>pO!KXQdO,5>pO1XQdO,5>pOOQV1G1U1G1UO!KaQdO'#FSO!KrQ!fO1G1WO!KzQdO1G1WOOQV1G1]1G1]O4iQdO1G1]O!LPQdO1G1]O!LXQdO'#F^OOQV1G1b1G1bO!#ZQtO1G1bPOOO1G2v1G2vP!L^OSO1G2vOOQS,5=},5=}OOQS'#Dp'#DpO0rQdO,5=}O!LfQdO,5=|O!LyQdO,5=|OOQS1G/u1G/uO!MRQdO,5>PO!McQdO,5>PO!MkQdO,5>PO!NOQdO,5>PO!N`QdO,5>POOQS1G3j1G3jOOQS7+$h7+$hO!8kQdO7+$pO#!RQdO1G.|O#!YQdO1G.|OOQS1G/`1G/`OOQS,5<`,5<`O'vQdO,5<`OOQS7+%P7+%PO#!aQdO7+%POOQS-E9r-E9rOOQS7+%Q7+%QO#!qQdO,5=vO'vQdO,5=vOOQS7+$g7+$gO#!vQdO7+%PO##OQdO7+%QO##TQdO1G3fOOQS7+%X7+%XO##eQdO1G3fO##mQdO7+%XOOQS,5<_,5<_O'vQdO,5<_O##rQdO1G3aOOQS-E9q-E9qO#$iQdO7+%]OOQS7+%_7+%_O#$wQdO1G3aO#%fQdO7+%_O#%kQdO1G3gO#%{QdO1G3gO#&TQdO7+%]O#&YQdO,5>dO#&sQdO,5>dO#&sQdO,5>dOOQS'#Dx'#DxO#'UO&jO'#DzO#'aO`O'#HyOOOW1G3}1G3}O#'fQdO1G3}O#'nQdO1G3}O#'yQ#xO7+(fO#(jQtO1G2UP#)TQdO'#GOOOQS,5<m,5<mOOQS-E:P-E:POOQS7+&z7+&zOOQS1G3]1G3]OOQS,5<^,5<^OOQS-E9p-E9pOOQS7+$s7+$sO#)bQdO,5=`O#){QdO,5=`O#*^QtO,5<aO#*qQdO1G3cOOQS-E9s-E9sOOQS7+&U7+&UO#+RQdO7+&UO#+aQdO,5<nO#+uQdO1G4UOOQS-E:Q-E:QO#,WQdO1G4UOOQS1G4T1G4TOOQS7+&W7+&WO#,iQdO7+&WOOQS,5<p,5<pO#,tQdO1G4WOOQS-E:S-E:SOOQS,5<l,5<lO#-SQdO1G4SOOQS-E:O-E:OO1XQdO'#EqO#-jQdO'#EqO#-uQdO'#IRO#-}QdO,5;[OOQS7+&`7+&`O0rQdO7+&`O#.SQgO7+&fO!JmQdO'#GXO4iQdO7+&fO4iQdO7+&iO#2QQtO,5<tO'vQdO,5<tO#2[QdO1G4ZOOQS-E:W-E:WO#2fQdO1G4ZO4iQdO7+&kO0rQdO7+&kOOQV7+&p7+&pO!KrQ!fO7+&rO!KzQdO7+&rO`QeO1G0{OOQV-E:X-E:XO4iQdO7+&lO4iQdO7+&lOOQV,5<u,5<uO#2nQdO,5<uO!JmQdO,5<uOOQV7+&l7+&lO#2yQgO7+&lO#6tQdO,5<vO#7PQdO1G4[OOQS-E:Y-E:YO#7^QdO1G4[O#7fQdO'#IWO#7tQdO'#IWO1XQdO'#IWOOQS'#IW'#IWO#8PQdO'#IVOOQS,5;n,5;nO#8XQdO,5;nO0rQdO'#FUOOQV7+&r7+&rO4iQdO7+&rOOQV7+&w7+&wO4iQdO7+&wO#8^QfO,5;xOOQV7+&|7+&|POOO7+(b7+(bO#8cQdO1G3iOOQS,5<c,5<cO#8qQdO1G3hOOQS-E9u-E9uO#9UQdO,5<dO#9aQdO,5<dO#9tQdO1G3kOOQS-E9v-E9vO#:UQdO1G3kO#:^QdO1G3kO#:nQdO1G3kO#:UQdO1G3kOOQS<<H[<<H[O#:yQtO1G1zOOQS<<Hk<<HkP#;WQdO'#FtO8vQdO1G3bO#;eQdO1G3bO#;jQdO<<HkOOQS<<Hl<<HlO#;zQdO7+)QOOQS<<Hs<<HsO#<[QtO1G1yP#<{QdO'#FsO#=YQdO7+)RO#=jQdO7+)RO#=rQdO<<HwO#=wQdO7+({OOQS<<Hy<<HyO#>nQdO,5<bO'vQdO,5<bOOQS-E9t-E9tOOQS<<Hw<<HwOOQS,5<g,5<gO0rQdO,5<gO#>sQdO1G4OOOQS-E9y-E9yO#?^QdO1G4OO<[QdO'#H{OOOO'#D{'#D{OOOO'#F|'#F|O#?oO&jO,5:fOOOW,5>e,5>eOOOW7+)i7+)iO#?zQdO7+)iO#@SQdO1G2zO#@mQdO1G2zP'vQdO'#FuO0rQdO<<IpO1XQdO1G2YP1XQdO'#GSO#AOQdO7+)pO#AaQdO7+)pOOQS<<Ir<<IrP1XQdO'#GUP0rQdO'#GQOOQS,5;],5;]O#ArQdO,5>mO#BQQdO,5>mOOQS1G0v1G0vOOQS<<Iz<<IzOOQV-E:V-E:VO4iQdO<<JQOOQV,5<s,5<sO4iQdO,5<sOOQV<<JQ<<JQOOQV<<JT<<JTO#BYQtO1G2`P#BdQdO'#GYO#BkQdO7+)uO#BuQgO<<JVO4iQdO<<JVOOQV<<J^<<J^O4iQdO<<J^O!KrQ!fO<<J^O#FpQgO7+&gOOQV<<JW<<JWO#FzQgO<<JWOOQV1G2a1G2aO1XQdO1G2aO#JuQdO1G2aO4iQdO<<JWO1XQdO1G2bP0rQdO'#G[O#KQQdO7+)vO#K_QdO7+)vOOQS'#FT'#FTO0rQdO,5>rO#KgQdO,5>rO#KrQdO,5>rO#K}QdO,5>qO#L`QdO,5>qOOQS1G1Y1G1YOOQS,5;p,5;pOOQV<<Jc<<JcO#LhQdO1G1dOOQS7+)T7+)TP#LmQdO'#FwO#L}QdO1G2OO#MbQdO1G2OO#MrQdO1G2OP#M}QdO'#FxO#N[QdO7+)VO#NlQdO7+)VO#NlQdO7+)VO#NtQdO7+)VO$ UQdO7+(|O8vQdO7+(|OOQSAN>VAN>VO$ oQdO<<LmOOQSAN>cAN>cO0rQdO1G1|O$!PQtO1G1|P$!ZQdO'#FvOOQS1G2R1G2RP$!hQdO'#F{O$!uQdO7+)jO$#`QdO,5>gOOOO-E9z-E9zOOOW<<MT<<MTO$#nQdO7+(fOOQSAN?[AN?[OOQS7+'t7+'tO$$XQdO<<M[OOQS,5<q,5<qO$$jQdO1G4XOOQS-E:T-E:TOOQVAN?lAN?lOOQV1G2_1G2_O4iQdOAN?qO$$xQgOAN?qOOQVAN?xAN?xO4iQdOAN?xOOQV<<JR<<JRO4iQdOAN?rO4iQdO7+'{OOQV7+'{7+'{O1XQdO7+'{OOQVAN?rAN?rOOQS7+'|7+'|O$(sQdO<<MbOOQS1G4^1G4^O0rQdO1G4^OOQS,5<w,5<wO$)QQdO1G4]OOQS-E:Z-E:ZOOQU'#G_'#G_O$)cQfO7+'OO$)nQdO'#F_O$*uQdO7+'jO$+VQdO7+'jOOQS7+'j7+'jO$+bQdO<<LqO$+rQdO<<LqO$+rQdO<<LqO$+zQdO'#H^OOQS<<Lh<<LhO$,UQdO<<LhOOQS7+'h7+'hOOQS'#D|'#D|OOOO1G4R1G4RO$,oQdO1G4RO$,wQdO1G4RP!=hQdO'#GVOOQVG25]G25]O4iQdOG25]OOQVG25dG25dOOQVG25^G25^OOQV<<Kg<<KgO4iQdO<<KgOOQS7+)x7+)xP$-SQdO'#G]OOQU-E:]-E:]OOQV<<Jj<<JjO$-vQtO'#FaOOQS'#Fc'#FcO$.WQdO'#FbO$.xQdO'#FbOOQS'#Fb'#FbO$.}QdO'#IYO$)nQdO'#FiO$)nQdO'#FiO$/fQdO'#FjO$)nQdO'#FkO$/mQdO'#IZOOQS'#IZ'#IZO$0[QdO,5;yOOQS<<KU<<KUO$0dQdO<<KUO$0tQdOANB]O$1UQdOANB]O$1^QdO'#H_OOQS'#H_'#H_O1sQdO'#DcO$1wQdO,5=xOOQSANBSANBSOOOO7+)m7+)mO$2`QdO7+)mOOQVLD*wLD*wOOQVANARANARO5uQ!fO'#GaO$2hQtO,5<SO$)nQdO'#FmOOQS,5<W,5<WOOQS'#Fd'#FdO$3YQdO,5;|O$3_QdO,5;|OOQS'#Fg'#FgO$)nQdO'#G`O$4PQdO,5<QO$4kQdO,5>tO$4{QdO,5>tO1XQdO,5<PO$5^QdO,5<TO$5cQdO,5<TO$)nQdO'#I[O$5hQdO'#I[O$5mQdO,5<UOOQS,5<V,5<VO0rQdO'#FpOOQU1G1e1G1eO4iQdO1G1eOOQSAN@pAN@pO$5rQdOG27wO$6SQdO,59}OOQS1G3d1G3dOOOO<<MX<<MXOOQS,5<{,5<{OOQS-E:_-E:_O$6XQtO'#FaO$6`QdO'#I]O$6nQdO'#I]O$6vQdO,5<XOOQS1G1h1G1hO$6{QdO1G1hO$7QQdO,5<zOOQS-E:^-E:^O$7lQdO,5=OO$8TQdO1G4`OOQS-E:b-E:bOOQS1G1k1G1kOOQS1G1o1G1oO$8eQdO,5>vO$)nQdO,5>vOOQS1G1p1G1pOOQS,5<[,5<[OOQU7+'P7+'PO$+zQdO1G/iO$)nQdO,5<YO$8sQdO,5>wO$8zQdO,5>wOOQS1G1s1G1sOOQS7+'S7+'SP$)nQdO'#GdO$9SQdO1G4bO$9^QdO1G4bO$9fQdO1G4bOOQS7+%T7+%TO$9tQdO1G1tO$:SQtO'#FaO$:ZQdO,5<}OOQS,5<},5<}O$:iQdO1G4cOOQS-E:a-E:aO$)nQdO,5<|O$:pQdO,5<|O$:uQdO7+)|OOQS-E:`-E:`O$;PQdO7+)|O$)nQdO,5<ZP$)nQdO'#GcO$;XQdO1G2hO$)nQdO1G2hP$;gQdO'#GbO$;nQdO<<MhO$;xQdO1G1uO$<WQdO7+(SO8vQdO'#C}O8vQdO,59bO8vQdO,59bO8vQdO,59bO$<fQtO,5=`O8vQdO1G.|O0rQdO1G/XO0rQdO7+$pP$<yQdO'#GOO'vQdO'#GtO$=WQdO,59bO$=]QdO,59bO$=dQdO,59mO$=iQdO1G/UO1sQdO'#DRO8vQdO,59j",stateData:"$>S~O%cOS%^OSSOS%]PQ~OPdOVaOfoOhYOopOs!POvqO!PrO!Q{O!T!SO!U!RO!XZO!][O!h`O!r`O!s`O!t`O!{tO!}uO#PvO#RwO#TxO#XyO#ZzO#^|O#_|O#a}O#c!OO#l!QO#o!TO#s!UO#u!VO#z!WO#}hO$P!XO%oRO%pRO%tSO%uWO&Z]O&[]O&]]O&^]O&_]O&`]O&a]O&b]O&c^O&d^O&e^O&f^O&g^O&h^O&i^O&j^O~O%]!YO~OV!aO_!aOa!bOh!iO!X!kO!f!mO%j![O%k!]O%l!^O%m!_O%n!_O%o!`O%p!`O%q!aO%r!aO%s!aO~Ok%xXl%xXm%xXn%xXo%xXp%xXs%xXz%xX{%xX!x%xX#g%xX%[%xX%_%xX%z%xXg%xX!T%xX!U%xX%{%xX!W%xX![%xX!Q%xX#[%xXt%xX!m%xX~P%SOfoOhYO!XZO!][O!h`O!r`O!s`O!t`O%oRO%pRO%tSO%uWO&Z]O&[]O&]]O&^]O&_]O&`]O&a]O&b]O&c^O&d^O&e^O&f^O&g^O&h^O&i^O&j^O~Oz%wX{%wX#g%wX%[%wX%_%wX%z%wX~Ok!pOl!qOm!oOn!oOo!rOp!sOs!tO!x%wX~P)pOV!zOg!|Oo0cOv0qO!PrO~P'vOV#OOo0cOv0qO!W#PO~P'vOV#SOa#TOo0cOv0qO![#UO~P'vOQ#XO%`#XO%a#ZO~OQ#^OR#[O%`#^O%a#`O~OV%iX_%iXa%iXh%iXk%iXl%iXm%iXn%iXo%iXp%iXs%iXz%iX!X%iX!f%iX%j%iX%k%iX%l%iX%m%iX%n%iX%o%iX%p%iX%q%iX%r%iX%s%iXg%iX!T%iX!U%iX~O&Z]O&[]O&]]O&^]O&_]O&`]O&a]O&b]O&c^O&d^O&e^O&f^O&g^O&h^O&i^O&j^O{%iX!x%iX#g%iX%[%iX%_%iX%z%iX%{%iX!W%iX![%iX!Q%iX#[%iXt%iX!m%iX~P,eOz#dO{%hX!x%hX#g%hX%[%hX%_%hX%z%hX~Oo0cOv0qO~P'vO#g#gO%[#iO%_#iO~O%uWO~O!T#nO#u!VO#z!WO#}hO~OopO~P'vOV#sOa#tO%uWO{wP~OV#xOo0cOv0qO!Q#yO~P'vO{#{O!x$QO%z#|O#g!yX%[!yX%_!yX~OV#xOo0cOv0qO#g#SX%[#SX%_#SX~P'vOo0cOv0qO#g#WX%[#WX%_#WX~P'vOh$WO%uWO~O!f$YO!r$YO%uWO~OV$eO~P'vO!U$gO#s$hO#u$iO~O{$jO~OV$qO~P'vOS$sO%[$rO%_$rO%c$tO~OV$}Oa$}Og%POo0cOv0qO~P'vOo0cOv0qO{%SO~P'vO&Y%UO~Oa!bOh!iO!X!kO!f!mOVba_bakbalbambanbaobapbasbazba{ba!xba#gba%[ba%_ba%jba%kba%lba%mba%nba%oba%pba%qba%rba%sba%zbagba!Tba!Uba%{ba!Wba![ba!Qba#[batba!mba~On%ZO~Oo%ZO~P'vOo0cO~P'vOk0eOl0fOm0dOn0dOo0mOp0nOs0rOg%wX!T%wX!U%wX%{%wX!W%wX![%wX!Q%wX#[%wX!m%wX~P)pO%{%]Og%vXz%vX!T%vX!U%vX!W%vX{%vX~Og%_Oz%`O!T%dO!U%cO~Og%_O~Oz%gO!T%dO!U%cO!W&SX~O!W%kO~Oz%lO{%nO!T%dO!U%cO![%}X~O![%rO~O![%sO~OQ#XO%`#XO%a%uO~OV%wOo0cOv0qO!PrO~P'vOQ#^OR#[O%`#^O%a%zO~OV!qa_!qaa!qah!qak!qal!qam!qan!qao!qap!qas!qaz!qa{!qa!X!qa!f!qa!x!qa#g!qa%[!qa%_!qa%j!qa%k!qa%l!qa%m!qa%n!qa%o!qa%p!qa%q!qa%r!qa%s!qa%z!qag!qa!T!qa!U!qa%{!qa!W!qa![!qa!Q!qa#[!qat!qa!m!qa~P#yOz%|O{%ha!x%ha#g%ha%[%ha%_%ha%z%ha~P%SOV&OOopOvqO{%ha!x%ha#g%ha%[%ha%_%ha%z%ha~P'vOz%|O{%ha!x%ha#g%ha%[%ha%_%ha%z%ha~OPdOVaOopOvqO!PrO!Q{O!{tO!}uO#PvO#RwO#TxO#XyO#ZzO#^|O#_|O#a}O#c!OO#g$zX%[$zX%_$zX~P'vO#g#gO%[&TO%_&TO~O!f&UOh&sX%[&sXz&sX#[&sX#g&sX%_&sX#Z&sXg&sX~Oh!iO%[&WO~Okealeameaneaoeapeaseazea{ea!xea#gea%[ea%_ea%zeagea!Tea!Uea%{ea!Wea![ea!Qea#[eatea!mea~P%SOsqazqa{qa#gqa%[qa%_qa%zqa~Ok!pOl!qOm!oOn!oOo!rOp!sO!xqa~PEcO%z&YOz%yX{%yX~O%uWOz%yX{%yX~Oz&]O{wX~O{&_O~Oz%lO#g%}X%[%}X%_%}Xg%}X{%}X![%}X!m%}X%z%}X~OV0lOo0cOv0qO!PrO~P'vO%z#|O#gUa%[Ua%_Ua~Oz&hO#g&PX%[&PX%_&PXn&PX~P%SOz&kO!Q&jO#g#Wa%[#Wa%_#Wa~Oz&lO#[&nO#g&rX%[&rX%_&rXg&rX~O!f$YO!r$YO#Z&qO%uWO~O#Z&qO~Oz&sO#g&tX%[&tX%_&tX~Oz&uO#g&pX%[&pX%_&pX{&pX~O!X&wO%z&xO~Oz&|On&wX~P%SOn'PO~OPdOVaOopOvqO!PrO!Q{O!{tO!}uO#PvO#RwO#TxO#XyO#ZzO#^|O#_|O#a}O#c!OO%['UO~P'vOt'YO#p'WO#q'XOP#naV#naf#nah#nao#nas#nav#na!P#na!Q#na!T#na!U#na!X#na!]#na!h#na!r#na!s#na!t#na!{#na!}#na#P#na#R#na#T#na#X#na#Z#na#^#na#_#na#a#na#c#na#l#na#o#na#s#na#u#na#z#na#}#na$P#na%X#na%o#na%p#na%t#na%u#na&Z#na&[#na&]#na&^#na&_#na&`#na&a#na&b#na&c#na&d#na&e#na&f#na&g#na&h#na&i#na&j#na%Z#na%_#na~Oz'ZO#[']O{&xX~Oh'_O!X&wO~Oh!iO{$jO!X&wO~O{'eO~P%SO%['hO%_'hO~OS'iO%['hO%_'hO~OV!aO_!aOa!bOh!iO!X!kO!f!mO%l!^O%m!_O%n!_O%o!`O%p!`O%q!aO%r!aO%s!aOkWilWimWinWioWipWisWizWi{Wi!xWi#gWi%[Wi%_Wi%jWi%zWigWi!TWi!UWi%{Wi!WWi![Wi!QWi#[WitWi!mWi~O%k!]O~P!#uO%kWi~P!#uOV!aO_!aOa!bOh!iO!X!kO!f!mO%o!`O%p!`O%q!aO%r!aO%s!aOkWilWimWinWioWipWisWizWi{Wi!xWi#gWi%[Wi%_Wi%jWi%kWi%lWi%zWigWi!TWi!UWi%{Wi!WWi![Wi!QWi#[WitWi!mWi~O%m!_O%n!_O~P!&pO%mWi%nWi~P!&pOa!bOh!iO!X!kO!f!mOkWilWimWinWioWipWisWizWi{Wi!xWi#gWi%[Wi%_Wi%jWi%kWi%lWi%mWi%nWi%oWi%pWi%zWigWi!TWi!UWi%{Wi!WWi![Wi!QWi#[WitWi!mWi~OV!aO_!aO%q!aO%r!aO%s!aO~P!)nOVWi_Wi%qWi%rWi%sWi~P!)nO!T%dO!U%cOg&VXz&VX~O%z'kO%{'kO~P,eOz'mOg&UX~Og'oO~Oz'pO{'rO!W&XX~Oo0cOv0qOz'pO{'sO!W&XX~P'vO!W'uO~Om!oOn!oOo!rOp!sOkjisjizji{ji!xji#gji%[ji%_ji%zji~Ol!qO~P!.aOlji~P!.aOk0eOl0fOm0dOn0dOo0mOp0nO~Ot'wO~P!/jOV'|Og'}Oo0cOv0qO~P'vOg'}Oz(OO~Og(QO~O!U(SO~Og(TOz(OO!T%dO!U%cO~P%SOk0eOl0fOm0dOn0dOo0mOp0nOgqa!Tqa!Uqa%{qa!Wqa![qa!Qqa#[qatqa!mqa~PEcOV'|Oo0cOv0qO!W&Sa~P'vOz(WO!W&Sa~O!W(XO~Oz(WO!T%dO!U%cO!W&Sa~P%SOV(]Oo0cOv0qO![%}a#g%}a%[%}a%_%}ag%}a{%}a!m%}a%z%}a~P'vOz(^O![%}a#g%}a%[%}a%_%}ag%}a{%}a!m%}a%z%}a~O![(aO~Oz(^O!T%dO!U%cO![%}a~P%SOz(dO!T%dO!U%cO![&Ta~P%SOz(gO{&lX![&lX!m&lX%z&lX~O{(kO![(mO!m(nO%z(jO~OV&OOopOvqO{%hi!x%hi#g%hi%[%hi%_%hi%z%hi~P'vOz(pO{%hi!x%hi#g%hi%[%hi%_%hi%z%hi~O!f&UOh&sa%[&saz&sa#[&sa#g&sa%_&sa#Z&sag&sa~O%[(uO~OV#sOa#tO%uWO~Oz&]O{wa~OopOvqO~P'vOz(^O#g%}a%[%}a%_%}ag%}a{%}a![%}a!m%}a%z%}a~P%SOz(zO#g%hX%[%hX%_%hX%z%hX~O%z#|O#gUi%[Ui%_Ui~O#g&Pa%[&Pa%_&Pan&Pa~P'vOz(}O#g&Pa%[&Pa%_&Pan&Pa~O%uWO#g&ra%[&ra%_&rag&ra~Oz)SO#g&ra%[&ra%_&rag&ra~Og)VO~OV)WOh$WO%uWO~O#Z)XO~O%uWO#g&ta%[&ta%_&ta~Oz)ZO#g&ta%[&ta%_&ta~Oo0cOv0qO#g&pa%[&pa%_&pa{&pa~P'vOz)^O#g&pa%[&pa%_&pa{&pa~OV)`Oa)`O%uWO~O%z)eO~Ot)hO#j)gOP#hiV#hif#hih#hio#his#hiv#hi!P#hi!Q#hi!T#hi!U#hi!X#hi!]#hi!h#hi!r#hi!s#hi!t#hi!{#hi!}#hi#P#hi#R#hi#T#hi#X#hi#Z#hi#^#hi#_#hi#a#hi#c#hi#l#hi#o#hi#s#hi#u#hi#z#hi#}#hi$P#hi%X#hi%o#hi%p#hi%t#hi%u#hi&Z#hi&[#hi&]#hi&^#hi&_#hi&`#hi&a#hi&b#hi&c#hi&d#hi&e#hi&f#hi&g#hi&h#hi&i#hi&j#hi%Z#hi%_#hi~Ot)iOP#kiV#kif#kih#kio#kis#kiv#ki!P#ki!Q#ki!T#ki!U#ki!X#ki!]#ki!h#ki!r#ki!s#ki!t#ki!{#ki!}#ki#P#ki#R#ki#T#ki#X#ki#Z#ki#^#ki#_#ki#a#ki#c#ki#l#ki#o#ki#s#ki#u#ki#z#ki#}#ki$P#ki%X#ki%o#ki%p#ki%t#ki%u#ki&Z#ki&[#ki&]#ki&^#ki&_#ki&`#ki&a#ki&b#ki&c#ki&d#ki&e#ki&f#ki&g#ki&h#ki&i#ki&j#ki%Z#ki%_#ki~OV)kOn&wa~P'vOz)lOn&wa~Oz)lOn&wa~P%SOn)pO~O%Y)tO~Ot)wO#p'WO#q)vOP#niV#nif#nih#nio#nis#niv#ni!P#ni!Q#ni!T#ni!U#ni!X#ni!]#ni!h#ni!r#ni!s#ni!t#ni!{#ni!}#ni#P#ni#R#ni#T#ni#X#ni#Z#ni#^#ni#_#ni#a#ni#c#ni#l#ni#o#ni#s#ni#u#ni#z#ni#}#ni$P#ni%X#ni%o#ni%p#ni%t#ni%u#ni&Z#ni&[#ni&]#ni&^#ni&_#ni&`#ni&a#ni&b#ni&c#ni&d#ni&e#ni&f#ni&g#ni&h#ni&i#ni&j#ni%Z#ni%_#ni~OV)zOo0cOv0qO{$jO~P'vOo0cOv0qO{&xa~P'vOz*OO{&xa~OV*SOa*TOg*WO%q*UO%uWO~O{$jO&{*YO~Oh'_O~Oh!iO{$jO~O%[*_O~O%[*aO%_*aO~OV$}Oa$}Oo0cOv0qOg&Ua~P'vOz*dOg&Ua~Oo0cOv0qO{*gO!W&Xa~P'vOz*hO!W&Xa~Oo0cOv0qOz*hO{*kO!W&Xa~P'vOo0cOv0qOz*hO!W&Xa~P'vOz*hO{*kO!W&Xa~Om0dOn0dOo0mOp0nOgjikjisjizji!Tji!Uji%{ji!Wji{ji![ji#gji%[ji%_ji!Qji#[jitji!mji%zji~Ol0fO~P!NkOlji~P!NkOV'|Og*pOo0cOv0qO~P'vOn*rO~Og*pOz*tO~Og*uO~OV'|Oo0cOv0qO!W&Si~P'vOz*vO!W&Si~O!W*wO~OV(]Oo0cOv0qO![%}i#g%}i%[%}i%_%}ig%}i{%}i!m%}i%z%}i~P'vOz*zO!T%dO!U%cO![&Ti~Oz*}O![%}i#g%}i%[%}i%_%}ig%}i{%}i!m%}i%z%}i~O![+OO~Oa+QOo0cOv0qO![&Ti~P'vOz*zO![&Ti~O![+SO~OV+UOo0cOv0qO{&la![&la!m&la%z&la~P'vOz+VO{&la![&la!m&la%z&la~O!]+YO&n+[O![!nX~O![+^O~O{(kO![+_O~O{(kO![+_O!m+`O~OV&OOopOvqO{%hq!x%hq#g%hq%[%hq%_%hq%z%hq~P'vOz$ri{$ri!x$ri#g$ri%[$ri%_$ri%z$ri~P%SOV&OOopOvqO~P'vOV&OOo0cOv0qO#g%ha%[%ha%_%ha%z%ha~P'vOz+aO#g%ha%[%ha%_%ha%z%ha~Oz$ia#g$ia%[$ia%_$ian$ia~P%SO#g&Pi%[&Pi%_&Pin&Pi~P'vOz+dO#g#Wq%[#Wq%_#Wq~O#[+eOz$va#g$va%[$va%_$vag$va~O%uWO#g&ri%[&ri%_&rig&ri~Oz+gO#g&ri%[&ri%_&rig&ri~OV+iOh$WO%uWO~O%uWO#g&ti%[&ti%_&ti~Oo0cOv0qO#g&pi%[&pi%_&pi{&pi~P'vO{#{Oz#eX!W#eX~Oz+mO!W&uX~O!W+oO~Ot+rO#j)gOP#hqV#hqf#hqh#hqo#hqs#hqv#hq!P#hq!Q#hq!T#hq!U#hq!X#hq!]#hq!h#hq!r#hq!s#hq!t#hq!{#hq!}#hq#P#hq#R#hq#T#hq#X#hq#Z#hq#^#hq#_#hq#a#hq#c#hq#l#hq#o#hq#s#hq#u#hq#z#hq#}#hq$P#hq%X#hq%o#hq%p#hq%t#hq%u#hq&Z#hq&[#hq&]#hq&^#hq&_#hq&`#hq&a#hq&b#hq&c#hq&d#hq&e#hq&f#hq&g#hq&h#hq&i#hq&j#hq%Z#hq%_#hq~On$|az$|a~P%SOV)kOn&wi~P'vOz+yOn&wi~Oz,TO{$jO#[,TO~O#q,VOP#nqV#nqf#nqh#nqo#nqs#nqv#nq!P#nq!Q#nq!T#nq!U#nq!X#nq!]#nq!h#nq!r#nq!s#nq!t#nq!{#nq!}#nq#P#nq#R#nq#T#nq#X#nq#Z#nq#^#nq#_#nq#a#nq#c#nq#l#nq#o#nq#s#nq#u#nq#z#nq#}#nq$P#nq%X#nq%o#nq%p#nq%t#nq%u#nq&Z#nq&[#nq&]#nq&^#nq&_#nq&`#nq&a#nq&b#nq&c#nq&d#nq&e#nq&f#nq&g#nq&h#nq&i#nq&j#nq%Z#nq%_#nq~O#[,WOz%Oa{%Oa~Oo0cOv0qO{&xi~P'vOz,YO{&xi~O{#{O%z,[Og&zXz&zX~O%uWOg&zXz&zX~Oz,`Og&yX~Og,bO~O%Y,eO~O!T%dO!U%cOg&Viz&Vi~OV$}Oa$}Oo0cOv0qOg&Ui~P'vO{,hOz$la!W$la~Oo0cOv0qO{,iOz$la!W$la~P'vOo0cOv0qO{*gO!W&Xi~P'vOz,lO!W&Xi~Oo0cOv0qOz,lO!W&Xi~P'vOz,lO{,oO!W&Xi~Og$hiz$hi!W$hi~P%SOV'|Oo0cOv0qO~P'vOn,qO~OV'|Og,rOo0cOv0qO~P'vOV'|Oo0cOv0qO!W&Sq~P'vOz$gi![$gi#g$gi%[$gi%_$gig$gi{$gi!m$gi%z$gi~P%SOV(]Oo0cOv0qO~P'vOa+QOo0cOv0qO![&Tq~P'vOz,sO![&Tq~O![,tO~OV(]Oo0cOv0qO![%}q#g%}q%[%}q%_%}qg%}q{%}q!m%}q%z%}q~P'vO{,uO~OV+UOo0cOv0qO{&li![&li!m&li%z&li~P'vOz,zO{&li![&li!m&li%z&li~O!]+YO&n+[O![!na~O{(kO![,}O~OV&OOo0cOv0qO#g%hi%[%hi%_%hi%z%hi~P'vOz-OO#g%hi%[%hi%_%hi%z%hi~O%uWO#g&rq%[&rq%_&rqg&rq~Oz-RO#g&rq%[&rq%_&rqg&rq~OV)`Oa)`O%uWO!W&ua~Oz-TO!W&ua~On$|iz$|i~P%SOV)kO~P'vOV)kOn&wq~P'vOt-XOP#myV#myf#myh#myo#mys#myv#my!P#my!Q#my!T#my!U#my!X#my!]#my!h#my!r#my!s#my!t#my!{#my!}#my#P#my#R#my#T#my#X#my#Z#my#^#my#_#my#a#my#c#my#l#my#o#my#s#my#u#my#z#my#}#my$P#my%X#my%o#my%p#my%t#my%u#my&Z#my&[#my&]#my&^#my&_#my&`#my&a#my&b#my&c#my&d#my&e#my&f#my&g#my&h#my&i#my&j#my%Z#my%_#my~O%Z-]O%_-]O~P`O#q-^OP#nyV#nyf#nyh#nyo#nys#nyv#ny!P#ny!Q#ny!T#ny!U#ny!X#ny!]#ny!h#ny!r#ny!s#ny!t#ny!{#ny!}#ny#P#ny#R#ny#T#ny#X#ny#Z#ny#^#ny#_#ny#a#ny#c#ny#l#ny#o#ny#s#ny#u#ny#z#ny#}#ny$P#ny%X#ny%o#ny%p#ny%t#ny%u#ny&Z#ny&[#ny&]#ny&^#ny&_#ny&`#ny&a#ny&b#ny&c#ny&d#ny&e#ny&f#ny&g#ny&h#ny&i#ny&j#ny%Z#ny%_#ny~Oz-aO{$jO#[-aO~Oo0cOv0qO{&xq~P'vOz-dO{&xq~O%z,[Og&zaz&za~O{#{Og&zaz&za~OV*SOa*TO%q*UO%uWOg&ya~Oz-hOg&ya~O$S-lO~OV$}Oa$}Oo0cOv0qO~P'vOo0cOv0qO{-mOz$li!W$li~P'vOo0cOv0qOz$li!W$li~P'vO{-mOz$li!W$li~Oo0cOv0qO{*gO~P'vOo0cOv0qO{*gO!W&Xq~P'vOz-pO!W&Xq~Oo0cOv0qOz-pO!W&Xq~P'vOs-sO!T%dO!U%cOg&Oq!W&Oq![&Oqz&Oq~P!/jOa+QOo0cOv0qO![&Ty~P'vOz$ji![$ji~P%SOa+QOo0cOv0qO~P'vOV+UOo0cOv0qO~P'vOV+UOo0cOv0qO{&lq![&lq!m&lq%z&lq~P'vO{(kO![-xO!m-yO%z-wO~OV&OOo0cOv0qO#g%hq%[%hq%_%hq%z%hq~P'vO%uWO#g&ry%[&ry%_&ryg&ry~OV)`Oa)`O%uWO!W&ui~Ot-}OP#m!RV#m!Rf#m!Rh#m!Ro#m!Rs#m!Rv#m!R!P#m!R!Q#m!R!T#m!R!U#m!R!X#m!R!]#m!R!h#m!R!r#m!R!s#m!R!t#m!R!{#m!R!}#m!R#P#m!R#R#m!R#T#m!R#X#m!R#Z#m!R#^#m!R#_#m!R#a#m!R#c#m!R#l#m!R#o#m!R#s#m!R#u#m!R#z#m!R#}#m!R$P#m!R%X#m!R%o#m!R%p#m!R%t#m!R%u#m!R&Z#m!R&[#m!R&]#m!R&^#m!R&_#m!R&`#m!R&a#m!R&b#m!R&c#m!R&d#m!R&e#m!R&f#m!R&g#m!R&h#m!R&i#m!R&j#m!R%Z#m!R%_#m!R~Oo0cOv0qO{&xy~P'vOV*SOa*TO%q*UO%uWOg&yi~O$S-lO%Z.VO%_.VO~OV.aOh._O!X.^O!].`O!h.YO!s.[O!t.[O%p.XO%uWO&Z]O&[]O&]]O&^]O&_]O&`]O&a]O&b]O~Oo0cOv0qOz$lq!W$lq~P'vO{.fOz$lq!W$lq~Oo0cOv0qO{*gO!W&Xy~P'vOz.gO!W&Xy~Oo0cOv.kO~P'vOs-sO!T%dO!U%cOg&Oy!W&Oy![&Oyz&Oy~P!/jO{(kO![.nO~O{(kO![.nO!m.oO~OV*SOa*TO%q*UO%uWO~Oh.tO!f.rOz$TX#[$TX%j$TXg$TX~Os$TX{$TX!W$TX![$TX~P$-bO%o.vO%p.vOs$UXz$UX{$UX#[$UX%j$UX!W$UXg$UX![$UX~O!h.xO~Oz.|O#[/OO%j.yOs&|X{&|X!W&|Xg&|X~Oa/RO~P$)zOh.tOs&}Xz&}X{&}X#[&}X%j&}X!W&}Xg&}X![&}X~Os/VO{$jO~Oo0cOv0qOz$ly!W$ly~P'vOo0cOv0qO{*gO!W&X!R~P'vOz/ZO!W&X!R~Og&RXs&RX!T&RX!U&RX!W&RX![&RXz&RX~P!/jOs-sO!T%dO!U%cOg&Qa!W&Qa![&Qaz&Qa~O{(kO![/^O~O!f.rOh$[as$[az$[a{$[a#[$[a%j$[a!W$[ag$[a![$[a~O!h/eO~O%o.vO%p.vOs$Uaz$Ua{$Ua#[$Ua%j$Ua!W$Uag$Ua![$Ua~O%j.yOs$Yaz$Ya{$Ya#[$Ya!W$Yag$Ya![$Ya~Os&|a{&|a!W&|ag&|a~P$)nOz/jOs&|a{&|a!W&|ag&|a~O!W/mO~Og/mO~O{/oO~O![/pO~Oo0cOv0qO{*gO!W&X!Z~P'vO{/sO~O%z/tO~P$-bOz/uO#[/OO%j.yOg'PX~Oz/uOg'PX~Og/wO~O!h/xO~O#[/OOs%Saz%Sa{%Sa%j%Sa!W%Sag%Sa![%Sa~O#[/OO%j.yOs%Waz%Wa{%Wa!W%Wag%Wa~Os&|i{&|i!W&|ig&|i~P$)nOz/zO#[/OO%j.yO!['Oa~Og'Pa~P$)nOz0SOg'Pa~Oa0UO!['Oi~P$)zOz0WO!['Oi~Oz0WO#[/OO%j.yO!['Oi~O#[/OO%j.yOg$biz$bi~O%z0ZO~P$-bO#[/OO%j.yOg%Vaz%Va~Og'Pi~P$)nO{0^O~Oa0UO!['Oq~P$)zOz0`O!['Oq~O#[/OO%j.yOz%Ui![%Ui~Oa0UO~P$)zOa0UO!['Oy~P$)zO#[/OO%j.yOg$ciz$ci~O#[/OO%j.yOz%Uq![%Uq~Oz+aO#g%ha%[%ha%_%ha%z%ha~P%SOV&OOo0cOv0qO~P'vOn0hO~Oo0hO~P'vO{0iO~Ot0jO~P!/jO&]&Z&j&h&i&g&f&d&e&c&b&`&a&_&^&[%u~",goto:"!=j'QPPPPPP'RP'Z*s+[+t,_,y-fP.SP'Z.r.r'ZPPP'Z2[PPPPPP2[5PPP5PP7b7k=sPP=v>h>kPP'Z'ZPP>zPP'Z'ZPP'Z'Z'Z'Z'Z?O?w'ZP?zP@QDXGuGyPG|HWH['ZPPPH_Hk'RP'R'RP'RP'RP'RP'RP'R'R'RP'RPP'RPP'RP'RPHqH}IVPI^IdPI^PI^I^PPPI^PKrPK{LVL]KrPI^LfPI^PLmLsPLwM]MzNeLwLwNkNxLwLwLwLw! ^! d! g! l! o! y!!P!!]!!o!!u!#P!#V!#s!#y!$P!$Z!$a!$g!$y!%T!%Z!%a!%k!%q!%w!%}!&T!&Z!&e!&k!&u!&{!'U!'[!'k!'s!'}!(UPPPPPPPPPPP!([!(_!(e!(n!(x!)TPPPPPPPPPPPP!-u!/Z!3^!6oPP!6w!7W!7a!8Y!8P!8c!8i!8l!8o!8r!8z!9jPPPPPPPPPPPPPPPPP!9m!9q!9wP!:]!:a!:m!:v!;S!;j!;m!;p!;v!;|!<S!<VP!<_!<h!=d!=g]eOn#g$j)t,P'}`OTYZ[adnoprtxy}!P!Q!R!U!X!c!d!e!f!g!h!i!k!o!p!q!s!t!z#O#S#T#[#d#g#x#y#{#}$Q$e$g$h$j$q$}%S%Z%^%`%c%g%l%n%w%|&O&Z&_&h&j&k&u&x&|'P'W'Z'l'm'p'r's'w'|(O(S(W(](^(d(g(p(r(z(})^)e)g)k)l)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+Q+U+V+Y+a+c+d+k+x+y,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0l0n0r{!cQ#c#p$R$d$p%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g}!dQ#c#p$R$d$p$u%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g!P!eQ#c#p$R$d$p$u$v%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g!R!fQ#c#p$R$d$p$u$v$w%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g!T!gQ#c#p$R$d$p$u$v$w$x%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g!V!hQ#c#p$R$d$p$u$v$w$x$y%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g!Z!hQ!n#c#p$R$d$p$u$v$w$x$y$z%e%j%p%q&`'O'g(q(|)j*o*x+w,v0g'}TOTYZ[adnoprtxy}!P!Q!R!U!X!c!d!e!f!g!h!i!k!o!p!q!s!t!z#O#S#T#[#d#g#x#y#{#}$Q$e$g$h$j$q$}%S%Z%^%`%c%g%l%n%w%|&O&Z&_&h&j&k&u&x&|'P'W'Z'l'm'p'r's'w'|(O(S(W(](^(d(g(p(r(z(})^)e)g)k)l)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+Q+U+V+Y+a+c+d+k+x+y,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0l0n0r&eVOYZ[dnprxy}!P!Q!U!i!k!o!p!q!s!t#[#d#g#y#{#}$Q$h$j$}%S%Z%^%`%g%l%n%w%|&Z&_&j&k&u&x'P'W'Z'l'm'p'r's'w(O(W(^(d(g(p(r(z)^)e)g)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+U+V+Y+a+d+k,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0n0r%oXOYZ[dnrxy}!P!Q!U!i!k#[#d#g#y#{#}$Q$h$j$}%S%^%`%g%l%n%w%|&Z&_&j&k&u&x'P'W'Z'l'm'p'r's'w(O(W(^(d(g(p(r(z)^)e)g)p)t)z*O*Y*d*g*h*k*q*t*v*y*z*}+U+V+Y+a+d+k,P,X,Y,],g,h,i,k,l,o,s,u,w,y,z-O-d-f-m-p.f.g/V/Z0i0j0kQ#vqQ/[.kR0o0q't`OTYZ[adnoprtxy}!P!Q!R!U!X!c!d!e!f!g!h!k!o!p!q!s!t!z#O#S#T#[#d#g#x#y#{#}$Q$e$g$h$j$q$}%S%Z%^%`%c%g%l%n%w%|&O&Z&_&h&j&k&u&x&|'P'W'Z'l'p'r's'w'|(O(S(W(](^(d(g(p(r(z(})^)e)g)k)l)p)t)z*O*Y*g*h*k*q*r*t*v*y*z*}+Q+U+V+Y+a+c+d+k+x+y,P,X,Y,],h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0l0n0rh#jhz{$W$Z&l&q)S)X+f+g-RW#rq&].k0qQ$]|Q$a!OQ$n!VQ$o!WW$|!i'm*d,gS&[#s#tQ'S$iQ(s&UQ)U&nU)Y&s)Z+jW)a&w+m-T-{Q*Q']W*R'_,`-h.TQ+l)`S,_*S*TQ-Q+eQ-_,TQ-c,WQ.R-al.W-l.^._.a.z.|/R/j/o/t/y0U0Z0^Q/S.`Q/a.tQ/l/OU0P/u0S0[X0V/z0W0_0`R&Z#r!_!wYZ!P!Q!k%S%`%g'p'r's(O(W)g*g*h*k*q*t*v,h,i,k,l,o-m-p.f.g/ZR%^!vQ!{YQ%x#[Q&d#}Q&g$QR,{+YT.j-s/s!Y!jQ!n#c#p$R$d$p$u$v$w$x$y$z%e%j%p%q&`'O'g(q(|)j*o*x+w,v0gQ&X#kQ'c$oR*^'dR'l$|Q%V!mR/_.r'|_OTYZ[adnoprtxy}!P!Q!R!U!X!c!d!e!f!g!h!i!k!o!p!q!s!t!z#O#S#T#[#d#g#x#y#{#}$Q$e$g$h$j$q$}%S%Z%^%`%c%g%l%n%w%|&O&Z&_&h&j&k&u&x&|'P'W'Z'l'm'p'r's'w'|(O(S(W(](^(d(g(p(r(z(})^)e)g)k)l)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+Q+U+V+Y+a+c+d+k+x+y,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0l0n0rS#a_#b!P.[-l.^._.`.a.t.z.|/R/j/o/t/u/y/z0S0U0W0Z0[0^0_0`'|_OTYZ[adnoprtxy}!P!Q!R!U!X!c!d!e!f!g!h!i!k!o!p!q!s!t!z#O#S#T#[#d#g#x#y#{#}$Q$e$g$h$j$q$}%S%Z%^%`%c%g%l%n%w%|&O&Z&_&h&j&k&u&x&|'P'W'Z'l'm'p'r's'w'|(O(S(W(](^(d(g(p(r(z(})^)e)g)k)l)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+Q+U+V+Y+a+c+d+k+x+y,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0l0n0rT#a_#bT#^^#_R(o%xa(l%x(n(o+`,{-y-z.oT+[(k+]R-z,{Q$PsQ+l)aQ,^*RR-e,_X#}s$O$P&fQ&y$aQ'a$nQ'd$oR)s'SQ)b&wV-S+m-T-{ZgOn$j)t,PXkOn)t,PQ$k!TQ&z$bQ&{$cQ'^$mQ'b$oQ)q'RQ)x'WQ){'XQ)|'YQ*Z'`S*]'c'dQ+s)gQ+u)hQ+v)iQ+z)oS+|)r*[Q,Q)vQ,R)wS,S)y)zQ,d*^Q-V+rQ-W+tQ-Y+{S-Z+},OQ-`,UQ-b,VQ-|-XQ.O-[Q.P-^Q.Q-_Q.p-}Q.q.RQ/W.dR/r/XWkOn)t,PR#mjQ'`$nS)r'S'aR,O)sQ,]*RR-f,^Q*['`Q+})rR-[,OZiOjn)t,PQ'f$pR*`'gT-j,e-ku.c-l.^._.a.t.z.|/R/j/o/t/u/y0S0U0Z0[0^t.c-l.^._.a.t.z.|/R/j/o/t/u/y0S0U0Z0[0^Q/S.`X0V/z0W0_0`!P.Z-l.^._.`.a.t.z.|/R/j/o/t/u/y/z0S0U0W0Z0[0^0_0`Q.w.YR/f.xg.z.].{/b/i/n/|0O0Q0]0a0bu.b-l.^._.a.t.z.|/R/j/o/t/u/y0S0U0Z0[0^X.u.W.b/a0PR/c.tV0R/u0S0[R/X.dQnOS#on,PR,P)tQ&^#uR(x&^S%m#R#wS(_%m(bT(b%p&`Q%a!yQ%h!}W(P%a%h(U(YQ(U%eR(Y%jQ&i$RR)O&iQ(e%qQ*{(`T+R(e*{Q'n%OR*e'nS'q%R%SY*i'q*j,m-q.hU*j'r's'tU,m*k*l*mS-q,n,oR.h-rQ#Y]R%t#YQ#_^R%y#_Q(h%vS+W(h+XR+X(iQ+](kR,|+]Q#b_R%{#bQ#ebQ%}#cW&Q#e%}({+bQ({&cR+b0gQ$OsS&e$O&fR&f$PQ&v$_R)_&vQ&V#jR(t&VQ&m$VS)T&m+hR+h)UQ$Z{R&p$ZQ&t$]R)[&tQ+n)bR-U+nQ#hfR&S#hQ)f&zR+q)fQ&}$dS)m&})nR)n'OQ'V$kR)u'VQ'[$lS*P'[,ZR,Z*QQ,a*VR-i,aWjOn)t,PR#ljQ-k,eR.U-kd.{.]/b/i/n/|0O0Q0]0a0bR/h.{U.s.W/a0PR/`.sQ/{/nS0X/{0YR0Y/|S/v/b/cR0T/vQ.}.]R/k.}R!ZPXmOn)t,PWlOn)t,PR'T$jYfOn$j)t,PR&R#g[sOn#g$j)t,PR&d#}&dQOYZ[dnprxy}!P!Q!U!i!k!o!p!q!s!t#[#d#g#y#{#}$Q$h$j$}%S%Z%^%`%g%l%n%w%|&Z&_&j&k&u&x'P'W'Z'l'm'p'r's'w(O(W(^(d(g(p(r(z)^)e)g)p)t)z*O*Y*d*g*h*k*q*r*t*v*y*z*}+U+V+Y+a+d+k,P,X,Y,],g,h,i,k,l,o,q,s,u,w,y,z-O-d-f-m-p-s.f.g/V/Z/s0c0d0e0f0h0i0j0k0n0rQ!nTQ#caQ#poU$Rt%c(SS$d!R$gQ$p!XQ$u!cQ$v!dQ$w!eQ$x!fQ$y!gQ$z!hQ%e!zQ%j#OQ%p#SQ%q#TQ&`#xQ'O$eQ'g$qQ(q&OU(|&h(}+cW)j&|)l+x+yQ*o'|Q*x(]Q+w)kQ,v+QR0g0lQ!yYQ!}ZQ$b!PQ$c!QQ%R!kQ't%S^'{%`%g(O(W*q*t*v^*f'p*h,k,l-p.g/ZQ*l'rQ*m'sQ+t)gQ,j*gQ,n*kQ-n,hQ-o,iQ-r,oQ.e-mR/Y.f[bOn#g$j)t,P!^!vYZ!P!Q!k%S%`%g'p'r's(O(W)g*g*h*k*q*t*v,h,i,k,l,o-m-p.f.g/ZQ#R[Q#fdS#wrxQ$UyW$_}$Q'P)pS$l!U$hW${!i'm*d,gS%v#[+Y`&P#d%|(p(r(z+a-O0kQ&a#yQ&b#{Q&c#}Q'j$}Q'z%^W([%l(^*y*}Q(`%nQ(i%wQ(v&ZS(y&_0iQ)P&jQ)Q&kU)]&u)^+kQ)d&xQ)y'WY)}'Z*O,X,Y-dQ*b'lS*n'w0jW+P(d*z,s,wW+T(g+V,y,zQ+p)eQ,U)zQ,c*YQ,x+UQ-P+dQ-e,]Q-v,uQ.S-fR/q/VhUOn#d#g$j%|&_'w(p(r)t,P%U!uYZ[drxy}!P!Q!U!i!k#[#y#{#}$Q$h$}%S%^%`%g%l%n%w&Z&j&k&u&x'P'W'Z'l'm'p'r's(O(W(^(d(g(z)^)e)g)p)z*O*Y*d*g*h*k*q*t*v*y*z*}+U+V+Y+a+d+k,X,Y,],g,h,i,k,l,o,s,u,w,y,z-O-d-f-m-p.f.g/V/Z0i0j0kQ#qpW%W!o!s0d0nQ%X!pQ%Y!qQ%[!tQ%f0cS'v%Z0hQ'x0eQ'y0fQ,p*rQ-u,qS.i-s/sR0p0rU#uq.k0qR(w&][cOn#g$j)t,PZ!xY#[#}$Q+YQ#W[Q#zrR$TxQ%b!yQ%i!}Q%o#RQ'j${Q(V%eQ(Z%jQ(c%pQ(f%qQ*|(`Q,f*bQ-t,pQ.m-uR/].lQ$StQ(R%cR*s(SQ.l-sR/}/sR#QZR#V[R%Q!iQ%O!iV*c'm*d,g!Z!lQ!n#c#p$R$d$p$u$v$w$x$y$z%e%j%p%q&`'O'g(q(|)j*o*x+w,v0gR%T!kT#]^#_Q%x#[R,{+YQ(m%xS+_(n(oQ,}+`Q-x,{S.n-y-zR/^.oT+Z(k+]Q$`}Q&g$QQ)o'PR+{)pQ$XzQ)W&qR+i)XQ$XzQ&o$WQ)W&qR+i)XQ#khW$Vz$W&q)XQ$[{Q&r$ZZ)R&l)S+f+g-RR$^|R)c&wXlOn)t,PQ$f!RR'Q$gQ$m!UR'R$hR*X'_Q*V'_V-g,`-h.TQ.d-lQ/P.^R/Q._U.]-l.^._Q/U.aQ/b.tQ/g.zU/i.|/j/yQ/n/RQ/|/oQ0O/tU0Q/u0S0[Q0]0UQ0a0ZR0b0^R/T.`R/d.t",nodeNames:"⚠ print Escape { Comment Script AssignStatement * BinaryExpression BitOp BitOp BitOp BitOp ArithOp ArithOp @ ArithOp ** UnaryExpression ArithOp BitOp AwaitExpression await ) ( ParenthesizedExpression BinaryExpression or and CompareOp in not is UnaryExpression ConditionalExpression if else LambdaExpression lambda ParamList VariableName AssignOp , : NamedExpression AssignOp YieldExpression yield from TupleExpression ComprehensionExpression async for LambdaExpression ] [ ArrayExpression ArrayComprehensionExpression } { DictionaryExpression DictionaryComprehensionExpression SetExpression SetComprehensionExpression CallExpression ArgList AssignOp MemberExpression . PropertyName Number String FormatString FormatReplacement FormatSelfDoc FormatConversion FormatSpec FormatReplacement FormatSelfDoc ContinuedString Ellipsis None Boolean TypeDef AssignOp UpdateStatement UpdateOp ExpressionStatement DeleteStatement del PassStatement pass BreakStatement break ContinueStatement continue ReturnStatement return YieldStatement PrintStatement RaiseStatement raise ImportStatement import as ScopeStatement global nonlocal AssertStatement assert TypeDefinition type TypeParamList TypeParam StatementGroup ; IfStatement Body elif WhileStatement while ForStatement TryStatement try except finally WithStatement with FunctionDefinition def ParamList AssignOp TypeDef ClassDefinition class DecoratedStatement Decorator At MatchStatement match MatchBody MatchClause case CapturePattern LiteralPattern ArithOp ArithOp AsPattern OrPattern LogicOp AttributePattern SequencePattern MappingPattern StarPattern ClassPattern PatternArgList KeywordPattern KeywordPattern Guard",maxTerm:277,context:IQe,nodeProps:[["isolate",-5,4,71,72,73,77,""],["group",-15,6,85,87,88,90,92,94,96,98,99,100,102,105,108,110,"Statement Statement",-22,8,18,21,25,40,49,50,56,57,60,61,62,63,64,67,70,71,72,79,80,81,82,"Expression",-10,114,116,119,121,122,126,128,133,135,138,"Statement",-9,143,144,147,148,150,151,152,153,154,"Pattern"],["openedBy",23,"(",54,"[",58,"{"],["closedBy",24,")",55,"]",59,"}"]],propSources:[zQe],skippedNodes:[0,4],repeatNodeCount:34,tokenData:"!2|~R!`OX%TXY%oY[%T[]%o]p%Tpq%oqr'ars)Yst*xtu%Tuv,dvw-hwx.Uxy/tyz0[z{0r{|2S|}2p}!O3W!O!P4_!P!Q:Z!Q!R;k!R![>_![!]Do!]!^Es!^!_FZ!_!`Gk!`!aHX!a!b%T!b!cIf!c!dJU!d!eK^!e!hJU!h!i!#f!i!tJU!t!u!,|!u!wJU!w!x!.t!x!}JU!}#O!0S#O#P&o#P#Q!0j#Q#R!1Q#R#SJU#S#T%T#T#UJU#U#VK^#V#YJU#Y#Z!#f#Z#fJU#f#g!,|#g#iJU#i#j!.t#j#oJU#o#p!1n#p#q!1s#q#r!2a#r#s!2f#s$g%T$g;'SJU;'S;=`KW<%lOJU`%YT&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%T`%lP;=`<%l%To%v]&n`%c_OX%TXY%oY[%T[]%o]p%Tpq%oq#O%T#O#P&o#P#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To&tX&n`OY%TYZ%oZ]%T]^%o^#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc'f[&n`O!_%T!_!`([!`#T%T#T#U(r#U#f%T#f#g(r#g#h(r#h#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc(cTmR&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc(yT!mR&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk)aV&n`&[ZOr%Trs)vs#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk){V&n`Or%Trs*bs#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk*iT&n`&^ZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To+PZS_&n`OY*xYZ%TZ]*x]^%T^#o*x#o#p+r#p#q*x#q#r+r#r;'S*x;'S;=`,^<%lO*x_+wTS_OY+rZ]+r^;'S+r;'S;=`,W<%lO+r_,ZP;=`<%l+ro,aP;=`<%l*xj,kV%rQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tj-XT!xY&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tj-oV%lQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk.]V&n`&ZZOw%Twx.rx#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk.wV&n`Ow%Twx/^x#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk/eT&n`&]ZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk/{ThZ&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc0cTgR&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk0yXVZ&n`Oz%Tz{1f{!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk1mVaR&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk2ZV%oZ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc2wTzR&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To3_W%pZ&n`O!_%T!_!`-Q!`!a3w!a#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Td4OT&{S&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk4fX!fQ&n`O!O%T!O!P5R!P!Q%T!Q![6T![#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk5WV&n`O!O%T!O!P5m!P#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk5tT!rZ&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti6[a!hX&n`O!Q%T!Q![6T![!g%T!g!h7a!h!l%T!l!m9s!m#R%T#R#S6T#S#X%T#X#Y7a#Y#^%T#^#_9s#_#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti7fZ&n`O{%T{|8X|}%T}!O8X!O!Q%T!Q![8s![#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti8^V&n`O!Q%T!Q![8s![#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti8z]!hX&n`O!Q%T!Q![8s![!l%T!l!m9s!m#R%T#R#S8s#S#^%T#^#_9s#_#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti9zT!hX&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk:bX%qR&n`O!P%T!P!Q:}!Q!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tj;UV%sQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti;ro!hX&n`O!O%T!O!P=s!P!Q%T!Q![>_![!d%T!d!e?q!e!g%T!g!h7a!h!l%T!l!m9s!m!q%T!q!rA]!r!z%T!z!{Bq!{#R%T#R#S>_#S#U%T#U#V?q#V#X%T#X#Y7a#Y#^%T#^#_9s#_#c%T#c#dA]#d#l%T#l#mBq#m#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti=xV&n`O!Q%T!Q![6T![#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti>fc!hX&n`O!O%T!O!P=s!P!Q%T!Q![>_![!g%T!g!h7a!h!l%T!l!m9s!m#R%T#R#S>_#S#X%T#X#Y7a#Y#^%T#^#_9s#_#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti?vY&n`O!Q%T!Q!R@f!R!S@f!S#R%T#R#S@f#S#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Ti@mY!hX&n`O!Q%T!Q!R@f!R!S@f!S#R%T#R#S@f#S#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TiAbX&n`O!Q%T!Q!YA}!Y#R%T#R#SA}#S#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TiBUX!hX&n`O!Q%T!Q!YA}!Y#R%T#R#SA}#S#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TiBv]&n`O!Q%T!Q![Co![!c%T!c!iCo!i#R%T#R#SCo#S#T%T#T#ZCo#Z#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TiCv]!hX&n`O!Q%T!Q![Co![!c%T!c!iCo!i#R%T#R#SCo#S#T%T#T#ZCo#Z#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%ToDvV{_&n`O!_%T!_!`E]!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TcEdT%{R&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkEzT#gZ&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkFbXmR&n`O!^%T!^!_F}!_!`([!`!a([!a#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TjGUV%mQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkGrV%zZ&n`O!_%T!_!`([!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkH`WmR&n`O!_%T!_!`([!`!aHx!a#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TjIPV%nQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkIoV_Q#}P&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%ToJ_]&n`&YS%uZO!Q%T!Q![JU![!c%T!c!}JU!}#R%T#R#SJU#S#T%T#T#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUoKZP;=`<%lJUoKge&n`&YS%uZOr%Trs)Ysw%Twx.Ux!Q%T!Q![JU![!c%T!c!tJU!t!uLx!u!}JU!}#R%T#R#SJU#S#T%T#T#fJU#f#gLx#g#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUoMRa&n`&YS%uZOr%TrsNWsw%Twx! vx!Q%T!Q![JU![!c%T!c!}JU!}#R%T#R#SJU#S#T%T#T#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUkN_V&n`&`ZOr%TrsNts#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%TkNyV&n`Or%Trs! `s#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk! gT&n`&bZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk! }V&n`&_ZOw%Twx!!dx#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!!iV&n`Ow%Twx!#Ox#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!#VT&n`&aZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To!#oe&n`&YS%uZOr%Trs!%Qsw%Twx!&px!Q%T!Q![JU![!c%T!c!tJU!t!u!(`!u!}JU!}#R%T#R#SJU#S#T%T#T#fJU#f#g!(`#g#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUk!%XV&n`&dZOr%Trs!%ns#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!%sV&n`Or%Trs!&Ys#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!&aT&n`&fZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!&wV&n`&cZOw%Twx!'^x#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!'cV&n`Ow%Twx!'xx#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!(PT&n`&eZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To!(ia&n`&YS%uZOr%Trs!)nsw%Twx!+^x!Q%T!Q![JU![!c%T!c!}JU!}#R%T#R#SJU#S#T%T#T#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUk!)uV&n`&hZOr%Trs!*[s#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!*aV&n`Or%Trs!*vs#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!*}T&n`&jZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!+eV&n`&gZOw%Twx!+zx#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!,PV&n`Ow%Twx!,fx#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tk!,mT&n`&iZO#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%To!-Vi&n`&YS%uZOr%TrsNWsw%Twx! vx!Q%T!Q![JU![!c%T!c!dJU!d!eLx!e!hJU!h!i!(`!i!}JU!}#R%T#R#SJU#S#T%T#T#UJU#U#VLx#V#YJU#Y#Z!(`#Z#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUo!.}a&n`&YS%uZOr%Trs)Ysw%Twx.Ux!Q%T!Q![JU![!c%T!c!}JU!}#R%T#R#SJU#S#T%T#T#oJU#p#q%T#r$g%T$g;'SJU;'S;=`KW<%lOJUk!0ZT!XZ&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tc!0qT!WR&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%Tj!1XV%kQ&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%T~!1sO!]~k!1zV%jR&n`O!_%T!_!`-Q!`#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%T~!2fO![~i!2mT%tX&n`O#o%T#p#q%T#r;'S%T;'S;=`%i<%lO%T",tokenizers:[LQe,MQe,PQe,BQe,0,1,2,3,4],topRules:{Script:[0,5]},specialized:[{term:221,get:e=>qQe[e]||-1}],tokenPrec:7668}),VQe=315,UQe=316,XX=1,jQe=2,ZQe=3,HQe=4,XQe=317,YQe=319,GQe=320,KQe=5,WQe=6,JQe=0,BM=[9,10,11,12,13,32,133,160,5760,8192,8193,8194,8195,8196,8197,8198,8199,8200,8201,8202,8232,8233,8239,8287,12288],Nge=125,eze=59,QM=47,tze=42,nze=43,rze=45,ize=60,aze=44,uze=63,lze=46,oze=91,sze=new Ree({start:!1,shift(e,t){return t==KQe||t==WQe||t==YQe?e:t==GQe},strict:!1}),cze=new gg((e,t)=>{let{next:n}=e;(n==Nge||n==-1||t.context)&&e.acceptToken(XQe)},{contextual:!0,fallback:!0}),fze=new gg((e,t)=>{let{next:n}=e,r;BM.indexOf(n)>-1||n==QM&&((r=e.peek(1))==QM||r==tze)||n!=Nge&&n!=eze&&n!=-1&&!t.context&&e.acceptToken(VQe)},{contextual:!0}),dze=new gg((e,t)=>{e.next==oze&&!t.context&&e.acceptToken(UQe)},{contextual:!0}),hze=new gg((e,t)=>{let{next:n}=e;if(n==nze||n==rze){if(e.advance(),n==e.next){e.advance();let r=!t.context&&t.canShift(XX);e.acceptToken(r?XX:jQe)}}else n==uze&&e.peek(1)==lze&&(e.advance(),e.advance(),(e.next<48||e.next>57)&&e.acceptToken(ZQe))},{contextual:!0});function kP(e,t){return e>=65&&e<=90||e>=97&&e<=122||e==95||e>=192||!t&&e>=48&&e<=57}const pze=new gg((e,t)=>{if(e.next!=ize||!t.dialectEnabled(JQe)||(e.advance(),e.next==QM))return;let n=0;for(;BM.indexOf(e.next)>-1;)e.advance(),n++;if(kP(e.next,!0)){for(e.advance(),n++;kP(e.next,!1);)e.advance(),n++;for(;BM.indexOf(e.next)>-1;)e.advance(),n++;if(e.next==aze)return;for(let r=0;;r++){if(r==7){if(!kP(e.next,!0))return;break}if(e.next!="extends".charCodeAt(r))break;e.advance(),n++}}e.acceptToken(HQe,-n)}),mze=nN({"get set async static":ot.modifier,"for while do if else switch try catch finally return throw break continue default case":ot.controlKeyword,"in of await yield void typeof delete instanceof as satisfies":ot.operatorKeyword,"let var const using function class extends":ot.definitionKeyword,"import export from":ot.moduleKeyword,"with debugger new":ot.keyword,TemplateString:ot.special(ot.string),super:ot.atom,BooleanLiteral:ot.bool,this:ot.self,null:ot.null,Star:ot.modifier,VariableName:ot.variableName,"CallExpression/VariableName TaggedTemplateExpression/VariableName":ot.function(ot.variableName),VariableDefinition:ot.definition(ot.variableName),Label:ot.labelName,PropertyName:ot.propertyName,PrivatePropertyName:ot.special(ot.propertyName),"CallExpression/MemberExpression/PropertyName":ot.function(ot.propertyName),"FunctionDeclaration/VariableDefinition":ot.function(ot.definition(ot.variableName)),"ClassDeclaration/VariableDefinition":ot.definition(ot.className),"NewExpression/VariableName":ot.className,PropertyDefinition:ot.definition(ot.propertyName),PrivatePropertyDefinition:ot.definition(ot.special(ot.propertyName)),UpdateOp:ot.updateOperator,"LineComment Hashbang":ot.lineComment,BlockComment:ot.blockComment,Number:ot.number,String:ot.string,Escape:ot.escape,ArithOp:ot.arithmeticOperator,LogicOp:ot.logicOperator,BitOp:ot.bitwiseOperator,CompareOp:ot.compareOperator,RegExp:ot.regexp,Equals:ot.definitionOperator,Arrow:ot.function(ot.punctuation),": Spread":ot.punctuation,"( )":ot.paren,"[ ]":ot.squareBracket,"{ }":ot.brace,"InterpolationStart InterpolationEnd":ot.special(ot.brace),".":ot.derefOperator,", ;":ot.separator,"@":ot.meta,TypeName:ot.typeName,TypeDefinition:ot.definition(ot.typeName),"type enum interface implements namespace module declare":ot.definitionKeyword,"abstract global Privacy readonly override":ot.modifier,"is keyof unique infer asserts":ot.operatorKeyword,JSXAttributeValue:ot.attributeValue,JSXText:ot.content,"JSXStartTag JSXStartCloseTag JSXSelfCloseEndTag JSXEndTag":ot.angleBracket,"JSXIdentifier JSXNameSpacedName":ot.tagName,"JSXAttribute/JSXIdentifier JSXAttribute/JSXNameSpacedName":ot.attributeName,"JSXBuiltin/JSXIdentifier":ot.standard(ot.tagName)}),gze={__proto__:null,export:20,as:25,from:33,default:36,async:41,function:42,in:52,out:55,const:56,extends:60,this:64,true:72,false:72,null:84,void:88,typeof:92,super:108,new:142,delete:154,yield:163,await:167,class:172,public:235,private:235,protected:235,readonly:237,instanceof:256,satisfies:259,import:292,keyof:349,unique:353,infer:359,asserts:395,is:397,abstract:417,implements:419,type:421,let:424,var:426,using:429,interface:435,enum:439,namespace:445,module:447,declare:451,global:455,for:474,of:483,while:486,with:490,do:494,if:498,else:500,switch:504,case:510,try:516,catch:520,finally:524,return:528,throw:532,break:536,continue:540,debugger:544},vze={__proto__:null,async:129,get:131,set:133,declare:195,public:197,private:197,protected:197,static:199,abstract:201,override:203,readonly:209,accessor:211,new:401},yze={__proto__:null,"<":193},tut=$3.deserialize({version:14,states:"$EOQ%TQlOOO%[QlOOO'_QpOOP(lO`OOO*zQ!0MxO'#CiO+RO#tO'#CjO+aO&jO'#CjO+oO#@ItO'#DaO.QQlO'#DgO.bQlO'#DrO%[QlO'#DzO0fQlO'#ESOOQ!0Lf'#E['#E[O1PQ`O'#EXOOQO'#Ep'#EpOOQO'#Ik'#IkO1XQ`O'#GsO1dQ`O'#EoO1iQ`O'#EoO3hQ!0MxO'#JqO6[Q!0MxO'#JrO6uQ`O'#F]O6zQ,UO'#FtOOQ!0Lf'#Ff'#FfO7VO7dO'#FfO7eQMhO'#F|O9[Q`O'#F{OOQ!0Lf'#Jr'#JrOOQ!0Lb'#Jq'#JqO9aQ`O'#GwOOQ['#K^'#K^O9lQ`O'#IXO9qQ!0LrO'#IYOOQ['#J_'#J_OOQ['#I^'#I^Q`QlOOQ`QlOOO9yQ!L^O'#DvO:QQlO'#EOO:XQlO'#EQO9gQ`O'#GsO:`QMhO'#CoO:nQ`O'#EnO:yQ`O'#EyO;OQMhO'#FeO;mQ`O'#GsOOQO'#K_'#K_O;rQ`O'#K_O<QQ`O'#G{O<QQ`O'#G|O<QQ`O'#HOO9gQ`O'#HRO<wQ`O'#HUO>`Q`O'#CeO>pQ`O'#HbO>xQ`O'#HhO>xQ`O'#HjO`QlO'#HlO>xQ`O'#HnO>xQ`O'#HqO>}Q`O'#HwO?SQ!0LsO'#H}O%[QlO'#IPO?_Q!0LsO'#IRO?jQ!0LsO'#ITO9qQ!0LrO'#IVO?uQ!0MxO'#CiO@wQpO'#DlQOQ`OOO%[QlO'#EQOA_Q`O'#ETO:`QMhO'#EnOAjQ`O'#EnOAuQ!bO'#FeOOQ['#Cg'#CgOOQ!0Lb'#Dq'#DqOOQ!0Lb'#Ju'#JuO%[QlO'#JuOOQO'#Jx'#JxOOQO'#Ig'#IgOBuQpO'#EgOOQ!0Lb'#Ef'#EfOOQ!0Lb'#J|'#J|OCqQ!0MSO'#EgOC{QpO'#EWOOQO'#Jw'#JwODaQpO'#JxOEnQpO'#EWOC{QpO'#EgPE{O&2DjO'#CbPOOO)CD|)CD|OOOO'#I_'#I_OFWO#tO,59UOOQ!0Lh,59U,59UOOOO'#I`'#I`OFfO&jO,59UOFtQ!L^O'#DcOOOO'#Ib'#IbOF{O#@ItO,59{OOQ!0Lf,59{,59{OGZQlO'#IcOGnQ`O'#JsOImQ!fO'#JsO+}QlO'#JsOItQ`O,5:ROJ[Q`O'#EpOJiQ`O'#KSOJtQ`O'#KROJtQ`O'#KROJ|Q`O,5;^OKRQ`O'#KQOOQ!0Ln,5:^,5:^OKYQlO,5:^OMWQ!0MxO,5:fOMwQ`O,5:nONbQ!0LrO'#KPONiQ`O'#KOO9aQ`O'#KOON}Q`O'#KOO! VQ`O,5;]O! [Q`O'#KOO!#aQ!fO'#JrOOQ!0Lh'#Ci'#CiO%[QlO'#ESO!$PQ!fO,5:sOOQS'#Jy'#JyOOQO-E<i-E<iO9gQ`O,5=_O!$gQ`O,5=_O!$lQlO,5;ZO!&oQMhO'#EkO!(YQ`O,5;ZO!(_QlO'#DyO!(iQpO,5;dO!(qQpO,5;dO%[QlO,5;dOOQ['#FT'#FTOOQ['#FV'#FVO%[QlO,5;eO%[QlO,5;eO%[QlO,5;eO%[QlO,5;eO%[QlO,5;eO%[QlO,5;eO%[QlO,5;eO%[QlO,5;eO%[QlO,5;eO%[QlO,5;eOOQ['#FZ'#FZO!)PQlO,5;tOOQ!0Lf,5;y,5;yOOQ!0Lf,5;z,5;zOOQ!0Lf,5;|,5;|O%[QlO'#IoO!+SQ!0LrO,5<iO%[QlO,5;eO!&oQMhO,5;eO!+qQMhO,5;eO!-cQMhO'#E^O%[QlO,5;wOOQ!0Lf,5;{,5;{O!-jQ,UO'#FjO!.gQ,UO'#KWO!.RQ,UO'#KWO!.nQ,UO'#KWOOQO'#KW'#KWO!/SQ,UO,5<SOOOW,5<`,5<`O!/eQlO'#FvOOOW'#In'#InO7VO7dO,5<QO!/lQ,UO'#FxOOQ!0Lf,5<Q,5<QO!0]Q$IUO'#CyOOQ!0Lh'#C}'#C}O!0pO#@ItO'#DRO!1^QMjO,5<eO!1eQ`O,5<hO!3QQ(CWO'#GXO!3_Q`O'#GYO!3dQ`O'#GYO!5SQ(CWO'#G^O!6XQpO'#GbOOQO'#Gn'#GnO!+xQMhO'#GmOOQO'#Gp'#GpO!+xQMhO'#GoO!6zQ$IUO'#JkOOQ!0Lh'#Jk'#JkO!7UQ`O'#JjO!7dQ`O'#JiO!7lQ`O'#CuOOQ!0Lh'#C{'#C{O!7}Q`O'#C}OOQ!0Lh'#DV'#DVOOQ!0Lh'#DX'#DXO1SQ`O'#DZO!+xQMhO'#GPO!+xQMhO'#GRO!8SQ`O'#GTO!8XQ`O'#GUO!3dQ`O'#G[O!+xQMhO'#GaO<QQ`O'#JjO!8^Q`O'#EqO!8{Q`O,5<gOOQ!0Lb'#Cr'#CrO!9TQ`O'#ErO!9}QpO'#EsOOQ!0Lb'#KQ'#KQO!:UQ!0LrO'#K`O9qQ!0LrO,5=cO`QlO,5>sOOQ['#Jg'#JgOOQ[,5>t,5>tOOQ[-E<[-E<[O!<TQ!0MxO,5:bO!9xQpO,5:`O!>nQ!0MxO,5:jO%[QlO,5:jO!AUQ!0MxO,5:lOOQO,5@y,5@yO!AuQMhO,5=_O!BTQ!0LrO'#JhO9[Q`O'#JhO!BfQ!0LrO,59ZO!BqQpO,59ZO!ByQMhO,59ZO:`QMhO,59ZO!CUQ`O,5;ZO!C^Q`O'#HaO!CrQ`O'#KcO%[QlO,5;}O!9xQpO,5<PO!CzQ`O,5=zO!DPQ`O,5=zO!DUQ`O,5=zO9qQ!0LrO,5=zO<QQ`O,5=jOOQO'#Cy'#CyO!DdQpO,5=gO!DlQMhO,5=hO!DwQ`O,5=jO!D|Q!bO,5=mO!EUQ`O'#K_O>}Q`O'#HWO9gQ`O'#HYO!EZQ`O'#HYO:`QMhO'#H[O!E`Q`O'#H[OOQ[,5=p,5=pO!EeQ`O'#H]O!EvQ`O'#CoO!E{Q`O,59PO!FVQ`O,59PO!H[QlO,59POOQ[,59P,59PO!HlQ!0LrO,59PO%[QlO,59PO!JwQlO'#HdOOQ['#He'#HeOOQ['#Hf'#HfO`QlO,5=|O!K_Q`O,5=|O`QlO,5>SO`QlO,5>UO!KdQ`O,5>WO`QlO,5>YO!KiQ`O,5>]O!KnQlO,5>cOOQ[,5>i,5>iO%[QlO,5>iO9qQ!0LrO,5>kOOQ[,5>m,5>mO# xQ`O,5>mOOQ[,5>o,5>oO# xQ`O,5>oOOQ[,5>q,5>qO#!fQpO'#D_O%[QlO'#JuO##XQpO'#JuO##cQpO'#DmO##tQpO'#DmO#&VQlO'#DmO#&^Q`O'#JtO#&fQ`O,5:WO#&kQ`O'#EtO#&yQ`O'#KTO#'RQ`O,5;_O#'WQpO'#DmO#'eQpO'#EVOOQ!0Lf,5:o,5:oO%[QlO,5:oO#'lQ`O,5:oO>}Q`O,5;YO!BqQpO,5;YO!ByQMhO,5;YO:`QMhO,5;YO#'tQ`O,5@aO#'yQ07dO,5:sOOQO-E<e-E<eO#)PQ!0MSO,5;ROC{QpO,5:rO#)ZQpO,5:rOC{QpO,5;RO!BfQ!0LrO,5:rOOQ!0Lb'#Ej'#EjOOQO,5;R,5;RO%[QlO,5;RO#)hQ!0LrO,5;RO#)sQ!0LrO,5;RO!BqQpO,5:rOOQO,5;X,5;XO#*RQ!0LrO,5;RPOOO'#I]'#I]P#*gO&2DjO,58|POOO,58|,58|OOOO-E<]-E<]OOQ!0Lh1G.p1G.pOOOO-E<^-E<^OOOO,59},59}O#*rQ!bO,59}OOOO-E<`-E<`OOQ!0Lf1G/g1G/gO#*wQ!fO,5>}O+}QlO,5>}OOQO,5?T,5?TO#+RQlO'#IcOOQO-E<a-E<aO#+`Q`O,5@_O#+hQ!fO,5@_O#+oQ`O,5@mOOQ!0Lf1G/m1G/mO%[QlO,5@nO#+wQ`O'#IiOOQO-E<g-E<gO#+oQ`O,5@mOOQ!0Lb1G0x1G0xOOQ!0Ln1G/x1G/xOOQ!0Ln1G0Y1G0YO%[QlO,5@kO#,]Q!0LrO,5@kO#,nQ!0LrO,5@kO#,uQ`O,5@jO9aQ`O,5@jO#,}Q`O,5@jO#-]Q`O'#IlO#,uQ`O,5@jOOQ!0Lb1G0w1G0wO!(iQpO,5:uO!(tQpO,5:uOOQS,5:w,5:wO#-}QdO,5:wO#.VQMhO1G2yO9gQ`O1G2yOOQ!0Lf1G0u1G0uO#.eQ!0MxO1G0uO#/jQ!0MvO,5;VOOQ!0Lh'#GW'#GWO#0WQ!0MzO'#JkO!$lQlO1G0uO#2cQ!fO'#JvO%[QlO'#JvO#2mQ`O,5:eOOQ!0Lh'#D_'#D_OOQ!0Lf1G1O1G1OO%[QlO1G1OOOQ!0Lf1G1f1G1fO#2rQ`O1G1OO#5WQ!0MxO1G1PO#5_Q!0MxO1G1PO#7uQ!0MxO1G1PO#7|Q!0MxO1G1PO#:dQ!0MxO1G1PO#<zQ!0MxO1G1PO#=RQ!0MxO1G1PO#=YQ!0MxO1G1PO#?pQ!0MxO1G1PO#?wQ!0MxO1G1PO#BUQ?MtO'#CiO#DPQ?MtO1G1`O#DWQ?MtO'#JrO#DkQ!0MxO,5?ZOOQ!0Lb-E<m-E<mO#FxQ!0MxO1G1PO#GuQ!0MzO1G1POOQ!0Lf1G1P1G1PO#HxQMjO'#J{O#ISQ`O,5:xO#IXQ!0MxO1G1cO#I{Q,UO,5<WO#JTQ,UO,5<XO#J]Q,UO'#FoO#JtQ`O'#FnOOQO'#KX'#KXOOQO'#Im'#ImO#JyQ,UO1G1nOOQ!0Lf1G1n1G1nOOOW1G1y1G1yO#K[Q?MtO'#JqO#KfQ`O,5<bO!)PQlO,5<bOOOW-E<l-E<lOOQ!0Lf1G1l1G1lO#KkQpO'#KWOOQ!0Lf,5<d,5<dO#KsQpO,5<dO#KxQMhO'#DTOOOO'#Ia'#IaO#LPO#@ItO,59mOOQ!0Lh,59m,59mO%[QlO1G2PO!8XQ`O'#IqO#L[Q`O,5<zOOQ!0Lh,5<w,5<wO!+xQMhO'#ItO#LxQMjO,5=XO!+xQMhO'#IvO#MkQMjO,5=ZO!&oQMhO,5=]OOQO1G2S1G2SO#MuQ!dO'#CrO#NYQ(CWO'#ErO$ _QpO'#GbO$ uQ!dO,5<sO$ |Q`O'#KZO9aQ`O'#KZO$![Q`O,5<uO!+xQMhO,5<tO$!aQ`O'#GZO$!rQ`O,5<tO$!wQ!dO'#GWO$#UQ!dO'#K[O$#`Q`O'#K[O!&oQMhO'#K[O$#eQ`O,5<xO$#jQlO'#JuO$#tQpO'#GcO##tQpO'#GcO$$VQ`O'#GgO!3dQ`O'#GkO$$[Q!0LrO'#IsO$$gQpO,5<|OOQ!0Lp,5<|,5<|O$$nQpO'#GcO$${QpO'#GdO$%^QpO'#GdO$%cQMjO,5=XO$%sQMjO,5=ZOOQ!0Lh,5=^,5=^O!+xQMhO,5@UO!+xQMhO,5@UO$&TQ`O'#IxO$&iQ`O,5@TO$&qQ`O,59aOOQ!0Lh,59i,59iO$'hQ$IYO,59uOOQ!0Lh'#Jo'#JoO$(ZQMjO,5<kO$(|QMjO,5<mO@oQ`O,5<oOOQ!0Lh,5<p,5<pO$)WQ`O,5<vO$)]QMjO,5<{O$)mQ`O,5@UO$){Q`O'#KOO!$lQlO1G2RO$*QQ`O1G2RO9aQ`O'#KRO9aQ`O'#EtO%[QlO'#EtO9aQ`O'#IzO$*VQ!0LrO,5@zOOQ[1G2}1G2}OOQ[1G4_1G4_OOQ!0Lf1G/|1G/|OOQ!0Lf1G/z1G/zO$,XQ!0MxO1G0UOOQ[1G2y1G2yO!&oQMhO1G2yO%[QlO1G2yO#.YQ`O1G2yO$.]QMhO'#EkOOQ!0Lb,5@S,5@SO$.jQ!0LrO,5@SOOQ[1G.u1G.uO!BfQ!0LrO1G.uO!BqQpO1G.uO!ByQMhO1G.uO$.{Q`O1G0uO$/QQ`O'#CiO$/]Q`O'#KdO$/eQ`O,5={O$/jQ`O'#KdO$/oQ`O'#KdO$/}Q`O'#JQO$0]Q`O,5@}O$0eQ!fO1G1iOOQ!0Lf1G1k1G1kO9gQ`O1G3fO@oQ`O1G3fO$0lQ`O1G3fO$0qQ`O1G3fOOQ[1G3f1G3fO!DwQ`O1G3UO!&oQMhO1G3RO$0vQ`O1G3ROOQ[1G3S1G3SO!&oQMhO1G3SO$0{Q`O1G3SO$1TQpO'#HQOOQ[1G3U1G3UO!6SQpO'#I|O!D|Q!bO1G3XOOQ[1G3X1G3XOOQ[,5=r,5=rO$1]QMhO,5=tO9gQ`O,5=tO$$VQ`O,5=vO9[Q`O,5=vO!BqQpO,5=vO!ByQMhO,5=vO:`QMhO,5=vO$1kQ`O'#KbO$1vQ`O,5=wOOQ[1G.k1G.kO$1{Q!0LrO1G.kO@oQ`O1G.kO$2WQ`O1G.kO9qQ!0LrO1G.kO$4`Q!fO,5APO$4mQ`O,5APO9aQ`O,5APO$4xQlO,5>OO$5PQ`O,5>OOOQ[1G3h1G3hO`QlO1G3hOOQ[1G3n1G3nOOQ[1G3p1G3pO>xQ`O1G3rO$5UQlO1G3tO$9YQlO'#HsOOQ[1G3w1G3wO$9gQ`O'#HyO>}Q`O'#H{OOQ[1G3}1G3}O$9oQlO1G3}O9qQ!0LrO1G4TOOQ[1G4V1G4VOOQ!0Lb'#G_'#G_O9qQ!0LrO1G4XO9qQ!0LrO1G4ZO$=vQ`O,5@aO!)PQlO,5;`O9aQ`O,5;`O>}Q`O,5:XO!)PQlO,5:XO!BqQpO,5:XO$={Q?MtO,5:XOOQO,5;`,5;`O$>VQpO'#IdO$>mQ`O,5@`OOQ!0Lf1G/r1G/rO$>uQpO'#IjO$?PQ`O,5@oOOQ!0Lb1G0y1G0yO##tQpO,5:XOOQO'#If'#IfO$?XQpO,5:qOOQ!0Ln,5:q,5:qO#'oQ`O1G0ZOOQ!0Lf1G0Z1G0ZO%[QlO1G0ZOOQ!0Lf1G0t1G0tO>}Q`O1G0tO!BqQpO1G0tO!ByQMhO1G0tOOQ!0Lb1G5{1G5{O!BfQ!0LrO1G0^OOQO1G0m1G0mO%[QlO1G0mO$?`Q!0LrO1G0mO$?kQ!0LrO1G0mO!BqQpO1G0^OC{QpO1G0^O$?yQ!0LrO1G0mOOQO1G0^1G0^O$@_Q!0MxO1G0mPOOO-E<Z-E<ZPOOO1G.h1G.hOOOO1G/i1G/iO$@iQ!bO,5<iO$@qQ!fO1G4iOOQO1G4o1G4oO%[QlO,5>}O$@{Q`O1G5yO$ATQ`O1G6XO$A]Q!fO1G6YO9aQ`O,5?TO$AgQ!0MxO1G6VO%[QlO1G6VO$AwQ!0LrO1G6VO$BYQ`O1G6UO$BYQ`O1G6UO9aQ`O1G6UO$BbQ`O,5?WO9aQ`O,5?WOOQO,5?W,5?WO$BvQ`O,5?WO$){Q`O,5?WOOQO-E<j-E<jOOQS1G0a1G0aOOQS1G0c1G0cO#.QQ`O1G0cOOQ[7+(e7+(eO!&oQMhO7+(eO%[QlO7+(eO$CUQ`O7+(eO$CaQMhO7+(eO$CoQ!0MzO,5=XO$EzQ!0MzO,5=ZO$HVQ!0MzO,5=XO$JhQ!0MzO,5=ZO$LyQ!0MzO,59uO% OQ!0MzO,5<kO%#ZQ!0MzO,5<mO%%fQ!0MzO,5<{OOQ!0Lf7+&a7+&aO%'wQ!0MxO7+&aO%(kQlO'#IeO%(xQ`O,5@bO%)QQ!fO,5@bOOQ!0Lf1G0P1G0PO%)[Q`O7+&jOOQ!0Lf7+&j7+&jO%)aQ?MtO,5:fO%[QlO7+&zO%)kQ?MtO,5:bO%)xQ?MtO,5:jO%*SQ?MtO,5:lO%*^QMhO'#IhO%*hQ`O,5@gOOQ!0Lh1G0d1G0dOOQO1G1r1G1rOOQO1G1s1G1sO%*pQ!jO,5<ZO!)PQlO,5<YOOQO-E<k-E<kOOQ!0Lf7+'Y7+'YOOOW7+'e7+'eOOOW1G1|1G1|O%*{Q`O1G1|OOQ!0Lf1G2O1G2OOOOO,59o,59oO%+QQ!dO,59oOOOO-E<_-E<_OOQ!0Lh1G/X1G/XO%+XQ!0MxO7+'kOOQ!0Lh,5?],5?]O%+{QMhO1G2fP%,SQ`O'#IqPOQ!0Lh-E<o-E<oO%,pQMjO,5?`OOQ!0Lh-E<r-E<rO%-cQMjO,5?bOOQ!0Lh-E<t-E<tO%-mQ!dO1G2wO%-tQ!dO'#CrO%.[QMhO'#KRO$#jQlO'#JuOOQ!0Lh1G2_1G2_O%.cQ`O'#IpO%.wQ`O,5@uO%.wQ`O,5@uO%/PQ`O,5@uO%/[Q`O,5@uOOQO1G2a1G2aO%/jQMjO1G2`O!+xQMhO1G2`O%/zQ(CWO'#IrO%0XQ`O,5@vO!&oQMhO,5@vO%0aQ!dO,5@vOOQ!0Lh1G2d1G2dO%2qQ!fO'#CiO%2{Q`O,5=POOQ!0Lb,5<},5<}O%3TQpO,5<}OOQ!0Lb,5=O,5=OOClQ`O,5<}O%3`QpO,5<}OOQ!0Lb,5=R,5=RO$){Q`O,5=VOOQO,5?_,5?_OOQO-E<q-E<qOOQ!0Lp1G2h1G2hO##tQpO,5<}O$#jQlO,5=PO%3nQ`O,5=OO%3yQpO,5=OO!+xQMhO'#ItO%4sQMjO1G2sO!+xQMhO'#IvO%5fQMjO1G2uO%5pQMjO1G5pO%5zQMjO1G5pOOQO,5?d,5?dOOQO-E<v-E<vOOQO1G.{1G.{O!9xQpO,59wO%[QlO,59wOOQ!0Lh,5<j,5<jO%6XQ`O1G2ZO!+xQMhO1G2bO!+xQMhO1G5pO!+xQMhO1G5pO%6^Q!0MxO7+'mOOQ!0Lf7+'m7+'mO!$lQlO7+'mO%7QQ`O,5;`OOQ!0Lb,5?f,5?fOOQ!0Lb-E<x-E<xO%7VQ!dO'#K]O#'oQ`O7+(eO4UQ!fO7+(eO$CXQ`O7+(eO%7aQ!0MvO'#CiO%7tQ!0MvO,5=SO%8fQ`O,5=SO%8nQ`O,5=SOOQ!0Lb1G5n1G5nOOQ[7+$a7+$aO!BfQ!0LrO7+$aO!BqQpO7+$aO!$lQlO7+&aO%8sQ`O'#JPO%9[Q`O,5AOOOQO1G3g1G3gO9gQ`O,5AOO%9[Q`O,5AOO%9dQ`O,5AOOOQO,5?l,5?lOOQO-E=O-E=OOOQ!0Lf7+'T7+'TO%9iQ`O7+)QO9qQ!0LrO7+)QO9gQ`O7+)QO@oQ`O7+)QOOQ[7+(p7+(pO%9nQ!0MvO7+(mO!&oQMhO7+(mO!DrQ`O7+(nOOQ[7+(n7+(nO!&oQMhO7+(nO%9xQ`O'#KaO%:TQ`O,5=lOOQO,5?h,5?hOOQO-E<z-E<zOOQ[7+(s7+(sO%;gQpO'#HZOOQ[1G3`1G3`O!&oQMhO1G3`O%[QlO1G3`O%;nQ`O1G3`O%;yQMhO1G3`O9qQ!0LrO1G3bO$$VQ`O1G3bO9[Q`O1G3bO!BqQpO1G3bO!ByQMhO1G3bO%<XQ`O'#JOO%<mQ`O,5@|O%<uQpO,5@|OOQ!0Lb1G3c1G3cOOQ[7+$V7+$VO@oQ`O7+$VO9qQ!0LrO7+$VO%=QQ`O7+$VO%[QlO1G6kO%[QlO1G6lO%=VQ!0LrO1G6kO%=aQlO1G3jO%=hQ`O1G3jO%=mQlO1G3jOOQ[7+)S7+)SO9qQ!0LrO7+)^O`QlO7+)`OOQ['#Kg'#KgOOQ['#JR'#JRO%=tQlO,5>_OOQ[,5>_,5>_O%[QlO'#HtO%>RQ`O'#HvOOQ[,5>e,5>eO9aQ`O,5>eOOQ[,5>g,5>gOOQ[7+)i7+)iOOQ[7+)o7+)oOOQ[7+)s7+)sOOQ[7+)u7+)uO%>WQpO1G5{O%>rQ?MtO1G0zO%>|Q`O1G0zOOQO1G/s1G/sO%?XQ?MtO1G/sO>}Q`O1G/sO!)PQlO'#DmOOQO,5?O,5?OOOQO-E<b-E<bOOQO,5?U,5?UOOQO-E<h-E<hO!BqQpO1G/sOOQO-E<d-E<dOOQ!0Ln1G0]1G0]OOQ!0Lf7+%u7+%uO#'oQ`O7+%uOOQ!0Lf7+&`7+&`O>}Q`O7+&`O!BqQpO7+&`OOQO7+%x7+%xO$@_Q!0MxO7+&XOOQO7+&X7+&XO%[QlO7+&XO%?cQ!0LrO7+&XO!BfQ!0LrO7+%xO!BqQpO7+%xO%?nQ!0LrO7+&XO%?|Q!0MxO7++qO%[QlO7++qO%@^Q`O7++pO%@^Q`O7++pOOQO1G4r1G4rO9aQ`O1G4rO%@fQ`O1G4rOOQS7+%}7+%}O#'oQ`O<<LPO4UQ!fO<<LPO%@tQ`O<<LPOOQ[<<LP<<LPO!&oQMhO<<LPO%[QlO<<LPO%@|Q`O<<LPO%AXQ!0MzO,5?`O%CdQ!0MzO,5?bO%EoQ!0MzO1G2`O%HQQ!0MzO1G2sO%J]Q!0MzO1G2uO%LhQ!fO,5?PO%[QlO,5?POOQO-E<c-E<cO%LrQ`O1G5|OOQ!0Lf<<JU<<JUO%LzQ?MtO1G0uO& RQ?MtO1G1PO& YQ?MtO1G1PO&#ZQ?MtO1G1PO&#bQ?MtO1G1PO&%cQ?MtO1G1PO&'dQ?MtO1G1PO&'kQ?MtO1G1PO&'rQ?MtO1G1PO&)sQ?MtO1G1PO&)zQ?MtO1G1PO&*RQ!0MxO<<JfO&+yQ?MtO1G1PO&,vQ?MvO1G1PO&-yQ?MvO'#JkO&0PQ?MtO1G1cO&0^Q?MtO1G0UO&0hQMjO,5?SOOQO-E<f-E<fO!)PQlO'#FqOOQO'#KY'#KYOOQO1G1u1G1uO&0rQ`O1G1tO&0wQ?MtO,5?ZOOOW7+'h7+'hOOOO1G/Z1G/ZO&1RQ!dO1G4wOOQ!0Lh7+(Q7+(QP!&oQMhO,5?]O!+xQMhO7+(cO&1YQ`O,5?[O9aQ`O,5?[OOQO-E<n-E<nO&1hQ`O1G6aO&1hQ`O1G6aO&1pQ`O1G6aO&1{QMjO7+'zO&2]Q!dO,5?^O&2gQ`O,5?^O!&oQMhO,5?^OOQO-E<p-E<pO&2lQ!dO1G6bO&2vQ`O1G6bO&3OQ`O1G2kO!&oQMhO1G2kOOQ!0Lb1G2i1G2iOOQ!0Lb1G2j1G2jO%3TQpO1G2iO!BqQpO1G2iOClQ`O1G2iOOQ!0Lb1G2q1G2qO&3TQpO1G2iO&3cQ`O1G2kO$){Q`O1G2jOClQ`O1G2jO$#jQlO1G2kO&3kQ`O1G2jO&4_QMjO,5?`OOQ!0Lh-E<s-E<sO&5QQMjO,5?bOOQ!0Lh-E<u-E<uO!+xQMhO7++[OOQ!0Lh1G/c1G/cO&5[Q`O1G/cOOQ!0Lh7+'u7+'uO&5aQMjO7+'|O&5qQMjO7++[O&5{QMjO7++[O&6YQ!0MxO<<KXOOQ!0Lf<<KX<<KXO&6|Q`O1G0zO!&oQMhO'#IyO&7RQ`O,5@wO&9TQ!fO<<LPO!&oQMhO1G2nO&9[Q!0LrO1G2nOOQ[<<G{<<G{O!BfQ!0LrO<<G{O&9mQ!0MxO<<I{OOQ!0Lf<<I{<<I{OOQO,5?k,5?kO&:aQ`O,5?kO&:fQ`O,5?kOOQO-E<}-E<}O&:tQ`O1G6jO&:tQ`O1G6jO9gQ`O1G6jO@oQ`O<<LlOOQ[<<Ll<<LlO&:|Q`O<<LlO9qQ!0LrO<<LlOOQ[<<LX<<LXO%9nQ!0MvO<<LXOOQ[<<LY<<LYO!DrQ`O<<LYO&;RQpO'#I{O&;^Q`O,5@{O!)PQlO,5@{OOQ[1G3W1G3WOOQO'#I}'#I}O9qQ!0LrO'#I}O&;fQpO,5=uOOQ[,5=u,5=uO&;mQpO'#EgO&;tQpO'#GeO&;yQ`O7+(zO&<OQ`O7+(zOOQ[7+(z7+(zO!&oQMhO7+(zO%[QlO7+(zO&<WQ`O7+(zOOQ[7+(|7+(|O9qQ!0LrO7+(|O$$VQ`O7+(|O9[Q`O7+(|O!BqQpO7+(|O&<cQ`O,5?jOOQO-E<|-E<|OOQO'#H^'#H^O&<nQ`O1G6hO9qQ!0LrO<<GqOOQ[<<Gq<<GqO@oQ`O<<GqO&<vQ`O7+,VO&<{Q`O7+,WO%[QlO7+,VO%[QlO7+,WOOQ[7+)U7+)UO&=QQ`O7+)UO&=VQlO7+)UO&=^Q`O7+)UOOQ[<<Lx<<LxOOQ[<<Lz<<LzOOQ[-E=P-E=POOQ[1G3y1G3yO&=cQ`O,5>`OOQ[,5>b,5>bO&=hQ`O1G4PO9aQ`O7+&fO!)PQlO7+&fOOQO7+%_7+%_O&=mQ?MtO1G6YO>}Q`O7+%_OOQ!0Lf<<Ia<<IaOOQ!0Lf<<Iz<<IzO>}Q`O<<IzOOQO<<Is<<IsO$@_Q!0MxO<<IsO%[QlO<<IsOOQO<<Id<<IdO!BfQ!0LrO<<IdO&=wQ!0LrO<<IsO&>SQ!0MxO<= ]O&>dQ`O<= [OOQO7+*^7+*^O9aQ`O7+*^OOQ[ANAkANAkO&>lQ!fOANAkO!&oQMhOANAkO#'oQ`OANAkO4UQ!fOANAkO&>sQ`OANAkO%[QlOANAkO&>{Q!0MzO7+'zO&A^Q!0MzO,5?`O&CiQ!0MzO,5?bO&EtQ!0MzO7+'|O&HVQ!fO1G4kO&HaQ?MtO7+&aO&JeQ?MvO,5=XO&LlQ?MvO,5=ZO&L|Q?MvO,5=XO&M^Q?MvO,5=ZO&MnQ?MvO,59uO' tQ?MvO,5<kO'#wQ?MvO,5<mO'&]Q?MvO,5<{O'(RQ?MtO7+'kO'(`Q?MtO7+'mO'(mQ`O,5<]OOQO7+'`7+'`OOQ!0Lh7+*c7+*cO'(rQMjO<<K}OOQO1G4v1G4vO'(yQ`O1G4vO')UQ`O1G4vO')dQ`O7++{O')dQ`O7++{O!&oQMhO1G4xO')lQ!dO1G4xO')vQ`O7++|O'*OQ`O7+(VO'*ZQ!dO7+(VOOQ!0Lb7+(T7+(TOOQ!0Lb7+(U7+(UO!BqQpO7+(TOClQ`O7+(TO'*eQ`O7+(VO!&oQMhO7+(VO$){Q`O7+(UO'*jQ`O7+(VOClQ`O7+(UO'*rQMjO<<NvOOQ!0Lh7+$}7+$}O!+xQMhO<<NvO'*|Q!dO,5?eOOQO-E<w-E<wO'+WQ!0MvO7+(YO!&oQMhO7+(YOOQ[AN=gAN=gO9gQ`O1G5VOOQO1G5V1G5VO'+hQ`O1G5VO'+mQ`O7+,UO'+mQ`O7+,UO9qQ!0LrOANBWO@oQ`OANBWOOQ[ANBWANBWOOQ[ANAsANAsOOQ[ANAtANAtO'+uQ`O,5?gOOQO-E<y-E<yO',QQ?MtO1G6gOOQO,5?i,5?iOOQO-E<{-E<{OOQ[1G3a1G3aO',[Q`O,5=POOQ[<<Lf<<LfO!&oQMhO<<LfO&;yQ`O<<LfO',aQ`O<<LfO%[QlO<<LfOOQ[<<Lh<<LhO9qQ!0LrO<<LhO$$VQ`O<<LhO9[Q`O<<LhO',iQpO1G5UO',tQ`O7+,SOOQ[AN=]AN=]O9qQ!0LrOAN=]OOQ[<= q<= qOOQ[<= r<= rO',|Q`O<= qO'-RQ`O<= rOOQ[<<Lp<<LpO'-WQ`O<<LpO'-]QlO<<LpOOQ[1G3z1G3zO>}Q`O7+)kO'-dQ`O<<JQO'-oQ?MtO<<JQOOQO<<Hy<<HyOOQ!0LfAN?fAN?fOOQOAN?_AN?_O$@_Q!0MxOAN?_OOQOAN?OAN?OO%[QlOAN?_OOQO<<Mx<<MxOOQ[G27VG27VO!&oQMhOG27VO#'oQ`OG27VO'-yQ!fOG27VO4UQ!fOG27VO'.QQ`OG27VO'.YQ?MtO<<JfO'.gQ?MvO1G2`O'0]Q?MvO,5?`O'2`Q?MvO,5?bO'4cQ?MvO1G2sO'6fQ?MvO1G2uO'8iQ?MtO<<KXO'8vQ?MtO<<I{OOQO1G1w1G1wO!+xQMhOANAiOOQO7+*b7+*bO'9TQ`O7+*bO'9`Q`O<= gO'9hQ!dO7+*dOOQ!0Lb<<Kq<<KqO$){Q`O<<KqOClQ`O<<KqO'9rQ`O<<KqO!&oQMhO<<KqOOQ!0Lb<<Ko<<KoO!BqQpO<<KoO'9}Q!dO<<KqOOQ!0Lb<<Kp<<KpO':XQ`O<<KqO!&oQMhO<<KqO$){Q`O<<KpO':^QMjOANDbO':hQ!0MvO<<KtOOQO7+*q7+*qO9gQ`O7+*qO':xQ`O<= pOOQ[G27rG27rO9qQ!0LrOG27rO!)PQlO1G5RO';QQ`O7+,RO';YQ`O1G2kO&;yQ`OANBQOOQ[ANBQANBQO!&oQMhOANBQO';_Q`OANBQOOQ[ANBSANBSO9qQ!0LrOANBSO$$VQ`OANBSOOQO'#H_'#H_OOQO7+*p7+*pOOQ[G22wG22wOOQ[ANE]ANE]OOQ[ANE^ANE^OOQ[ANB[ANB[O';gQ`OANB[OOQ[<<MV<<MVO!)PQlOAN?lOOQOG24yG24yO$@_Q!0MxOG24yO#'oQ`OLD,qOOQ[LD,qLD,qO!&oQMhOLD,qO';lQ!fOLD,qO';sQ?MvO7+'zO'=iQ?MvO,5?`O'?lQ?MvO,5?bO'AoQ?MvO7+'|O'CeQMjOG27TOOQO<<M|<<M|OOQ!0LbANA]ANA]O$){Q`OANA]OClQ`OANA]O'CuQ!dOANA]OOQ!0LbANAZANAZO'C|Q`OANA]O!&oQMhOANA]O'DXQ!dOANA]OOQ!0LbANA[ANA[OOQO<<N]<<N]OOQ[LD-^LD-^O'DcQ?MtO7+*mOOQO'#Gf'#GfOOQ[G27lG27lO&;yQ`OG27lO!&oQMhOG27lOOQ[G27nG27nO9qQ!0LrOG27nOOQ[G27vG27vO'DmQ?MtOG25WOOQOLD*eLD*eOOQ[!$(!]!$(!]O#'oQ`O!$(!]O!&oQMhO!$(!]O'DwQ!0MzOG27TOOQ!0LbG26wG26wO$){Q`OG26wO'GYQ`OG26wOClQ`OG26wO'GeQ!dOG26wO!&oQMhOG26wOOQ[LD-WLD-WO&;yQ`OLD-WOOQ[LD-YLD-YOOQ[!)9Ew!)9EwO#'oQ`O!)9EwOOQ!0LbLD,cLD,cO$){Q`OLD,cOClQ`OLD,cO'GlQ`OLD,cO'GwQ!dOLD,cOOQ[!$(!r!$(!rOOQ[!.K;c!.K;cO'HOQ?MvOG27TOOQ!0Lb!$( }!$( }O$){Q`O!$( }OClQ`O!$( }O'ItQ`O!$( }OOQ!0Lb!)9Ei!)9EiO$){Q`O!)9EiOClQ`O!)9EiOOQ!0Lb!.K;T!.K;TO$){Q`O!.K;TOOQ!0Lb!4/0o!4/0oO!)PQlO'#DzO1PQ`O'#EXO'JPQ!fO'#JqO'JWQ!L^O'#DvO'J_QlO'#EOO'JfQ!fO'#CiO'L|Q!fO'#CiO!)PQlO'#EQO'M^QlO,5;ZO!)PQlO,5;eO!)PQlO,5;eO!)PQlO,5;eO!)PQlO,5;eO!)PQlO,5;eO!)PQlO,5;eO!)PQlO,5;eO!)PQlO,5;eO!)PQlO,5;eO!)PQlO,5;eO!)PQlO'#IoO( aQ`O,5<iO!)PQlO,5;eO( iQMhO,5;eO(#SQMhO,5;eO!)PQlO,5;wO!&oQMhO'#GmO( iQMhO'#GmO!&oQMhO'#GoO( iQMhO'#GoO1SQ`O'#DZO1SQ`O'#DZO!&oQMhO'#GPO( iQMhO'#GPO!&oQMhO'#GRO( iQMhO'#GRO!&oQMhO'#GaO( iQMhO'#GaO!)PQlO,5:jO(#ZQpO'#D_O(#eQpO'#JuO!)PQlO,5@nO'M^QlO1G0uO(#oQ?MtO'#CiO!)PQlO1G2PO!&oQMhO'#ItO( iQMhO'#ItO!&oQMhO'#IvO( iQMhO'#IvO(#yQ!dO'#CrO!&oQMhO,5<tO( iQMhO,5<tO'M^QlO1G2RO!)PQlO7+&zO!&oQMhO1G2`O( iQMhO1G2`O!&oQMhO'#ItO( iQMhO'#ItO!&oQMhO'#IvO( iQMhO'#IvO!&oQMhO1G2bO( iQMhO1G2bO'M^QlO7+'mO'M^QlO7+&aO!&oQMhOANAiO( iQMhOANAiO($^Q`O'#EoO($cQ`O'#EoO($kQ`O'#F]O($pQ`O'#EyO($uQ`O'#KSO(%QQ`O'#KQO(%]Q`O,5;ZO(%bQMjO,5<eO(%iQ`O'#GYO(%nQ`O'#GYO(%sQ`O,5<gO(%{Q`O,5;ZO(&TQ?MtO1G1`O(&[Q`O,5<tO(&aQ`O,5<tO(&fQ`O,5<vO(&kQ`O,5<vO(&pQ`O1G2RO(&uQ`O1G0uO(&zQMjO<<K}O('RQMjO<<K}O7eQMhO'#F|O9[Q`O'#F{OAjQ`O'#EnO!)PQlO,5;tO!3dQ`O'#GYO!3dQ`O'#GYO!3dQ`O'#G[O!3dQ`O'#G[O!+xQMhO7+(cO!+xQMhO7+(cO%-mQ!dO1G2wO%-mQ!dO1G2wO!&oQMhO,5=]O!&oQMhO,5=]",stateData:"((X~O'{OS'|OSTOS'}RQ~OPYOQYOSfOY!VOaqOdzOeyOl!POpkOrYOskOtkOzkO|YO!OYO!SWO!WkO!XkO!_XO!iuO!lZO!oYO!pYO!qYO!svO!uwO!xxO!|]O$W|O$niO%h}O%j!QO%l!OO%m!OO%n!OO%q!RO%s!SO%v!TO%w!TO%y!UO&V!WO&]!XO&_!YO&a!ZO&c![O&f!]O&l!^O&r!_O&t!`O&v!aO&x!bO&z!cO(SSO(UTO(XUO(`VO(n[O~OWtO~P`OPYOQYOSfOd!jOe!iOpkOrYOskOtkOzkO|YO!OYO!SWO!WkO!XkO!_!eO!iuO!lZO!oYO!pYO!qYO!svO!u!gO!x!hO$W!kO$niO(S!dO(UTO(XUO(`VO(n[O~Oa!wOs!nO!S!oO!b!yO!c!vO!d!vO!|;wO#T!pO#U!pO#V!xO#W!pO#X!pO#[!zO#]!zO(T!lO(UTO(XUO(d!mO(n!sO~O'}!{O~OP]XR]X[]Xa]Xj]Xr]X!Q]X!S]X!]]X!l]X!p]X#R]X#S]X#`]X#kfX#n]X#o]X#p]X#q]X#r]X#s]X#t]X#u]X#v]X#x]X#z]X#{]X$Q]X'y]X(`]X(q]X(x]X(y]X~O!g%RX~P(qO_!}O(U#PO(V!}O(W#PO~O_#QO(W#PO(X#PO(Y#QO~Ox#SO!U#TO(a#TO(b#VO~OPYOQYOSfOd!jOe!iOpkOrYOskOtkOzkO|YO!OYO!SWO!WkO!XkO!_!eO!iuO!lZO!oYO!pYO!qYO!svO!u!gO!x!hO$W!kO$niO(S;{O(UTO(XUO(`VO(n[O~O![#ZO!]#WO!Y(gP!Y(uP~P+}O!^#cO~P`OPYOQYOSfOd!jOe!iOrYOskOtkOzkO|YO!OYO!SWO!WkO!XkO!_!eO!iuO!lZO!oYO!pYO!qYO!svO!u!gO!x!hO$W!kO$niO(UTO(XUO(`VO(n[O~Op#mO![#iO!|]O#i#lO#j#iO(S;|O!k(rP~P.iO!l#oO(S#nO~O!x#sO!|]O%h#tO~O#k#uO~O!g#vO#k#uO~OP$[OR#zO[$cOj$ROr$aO!Q#yO!S#{O!]$_O!l#xO!p$[O#R$RO#n$OO#o$PO#p$PO#q$PO#r$QO#s$RO#t$RO#u$bO#v$SO#x$UO#z$WO#{$XO(`VO(q$YO(x#|O(y#}O~Oa(eX'y(eX'v(eX!k(eX!Y(eX!_(eX%i(eX!g(eX~P1qO#S$dO#`$eO$Q$eOP(fXR(fX[(fXj(fXr(fX!Q(fX!S(fX!](fX!l(fX!p(fX#R(fX#n(fX#o(fX#p(fX#q(fX#r(fX#s(fX#t(fX#u(fX#v(fX#x(fX#z(fX#{(fX(`(fX(q(fX(x(fX(y(fX!_(fX%i(fX~Oa(fX'y(fX'v(fX!Y(fX!k(fXv(fX!g(fX~P4UO#`$eO~O$]$hO$_$gO$f$mO~OSfO!_$nO$i$oO$k$qO~Oh%VOj%cOk%cOl%cOp%WOr%XOs$tOt$tOz%YO|%ZO!O%[O!S${O!_$|O!i%aO!l$xO#j%bO$W%_O$t%]O$v%^O$y%`O(S$sO(UTO(XUO(`$uO(x$}O(y%POg(]P~O!l%dO~O!S%gO!_%hO(S%fO~O!g%lO~Oa%mO'y%mO~O!Q%qO~P%[O(T!lO~P%[O%n%uO~P%[Oh%VO!l%dO(S%fO(T!lO~Oe%|O!l%dO(S%fO~Oj$RO~O!Q&RO!_&OO!l&QO%j&UO(S%fO(T!lO(UTO(XUO`)VP~O!x#sO~O%s&WO!S)RX!_)RX(S)RX~O(S&XO~Ol!PO!u&^O%j!QO%l!OO%m!OO%n!OO%q!RO%s!SO%v!TO%w!TO~Od&cOe&bO!x&`O%h&aO%{&_O~P<VOd&fOeyOl!PO!_&eO!u&^O!xxO!|]O%h}O%l!OO%m!OO%n!OO%q!RO%s!SO%v!TO%w!TO%y!UO~Ob&iO#`&lO%j&gO(T!lO~P=[O!l&mO!u&qO~O!l#oO~O!_XO~Oa%mO'w&yO'y%mO~Oa%mO'w&|O'y%mO~Oa%mO'w'OO'y%mO~O'v]X!Y]Xv]X!k]X&Z]X!_]X%i]X!g]X~P(qO!b']O!c'UO!d'UO(T!lO(UTO(XUO~Os'SO!S'RO!['VO(d'QO!^(hP!^(wP~P@cOn'`O!_'^O(S%fO~Oe'eO!l%dO(S%fO~O!Q&RO!l&QO~Os!nO!S!oO!|;wO#T!pO#U!pO#W!pO#X!pO(T!lO(UTO(XUO(d!mO(n!sO~O!b'kO!c'jO!d'jO#V!pO#['lO#]'lO~PA}Oa%mOh%VO!g#vO!l%dO'y%mO(q'nO~O!p'rO#`'pO~PC]Os!nO!S!oO(UTO(XUO(d!mO(n!sO~O!_XOs(lX!S(lX!b(lX!c(lX!d(lX!|(lX#T(lX#U(lX#V(lX#W(lX#X(lX#[(lX#](lX(T(lX(U(lX(X(lX(d(lX(n(lX~O!c'jO!d'jO(T!lO~PC{O(O'vO(P'vO(Q'xO~O_!}O(U'zO(V!}O(W'zO~O_#QO(W'zO(X'zO(Y#QO~Ov'|O~P%[Ox#SO!U#TO(a#TO(b(PO~O![(RO!Y'VX!Y']X!]'VX!]']X~P+}O!](TO!Y(gX~OP$[OR#zO[$cOj$ROr$aO!Q#yO!S#{O!](TO!l#xO!p$[O#R$RO#n$OO#o$PO#p$PO#q$PO#r$QO#s$RO#t$RO#u$bO#v$SO#x$UO#z$WO#{$XO(`VO(q$YO(x#|O(y#}O~O!Y(gX~PGvO!Y(YO~O!Y(tX!](tX!g(tX!k(tX(q(tX~O#`(tX#k#dX!^(tX~PIyO#`(ZO!Y(vX!](vX~O!]([O!Y(uX~O!Y(_O~O#`$eO~PIyO!^(`O~P`OR#zO!Q#yO!S#{O!l#xO(`VOP!na[!naj!nar!na!]!na!p!na#R!na#n!na#o!na#p!na#q!na#r!na#s!na#t!na#u!na#v!na#x!na#z!na#{!na(q!na(x!na(y!na~Oa!na'y!na'v!na!Y!na!k!nav!na!_!na%i!na!g!na~PKaO!k(aO~O!g#vO#`(bO(q'nO!](sXa(sX'y(sX~O!k(sX~PM|O!S%gO!_%hO!|]O#i(gO#j(fO(S%fO~O!](hO!k(rX~O!k(jO~O!S%gO!_%hO#j(fO(S%fO~OP(fXR(fX[(fXj(fXr(fX!Q(fX!S(fX!](fX!l(fX!p(fX#R(fX#n(fX#o(fX#p(fX#q(fX#r(fX#s(fX#t(fX#u(fX#v(fX#x(fX#z(fX#{(fX(`(fX(q(fX(x(fX(y(fX~O!g#vO!k(fX~P! jOR(lO!Q(kO!l#xO#S$dO!|!{a!S!{a~O!x!{a%h!{a!_!{a#i!{a#j!{a(S!{a~P!#kO!x(pO~OPYOQYOSfOd!jOe!iOpkOrYOskOtkOzkO|YO!OYO!SWO!WkO!XkO!_XO!iuO!lZO!oYO!pYO!qYO!svO!u!gO!x!hO$W!kO$niO(S!dO(UTO(XUO(`VO(n[O~Oh%VOp%WOr%XOs$tOt$tOz%YO|%ZO!O<eO!S${O!_$|O!i=vO!l$xO#j<kO$W%_O$t<gO$v<iO$y%`O(S(tO(UTO(XUO(`$uO(x$}O(y%PO~O#k(vO~O![(xO!k(jP~P%[O(d(zO(n[O~O!S(|O!l#xO(d(zO(n[O~OP;vOQ;vOSfOd=rOe!iOpkOr;vOskOtkOzkO|;vO!O;vO!SWO!WkO!XkO!_!eO!i;yO!lZO!o;vO!p;vO!q;vO!s;zO!u;}O!x!hO$W!kO$n=pO(S)ZO(UTO(XUO(`VO(n[O~O!]$_Oa$qa'y$qa'v$qa!k$qa!Y$qa!_$qa%i$qa!g$qa~Ol)bO~P!&oOh%VOp%WOr%XOs$tOt$tOz%YO|%ZO!O%[O!S${O!_$|O!i%aO!l$xO#j%bO$W%_O$t%]O$v%^O$y%`O(S(tO(UTO(XUO(`$uO(x$}O(y%PO~Og(oP~P!+xO!Q)gO!g)fO!_$^X$Z$^X$]$^X$_$^X$f$^X~O!g)fO!_(zX$Z(zX$](zX$_(zX$f(zX~O!Q)gO~P!.RO!Q)gO!_(zX$Z(zX$](zX$_(zX$f(zX~O!_)iO$Z)mO$])hO$_)hO$f)nO~O![)qO~P!)PO$]$hO$_$gO$f)uO~On$zX!Q$zX#S$zX'x$zX(x$zX(y$zX~OgmXg$zXnmX!]mX#`mX~P!/wOx)wO(a)xO(b)zO~On*TO!Q)|O'x)}O(x$}O(y%PO~Og){O~P!0{Og*UO~Oh%VOp%WOr%XOs$tOt$tOz%YO|%ZO!O<eO!S*WO!_*XO!i=vO!l$xO#j<kO$W%_O$t<gO$v<iO$y%`O(UTO(XUO(`$uO(x$}O(y%PO~O![*[O(S*VO!k(}P~P!1jO#k*^O~O!l*_O~Oh%VOp%WOr%XOs$tOt$tOz%YO|%ZO!O<eO!S${O!_$|O!i=vO!l$xO#j<kO$W%_O$t<gO$v<iO$y%`O(S*aO(UTO(XUO(`$uO(x$}O(y%PO~O![*dO!Y)OP~P!3iOr*pOs!nO!S*fO!b*nO!c*hO!d*hO!l*_O#[*oO%`*jO(T!lO(UTO(XUO(d!mO~O!^*mO~P!5^O#S$dOn(_X!Q(_X'x(_X(x(_X(y(_X!](_X#`(_X~Og(_X$O(_X~P!6`On*uO#`*tOg(^X!](^X~O!]*vOg(]X~Oj%cOk%cOl%cO(S&XOg(]P~Os*yO~O!l+OO~O(S(tO~Op+TO!S%gO![#iO!_%hO!|]O#i#lO#j#iO(S%fO!k(rP~O!g#vO#k+UO~O!S%gO![+WO!]([O!_%hO(S%fO!Y(uP~Os'YO!S+YO![+XO(UTO(XUO(d(zO~O!^(wP~P!9iO!]+ZOa)SX'y)SX~OP$[OR#zO[$cOj$ROr$aO!Q#yO!S#{O!l#xO!p$[O#R$RO#n$OO#o$PO#p$PO#q$PO#r$QO#s$RO#t$RO#u$bO#v$SO#x$UO#z$WO#{$XO(`VO(q$YO(x#|O(y#}O~Oa!ja!]!ja'y!ja'v!ja!Y!ja!k!jav!ja!_!ja%i!ja!g!ja~P!:aOR#zO!Q#yO!S#{O!l#xO(`VOP!ra[!raj!rar!ra!]!ra!p!ra#R!ra#n!ra#o!ra#p!ra#q!ra#r!ra#s!ra#t!ra#u!ra#v!ra#x!ra#z!ra#{!ra(q!ra(x!ra(y!ra~Oa!ra'y!ra'v!ra!Y!ra!k!rav!ra!_!ra%i!ra!g!ra~P!<wOR#zO!Q#yO!S#{O!l#xO(`VOP!ta[!taj!tar!ta!]!ta!p!ta#R!ta#n!ta#o!ta#p!ta#q!ta#r!ta#s!ta#t!ta#u!ta#v!ta#x!ta#z!ta#{!ta(q!ta(x!ta(y!ta~Oa!ta'y!ta'v!ta!Y!ta!k!tav!ta!_!ta%i!ta!g!ta~P!?_Oh%VOn+dO!_'^O%i+cO~O!g+fOa([X!_([X'y([X!]([X~Oa%mO!_XO'y%mO~Oh%VO!l%dO~Oh%VO!l%dO(S%fO~O!g#vO#k(vO~Ob+qO%j+rO(S+nO(UTO(XUO!^)WP~O!]+sO`)VX~O[+wO~O`+xO~O!_&OO(S%fO(T!lO`)VP~Oh%VO#`+}O~Oh%VOn,QO!_$|O~O!_,SO~O!Q,UO!_XO~O%n%uO~O!x,ZO~Oe,`O~Ob,aO(S#nO(UTO(XUO!^)UP~Oe%|O~O%j!QO(S&XO~P=[O[,fO`,eO~OPYOQYOSfOdzOeyOpkOrYOskOtkOzkO|YO!OYO!SWO!WkO!XkO!iuO!lZO!oYO!pYO!qYO!svO!xxO!|]O$niO%h}O(UTO(XUO(`VO(n[O~O!_!eO!u!gO$W!kO(S!dO~P!F_O`,eOa%mO'y%mO~OPYOQYOSfOd!jOe!iOpkOrYOskOtkOzkO|YO!OYO!SWO!WkO!XkO!_!eO!iuO!lZO!oYO!pYO!qYO!svO!x!hO$W!kO$niO(S!dO(UTO(XUO(`VO(n[O~Oa,kOl!OO!uwO%l!OO%m!OO%n!OO~P!HwO!l&mO~O&],qO~O!_,sO~O&n,uO&p,vOP&kaQ&kaS&kaY&kaa&kad&kae&kal&kap&kar&kas&kat&kaz&ka|&ka!O&ka!S&ka!W&ka!X&ka!_&ka!i&ka!l&ka!o&ka!p&ka!q&ka!s&ka!u&ka!x&ka!|&ka$W&ka$n&ka%h&ka%j&ka%l&ka%m&ka%n&ka%q&ka%s&ka%v&ka%w&ka%y&ka&V&ka&]&ka&_&ka&a&ka&c&ka&f&ka&l&ka&r&ka&t&ka&v&ka&x&ka&z&ka'v&ka(S&ka(U&ka(X&ka(`&ka(n&ka!^&ka&d&kab&ka&i&ka~O(S,{O~Oh!eX!]!RX!^!RX!g!RX!g!eX!l!eX#`!RX~O!]!eX!^!eX~P# }O!g-QO#`-POh(iX!]#hX!^#hX!g(iX!l(iX~O!](iX!^(iX~P#!pOh%VO!g-SO!l%dO!]!aX!^!aX~Os!nO!S!oO(UTO(XUO(d!mO~OP;vOQ;vOSfOd=rOe!iOpkOr;vOskOtkOzkO|;vO!O;vO!SWO!WkO!XkO!_!eO!i;yO!lZO!o;vO!p;vO!q;vO!s;zO!u;}O!x!hO$W!kO$n=pO(UTO(XUO(`VO(n[O~O(S<rO~P#$VO!]-WO!^(hX~O!^-YO~O!g-QO#`-PO!]#hX!^#hX~O!]-ZO!^(wX~O!^-]O~O!c-^O!d-^O(T!lO~P##tO!^-aO~P'_On-dO!_'^O~O!Y-iO~Os!{a!b!{a!c!{a!d!{a#T!{a#U!{a#V!{a#W!{a#X!{a#[!{a#]!{a(T!{a(U!{a(X!{a(d!{a(n!{a~P!#kO!p-nO#`-lO~PC]O!c-pO!d-pO(T!lO~PC{Oa%mO#`-lO'y%mO~Oa%mO!g#vO#`-lO'y%mO~Oa%mO!g#vO!p-nO#`-lO'y%mO(q'nO~O(O'vO(P'vO(Q-uO~Ov-vO~O!Y'Va!]'Va~P!:aO![-zO!Y'VX!]'VX~P%[O!](TO!Y(ga~O!Y(ga~PGvO!]([O!Y(ua~O!S%gO![.OO!_%hO(S%fO!Y']X!]']X~O#`.QO!](sa!k(saa(sa'y(sa~O!g#vO~P#,]O!](hO!k(ra~O!S%gO!_%hO#j.UO(S%fO~Op.ZO!S%gO![.WO!_%hO!|]O#i.YO#j.WO(S%fO!]'`X!k'`X~OR._O!l#xO~Oh%VOn.bO!_'^O%i.aO~Oa#ci!]#ci'y#ci'v#ci!Y#ci!k#civ#ci!_#ci%i#ci!g#ci~P!:aOn=|O!Q)|O'x)}O(x$}O(y%PO~O#k#_aa#_a#`#_a'y#_a!]#_a!k#_a!_#_a!Y#_a~P#/XO#k(_XP(_XR(_X[(_Xa(_Xj(_Xr(_X!S(_X!l(_X!p(_X#R(_X#n(_X#o(_X#p(_X#q(_X#r(_X#s(_X#t(_X#u(_X#v(_X#x(_X#z(_X#{(_X'y(_X(`(_X(q(_X!k(_X!Y(_X'v(_Xv(_X!_(_X%i(_X!g(_X~P!6`O!].oO!k(jX~P!:aO!k.rO~O!Y.tO~OP$[OR#zO!Q#yO!S#{O!l#xO!p$[O(`VO[#mia#mij#mir#mi!]#mi#R#mi#o#mi#p#mi#q#mi#r#mi#s#mi#t#mi#u#mi#v#mi#x#mi#z#mi#{#mi'y#mi(q#mi(x#mi(y#mi'v#mi!Y#mi!k#miv#mi!_#mi%i#mi!g#mi~O#n#mi~P#2wO#n$OO~P#2wOP$[OR#zOr$aO!Q#yO!S#{O!l#xO!p$[O#n$OO#o$PO#p$PO#q$PO(`VO[#mia#mij#mi!]#mi#R#mi#s#mi#t#mi#u#mi#v#mi#x#mi#z#mi#{#mi'y#mi(q#mi(x#mi(y#mi'v#mi!Y#mi!k#miv#mi!_#mi%i#mi!g#mi~O#r#mi~P#5fO#r$QO~P#5fOP$[OR#zO[$cOj$ROr$aO!Q#yO!S#{O!l#xO!p$[O#R$RO#n$OO#o$PO#p$PO#q$PO#r$QO#s$RO#t$RO#u$bO(`VOa#mi!]#mi#x#mi#z#mi#{#mi'y#mi(q#mi(x#mi(y#mi'v#mi!Y#mi!k#miv#mi!_#mi%i#mi!g#mi~O#v#mi~P#8TOP$[OR#zO[$cOj$ROr$aO!Q#yO!S#{O!l#xO!p$[O#R$RO#n$OO#o$PO#p$PO#q$PO#r$QO#s$RO#t$RO#u$bO#v$SO(`VO(y#}Oa#mi!]#mi#z#mi#{#mi'y#mi(q#mi(x#mi'v#mi!Y#mi!k#miv#mi!_#mi%i#mi!g#mi~O#x$UO~P#:kO#x#mi~P#:kO#v$SO~P#8TOP$[OR#zO[$cOj$ROr$aO!Q#yO!S#{O!l#xO!p$[O#R$RO#n$OO#o$PO#p$PO#q$PO#r$QO#s$RO#t$RO#u$bO#v$SO#x$UO(`VO(x#|O(y#}Oa#mi!]#mi#{#mi'y#mi(q#mi'v#mi!Y#mi!k#miv#mi!_#mi%i#mi!g#mi~O#z#mi~P#=aO#z$WO~P#=aOP]XR]X[]Xj]Xr]X!Q]X!S]X!l]X!p]X#R]X#S]X#`]X#kfX#n]X#o]X#p]X#q]X#r]X#s]X#t]X#u]X#v]X#x]X#z]X#{]X$Q]X(`]X(q]X(x]X(y]X!]]X!^]X~O$O]X~P#@OOP$[OR#zO[<_Oj<SOr<]O!Q#yO!S#{O!l#xO!p$[O#R<SO#n<PO#o<QO#p<QO#q<QO#r<RO#s<SO#t<SO#u<^O#v<TO#x<VO#z<XO#{<YO(`VO(q$YO(x#|O(y#}O~O$O.vO~P#B]O#S$dO#`<`O$Q<`O$O(fX!^(fX~P! jOa'ca!]'ca'y'ca'v'ca!k'ca!Y'cav'ca!_'ca%i'ca!g'ca~P!:aO[#mia#mij#mir#mi!]#mi#R#mi#r#mi#s#mi#t#mi#u#mi#v#mi#x#mi#z#mi#{#mi'y#mi(q#mi'v#mi!Y#mi!k#miv#mi!_#mi%i#mi!g#mi~OP$[OR#zO!Q#yO!S#{O!l#xO!p$[O#n$OO#o$PO#p$PO#q$PO(`VO(x#mi(y#mi~P#E_On=|O!Q)|O'x)}O(x$}O(y%POP#miR#mi!S#mi!l#mi!p#mi#n#mi#o#mi#p#mi#q#mi(`#mi~P#E_O!].zOg(oX~P!0{Og.|O~Oa$Pi!]$Pi'y$Pi'v$Pi!Y$Pi!k$Piv$Pi!_$Pi%i$Pi!g$Pi~P!:aO$].}O$_.}O~O$]/OO$_/OO~O!g)fO#`/PO!_$cX$Z$cX$]$cX$_$cX$f$cX~O![/QO~O!_)iO$Z/SO$])hO$_)hO$f/TO~O!]<ZO!^(eX~P#B]O!^/UO~O!g)fO$f(zX~O$f/WO~Ov/XO~P!&oOx)wO(a)xO(b/[O~O!S/_O~O(x$}On%aa!Q%aa'x%aa(y%aa!]%aa#`%aa~Og%aa$O%aa~P#LaO(y%POn%ca!Q%ca'x%ca(x%ca!]%ca#`%ca~Og%ca$O%ca~P#MSO!]fX!gfX!kfX!k$zX(qfX~P!/wO![/hO!]([O(S/gO!Y(uP!Y)OP~P!1jOr*pO!b*nO!c*hO!d*hO!l*_O#[*oO%`*jO(T!lO(UTO(XUO~Os<oO!S/iO![+XO!^*mO(d<nO!^(wP~P#NmO!k/jO~P#/XO!]/kO!g#vO(q'nO!k(}X~O!k/pO~O!S%gO![*[O!_%hO(S%fO!k(}P~O#k/rO~O!Y$zX!]$zX!g%RX~P!/wO!]/sO!Y)OX~P#/XO!g/uO~O!Y/wO~OpkO(S/xO~P.iOh%VOr/}O!g#vO!l%dO(q'nO~O!g+fO~Oa%mO!]0RO'y%mO~O!^0TO~P!5^O!c0UO!d0UO(T!lO~P##tOs!nO!S0VO(UTO(XUO(d!mO~O#[0XO~Og%aa!]%aa#`%aa$O%aa~P!0{Og%ca!]%ca#`%ca$O%ca~P!0{Oj%cOk%cOl%cO(S&XOg'lX!]'lX~O!]*vOg(]a~Og0bO~OR0cO!Q0cO!S0dO#S$dOn}a'x}a(x}a(y}a!]}a#`}a~Og}a$O}a~P$&vO!Q)|O'x)}On$sa(x$sa(y$sa!]$sa#`$sa~Og$sa$O$sa~P$'rO!Q)|O'x)}On$ua(x$ua(y$ua!]$ua#`$ua~Og$ua$O$ua~P$(eO#k0gO~Og%Ta!]%Ta#`%Ta$O%Ta~P!0{On0iO#`0hOg(^a!](^a~O!g#vO~O#k0lO~O!]+ZOa)Sa'y)Sa~OR#zO!Q#yO!S#{O!l#xO(`VOP!ri[!rij!rir!ri!]!ri!p!ri#R!ri#n!ri#o!ri#p!ri#q!ri#r!ri#s!ri#t!ri#u!ri#v!ri#x!ri#z!ri#{!ri(q!ri(x!ri(y!ri~Oa!ri'y!ri'v!ri!Y!ri!k!riv!ri!_!ri%i!ri!g!ri~P$*bOh%VOr%XOs$tOt$tOz%YO|%ZO!O<eO!S${O!_$|O!i=vO!l$xO#j<kO$W%_O$t<gO$v<iO$y%`O(UTO(XUO(`$uO(x$}O(y%PO~Op0uO%]0vO(S0tO~P$,xO!g+fOa([a!_([a'y([a!]([a~O#k0|O~O[]X!]fX!^fX~O!]0}O!^)WX~O!^1PO~O[1QO~Ob1SO(S+nO(UTO(XUO~O!_&OO(S%fO`'tX!]'tX~O!]+sO`)Va~O!k1VO~P!:aO[1YO~O`1ZO~O#`1^O~On1aO!_$|O~O(d(zO!^)TP~Oh%VOn1jO!_1gO%i1iO~O[1tO!]1rO!^)UX~O!^1uO~O`1wOa%mO'y%mO~O(S#nO(UTO(XUO~O#S$dO#`$eO$Q$eOP(fXR(fX[(fXr(fX!Q(fX!S(fX!](fX!l(fX!p(fX#R(fX#n(fX#o(fX#p(fX#q(fX#r(fX#s(fX#t(fX#u(fX#v(fX#x(fX#z(fX#{(fX(`(fX(q(fX(x(fX(y(fX~Oj1zO&Z1{Oa(fX~P$2cOj1zO#`$eO&Z1{O~Oa1}O~P%[Oa2PO~O&d2SOP&biQ&biS&biY&bia&bid&bie&bil&bip&bir&bis&bit&biz&bi|&bi!O&bi!S&bi!W&bi!X&bi!_&bi!i&bi!l&bi!o&bi!p&bi!q&bi!s&bi!u&bi!x&bi!|&bi$W&bi$n&bi%h&bi%j&bi%l&bi%m&bi%n&bi%q&bi%s&bi%v&bi%w&bi%y&bi&V&bi&]&bi&_&bi&a&bi&c&bi&f&bi&l&bi&r&bi&t&bi&v&bi&x&bi&z&bi'v&bi(S&bi(U&bi(X&bi(`&bi(n&bi!^&bib&bi&i&bi~Ob2YO!^2WO&i2XO~P`O!_XO!l2[O~O&p,vOP&kiQ&kiS&kiY&kia&kid&kie&kil&kip&kir&kis&kit&kiz&ki|&ki!O&ki!S&ki!W&ki!X&ki!_&ki!i&ki!l&ki!o&ki!p&ki!q&ki!s&ki!u&ki!x&ki!|&ki$W&ki$n&ki%h&ki%j&ki%l&ki%m&ki%n&ki%q&ki%s&ki%v&ki%w&ki%y&ki&V&ki&]&ki&_&ki&a&ki&c&ki&f&ki&l&ki&r&ki&t&ki&v&ki&x&ki&z&ki'v&ki(S&ki(U&ki(X&ki(`&ki(n&ki!^&ki&d&kib&ki&i&ki~O!Y2bO~O!]!aa!^!aa~P#B]Os!nO!S!oO![2hO(d!mO!]'WX!^'WX~P@cO!]-WO!^(ha~O!]'^X!^'^X~P!9iO!]-ZO!^(wa~O!^2oO~P'_Oa%mO#`2xO'y%mO~Oa%mO!g#vO#`2xO'y%mO~Oa%mO!g#vO!p2|O#`2xO'y%mO(q'nO~Oa%mO'y%mO~P!:aO!]$_Ov$qa~O!Y'Vi!]'Vi~P!:aO!](TO!Y(gi~O!]([O!Y(ui~O!Y(vi!](vi~P!:aO!](si!k(sia(si'y(si~P!:aO#`3OO!](si!k(sia(si'y(si~O!](hO!k(ri~O!S%gO!_%hO!|]O#i3TO#j3SO(S%fO~O!S%gO!_%hO#j3SO(S%fO~On3[O!_'^O%i3ZO~Oh%VOn3[O!_'^O%i3ZO~O#k%aaP%aaR%aa[%aaa%aaj%aar%aa!S%aa!l%aa!p%aa#R%aa#n%aa#o%aa#p%aa#q%aa#r%aa#s%aa#t%aa#u%aa#v%aa#x%aa#z%aa#{%aa'y%aa(`%aa(q%aa!k%aa!Y%aa'v%aav%aa!_%aa%i%aa!g%aa~P#LaO#k%caP%caR%ca[%caa%caj%car%ca!S%ca!l%ca!p%ca#R%ca#n%ca#o%ca#p%ca#q%ca#r%ca#s%ca#t%ca#u%ca#v%ca#x%ca#z%ca#{%ca'y%ca(`%ca(q%ca!k%ca!Y%ca'v%cav%ca!_%ca%i%ca!g%ca~P#MSO#k%aaP%aaR%aa[%aaa%aaj%aar%aa!S%aa!]%aa!l%aa!p%aa#R%aa#n%aa#o%aa#p%aa#q%aa#r%aa#s%aa#t%aa#u%aa#v%aa#x%aa#z%aa#{%aa'y%aa(`%aa(q%aa!k%aa!Y%aa'v%aa#`%aav%aa!_%aa%i%aa!g%aa~P#/XO#k%caP%caR%ca[%caa%caj%car%ca!S%ca!]%ca!l%ca!p%ca#R%ca#n%ca#o%ca#p%ca#q%ca#r%ca#s%ca#t%ca#u%ca#v%ca#x%ca#z%ca#{%ca'y%ca(`%ca(q%ca!k%ca!Y%ca'v%ca#`%cav%ca!_%ca%i%ca!g%ca~P#/XO#k}aP}a[}aa}aj}ar}a!l}a!p}a#R}a#n}a#o}a#p}a#q}a#r}a#s}a#t}a#u}a#v}a#x}a#z}a#{}a'y}a(`}a(q}a!k}a!Y}a'v}av}a!_}a%i}a!g}a~P$&vO#k$saP$saR$sa[$saa$saj$sar$sa!S$sa!l$sa!p$sa#R$sa#n$sa#o$sa#p$sa#q$sa#r$sa#s$sa#t$sa#u$sa#v$sa#x$sa#z$sa#{$sa'y$sa(`$sa(q$sa!k$sa!Y$sa'v$sav$sa!_$sa%i$sa!g$sa~P$'rO#k$uaP$uaR$ua[$uaa$uaj$uar$ua!S$ua!l$ua!p$ua#R$ua#n$ua#o$ua#p$ua#q$ua#r$ua#s$ua#t$ua#u$ua#v$ua#x$ua#z$ua#{$ua'y$ua(`$ua(q$ua!k$ua!Y$ua'v$uav$ua!_$ua%i$ua!g$ua~P$(eO#k%TaP%TaR%Ta[%Taa%Taj%Tar%Ta!S%Ta!]%Ta!l%Ta!p%Ta#R%Ta#n%Ta#o%Ta#p%Ta#q%Ta#r%Ta#s%Ta#t%Ta#u%Ta#v%Ta#x%Ta#z%Ta#{%Ta'y%Ta(`%Ta(q%Ta!k%Ta!Y%Ta'v%Ta#`%Tav%Ta!_%Ta%i%Ta!g%Ta~P#/XOa#cq!]#cq'y#cq'v#cq!Y#cq!k#cqv#cq!_#cq%i#cq!g#cq~P!:aO![3dO!]'XX!k'XX~P%[O!].oO!k(ja~O!].oO!k(ja~P!:aO!Y3gO~O$O!na!^!na~PKaO$O!ja!]!ja!^!ja~P#B]O$O!ra!^!ra~P!<wO$O!ta!^!ta~P!?_Og'[X!]'[X~P!+xO!].zOg(oa~OSfO!_3{O$d3|O~O!^4QO~Ov4RO~P#/XOa$mq!]$mq'y$mq'v$mq!Y$mq!k$mqv$mq!_$mq%i$mq!g$mq~P!:aO!Y4TO~P!&oO!S4UO~O!Q)|O'x)}O(y%POn'ha(x'ha!]'ha#`'ha~Og'ha$O'ha~P%,XO!Q)|O'x)}On'ja(x'ja(y'ja!]'ja#`'ja~Og'ja$O'ja~P%,zO(q$YO~P#/XO!YfX!Y$zX!]fX!]$zX!g%RX#`fX~P!/wO(S<xO~P!1jO!S%gO![4XO!_%hO(S%fO!]'dX!k'dX~O!]/kO!k(}a~O!]/kO!g#vO!k(}a~O!]/kO!g#vO(q'nO!k(}a~Og$|i!]$|i#`$|i$O$|i~P!0{O![4aO!Y'fX!]'fX~P!3iO!]/sO!Y)Oa~O!]/sO!Y)Oa~P#/XOP]XR]X[]Xj]Xr]X!Q]X!S]X!Y]X!]]X!l]X!p]X#R]X#S]X#`]X#kfX#n]X#o]X#p]X#q]X#r]X#s]X#t]X#u]X#v]X#x]X#z]X#{]X$Q]X(`]X(q]X(x]X(y]X~Oj%YX!g%YX~P%0kOj4fO!g#vO~Oh%VO!g#vO!l%dO~Oh%VOr4kO!l%dO(q'nO~Or4pO!g#vO(q'nO~Os!nO!S4qO(UTO(XUO(d!mO~O(x$}On%ai!Q%ai'x%ai(y%ai!]%ai#`%ai~Og%ai$O%ai~P%4[O(y%POn%ci!Q%ci'x%ci(x%ci!]%ci#`%ci~Og%ci$O%ci~P%4}Og(^i!](^i~P!0{O#`4wOg(^i!](^i~P!0{O!k4zO~Oa$oq!]$oq'y$oq'v$oq!Y$oq!k$oqv$oq!_$oq%i$oq!g$oq~P!:aO!Y5QO~O!]5RO!_)PX~P#/XOa$zX!_$zX%^]X'y$zX!]$zX~P!/wO%^5UOaoXnoX!QoX!_oX'xoX'yoX(xoX(yoX!]oX~Op5VO(S#nO~O%^5UO~Ob5]O%j5^O(S+nO(UTO(XUO!]'sX!^'sX~O!]0}O!^)Wa~O[5bO~O`5cO~Oa%mO'y%mO~P#/XO!]5kO#`5mO!^)TX~O!^5nO~Or5tOs!nO!S*fO!b!yO!c!vO!d!vO!|;wO#T!pO#U!pO#V!pO#W!pO#X!pO#[5sO#]!zO(T!lO(UTO(XUO(d!mO(n!sO~O!^5rO~P%:YOn5yO!_1gO%i5xO~Oh%VOn5yO!_1gO%i5xO~Ob6QO(S#nO(UTO(XUO!]'rX!^'rX~O!]1rO!^)Ua~O(UTO(XUO(d6SO~O`6WO~Oj6ZO&Z6[O~PM|O!k6]O~P%[Oa6_O~Oa6_O~P%[Ob2YO!^6dO&i2XO~P`O!g6fO~O!g6hOh(ii!](ii!^(ii!g(ii!l(iir(ii(q(ii~O!]#hi!^#hi~P#B]O#`6iO!]#hi!^#hi~O!]!ai!^!ai~P#B]Oa%mO#`6rO'y%mO~Oa%mO!g#vO#`6rO'y%mO~O!](sq!k(sqa(sq'y(sq~P!:aO!](hO!k(rq~O!S%gO!_%hO#j6yO(S%fO~O!_'^O%i6|O~On7QO!_'^O%i6|O~O#k'haP'haR'ha['haa'haj'har'ha!S'ha!l'ha!p'ha#R'ha#n'ha#o'ha#p'ha#q'ha#r'ha#s'ha#t'ha#u'ha#v'ha#x'ha#z'ha#{'ha'y'ha(`'ha(q'ha!k'ha!Y'ha'v'hav'ha!_'ha%i'ha!g'ha~P%,XO#k'jaP'jaR'ja['jaa'jaj'jar'ja!S'ja!l'ja!p'ja#R'ja#n'ja#o'ja#p'ja#q'ja#r'ja#s'ja#t'ja#u'ja#v'ja#x'ja#z'ja#{'ja'y'ja(`'ja(q'ja!k'ja!Y'ja'v'jav'ja!_'ja%i'ja!g'ja~P%,zO#k$|iP$|iR$|i[$|ia$|ij$|ir$|i!S$|i!]$|i!l$|i!p$|i#R$|i#n$|i#o$|i#p$|i#q$|i#r$|i#s$|i#t$|i#u$|i#v$|i#x$|i#z$|i#{$|i'y$|i(`$|i(q$|i!k$|i!Y$|i'v$|i#`$|iv$|i!_$|i%i$|i!g$|i~P#/XO#k%aiP%aiR%ai[%aia%aij%air%ai!S%ai!l%ai!p%ai#R%ai#n%ai#o%ai#p%ai#q%ai#r%ai#s%ai#t%ai#u%ai#v%ai#x%ai#z%ai#{%ai'y%ai(`%ai(q%ai!k%ai!Y%ai'v%aiv%ai!_%ai%i%ai!g%ai~P%4[O#k%ciP%ciR%ci[%cia%cij%cir%ci!S%ci!l%ci!p%ci#R%ci#n%ci#o%ci#p%ci#q%ci#r%ci#s%ci#t%ci#u%ci#v%ci#x%ci#z%ci#{%ci'y%ci(`%ci(q%ci!k%ci!Y%ci'v%civ%ci!_%ci%i%ci!g%ci~P%4}O!]'Xa!k'Xa~P!:aO!].oO!k(ji~O$O#ci!]#ci!^#ci~P#B]OP$[OR#zO!Q#yO!S#{O!l#xO!p$[O(`VO[#mij#mir#mi#R#mi#o#mi#p#mi#q#mi#r#mi#s#mi#t#mi#u#mi#v#mi#x#mi#z#mi#{#mi$O#mi(q#mi(x#mi(y#mi!]#mi!^#mi~O#n#mi~P%MXO#n<PO~P%MXOP$[OR#zOr<]O!Q#yO!S#{O!l#xO!p$[O#n<PO#o<QO#p<QO#q<QO(`VO[#mij#mi#R#mi#s#mi#t#mi#u#mi#v#mi#x#mi#z#mi#{#mi$O#mi(q#mi(x#mi(y#mi!]#mi!^#mi~O#r#mi~P& aO#r<RO~P& aOP$[OR#zO[<_Oj<SOr<]O!Q#yO!S#{O!l#xO!p$[O#R<SO#n<PO#o<QO#p<QO#q<QO#r<RO#s<SO#t<SO#u<^O(`VO#x#mi#z#mi#{#mi$O#mi(q#mi(x#mi(y#mi!]#mi!^#mi~O#v#mi~P&#iOP$[OR#zO[<_Oj<SOr<]O!Q#yO!S#{O!l#xO!p$[O#R<SO#n<PO#o<QO#p<QO#q<QO#r<RO#s<SO#t<SO#u<^O#v<TO(`VO(y#}O#z#mi#{#mi$O#mi(q#mi(x#mi!]#mi!^#mi~O#x<VO~P&%jO#x#mi~P&%jO#v<TO~P&#iOP$[OR#zO[<_Oj<SOr<]O!Q#yO!S#{O!l#xO!p$[O#R<SO#n<PO#o<QO#p<QO#q<QO#r<RO#s<SO#t<SO#u<^O#v<TO#x<VO(`VO(x#|O(y#}O#{#mi$O#mi(q#mi!]#mi!^#mi~O#z#mi~P&'yO#z<XO~P&'yOa#|y!]#|y'y#|y'v#|y!Y#|y!k#|yv#|y!_#|y%i#|y!g#|y~P!:aO[#mij#mir#mi#R#mi#r#mi#s#mi#t#mi#u#mi#v#mi#x#mi#z#mi#{#mi$O#mi(q#mi!]#mi!^#mi~OP$[OR#zO!Q#yO!S#{O!l#xO!p$[O#n<PO#o<QO#p<QO#q<QO(`VO(x#mi(y#mi~P&*uOn=}O!Q)|O'x)}O(x$}O(y%POP#miR#mi!S#mi!l#mi!p#mi#n#mi#o#mi#p#mi#q#mi(`#mi~P&*uO#S$dOP(_XR(_X[(_Xj(_Xn(_Xr(_X!Q(_X!S(_X!l(_X!p(_X#R(_X#n(_X#o(_X#p(_X#q(_X#r(_X#s(_X#t(_X#u(_X#v(_X#x(_X#z(_X#{(_X$O(_X'x(_X(`(_X(q(_X(x(_X(y(_X!](_X!^(_X~O$O$Pi!]$Pi!^$Pi~P#B]O$O!ri!^!ri~P$*bOg'[a!]'[a~P!0{O!^7dO~O!]'ca!^'ca~P#B]O!Y7eO~P#/XO!g#vO(q'nO!]'da!k'da~O!]/kO!k(}i~O!]/kO!g#vO!k(}i~Og$|q!]$|q#`$|q$O$|q~P!0{O!Y'fa!]'fa~P#/XO!g7lO~O!]/sO!Y)Oi~P#/XO!]/sO!Y)Oi~O!Y7oO~Oh%VOr7tO!l%dO(q'nO~Oj7vO!g#vO~Or7yO!g#vO(q'nO~O!Q)|O'x)}O(y%POn'ia(x'ia!]'ia#`'ia~Og'ia$O'ia~P&3vO!Q)|O'x)}On'ka(x'ka(y'ka!]'ka#`'ka~Og'ka$O'ka~P&4iO!Y7{O~Og%Oq!]%Oq#`%Oq$O%Oq~P!0{Og(^q!](^q~P!0{O#`7|Og(^q!](^q~P!0{Oa$oy!]$oy'y$oy'v$oy!Y$oy!k$oyv$oy!_$oy%i$oy!g$oy~P!:aO!g6hO~O!]5RO!_)Pa~O!_'^OP$TaR$Ta[$Taj$Tar$Ta!Q$Ta!S$Ta!]$Ta!l$Ta!p$Ta#R$Ta#n$Ta#o$Ta#p$Ta#q$Ta#r$Ta#s$Ta#t$Ta#u$Ta#v$Ta#x$Ta#z$Ta#{$Ta(`$Ta(q$Ta(x$Ta(y$Ta~O%i6|O~P&7ZO%^8QOa%[i!_%[i'y%[i!]%[i~Oa#cy!]#cy'y#cy'v#cy!Y#cy!k#cyv#cy!_#cy%i#cy!g#cy~P!:aO[8SO~Ob8UO(S+nO(UTO(XUO~O!]0}O!^)Wi~O`8YO~O(d(zO!]'oX!^'oX~O!]5kO!^)Ta~O!^8cO~P%:YO(n!sO~P$${O#[8dO~O!_1gO~O!_1gO%i8fO~On8iO!_1gO%i8fO~O[8nO!]'ra!^'ra~O!]1rO!^)Ui~O!k8rO~O!k8sO~O!k8vO~O!k8vO~P%[Oa8xO~O!g8yO~O!k8zO~O!](vi!^(vi~P#B]Oa%mO#`9SO'y%mO~O!](sy!k(sya(sy'y(sy~P!:aO!](hO!k(ry~O%i9VO~P&7ZO!_'^O%i9VO~O#k$|qP$|qR$|q[$|qa$|qj$|qr$|q!S$|q!]$|q!l$|q!p$|q#R$|q#n$|q#o$|q#p$|q#q$|q#r$|q#s$|q#t$|q#u$|q#v$|q#x$|q#z$|q#{$|q'y$|q(`$|q(q$|q!k$|q!Y$|q'v$|q#`$|qv$|q!_$|q%i$|q!g$|q~P#/XO#k'iaP'iaR'ia['iaa'iaj'iar'ia!S'ia!l'ia!p'ia#R'ia#n'ia#o'ia#p'ia#q'ia#r'ia#s'ia#t'ia#u'ia#v'ia#x'ia#z'ia#{'ia'y'ia(`'ia(q'ia!k'ia!Y'ia'v'iav'ia!_'ia%i'ia!g'ia~P&3vO#k'kaP'kaR'ka['kaa'kaj'kar'ka!S'ka!l'ka!p'ka#R'ka#n'ka#o'ka#p'ka#q'ka#r'ka#s'ka#t'ka#u'ka#v'ka#x'ka#z'ka#{'ka'y'ka(`'ka(q'ka!k'ka!Y'ka'v'kav'ka!_'ka%i'ka!g'ka~P&4iO#k%OqP%OqR%Oq[%Oqa%Oqj%Oqr%Oq!S%Oq!]%Oq!l%Oq!p%Oq#R%Oq#n%Oq#o%Oq#p%Oq#q%Oq#r%Oq#s%Oq#t%Oq#u%Oq#v%Oq#x%Oq#z%Oq#{%Oq'y%Oq(`%Oq(q%Oq!k%Oq!Y%Oq'v%Oq#`%Oqv%Oq!_%Oq%i%Oq!g%Oq~P#/XO!]'Xi!k'Xi~P!:aO$O#cq!]#cq!^#cq~P#B]O(x$}OP%aaR%aa[%aaj%aar%aa!S%aa!l%aa!p%aa#R%aa#n%aa#o%aa#p%aa#q%aa#r%aa#s%aa#t%aa#u%aa#v%aa#x%aa#z%aa#{%aa$O%aa(`%aa(q%aa!]%aa!^%aa~On%aa!Q%aa'x%aa(y%aa~P&HnO(y%POP%caR%ca[%caj%car%ca!S%ca!l%ca!p%ca#R%ca#n%ca#o%ca#p%ca#q%ca#r%ca#s%ca#t%ca#u%ca#v%ca#x%ca#z%ca#{%ca$O%ca(`%ca(q%ca!]%ca!^%ca~On%ca!Q%ca'x%ca(x%ca~P&JuOn=}O!Q)|O'x)}O(y%PO~P&HnOn=}O!Q)|O'x)}O(x$}O~P&JuOR0cO!Q0cO!S0dO#S$dOP}a[}aj}an}ar}a!l}a!p}a#R}a#n}a#o}a#p}a#q}a#r}a#s}a#t}a#u}a#v}a#x}a#z}a#{}a$O}a'x}a(`}a(q}a(x}a(y}a!]}a!^}a~O!Q)|O'x)}OP$saR$sa[$saj$san$sar$sa!S$sa!l$sa!p$sa#R$sa#n$sa#o$sa#p$sa#q$sa#r$sa#s$sa#t$sa#u$sa#v$sa#x$sa#z$sa#{$sa$O$sa(`$sa(q$sa(x$sa(y$sa!]$sa!^$sa~O!Q)|O'x)}OP$uaR$ua[$uaj$uan$uar$ua!S$ua!l$ua!p$ua#R$ua#n$ua#o$ua#p$ua#q$ua#r$ua#s$ua#t$ua#u$ua#v$ua#x$ua#z$ua#{$ua$O$ua(`$ua(q$ua(x$ua(y$ua!]$ua!^$ua~On=}O!Q)|O'x)}O(x$}O(y%PO~OP%TaR%Ta[%Taj%Tar%Ta!S%Ta!l%Ta!p%Ta#R%Ta#n%Ta#o%Ta#p%Ta#q%Ta#r%Ta#s%Ta#t%Ta#u%Ta#v%Ta#x%Ta#z%Ta#{%Ta$O%Ta(`%Ta(q%Ta!]%Ta!^%Ta~P'%zO$O$mq!]$mq!^$mq~P#B]O$O$oq!]$oq!^$oq~P#B]O!^9dO~O$O9eO~P!0{O!g#vO!]'di!k'di~O!g#vO(q'nO!]'di!k'di~O!]/kO!k(}q~O!Y'fi!]'fi~P#/XO!]/sO!Y)Oq~Or9lO!g#vO(q'nO~O[9nO!Y9mO~P#/XO!Y9mO~Oj9tO!g#vO~Og(^y!](^y~P!0{O!]'ma!_'ma~P#/XOa%[q!_%[q'y%[q!]%[q~P#/XO[9yO~O!]0}O!^)Wq~O#`9}O!]'oa!^'oa~O!]5kO!^)Ti~P#B]O!S:PO~O!_1gO%i:SO~O(UTO(XUO(d:XO~O!]1rO!^)Uq~O!k:[O~O!k:]O~O!k:^O~O!k:^O~P%[O#`:aO!]#hy!^#hy~O!]#hy!^#hy~P#B]O%i:fO~P&7ZO!_'^O%i:fO~O$O#|y!]#|y!^#|y~P#B]OP$|iR$|i[$|ij$|ir$|i!S$|i!l$|i!p$|i#R$|i#n$|i#o$|i#p$|i#q$|i#r$|i#s$|i#t$|i#u$|i#v$|i#x$|i#z$|i#{$|i$O$|i(`$|i(q$|i!]$|i!^$|i~P'%zO!Q)|O'x)}O(y%POP'haR'ha['haj'han'har'ha!S'ha!l'ha!p'ha#R'ha#n'ha#o'ha#p'ha#q'ha#r'ha#s'ha#t'ha#u'ha#v'ha#x'ha#z'ha#{'ha$O'ha(`'ha(q'ha(x'ha!]'ha!^'ha~O!Q)|O'x)}OP'jaR'ja['jaj'jan'jar'ja!S'ja!l'ja!p'ja#R'ja#n'ja#o'ja#p'ja#q'ja#r'ja#s'ja#t'ja#u'ja#v'ja#x'ja#z'ja#{'ja$O'ja(`'ja(q'ja(x'ja(y'ja!]'ja!^'ja~O(x$}OP%aiR%ai[%aij%ain%air%ai!Q%ai!S%ai!l%ai!p%ai#R%ai#n%ai#o%ai#p%ai#q%ai#r%ai#s%ai#t%ai#u%ai#v%ai#x%ai#z%ai#{%ai$O%ai'x%ai(`%ai(q%ai(y%ai!]%ai!^%ai~O(y%POP%ciR%ci[%cij%cin%cir%ci!Q%ci!S%ci!l%ci!p%ci#R%ci#n%ci#o%ci#p%ci#q%ci#r%ci#s%ci#t%ci#u%ci#v%ci#x%ci#z%ci#{%ci$O%ci'x%ci(`%ci(q%ci(x%ci!]%ci!^%ci~O$O$oy!]$oy!^$oy~P#B]O$O#cy!]#cy!^#cy~P#B]O!g#vO!]'dq!k'dq~O!]/kO!k(}y~O!Y'fq!]'fq~P#/XOr:pO!g#vO(q'nO~O[:tO!Y:sO~P#/XO!Y:sO~Og(^!R!](^!R~P!0{Oa%[y!_%[y'y%[y!]%[y~P#/XO!]0}O!^)Wy~O!]5kO!^)Tq~O(S:zO~O!_1gO%i:}O~O!k;QO~O%i;VO~P&7ZOP$|qR$|q[$|qj$|qr$|q!S$|q!l$|q!p$|q#R$|q#n$|q#o$|q#p$|q#q$|q#r$|q#s$|q#t$|q#u$|q#v$|q#x$|q#z$|q#{$|q$O$|q(`$|q(q$|q!]$|q!^$|q~P'%zO!Q)|O'x)}O(y%POP'iaR'ia['iaj'ian'iar'ia!S'ia!l'ia!p'ia#R'ia#n'ia#o'ia#p'ia#q'ia#r'ia#s'ia#t'ia#u'ia#v'ia#x'ia#z'ia#{'ia$O'ia(`'ia(q'ia(x'ia!]'ia!^'ia~O!Q)|O'x)}OP'kaR'ka['kaj'kan'kar'ka!S'ka!l'ka!p'ka#R'ka#n'ka#o'ka#p'ka#q'ka#r'ka#s'ka#t'ka#u'ka#v'ka#x'ka#z'ka#{'ka$O'ka(`'ka(q'ka(x'ka(y'ka!]'ka!^'ka~OP%OqR%Oq[%Oqj%Oqr%Oq!S%Oq!l%Oq!p%Oq#R%Oq#n%Oq#o%Oq#p%Oq#q%Oq#r%Oq#s%Oq#t%Oq#u%Oq#v%Oq#x%Oq#z%Oq#{%Oq$O%Oq(`%Oq(q%Oq!]%Oq!^%Oq~P'%zOg%e!Z!]%e!Z#`%e!Z$O%e!Z~P!0{O!Y;ZO~P#/XOr;[O!g#vO(q'nO~O[;^O!Y;ZO~P#/XO!]'oq!^'oq~P#B]O!]#h!Z!^#h!Z~P#B]O#k%e!ZP%e!ZR%e!Z[%e!Za%e!Zj%e!Zr%e!Z!S%e!Z!]%e!Z!l%e!Z!p%e!Z#R%e!Z#n%e!Z#o%e!Z#p%e!Z#q%e!Z#r%e!Z#s%e!Z#t%e!Z#u%e!Z#v%e!Z#x%e!Z#z%e!Z#{%e!Z'y%e!Z(`%e!Z(q%e!Z!k%e!Z!Y%e!Z'v%e!Z#`%e!Zv%e!Z!_%e!Z%i%e!Z!g%e!Z~P#/XOr;fO!g#vO(q'nO~O!Y;gO~P#/XOr;nO!g#vO(q'nO~O!Y;oO~P#/XOP%e!ZR%e!Z[%e!Zj%e!Zr%e!Z!S%e!Z!l%e!Z!p%e!Z#R%e!Z#n%e!Z#o%e!Z#p%e!Z#q%e!Z#r%e!Z#s%e!Z#t%e!Z#u%e!Z#v%e!Z#x%e!Z#z%e!Z#{%e!Z$O%e!Z(`%e!Z(q%e!Z!]%e!Z!^%e!Z~P'%zOr;rO!g#vO(q'nO~Ov(eX~P1qO!Q%qO~P!)PO(T!lO~P!)PO!YfX!]fX#`fX~P%0kOP]XR]X[]Xj]Xr]X!Q]X!S]X!]]X!]fX!l]X!p]X#R]X#S]X#`]X#`fX#kfX#n]X#o]X#p]X#q]X#r]X#s]X#t]X#u]X#v]X#x]X#z]X#{]X$Q]X(`]X(q]X(x]X(y]X~O!gfX!k]X!kfX(qfX~P'JsOP;vOQ;vOSfOd=rOe!iOpkOr;vOskOtkOzkO|;vO!O;vO!SWO!WkO!XkO!_XO!i;yO!lZO!o;vO!p;vO!q;vO!s;zO!u;}O!x!hO$W!kO$n=pO(S)ZO(UTO(XUO(`VO(n[O~O!]<ZO!^$qa~Oh%VOp%WOr%XOs$tOt$tOz%YO|%ZO!O<fO!S${O!_$|O!i=wO!l$xO#j<lO$W%_O$t<hO$v<jO$y%`O(S(tO(UTO(XUO(`$uO(x$}O(y%PO~Ol)bO~P( iOr!eX(q!eX~P# }Or(iX(q(iX~P#!pO!^]X!^fX~P'JsO!YfX!Y$zX!]fX!]$zX#`fX~P!/wO#k<OO~O!g#vO#k<OO~O#`<`O~Oj<SO~O#`<pO!](vX!^(vX~O#`<`O!](tX!^(tX~O#k<qO~Og<sO~P!0{O#k<yO~O#k<zO~O!g#vO#k<{O~O!g#vO#k<qO~O$O<|O~P#B]O#k<}O~O#k=OO~O#k=TO~O#k=UO~O#k=VO~O#k=WO~O$O=XO~P!0{O$O=YO~P!0{Ok#S#T#U#W#X#[#i#j#u$n$t$v$y%]%^%h%i%j%q%s%v%w%y%{~'}T#o!X'{(T#ps#n#qr!Q'|$]'|(S$_(d~",goto:"$8g)[PPPPPP)]PP)`P)qP+R/WPPPP6bPP6xPP<pPPP@dP@zP@zPPP@zPCSP@zP@zP@zPCWPC]PCzPHtPPPHxPPPPHxK{PPPLRLsPHxPHxPP! RHxPPPHxPHxP!#YHxP!&p!'u!(OP!(r!(v!(r!,TPPPPPPP!,t!'uPP!-U!.vP!2SHxHx!2X!5e!:R!:R!>QPPP!>YHxPPPPPPPPP!AiP!BvPPHx!DXPHxPHxHxHxHxHxPHx!EkP!HuP!K{P!LP!LZ!L_!L_P!HrP!Lc!LcP# iP# mHxPHx# s#$xCW@zP@zP@z@zP#&V@z@z#(i@z#+a@z#-m@z@z#.]#0q#0q#0v#1P#0q#1[PP#0qP@z#1t@z#5s@z@z6bPPP#9xPPP#:c#:cP#:cP#:y#:cPP#;PP#:vP#:v#;d#:v#<O#<U#<X)`#<[)`P#<c#<c#<cP)`P)`P)`P)`PP)`P#<i#<lP#<l)`P#<pP#<sP)`P)`P)`P)`P)`P)`)`PP#<y#=P#=[#=b#=h#=n#=t#>S#>Y#>d#>j#>t#>z#?[#?b#@S#@f#@l#@r#AQ#Ag#C[#Cj#Cq#E]#Ek#G]#Gk#Gq#Gw#G}#HX#H_#He#Ho#IR#IXPPPPPPPPPPP#I_PPPPPPP#JS#MZ#Ns#Nz$ SPPP$&nP$&w$)p$0Z$0^$0a$1`$1c$1j$1rP$1x$1{P$2i$2m$3e$4s$4x$5`PP$5e$5k$5o$5r$5v$5z$6v$7_$7v$7z$7}$8Q$8W$8Z$8_$8cR!|RoqOXst!Z#d%l&p&r&s&u,n,s2S2VY!vQ'^-`1g5qQ%svQ%{yQ&S|Q&h!VS'U!e-WQ'd!iS'j!r!yU*h$|*X*lQ+l%|Q+y&UQ,_&bQ-^']Q-h'eQ-p'kQ0U*nQ1q,`R<m;z%SdOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%l%s&Q&i&l&p&r&s&u&y'R'`'p(R(T(Z(b(v(x(|){*f+U+Y,k,n,s-d-l-z.Q.o.v/i0V0d0l0|1j1z1{1}2P2S2V2X2x3O3d4q5y6Z6[6_6r8i8x9SS#q];w!r)]$Z$n'V)q-P-S/Q2h3{5m6i9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sU*{%[<e<fQ+q&OQ,a&eQ,h&mQ0r+dQ0w+fQ1S+rQ1y,fQ3W.bQ5V0vQ5]0}Q6Q1rQ7O3[Q8U5^R9Y7Q'QkOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%l%s&Q&i&l&m&p&r&s&u&y'R'V'`'p(R(T(Z(b(v(x(|)q){*f+U+Y+d,k,n,s-P-S-d-l-z.Q.b.o.v/Q/i0V0d0l0|1j1z1{1}2P2S2V2X2h2x3O3[3d3{4q5m5y6Z6[6_6i6r7Q8i8x9S9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=s!S!nQ!r!v!y!z$|'U']'^'j'k'l*h*l*n*o-W-^-`-p0U0X1g5q5s%[$ti#v$b$c$d$x${%O%Q%]%^%b)w*P*R*T*W*^*d*t*u+c+f+},Q.a.z/_/h/r/s/u0Y0[0g0h0i1^1a1i3Z4U4V4a4f4w5R5U5x6|7l7v7|8Q8f9V9e9n9t:S:f:t:};V;^<^<_<a<b<c<d<g<h<i<j<k<l<t<u<v<w<y<z<}=O=P=Q=R=S=T=U=X=Y=p=x=y=|=}Q&V|Q'S!eS'Y%h-ZQ+q&OQ,a&eQ0f+OQ1S+rQ1X+xQ1x,eQ1y,fQ5]0}Q5f1ZQ6Q1rQ6T1tQ6U1wQ8U5^Q8X5cQ8q6WQ9|8YQ:Y8nR<o*XrnOXst!V!Z#d%l&g&p&r&s&u,n,s2S2VR,c&i&z^OPXYstuvwz!Z!`!g!j!o#S#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%l%s&Q&i&l&m&p&r&s&u&y'R'`'p(T(Z(b(v(x(|)q){*f+U+Y+d,k,n,s-P-S-d-l-z.Q.b.o.v/Q/i0V0d0l0|1j1z1{1}2P2S2V2X2h2x3O3[3d3{4q5m5y6Z6[6_6i6r7Q8i8x9S9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=r=s[#]WZ#W#Z'V(R!b%im#h#i#l$x%d%g([(f(g(h*W*[*_+W+X+Z,j-Q.O.U.V.W.Y/h/k2[3S3T4X6h6yQ%vxQ%zyS&P|&UQ&]!TQ'a!hQ'c!iQ(o#sS+k%{%|Q+o&OQ,Y&`Q,^&bS-g'd'eQ.d(pQ0{+lQ1R+rQ1T+sQ1W+wQ1l,ZS1p,_,`Q2t-hQ5[0}Q5`1QQ5e1YQ6P1qQ8T5^Q8W5bQ9x8SR:w9y!U$zi$d%O%Q%]%^%b*P*R*^*t*u.z/r0Y0[0g0h0i4V4w7|9e=p=x=y!^%xy!i!u%z%{%|'T'c'd'e'i's*g+k+l-T-g-h-o/{0O0{2m2t2{4i4j4m7s9pQ+e%vQ,O&YQ,R&ZQ,]&bQ.c(oQ1k,YU1o,^,_,`Q3].dQ5z1lS6O1p1qQ8m6P#f=t#v$b$c$x${)w*T*W*d+c+f+},Q.a/_/h/s/u1^1a1i3Z4U4a4f5R5U5x6|7l7v8Q8f9V9n9t:S:f:t:};V;^<a<c<g<i<k<t<v<y<}=P=R=T=X=|=}o=u<^<_<b<d<h<j<l<u<w<z=O=Q=S=U=YW%Ti%V*v=pS&Y!Q&gQ&Z!RQ&[!SQ+S%cR+|&W%]%Si#v$b$c$d$x${%O%Q%]%^%b)w*P*R*T*W*^*d*t*u+c+f+},Q.a.z/_/h/r/s/u0Y0[0g0h0i1^1a1i3Z4U4V4a4f4w5R5U5x6|7l7v7|8Q8f9V9e9n9t:S:f:t:};V;^<^<_<a<b<c<d<g<h<i<j<k<l<t<u<v<w<y<z<}=O=P=Q=R=S=T=U=X=Y=p=x=y=|=}T)x$u)yV*{%[<e<fW'Y!e%h*X-ZS({#y#zQ+`%qQ+v&RS.](k(lQ1b,SQ4x0cR8^5k'QkOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%l%s&Q&i&l&m&p&r&s&u&y'R'V'`'p(R(T(Z(b(v(x(|)q){*f+U+Y+d,k,n,s-P-S-d-l-z.Q.b.o.v/Q/i0V0d0l0|1j1z1{1}2P2S2V2X2h2x3O3[3d3{4q5m5y6Z6[6_6i6r7Q8i8x9S9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=s$i$^c#Y#e%p%r%t(Q(W(r(w)P)Q)R)S)T)U)V)W)X)Y)[)^)`)e)o+a+u-U-s-x-}.P.n.q.u.w.x.y/]0j2c2f2v2}3c3h3i3j3k3l3m3n3o3p3q3r3s3t3w3x4P5O5Y6k6q6v7V7W7a7b8`8|9Q9[9b9c:c:y;R;x=gT#TV#U'RkOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%l%s&Q&i&l&m&p&r&s&u&y'R'V'`'p(R(T(Z(b(v(x(|)q){*f+U+Y+d,k,n,s-P-S-d-l-z.Q.b.o.v/Q/i0V0d0l0|1j1z1{1}2P2S2V2X2h2x3O3[3d3{4q5m5y6Z6[6_6i6r7Q8i8x9S9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sQ'W!eR2i-W!W!nQ!e!r!v!y!z$|'U']'^'j'k'l*X*h*l*n*o-W-^-`-p0U0X1g5q5sR1d,UnqOXst!Z#d%l&p&r&s&u,n,s2S2VQ&w!^Q't!xS(q#u<OQ+i%yQ,W&]Q,X&_Q-e'bQ-r'mS.m(v<qS0k+U<{Q0y+jQ1f,VQ2Z,uQ2],vQ2e-RQ2r-fQ2u-jS5P0l=VQ5W0zS5Z0|=WQ6j2gQ6n2sQ6s2zQ8R5XQ8}6lQ9O6oQ9R6tR:`8z$d$]c#Y#e%r%t(Q(W(r(w)P)Q)R)S)T)U)V)W)X)Y)[)^)`)e)o+a+u-U-s-x-}.P.n.q.u.x.y/]0j2c2f2v2}3c3h3i3j3k3l3m3n3o3p3q3r3s3t3w3x4P5O5Y6k6q6v7V7W7a7b8`8|9Q9[9b9c:c:y;R;x=gS(m#p'gQ(}#zS+_%p.wS.^(l(nR3U._'QkOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%l%s&Q&i&l&m&p&r&s&u&y'R'V'`'p(R(T(Z(b(v(x(|)q){*f+U+Y+d,k,n,s-P-S-d-l-z.Q.b.o.v/Q/i0V0d0l0|1j1z1{1}2P2S2V2X2h2x3O3[3d3{4q5m5y6Z6[6_6i6r7Q8i8x9S9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sS#q];wQ&r!XQ&s!YQ&u![Q&v!]R2R,qQ'_!hQ+b%vQ-c'aS.`(o+eQ2p-bW3Y.c.d0q0sQ6m2qW6z3V3X3]5TU9U6{6}7PU:e9W9X9ZS;T:d:gQ;b;UR;j;cU!wQ'^-`T5o1g5q!Q_OXZ`st!V!Z#d#h%d%l&g&i&p&r&s&u(h,n,s.V2S2V]!pQ!r'^-`1g5qT#q];w%^{OPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%l%s&Q&i&l&m&p&r&s&u&y'R'`'p(R(T(Z(b(v(x(|){*f+U+Y+d,k,n,s-d-l-z.Q.b.o.v/i0V0d0l0|1j1z1{1}2P2S2V2X2x3O3[3d4q5y6Z6[6_6r7Q8i8x9SS({#y#zS.](k(l!s=^$Z$n'V)q-P-S/Q2h3{5m6i9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sU$fd)],hS(n#p'gU*s%R(u3vU0e*z.i7]Q5T0rQ6{3WQ9X7OR:g9Ym!tQ!r!v!y!z'^'j'k'l-`-p1g5q5sQ'r!uS(d#g1|S-n'i'uQ/n*ZQ/{*gQ2|-qQ4]/oQ4i/}Q4j0OQ4o0WQ7h4WS7s4k4mS7w4p4rQ9g7iQ9k7oQ9p7tQ9u7yS:o9l9mS;Y:p:sS;e;Z;[S;m;f;gS;q;n;oR;t;rQ#wbQ'q!uS(c#g1|S(e#m+TQ+V%eQ+g%wQ+m%}U-m'i'r'uQ.R(dQ/m*ZQ/|*gQ0P*iQ0x+hQ1m,[S2y-n-qQ3R.ZS4[/n/oQ4e/yS4h/{0WQ4l0QQ5|1nQ6u2|Q7g4WQ7k4]U7r4i4o4rQ7u4nQ8k5}S9f7h7iQ9j7oQ9r7wQ9s7xQ:V8lQ:m9gS:n9k9mQ:v9uQ;P:WS;X:o:sS;d;Y;ZS;l;e;gS;p;m;oQ;s;qQ;u;tQ=a=[Q=l=eR=m=fV!wQ'^-`%^aOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%l%s&Q&i&l&m&p&r&s&u&y'R'`'p(R(T(Z(b(v(x(|){*f+U+Y+d,k,n,s-d-l-z.Q.b.o.v/i0V0d0l0|1j1z1{1}2P2S2V2X2x3O3[3d4q5y6Z6[6_6r7Q8i8x9SS#wz!j!r=Z$Z$n'V)q-P-S/Q2h3{5m6i9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sR=a=r%^bOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%l%s&Q&i&l&m&p&r&s&u&y'R'`'p(R(T(Z(b(v(x(|){*f+U+Y+d,k,n,s-d-l-z.Q.b.o.v/i0V0d0l0|1j1z1{1}2P2S2V2X2x3O3[3d4q5y6Z6[6_6r7Q8i8x9SQ%ej!^%wy!i!u%z%{%|'T'c'd'e'i's*g+k+l-T-g-h-o/{0O0{2m2t2{4i4j4m7s9pS%}z!jQ+h%xQ,[&bW1n,],^,_,`U5}1o1p1qS8l6O6PQ:W8m!r=[$Z$n'V)q-P-S/Q2h3{5m6i9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sQ=e=qR=f=r%QeOPXYstuvw!Z!`!g!o#S#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%l%s&Q&i&l&p&r&s&u&y'R'`'p(T(Z(b(v(x(|){*f+U+Y+d,k,n,s-d-l-z.Q.b.o.v/i0V0d0l0|1j1z1{1}2P2S2V2X2x3O3[3d4q5y6Z6[6_6r7Q8i8x9SY#bWZ#W#Z(R!b%im#h#i#l$x%d%g([(f(g(h*W*[*_+W+X+Z,j-Q.O.U.V.W.Y/h/k2[3S3T4X6h6yQ,i&m!p=]$Z$n)q-P-S/Q2h3{5m6i9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sR=`'VU'Z!e%h*XR2k-Z%SdOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%l%s&Q&i&l&p&r&s&u&y'R'`'p(R(T(Z(b(v(x(|){*f+U+Y,k,n,s-d-l-z.Q.o.v/i0V0d0l0|1j1z1{1}2P2S2V2X2x3O3d4q5y6Z6[6_6r8i8x9S!r)]$Z$n'V)q-P-S/Q2h3{5m6i9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sQ,h&mQ0r+dQ3W.bQ7O3[R9Y7Q!b$Tc#Y%p(Q(W(r(w)X)Y)^)e+u-s-x-}.P.n.q/]0j2v2}3c3s5O5Y6q6v7V9Q:c;x!P<U)[)o-U.w2c2f3h3q3r3w4P6k7W7a7b8`8|9[9b9c:y;R=g!f$Vc#Y%p(Q(W(r(w)U)V)X)Y)^)e+u-s-x-}.P.n.q/]0j2v2}3c3s5O5Y6q6v7V9Q:c;x!T<W)[)o-U.w2c2f3h3n3o3q3r3w4P6k7W7a7b8`8|9[9b9c:y;R=g!^$Zc#Y%p(Q(W(r(w)^)e+u-s-x-}.P.n.q/]0j2v2}3c3s5O5Y6q6v7V9Q:c;xQ4V/fz=s)[)o-U.w2c2f3h3w4P6k7W7a7b8`8|9[9b9c:y;R=gQ=x=zR=y={'QkOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%l%s&Q&i&l&m&p&r&s&u&y'R'V'`'p(R(T(Z(b(v(x(|)q){*f+U+Y+d,k,n,s-P-S-d-l-z.Q.b.o.v/Q/i0V0d0l0|1j1z1{1}2P2S2V2X2h2x3O3[3d3{4q5m5y6Z6[6_6i6r7Q8i8x9S9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sS$oh$pR3|/P'XgOPWXYZhstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n$p%l%s&Q&i&l&m&p&r&s&u&y'R'V'`'p(R(T(Z(b(v(x(|)q){*f+U+Y+d,k,n,s-P-S-d-l-z.Q.b.o.v/P/Q/i0V0d0l0|1j1z1{1}2P2S2V2X2h2x3O3[3d3{4q5m5y6Z6[6_6i6r7Q8i8x9S9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sT$kf$qQ$ifS)h$l)lR)t$qT$jf$qT)j$l)l'XhOPWXYZhstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n$p%l%s&Q&i&l&m&p&r&s&u&y'R'V'`'p(R(T(Z(b(v(x(|)q){*f+U+Y+d,k,n,s-P-S-d-l-z.Q.b.o.v/P/Q/i0V0d0l0|1j1z1{1}2P2S2V2X2h2x3O3[3d3{4q5m5y6Z6[6_6i6r7Q8i8x9S9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=sT$oh$pQ$rhR)s$p%^jOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%l%s&Q&i&l&m&p&r&s&u&y'R'`'p(R(T(Z(b(v(x(|){*f+U+Y+d,k,n,s-d-l-z.Q.b.o.v/i0V0d0l0|1j1z1{1}2P2S2V2X2x3O3[3d4q5y6Z6[6_6r7Q8i8x9S!s=q$Z$n'V)q-P-S/Q2h3{5m6i9}:a;v;y;z;}<O<P<Q<R<S<T<U<V<W<X<Y<Z<]<`<m<p<q<s<{<|=V=W=s#glOPXZst!Z!`!o#S#d#o#{$n%l&i&l&m&p&r&s&u&y'R'`(|)q*f+Y+d,k,n,s-d.b/Q/i0V0d1j1z1{1}2P2S2V2X3[3{4q5y6Z6[6_7Q8i8x!U%Ri$d%O%Q%]%^%b*P*R*^*t*u.z/r0Y0[0g0h0i4V4w7|9e=p=x=y#f(u#v$b$c$x${)w*T*W*d+c+f+},Q.a/_/h/s/u1^1a1i3Z4U4a4f5R5U5x6|7l7v8Q8f9V9n9t:S:f:t:};V;^<a<c<g<i<k<t<v<y<}=P=R=T=X=|=}Q+P%`Q/^)|o3v<^<_<b<d<h<j<l<u<w<z=O=Q=S=U=Y!U$yi$d%O%Q%]%^%b*P*R*^*t*u.z/r0Y0[0g0h0i4V4w7|9e=p=x=yQ*`$zU*i$|*X*lQ+Q%aQ0Q*j#f=c#v$b$c$x${)w*T*W*d+c+f+},Q.a/_/h/s/u1^1a1i3Z4U4a4f5R5U5x6|7l7v8Q8f9V9n9t:S:f:t:};V;^<a<c<g<i<k<t<v<y<}=P=R=T=X=|=}n=d<^<_<b<d<h<j<l<u<w<z=O=Q=S=U=YQ=h=tQ=i=uQ=j=vR=k=w!U%Ri$d%O%Q%]%^%b*P*R*^*t*u.z/r0Y0[0g0h0i4V4w7|9e=p=x=y#f(u#v$b$c$x${)w*T*W*d+c+f+},Q.a/_/h/s/u1^1a1i3Z4U4a4f5R5U5x6|7l7v8Q8f9V9n9t:S:f:t:};V;^<a<c<g<i<k<t<v<y<}=P=R=T=X=|=}o3v<^<_<b<d<h<j<l<u<w<z=O=Q=S=U=YnoOXst!Z#d%l&p&r&s&u,n,s2S2VS*c${*WQ,|&|Q,}'OR4`/s%[%Si#v$b$c$d$x${%O%Q%]%^%b)w*P*R*T*W*^*d*t*u+c+f+},Q.a.z/_/h/r/s/u0Y0[0g0h0i1^1a1i3Z4U4V4a4f4w5R5U5x6|7l7v7|8Q8f9V9e9n9t:S:f:t:};V;^<^<_<a<b<c<d<g<h<i<j<k<l<t<u<v<w<y<z<}=O=P=Q=R=S=T=U=X=Y=p=x=y=|=}Q,P&ZQ1`,RQ5i1_R8]5jV*k$|*X*lU*k$|*X*lT5p1g5qS/y*f/iQ4n0VT7x4q:PQ+g%wQ0P*iQ0x+hQ1m,[Q5|1nQ8k5}Q:V8lR;P:W!U%Oi$d%O%Q%]%^%b*P*R*^*t*u.z/r0Y0[0g0h0i4V4w7|9e=p=x=yx*P$v)c*Q*r+R/q0^0_3y4^4{4|4}7f7z9v:l=b=n=oS0Y*q0Z#f<a#v$b$c$x${)w*T*W*d+c+f+},Q.a/_/h/s/u1^1a1i3Z4U4a4f5R5U5x6|7l7v8Q8f9V9n9t:S:f:t:};V;^<a<c<g<i<k<t<v<y<}=P=R=T=X=|=}n<b<^<_<b<d<h<j<l<u<w<z=O=Q=S=U=Y!d<t(s)a*Y*b.e.h.l/Y/f/v0p1]3`4S4_4c5h7R7U7m7p7}8P9i9q9w:q:u;W;];h=z={`<u3u7X7[7`9]:h:k;kS=P.g3aT=Q7Z9`!U%Qi$d%O%Q%]%^%b*P*R*^*t*u.z/r0Y0[0g0h0i4V4w7|9e=p=x=y|*R$v)c*S*q+R/b/q0^0_3y4^4s4{4|4}7f7z9v:l=b=n=oS0[*r0]#f<c#v$b$c$x${)w*T*W*d+c+f+},Q.a/_/h/s/u1^1a1i3Z4U4a4f5R5U5x6|7l7v8Q8f9V9n9t:S:f:t:};V;^<a<c<g<i<k<t<v<y<}=P=R=T=X=|=}n<d<^<_<b<d<h<j<l<u<w<z=O=Q=S=U=Y!h<v(s)a*Y*b.f.g.l/Y/f/v0p1]3^3`4S4_4c5h7R7S7U7m7p7}8P9i9q9w:q:u;W;];h=z={d<w3u7Y7Z7`9]9^:h:i:k;kS=R.h3bT=S7[9arnOXst!V!Z#d%l&g&p&r&s&u,n,s2S2VQ&d!UR,k&mrnOXst!V!Z#d%l&g&p&r&s&u,n,s2S2VR&d!UQ,T&[R1[+|snOXst!V!Z#d%l&g&p&r&s&u,n,s2S2VQ1h,YS5w1k1lU8e5u5v5zS:R8g8hS:{:Q:TQ;_:|R;i;`Q&k!VR,d&gR6T1tR:Y8nS&P|&UR1T+sQ&p!WR,n&qR,t&vT2T,s2VR,x&wQ,w&wR2^,xQ'w!{R-t'wSsOtQ#dXT%os#dQ#OTR'y#OQ#RUR'{#RQ)y$uR/Z)yQ#UVR(O#UQ#XWU(U#X(V-{Q(V#YR-{(WQ-X'WR2j-XQ.p(wS3e.p3fR3f.qQ-`'^R2n-`Y!rQ'^-`1g5qR'h!rQ.{)cR3z.{U#_W%g*WU(]#_(^-|Q(^#`R-|(XQ-['ZR2l-[t`OXst!V!Z#d%l&g&i&p&r&s&u,n,s2S2VS#hZ%dU#r`#h.VR.V(hQ(i#jQ.S(eW.[(i.S3P6wQ3P.TR6w3QQ)l$lR/R)lQ$phR)r$pQ$`cU)_$`-w<[Q-w;xR<[)oQ/l*ZW4Y/l4Z7j9hU4Z/m/n/oS7j4[4]R9h7k$e*O$v(s)a)c*Y*b*q*r*|*}+R.g.h.j.k.l/Y/b/d/f/q/v0^0_0p1]3^3_3`3u3y4S4^4_4c4s4u4{4|4}5h7R7S7T7U7Z7[7^7_7`7f7m7p7z7}8P9]9^9_9i9q9v9w:h:i:j:k:l:q:u;W;];h;k=b=n=o=z={Q/t*bU4b/t4d7nQ4d/vR7n4cS*l$|*XR0S*lx*Q$v)c*q*r+R/q0^0_3y4^4{4|4}7f7z9v:l=b=n=o!d.e(s)a*Y*b.g.h.l/Y/f/v0p1]3`4S4_4c5h7R7U7m7p7}8P9i9q9w:q:u;W;];h=z={U/c*Q.e7Xa7X3u7Z7[7`9]:h:k;kQ0Z*qQ3a.gU4t0Z3a9`R9`7Z|*S$v)c*q*r+R/b/q0^0_3y4^4s4{4|4}7f7z9v:l=b=n=o!h.f(s)a*Y*b.g.h.l/Y/f/v0p1]3^3`4S4_4c5h7R7S7U7m7p7}8P9i9q9w:q:u;W;];h=z={U/e*S.f7Ye7Y3u7Z7[7`9]9^:h:i:k;kQ0]*rQ3b.hU4v0]3b9aR9a7[Q*w%UR0a*wQ5S0pR8O5SQ+[%jR0o+[Q5l1bS8_5l:OR:O8`Q,V&]R1e,VQ5q1gR8b5qQ1s,aS6R1s8oR8o6TQ1O+oW5_1O5a8V9zQ5a1RQ8V5`R9z8WQ+t&PR1U+tQ2V,sR6c2VYrOXst#dQ&t!ZQ+^%lQ,m&pQ,o&rQ,p&sQ,r&uQ2Q,nS2T,s2VR6b2SQ%npQ&x!_Q&{!aQ&}!bQ'P!cQ'o!uQ+]%kQ+i%yQ+{&VQ,c&kQ,z&zW-k'i'q'r'uQ-r'mQ0R*kQ0y+jS1v,d,gQ2_,yQ2`,|Q2a,}Q2u-jW2w-m-n-q-sQ5W0zQ5d1XQ5g1]Q5{1mQ6V1xQ6a2RU6p2v2y2|Q6s2zQ8R5XQ8Z5fQ8[5hQ8a5pQ8j5|Q8p6US9P6q6uQ9R6tQ9{8XQ:U8kQ:Z8qQ:b9QQ:x9|Q;O:VQ;S:cR;a;PQ%yyQ'b!iQ'm!uU+j%z%{%|Q-R'TU-f'c'd'eS-j'i'sQ/z*gS0z+k+lQ2g-TS2s-g-hQ2z-oS4g/{0OQ5X0{Q6l2mQ6o2tQ6t2{U7q4i4j4mQ9o7sR:r9pS$wi=pR*x%VU%Ui%V=pR0`*vQ$viS(s#v+fS)a$b$cQ)c$dQ*Y$xS*b${*WQ*q%OQ*r%QQ*|%]Q*}%^Q+R%bQ.g<aQ.h<cQ.j<gQ.k<iQ.l<kQ/Y)wQ/b*PQ/d*RQ/f*TQ/q*^S/v*d/hQ0^*tQ0_*ul0p+c,Q.a1a1i3Z5x6|8f9V:S:f:};VQ1]+}Q3^<tQ3_<vQ3`<yS3u<^<_Q3y.zS4S/_4UQ4^/rQ4_/sQ4c/uQ4s0YQ4u0[Q4{0gQ4|0hQ4}0iQ5h1^Q7R<}Q7S=PQ7T=RQ7U=TQ7Z<bQ7[<dQ7^<hQ7_<jQ7`<lQ7f4VQ7m4aQ7p4fQ7z4wQ7}5RQ8P5UQ9]<zQ9^<uQ9_<wQ9i7lQ9q7vQ9v7|Q9w8QQ:h=OQ:i=QQ:j=SQ:k=UQ:l9eQ:q9nQ:u9tQ;W=XQ;]:tQ;h;^Q;k=YQ=b=pQ=n=xQ=o=yQ=z=|R={=}Q*z%[Q.i<eR7]<fnpOXst!Z#d%l&p&r&s&u,n,s2S2VQ!fPS#fZ#oQ&z!`W'f!o*f0V4qQ'}#SQ)O#{Q)p$nS,g&i&lQ,l&mQ,y&yS-O'R/iQ-b'`Q.s(|Q/V)qQ0m+YQ0s+dQ2O,kQ2q-dQ3X.bQ4O/QQ4y0dQ5v1jQ6X1zQ6Y1{Q6^1}Q6`2PQ6e2XQ7P3[Q7c3{Q8h5yQ8t6ZQ8u6[Q8w6_Q9Z7QQ:T8iR:_8x#[cOPXZst!Z!`!o#d#o#{%l&i&l&m&p&r&s&u&y'R'`(|*f+Y+d,k,n,s-d.b/i0V0d1j1z1{1}2P2S2V2X3[4q5y6Z6[6_7Q8i8xQ#YWQ#eYQ%puQ%rvS%tw!gS(Q#W(TQ(W#ZQ(r#uQ(w#xQ)P$OQ)Q$PQ)R$QQ)S$RQ)T$SQ)U$TQ)V$UQ)W$VQ)X$WQ)Y$XQ)[$ZQ)^$_Q)`$aQ)e$eW)o$n)q/Q3{Q+a%sQ+u&QS-U'V2hQ-s'pS-x(R-zQ-}(ZQ.P(bQ.n(vQ.q(xQ.u;vQ.w;yQ.x;zQ.y;}Q/]){Q0j+UQ2c-PQ2f-SQ2v-lQ2}.QQ3c.oQ3h<OQ3i<PQ3j<QQ3k<RQ3l<SQ3m<TQ3n<UQ3o<VQ3p<WQ3q<XQ3r<YQ3s.vQ3t<]Q3w<`Q3x<mQ4P<ZQ5O0lQ5Y0|Q6k<pQ6q2xQ6v3OQ7V3dQ7W<qQ7a<sQ7b<{Q8`5mQ8|6iQ9Q6rQ9[<|Q9b=VQ9c=WQ:c9SQ:y9}Q;R:aQ;x#SR=g=sR#[WR'X!el!tQ!r!v!y!z'^'j'k'l-`-p1g5q5sS'T!e-WU*g$|*X*lS-T'U']S0O*h*nQ0W*oQ2m-^Q4m0UR4r0XR(y#xQ!fQT-_'^-`]!qQ!r'^-`1g5qQ#p]R'g;wR)d$dY!uQ'^-`1g5qQ'i!rS's!v!yS'u!z5sS-o'j'kQ-q'lR2{-pT#kZ%dS#jZ%dS%jm,jU(e#h#i#lS.T(f(gQ.X(hQ0n+ZQ3Q.UU3R.V.W.YS6x3S3TR9T6yd#^W#W#Z%g(R([*W+W.O/hr#gZm#h#i#l%d(f(g(h+Z.U.V.W.Y3S3T6yS*Z$x*_Q/o*[Q1|,jQ2d-QQ4W/kQ6g2[Q7i4XQ8{6hT=_'V+XV#aW%g*WU#`W%g*WS(S#W([U(X#Z+W/hS-V'V+XT-y(R.OV'[!e%h*XQ$lfR)v$qT)k$l)lR3}/PT*]$x*_T*e${*WQ0q+cQ1_,QQ3V.aQ5j1aQ5u1iQ6}3ZQ8g5xQ9W6|Q:Q8fQ:d9VQ:|:SQ;U:fQ;`:}R;c;VnqOXst!Z#d%l&p&r&s&u,n,s2S2VQ&j!VR,c&gtmOXst!U!V!Z#d%l&g&p&r&s&u,n,s2S2VR,j&mT%km,jR1c,SR,b&eQ&T|R+z&UR+p&OT&n!W&qT&o!W&qT2U,s2V",nodeNames:"⚠ ArithOp ArithOp ?. JSXStartTag LineComment BlockComment Script Hashbang ExportDeclaration export Star as VariableName String Escape from ; default FunctionDeclaration async function VariableDefinition > < TypeParamList in out const TypeDefinition extends ThisType this LiteralType ArithOp Number BooleanLiteral TemplateType InterpolationEnd Interpolation InterpolationStart NullType null VoidType void TypeofType typeof MemberExpression . PropertyName [ TemplateString Escape Interpolation super RegExp ] ArrayExpression Spread , } { ObjectExpression Property async get set PropertyDefinition Block : NewTarget new NewExpression ) ( ArgList UnaryExpression delete LogicOp BitOp YieldExpression yield AwaitExpression await ParenthesizedExpression ClassExpression class ClassBody MethodDeclaration Decorator @ MemberExpression PrivatePropertyName CallExpression TypeArgList CompareOp < declare Privacy static abstract override PrivatePropertyDefinition PropertyDeclaration readonly accessor Optional TypeAnnotation Equals StaticBlock FunctionExpression ArrowFunction ParamList ParamList ArrayPattern ObjectPattern PatternProperty Privacy readonly Arrow MemberExpression BinaryExpression ArithOp ArithOp ArithOp ArithOp BitOp CompareOp instanceof satisfies CompareOp BitOp BitOp BitOp LogicOp LogicOp ConditionalExpression LogicOp LogicOp AssignmentExpression UpdateOp PostfixExpression CallExpression InstantiationExpression TaggedTemplateExpression DynamicImport import ImportMeta JSXElement JSXSelfCloseEndTag JSXSelfClosingTag JSXIdentifier JSXBuiltin JSXIdentifier JSXNamespacedName JSXMemberExpression JSXSpreadAttribute JSXAttribute JSXAttributeValue JSXEscape JSXEndTag JSXOpenTag JSXFragmentTag JSXText JSXEscape JSXStartCloseTag JSXCloseTag PrefixCast < ArrowFunction TypeParamList SequenceExpression InstantiationExpression KeyofType keyof UniqueType unique ImportType InferredType infer TypeName ParenthesizedType FunctionSignature ParamList NewSignature IndexedType TupleType Label ArrayType ReadonlyType ObjectType MethodType PropertyType IndexSignature PropertyDefinition CallSignature TypePredicate asserts is NewSignature new UnionType LogicOp IntersectionType LogicOp ConditionalType ParameterizedType ClassDeclaration abstract implements type VariableDeclaration let var using TypeAliasDeclaration InterfaceDeclaration interface EnumDeclaration enum EnumBody NamespaceDeclaration namespace module AmbientDeclaration declare GlobalDeclaration global ClassDeclaration ClassBody AmbientFunctionDeclaration ExportGroup VariableName VariableName ImportDeclaration ImportGroup ForStatement for ForSpec ForInSpec ForOfSpec of WhileStatement while WithStatement with DoStatement do IfStatement if else SwitchStatement switch SwitchBody CaseLabel case DefaultLabel TryStatement try CatchClause catch FinallyClause finally ReturnStatement return ThrowStatement throw BreakStatement break ContinueStatement continue DebuggerStatement debugger LabeledStatement ExpressionStatement SingleExpression SingleClassItem",maxTerm:379,context:sze,nodeProps:[["isolate",-8,5,6,14,37,39,51,53,55,""],["group",-26,9,17,19,68,207,211,215,216,218,221,224,234,236,242,244,246,248,251,257,263,265,267,269,271,273,274,"Statement",-34,13,14,32,35,36,42,51,54,55,57,62,70,72,76,80,82,84,85,110,111,120,121,136,139,141,142,143,144,145,147,148,167,169,171,"Expression",-23,31,33,37,41,43,45,173,175,177,178,180,181,182,184,185,186,188,189,190,201,203,205,206,"Type",-3,88,103,109,"ClassItem"],["openedBy",23,"<",38,"InterpolationStart",56,"[",60,"{",73,"(",160,"JSXStartCloseTag"],["closedBy",-2,24,168,">",40,"InterpolationEnd",50,"]",61,"}",74,")",165,"JSXEndTag"]],propSources:[mze],skippedNodes:[0,5,6,277],repeatNodeCount:37,tokenData:"$Fq07[R!bOX%ZXY+gYZ-yZ[+g[]%Z]^.c^p%Zpq+gqr/mrs3cst:_tuEruvJSvwLkwx! Yxy!'iyz!(sz{!)}{|!,q|}!.O}!O!,q!O!P!/Y!P!Q!9j!Q!R#:O!R![#<_![!]#I_!]!^#Jk!^!_#Ku!_!`$![!`!a$$v!a!b$*T!b!c$,r!c!}Er!}#O$-|#O#P$/W#P#Q$4o#Q#R$5y#R#SEr#S#T$7W#T#o$8b#o#p$<r#p#q$=h#q#r$>x#r#s$@U#s$f%Z$f$g+g$g#BYEr#BY#BZ$A`#BZ$ISEr$IS$I_$A`$I_$I|Er$I|$I}$Dk$I}$JO$Dk$JO$JTEr$JT$JU$A`$JU$KVEr$KV$KW$A`$KW&FUEr&FU&FV$A`&FV;'SEr;'S;=`I|<%l?HTEr?HT?HU$A`?HUOEr(n%d_$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z&j&hT$i&jO!^&c!_#o&c#p;'S&c;'S;=`&w<%lO&c&j&zP;=`<%l&c'|'U]$i&j(Y!bOY&}YZ&cZw&}wx&cx!^&}!^!_'}!_#O&}#O#P&c#P#o&}#o#p'}#p;'S&};'S;=`(l<%lO&}!b(SU(Y!bOY'}Zw'}x#O'}#P;'S'};'S;=`(f<%lO'}!b(iP;=`<%l'}'|(oP;=`<%l&}'[(y]$i&j(VpOY(rYZ&cZr(rrs&cs!^(r!^!_)r!_#O(r#O#P&c#P#o(r#o#p)r#p;'S(r;'S;=`*a<%lO(rp)wU(VpOY)rZr)rs#O)r#P;'S)r;'S;=`*Z<%lO)rp*^P;=`<%l)r'[*dP;=`<%l(r#S*nX(Vp(Y!bOY*gZr*grs'}sw*gwx)rx#O*g#P;'S*g;'S;=`+Z<%lO*g#S+^P;=`<%l*g(n+dP;=`<%l%Z07[+rq$i&j(Vp(Y!b'{0/lOX%ZXY+gYZ&cZ[+g[p%Zpq+gqr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p$f%Z$f$g+g$g#BY%Z#BY#BZ+g#BZ$IS%Z$IS$I_+g$I_$JT%Z$JT$JU+g$JU$KV%Z$KV$KW+g$KW&FU%Z&FU&FV+g&FV;'S%Z;'S;=`+a<%l?HT%Z?HT?HU+g?HUO%Z07[.ST(W#S$i&j'|0/lO!^&c!_#o&c#p;'S&c;'S;=`&w<%lO&c07[.n_$i&j(Vp(Y!b'|0/lOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z)3p/x`$i&j!p),Q(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`0z!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW1V`#v(Ch$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`2X!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW2d_#v(Ch$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'At3l_(U':f$i&j(Y!bOY4kYZ5qZr4krs7nsw4kwx5qx!^4k!^!_8p!_#O4k#O#P5q#P#o4k#o#p8p#p;'S4k;'S;=`:X<%lO4k(^4r_$i&j(Y!bOY4kYZ5qZr4krs7nsw4kwx5qx!^4k!^!_8p!_#O4k#O#P5q#P#o4k#o#p8p#p;'S4k;'S;=`:X<%lO4k&z5vX$i&jOr5qrs6cs!^5q!^!_6y!_#o5q#o#p6y#p;'S5q;'S;=`7h<%lO5q&z6jT$d`$i&jO!^&c!_#o&c#p;'S&c;'S;=`&w<%lO&c`6|TOr6yrs7]s;'S6y;'S;=`7b<%lO6y`7bO$d``7eP;=`<%l6y&z7kP;=`<%l5q(^7w]$d`$i&j(Y!bOY&}YZ&cZw&}wx&cx!^&}!^!_'}!_#O&}#O#P&c#P#o&}#o#p'}#p;'S&};'S;=`(l<%lO&}!r8uZ(Y!bOY8pYZ6yZr8prs9hsw8pwx6yx#O8p#O#P6y#P;'S8p;'S;=`:R<%lO8p!r9oU$d`(Y!bOY'}Zw'}x#O'}#P;'S'};'S;=`(f<%lO'}!r:UP;=`<%l8p(^:[P;=`<%l4k%9[:hh$i&j(Vp(Y!bOY%ZYZ&cZq%Zqr<Srs&}st%ZtuCruw%Zwx(rx!^%Z!^!_*g!_!c%Z!c!}Cr!}#O%Z#O#P&c#P#R%Z#R#SCr#S#T%Z#T#oCr#o#p*g#p$g%Z$g;'SCr;'S;=`El<%lOCr(r<__WS$i&j(Vp(Y!bOY<SYZ&cZr<Srs=^sw<Swx@nx!^<S!^!_Bm!_#O<S#O#P>`#P#o<S#o#pBm#p;'S<S;'S;=`Cl<%lO<S(Q=g]WS$i&j(Y!bOY=^YZ&cZw=^wx>`x!^=^!^!_?q!_#O=^#O#P>`#P#o=^#o#p?q#p;'S=^;'S;=`@h<%lO=^&n>gXWS$i&jOY>`YZ&cZ!^>`!^!_?S!_#o>`#o#p?S#p;'S>`;'S;=`?k<%lO>`S?XSWSOY?SZ;'S?S;'S;=`?e<%lO?SS?hP;=`<%l?S&n?nP;=`<%l>`!f?xWWS(Y!bOY?qZw?qwx?Sx#O?q#O#P?S#P;'S?q;'S;=`@b<%lO?q!f@eP;=`<%l?q(Q@kP;=`<%l=^'`@w]WS$i&j(VpOY@nYZ&cZr@nrs>`s!^@n!^!_Ap!_#O@n#O#P>`#P#o@n#o#pAp#p;'S@n;'S;=`Bg<%lO@ntAwWWS(VpOYApZrAprs?Ss#OAp#O#P?S#P;'SAp;'S;=`Ba<%lOAptBdP;=`<%lAp'`BjP;=`<%l@n#WBvYWS(Vp(Y!bOYBmZrBmrs?qswBmwxApx#OBm#O#P?S#P;'SBm;'S;=`Cf<%lOBm#WCiP;=`<%lBm(rCoP;=`<%l<S%9[C}i$i&j(n%1l(Vp(Y!bOY%ZYZ&cZr%Zrs&}st%ZtuCruw%Zwx(rx!Q%Z!Q![Cr![!^%Z!^!_*g!_!c%Z!c!}Cr!}#O%Z#O#P&c#P#R%Z#R#SCr#S#T%Z#T#oCr#o#p*g#p$g%Z$g;'SCr;'S;=`El<%lOCr%9[EoP;=`<%lCr07[FRk$i&j(Vp(Y!b$]#t(S,2j(d$I[OY%ZYZ&cZr%Zrs&}st%ZtuEruw%Zwx(rx}%Z}!OGv!O!Q%Z!Q![Er![!^%Z!^!_*g!_!c%Z!c!}Er!}#O%Z#O#P&c#P#R%Z#R#SEr#S#T%Z#T#oEr#o#p*g#p$g%Z$g;'SEr;'S;=`I|<%lOEr+dHRk$i&j(Vp(Y!b$]#tOY%ZYZ&cZr%Zrs&}st%ZtuGvuw%Zwx(rx}%Z}!OGv!O!Q%Z!Q![Gv![!^%Z!^!_*g!_!c%Z!c!}Gv!}#O%Z#O#P&c#P#R%Z#R#SGv#S#T%Z#T#oGv#o#p*g#p$g%Z$g;'SGv;'S;=`Iv<%lOGv+dIyP;=`<%lGv07[JPP;=`<%lEr(KWJ_`$i&j(Vp(Y!b#p(ChOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KWKl_$i&j$Q(Ch(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z,#xLva(y+JY$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sv%ZvwM{wx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KWNW`$i&j#z(Ch(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'At! c_(X';W$i&j(VpOY!!bYZ!#hZr!!brs!#hsw!!bwx!$xx!^!!b!^!_!%z!_#O!!b#O#P!#h#P#o!!b#o#p!%z#p;'S!!b;'S;=`!'c<%lO!!b'l!!i_$i&j(VpOY!!bYZ!#hZr!!brs!#hsw!!bwx!$xx!^!!b!^!_!%z!_#O!!b#O#P!#h#P#o!!b#o#p!%z#p;'S!!b;'S;=`!'c<%lO!!b&z!#mX$i&jOw!#hwx6cx!^!#h!^!_!$Y!_#o!#h#o#p!$Y#p;'S!#h;'S;=`!$r<%lO!#h`!$]TOw!$Ywx7]x;'S!$Y;'S;=`!$l<%lO!$Y`!$oP;=`<%l!$Y&z!$uP;=`<%l!#h'l!%R]$d`$i&j(VpOY(rYZ&cZr(rrs&cs!^(r!^!_)r!_#O(r#O#P&c#P#o(r#o#p)r#p;'S(r;'S;=`*a<%lO(r!Q!&PZ(VpOY!%zYZ!$YZr!%zrs!$Ysw!%zwx!&rx#O!%z#O#P!$Y#P;'S!%z;'S;=`!']<%lO!%z!Q!&yU$d`(VpOY)rZr)rs#O)r#P;'S)r;'S;=`*Z<%lO)r!Q!'`P;=`<%l!%z'l!'fP;=`<%l!!b/5|!'t_!l/.^$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z#&U!)O_!k!Lf$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z-!n!*[b$i&j(Vp(Y!b(T%&f#q(ChOY%ZYZ&cZr%Zrs&}sw%Zwx(rxz%Zz{!+d{!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW!+o`$i&j(Vp(Y!b#n(ChOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z+;x!,|`$i&j(Vp(Y!br+4YOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z,$U!.Z_!]+Jf$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z07[!/ec$i&j(Vp(Y!b!Q.2^OY%ZYZ&cZr%Zrs&}sw%Zwx(rx!O%Z!O!P!0p!P!Q%Z!Q![!3Y![!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z#%|!0ya$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!O%Z!O!P!2O!P!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z#%|!2Z_![!L^$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad!3eg$i&j(Vp(Y!bs'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q![!3Y![!^%Z!^!_*g!_!g%Z!g!h!4|!h#O%Z#O#P&c#P#R%Z#R#S!3Y#S#X%Z#X#Y!4|#Y#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad!5Vg$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx{%Z{|!6n|}%Z}!O!6n!O!Q%Z!Q![!8S![!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S!8S#S#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad!6wc$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q![!8S![!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S!8S#S#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad!8_c$i&j(Vp(Y!bs'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q![!8S![!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S!8S#S#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z07[!9uf$i&j(Vp(Y!b#o(ChOY!;ZYZ&cZr!;Zrs!<nsw!;Zwx!Lcxz!;Zz{#-}{!P!;Z!P!Q#/d!Q!^!;Z!^!_#(i!_!`#7S!`!a#8i!a!}!;Z!}#O#,f#O#P!Dy#P#o!;Z#o#p#(i#p;'S!;Z;'S;=`#-w<%lO!;Z?O!;fb$i&j(Vp(Y!b!X7`OY!;ZYZ&cZr!;Zrs!<nsw!;Zwx!Lcx!P!;Z!P!Q#&`!Q!^!;Z!^!_#(i!_!}!;Z!}#O#,f#O#P!Dy#P#o!;Z#o#p#(i#p;'S!;Z;'S;=`#-w<%lO!;Z>^!<w`$i&j(Y!b!X7`OY!<nYZ&cZw!<nwx!=yx!P!<n!P!Q!Eq!Q!^!<n!^!_!Gr!_!}!<n!}#O!KS#O#P!Dy#P#o!<n#o#p!Gr#p;'S!<n;'S;=`!L]<%lO!<n<z!>Q^$i&j!X7`OY!=yYZ&cZ!P!=y!P!Q!>|!Q!^!=y!^!_!@c!_!}!=y!}#O!CW#O#P!Dy#P#o!=y#o#p!@c#p;'S!=y;'S;=`!Ek<%lO!=y<z!?Td$i&j!X7`O!^&c!_#W&c#W#X!>|#X#Z&c#Z#[!>|#[#]&c#]#^!>|#^#a&c#a#b!>|#b#g&c#g#h!>|#h#i&c#i#j!>|#j#k!>|#k#m&c#m#n!>|#n#o&c#p;'S&c;'S;=`&w<%lO&c7`!@hX!X7`OY!@cZ!P!@c!P!Q!AT!Q!}!@c!}#O!Ar#O#P!Bq#P;'S!@c;'S;=`!CQ<%lO!@c7`!AYW!X7`#W#X!AT#Z#[!AT#]#^!AT#a#b!AT#g#h!AT#i#j!AT#j#k!AT#m#n!AT7`!AuVOY!ArZ#O!Ar#O#P!B[#P#Q!@c#Q;'S!Ar;'S;=`!Bk<%lO!Ar7`!B_SOY!ArZ;'S!Ar;'S;=`!Bk<%lO!Ar7`!BnP;=`<%l!Ar7`!BtSOY!@cZ;'S!@c;'S;=`!CQ<%lO!@c7`!CTP;=`<%l!@c<z!C][$i&jOY!CWYZ&cZ!^!CW!^!_!Ar!_#O!CW#O#P!DR#P#Q!=y#Q#o!CW#o#p!Ar#p;'S!CW;'S;=`!Ds<%lO!CW<z!DWX$i&jOY!CWYZ&cZ!^!CW!^!_!Ar!_#o!CW#o#p!Ar#p;'S!CW;'S;=`!Ds<%lO!CW<z!DvP;=`<%l!CW<z!EOX$i&jOY!=yYZ&cZ!^!=y!^!_!@c!_#o!=y#o#p!@c#p;'S!=y;'S;=`!Ek<%lO!=y<z!EnP;=`<%l!=y>^!Ezl$i&j(Y!b!X7`OY&}YZ&cZw&}wx&cx!^&}!^!_'}!_#O&}#O#P&c#P#W&}#W#X!Eq#X#Z&}#Z#[!Eq#[#]&}#]#^!Eq#^#a&}#a#b!Eq#b#g&}#g#h!Eq#h#i&}#i#j!Eq#j#k!Eq#k#m&}#m#n!Eq#n#o&}#o#p'}#p;'S&};'S;=`(l<%lO&}8r!GyZ(Y!b!X7`OY!GrZw!Grwx!@cx!P!Gr!P!Q!Hl!Q!}!Gr!}#O!JU#O#P!Bq#P;'S!Gr;'S;=`!J|<%lO!Gr8r!Hse(Y!b!X7`OY'}Zw'}x#O'}#P#W'}#W#X!Hl#X#Z'}#Z#[!Hl#[#]'}#]#^!Hl#^#a'}#a#b!Hl#b#g'}#g#h!Hl#h#i'}#i#j!Hl#j#k!Hl#k#m'}#m#n!Hl#n;'S'};'S;=`(f<%lO'}8r!JZX(Y!bOY!JUZw!JUwx!Arx#O!JU#O#P!B[#P#Q!Gr#Q;'S!JU;'S;=`!Jv<%lO!JU8r!JyP;=`<%l!JU8r!KPP;=`<%l!Gr>^!KZ^$i&j(Y!bOY!KSYZ&cZw!KSwx!CWx!^!KS!^!_!JU!_#O!KS#O#P!DR#P#Q!<n#Q#o!KS#o#p!JU#p;'S!KS;'S;=`!LV<%lO!KS>^!LYP;=`<%l!KS>^!L`P;=`<%l!<n=l!Ll`$i&j(Vp!X7`OY!LcYZ&cZr!Lcrs!=ys!P!Lc!P!Q!Mn!Q!^!Lc!^!_# o!_!}!Lc!}#O#%P#O#P!Dy#P#o!Lc#o#p# o#p;'S!Lc;'S;=`#&Y<%lO!Lc=l!Mwl$i&j(Vp!X7`OY(rYZ&cZr(rrs&cs!^(r!^!_)r!_#O(r#O#P&c#P#W(r#W#X!Mn#X#Z(r#Z#[!Mn#[#](r#]#^!Mn#^#a(r#a#b!Mn#b#g(r#g#h!Mn#h#i(r#i#j!Mn#j#k!Mn#k#m(r#m#n!Mn#n#o(r#o#p)r#p;'S(r;'S;=`*a<%lO(r8Q# vZ(Vp!X7`OY# oZr# ors!@cs!P# o!P!Q#!i!Q!}# o!}#O#$R#O#P!Bq#P;'S# o;'S;=`#$y<%lO# o8Q#!pe(Vp!X7`OY)rZr)rs#O)r#P#W)r#W#X#!i#X#Z)r#Z#[#!i#[#])r#]#^#!i#^#a)r#a#b#!i#b#g)r#g#h#!i#h#i)r#i#j#!i#j#k#!i#k#m)r#m#n#!i#n;'S)r;'S;=`*Z<%lO)r8Q#$WX(VpOY#$RZr#$Rrs!Ars#O#$R#O#P!B[#P#Q# o#Q;'S#$R;'S;=`#$s<%lO#$R8Q#$vP;=`<%l#$R8Q#$|P;=`<%l# o=l#%W^$i&j(VpOY#%PYZ&cZr#%Prs!CWs!^#%P!^!_#$R!_#O#%P#O#P!DR#P#Q!Lc#Q#o#%P#o#p#$R#p;'S#%P;'S;=`#&S<%lO#%P=l#&VP;=`<%l#%P=l#&]P;=`<%l!Lc?O#&kn$i&j(Vp(Y!b!X7`OY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#W%Z#W#X#&`#X#Z%Z#Z#[#&`#[#]%Z#]#^#&`#^#a%Z#a#b#&`#b#g%Z#g#h#&`#h#i%Z#i#j#&`#j#k#&`#k#m%Z#m#n#&`#n#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z9d#(r](Vp(Y!b!X7`OY#(iZr#(irs!Grsw#(iwx# ox!P#(i!P!Q#)k!Q!}#(i!}#O#+`#O#P!Bq#P;'S#(i;'S;=`#,`<%lO#(i9d#)th(Vp(Y!b!X7`OY*gZr*grs'}sw*gwx)rx#O*g#P#W*g#W#X#)k#X#Z*g#Z#[#)k#[#]*g#]#^#)k#^#a*g#a#b#)k#b#g*g#g#h#)k#h#i*g#i#j#)k#j#k#)k#k#m*g#m#n#)k#n;'S*g;'S;=`+Z<%lO*g9d#+gZ(Vp(Y!bOY#+`Zr#+`rs!JUsw#+`wx#$Rx#O#+`#O#P!B[#P#Q#(i#Q;'S#+`;'S;=`#,Y<%lO#+`9d#,]P;=`<%l#+`9d#,cP;=`<%l#(i?O#,o`$i&j(Vp(Y!bOY#,fYZ&cZr#,frs!KSsw#,fwx#%Px!^#,f!^!_#+`!_#O#,f#O#P!DR#P#Q!;Z#Q#o#,f#o#p#+`#p;'S#,f;'S;=`#-q<%lO#,f?O#-tP;=`<%l#,f?O#-zP;=`<%l!;Z07[#.[b$i&j(Vp(Y!b'}0/l!X7`OY!;ZYZ&cZr!;Zrs!<nsw!;Zwx!Lcx!P!;Z!P!Q#&`!Q!^!;Z!^!_#(i!_!}!;Z!}#O#,f#O#P!Dy#P#o!;Z#o#p#(i#p;'S!;Z;'S;=`#-w<%lO!;Z07[#/o_$i&j(Vp(Y!bT0/lOY#/dYZ&cZr#/drs#0nsw#/dwx#4Ox!^#/d!^!_#5}!_#O#/d#O#P#1p#P#o#/d#o#p#5}#p;'S#/d;'S;=`#6|<%lO#/d06j#0w]$i&j(Y!bT0/lOY#0nYZ&cZw#0nwx#1px!^#0n!^!_#3R!_#O#0n#O#P#1p#P#o#0n#o#p#3R#p;'S#0n;'S;=`#3x<%lO#0n05W#1wX$i&jT0/lOY#1pYZ&cZ!^#1p!^!_#2d!_#o#1p#o#p#2d#p;'S#1p;'S;=`#2{<%lO#1p0/l#2iST0/lOY#2dZ;'S#2d;'S;=`#2u<%lO#2d0/l#2xP;=`<%l#2d05W#3OP;=`<%l#1p01O#3YW(Y!bT0/lOY#3RZw#3Rwx#2dx#O#3R#O#P#2d#P;'S#3R;'S;=`#3r<%lO#3R01O#3uP;=`<%l#3R06j#3{P;=`<%l#0n05x#4X]$i&j(VpT0/lOY#4OYZ&cZr#4Ors#1ps!^#4O!^!_#5Q!_#O#4O#O#P#1p#P#o#4O#o#p#5Q#p;'S#4O;'S;=`#5w<%lO#4O00^#5XW(VpT0/lOY#5QZr#5Qrs#2ds#O#5Q#O#P#2d#P;'S#5Q;'S;=`#5q<%lO#5Q00^#5tP;=`<%l#5Q05x#5zP;=`<%l#4O01p#6WY(Vp(Y!bT0/lOY#5}Zr#5}rs#3Rsw#5}wx#5Qx#O#5}#O#P#2d#P;'S#5};'S;=`#6v<%lO#5}01p#6yP;=`<%l#5}07[#7PP;=`<%l#/d)3h#7ab$i&j$Q(Ch(Vp(Y!b!X7`OY!;ZYZ&cZr!;Zrs!<nsw!;Zwx!Lcx!P!;Z!P!Q#&`!Q!^!;Z!^!_#(i!_!}!;Z!}#O#,f#O#P!Dy#P#o!;Z#o#p#(i#p;'S!;Z;'S;=`#-w<%lO!;ZAt#8vb$Z#t$i&j(Vp(Y!b!X7`OY!;ZYZ&cZr!;Zrs!<nsw!;Zwx!Lcx!P!;Z!P!Q#&`!Q!^!;Z!^!_#(i!_!}!;Z!}#O#,f#O#P!Dy#P#o!;Z#o#p#(i#p;'S!;Z;'S;=`#-w<%lO!;Z'Ad#:Zp$i&j(Vp(Y!bs'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!O%Z!O!P!3Y!P!Q%Z!Q![#<_![!^%Z!^!_*g!_!g%Z!g!h!4|!h#O%Z#O#P&c#P#R%Z#R#S#<_#S#U%Z#U#V#?i#V#X%Z#X#Y!4|#Y#b%Z#b#c#>_#c#d#Bq#d#l%Z#l#m#Es#m#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#<jk$i&j(Vp(Y!bs'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!O%Z!O!P!3Y!P!Q%Z!Q![#<_![!^%Z!^!_*g!_!g%Z!g!h!4|!h#O%Z#O#P&c#P#R%Z#R#S#<_#S#X%Z#X#Y!4|#Y#b%Z#b#c#>_#c#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#>j_$i&j(Vp(Y!bs'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#?rd$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q!R#AQ!R!S#AQ!S!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S#AQ#S#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#A]f$i&j(Vp(Y!bs'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q!R#AQ!R!S#AQ!S!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S#AQ#S#b%Z#b#c#>_#c#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#Bzc$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q!Y#DV!Y!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S#DV#S#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#Dbe$i&j(Vp(Y!bs'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q!Y#DV!Y!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S#DV#S#b%Z#b#c#>_#c#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#E|g$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q![#Ge![!^%Z!^!_*g!_!c%Z!c!i#Ge!i#O%Z#O#P&c#P#R%Z#R#S#Ge#S#T%Z#T#Z#Ge#Z#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#Gpi$i&j(Vp(Y!bs'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q![#Ge![!^%Z!^!_*g!_!c%Z!c!i#Ge!i#O%Z#O#P&c#P#R%Z#R#S#Ge#S#T%Z#T#Z#Ge#Z#b%Z#b#c#>_#c#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z*)x#Il_!g$b$i&j$O)Lv(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z)[#Jv_al$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z04f#LS^h#)`#R-<U(Vp(Y!b$n7`OY*gZr*grs'}sw*gwx)rx!P*g!P!Q#MO!Q!^*g!^!_#Mt!_!`$ f!`#O*g#P;'S*g;'S;=`+Z<%lO*g(n#MXX$k&j(Vp(Y!bOY*gZr*grs'}sw*gwx)rx#O*g#P;'S*g;'S;=`+Z<%lO*g(El#M}Z#r(Ch(Vp(Y!bOY*gZr*grs'}sw*gwx)rx!_*g!_!`#Np!`#O*g#P;'S*g;'S;=`+Z<%lO*g(El#NyX$Q(Ch(Vp(Y!bOY*gZr*grs'}sw*gwx)rx#O*g#P;'S*g;'S;=`+Z<%lO*g(El$ oX#s(Ch(Vp(Y!bOY*gZr*grs'}sw*gwx)rx#O*g#P;'S*g;'S;=`+Z<%lO*g*)x$!ga#`*!Y$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`0z!`!a$#l!a#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(K[$#w_#k(Cl$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z*)x$%Vag!*r#s(Ch$f#|$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`$&[!`!a$'f!a#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW$&g_#s(Ch$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW$'qa#r(Ch$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`!a$(v!a#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW$)R`#r(Ch$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(Kd$*`a(q(Ct$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!a%Z!a!b$+e!b#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW$+p`$i&j#{(Ch(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z%#`$,}_!|$Ip$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z04f$.X_!S0,v$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(n$/]Z$i&jO!^$0O!^!_$0f!_#i$0O#i#j$0k#j#l$0O#l#m$2^#m#o$0O#o#p$0f#p;'S$0O;'S;=`$4i<%lO$0O(n$0VT_#S$i&jO!^&c!_#o&c#p;'S&c;'S;=`&w<%lO&c#S$0kO_#S(n$0p[$i&jO!Q&c!Q![$1f![!^&c!_!c&c!c!i$1f!i#T&c#T#Z$1f#Z#o&c#o#p$3|#p;'S&c;'S;=`&w<%lO&c(n$1kZ$i&jO!Q&c!Q![$2^![!^&c!_!c&c!c!i$2^!i#T&c#T#Z$2^#Z#o&c#p;'S&c;'S;=`&w<%lO&c(n$2cZ$i&jO!Q&c!Q![$3U![!^&c!_!c&c!c!i$3U!i#T&c#T#Z$3U#Z#o&c#p;'S&c;'S;=`&w<%lO&c(n$3ZZ$i&jO!Q&c!Q![$0O![!^&c!_!c&c!c!i$0O!i#T&c#T#Z$0O#Z#o&c#p;'S&c;'S;=`&w<%lO&c#S$4PR!Q![$4Y!c!i$4Y#T#Z$4Y#S$4]S!Q![$4Y!c!i$4Y#T#Z$4Y#q#r$0f(n$4lP;=`<%l$0O#1[$4z_!Y#)l$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW$6U`#x(Ch$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z+;p$7c_$i&j(Vp(Y!b(`+4QOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z07[$8qk$i&j(Vp(Y!b(S,2j$_#t(d$I[OY%ZYZ&cZr%Zrs&}st%Ztu$8buw%Zwx(rx}%Z}!O$:f!O!Q%Z!Q![$8b![!^%Z!^!_*g!_!c%Z!c!}$8b!}#O%Z#O#P&c#P#R%Z#R#S$8b#S#T%Z#T#o$8b#o#p*g#p$g%Z$g;'S$8b;'S;=`$<l<%lO$8b+d$:qk$i&j(Vp(Y!b$_#tOY%ZYZ&cZr%Zrs&}st%Ztu$:fuw%Zwx(rx}%Z}!O$:f!O!Q%Z!Q![$:f![!^%Z!^!_*g!_!c%Z!c!}$:f!}#O%Z#O#P&c#P#R%Z#R#S$:f#S#T%Z#T#o$:f#o#p*g#p$g%Z$g;'S$:f;'S;=`$<f<%lO$:f+d$<iP;=`<%l$:f07[$<oP;=`<%l$8b#Jf$<{X!_#Hb(Vp(Y!bOY*gZr*grs'}sw*gwx)rx#O*g#P;'S*g;'S;=`+Z<%lO*g,#x$=sa(x+JY$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p#q$+e#q;'S%Z;'S;=`+a<%lO%Z)>v$?V_!^(CdvBr$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z?O$@a_!q7`$i&j(Vp(Y!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z07[$Aq|$i&j(Vp(Y!b'{0/l$]#t(S,2j(d$I[OX%ZXY+gYZ&cZ[+g[p%Zpq+gqr%Zrs&}st%ZtuEruw%Zwx(rx}%Z}!OGv!O!Q%Z!Q![Er![!^%Z!^!_*g!_!c%Z!c!}Er!}#O%Z#O#P&c#P#R%Z#R#SEr#S#T%Z#T#oEr#o#p*g#p$f%Z$f$g+g$g#BYEr#BY#BZ$A`#BZ$ISEr$IS$I_$A`$I_$JTEr$JT$JU$A`$JU$KVEr$KV$KW$A`$KW&FUEr&FU&FV$A`&FV;'SEr;'S;=`I|<%l?HTEr?HT?HU$A`?HUOEr07[$D|k$i&j(Vp(Y!b'|0/l$]#t(S,2j(d$I[OY%ZYZ&cZr%Zrs&}st%ZtuEruw%Zwx(rx}%Z}!OGv!O!Q%Z!Q![Er![!^%Z!^!_*g!_!c%Z!c!}Er!}#O%Z#O#P&c#P#R%Z#R#SEr#S#T%Z#T#oEr#o#p*g#p$g%Z$g;'SEr;'S;=`I|<%lOEr",tokenizers:[fze,dze,hze,pze,2,3,4,5,6,7,8,9,10,11,12,13,14,cze,new p9("$S~RRtu[#O#Pg#S#T#|~_P#o#pb~gOx~~jVO#i!P#i#j!U#j#l!P#l#m!q#m;'S!P;'S;=`#v<%lO!P~!UO!U~~!XS!Q![!e!c!i!e#T#Z!e#o#p#Z~!hR!Q![!q!c!i!q#T#Z!q~!tR!Q![!}!c!i!}#T#Z!}~#QR!Q![!P!c!i!P#T#Z!P~#^R!Q![#g!c!i#g#T#Z#g~#jS!Q![#g!c!i#g#T#Z#g#q#r!P~#yP;=`<%l!P~$RO(b~~",141,339),new p9("j~RQYZXz{^~^O(P~~aP!P!Qd~iO(Q~~",25,322)],topRules:{Script:[0,7],SingleExpression:[1,275],SingleClassItem:[2,276]},dialects:{jsx:0,ts:15098},dynamicPrecedences:{80:1,82:1,94:1,169:1,199:1},specialized:[{term:326,get:e=>gze[e]||-1},{term:342,get:e=>vze[e]||-1},{term:95,get:e=>yze[e]||-1}],tokenPrec:15124});var x1={},Nf={},f2={},S1={},PP={},YX;function bze(){return YX||(YX=1,Object.defineProperty(PP,"__esModule",{value:!0})),PP}var d2={},h2={},GX;function Pb(){var t,n,r,i,a,Ige,l;if(GX)return h2;GX=1,Object.defineProperty(h2,"__esModule",{value:!0}),h2.CronField=void 0;let e=(l=class{constructor(s,c={rawValue:""}){Ui(this,a);Ui(this,t,!1);Ui(this,n,!1);Ui(this,r,!1);Ui(this,i,[]);$_(this,"options",{rawValue:""});if(!Array.isArray(s))throw new Error(`${this.constructor.name} Validation error, values is not an array`);if(!(s.length>0))throw new Error(`${this.constructor.name} Validation error, values contains no values`);this.options={...c,rawValue:c.rawValue??""},Rn(this,i,s.sort(l.sorter)),Rn(this,r,this.options.wildcard!==void 0?this.options.wildcard:jn(this,a,Ige).call(this)),Rn(this,t,this.options.rawValue.includes("L")),Rn(this,n,this.options.rawValue.includes("?"))}static get min(){throw new Error("min must be overridden")}static get max(){throw new Error("max must be overridden")}static get chars(){return Object.freeze([])}static get validChars(){return/^[?,*\dH/-]+$|^.*H\(\d+-\d+\)\/\d+.*$|^.*H\(\d+-\d+\).*$|^.*H\/\d+.*$/}static get constraints(){return{min:this.min,max:this.max,chars:this.chars,validChars:this.validChars}}get min(){return this.constructor.min}get max(){return this.constructor.max}get chars(){return this.constructor.chars}get hasLastChar(){return bt(this,t)}get hasQuestionMarkChar(){return bt(this,n)}get isWildcard(){return bt(this,r)}get values(){return bt(this,i)}static sorter(s,c){const d=typeof s=="number",h=typeof c=="number";return d&&h?s-c:!d&&!h?s.localeCompare(c):d?-1:1}serialize(){return{wildcard:bt(this,r),values:bt(this,i)}}validate(){let s;const c=this.chars.length>0?` or chars ${this.chars.join("")}`:"",d=v=>_=>new RegExp(`^\\d{0,2}${_}$`).test(v),h=v=>(s=v,typeof v=="number"?v>=this.min&&v<=this.max:this.chars.some(d(v)));if(!bt(this,i).every(h))throw new Error(`${this.constructor.name} Validation error, got value ${s} expected range ${this.min}-${this.max}${c}`);const y=bt(this,i).find((v,_)=>bt(this,i).indexOf(v)!==_);if(y)throw new Error(`${this.constructor.name} Validation error, duplicate values found: ${y}`)}},t=new WeakMap,n=new WeakMap,r=new WeakMap,i=new WeakMap,a=new WeakSet,Ige=function(){return this.options.rawValue.length>0?["*","?"].includes(this.options.rawValue):Array.from({length:this.max-this.min+1},(s,c)=>c+this.min).every(s=>bt(this,i).includes(s))},l);return h2.CronField=e,h2}var KX;function Oze(){if(KX)return d2;KX=1,Object.defineProperty(d2,"__esModule",{value:!0}),d2.CronDayOfMonth=void 0;const e=Pb(),t=1,n=31,r=Object.freeze(["L"]);let i=class extends e.CronField{static get min(){return t}static get max(){return n}static get chars(){return r}static get validChars(){return/^[?,*\dLH/-]+$|^.*H\(\d+-\d+\)\/\d+.*$|^.*H\(\d+-\d+\).*$|^.*H\/\d+.*$/}constructor(u,l){super(u,l),this.validate()}get values(){return super.values}};return d2.CronDayOfMonth=i,d2}var p2={},WX;function xze(){if(WX)return p2;WX=1,Object.defineProperty(p2,"__esModule",{value:!0}),p2.CronDayOfWeek=void 0;const e=Pb(),t=0,n=7,r=Object.freeze(["L"]);let i=class extends e.CronField{static get min(){return t}static get max(){return n}static get chars(){return r}static get validChars(){return/^[?,*\dLH#/-]+$|^.*H\(\d+-\d+\)\/\d+.*$|^.*H\(\d+-\d+\).*$|^.*H\/\d+.*$/}constructor(u,l){super(u,l),this.validate()}get values(){return super.values}get nthDay(){return this.options.nthDayOfWeek??0}};return p2.CronDayOfWeek=i,p2}var m2={},JX;function Sze(){if(JX)return m2;JX=1,Object.defineProperty(m2,"__esModule",{value:!0}),m2.CronHour=void 0;const e=Pb(),t=0,n=23,r=Object.freeze([]);let i=class extends e.CronField{static get min(){return t}static get max(){return n}static get chars(){return r}constructor(u,l){super(u,l),this.validate()}get values(){return super.values}};return m2.CronHour=i,m2}var g2={},eY;function _ze(){if(eY)return g2;eY=1,Object.defineProperty(g2,"__esModule",{value:!0}),g2.CronMinute=void 0;const e=Pb(),t=0,n=59,r=Object.freeze([]);let i=class extends e.CronField{static get min(){return t}static get max(){return n}static get chars(){return r}constructor(u,l){super(u,l),this.validate()}get values(){return super.values}};return g2.CronMinute=i,g2}var v2={},MP={},Hc={},tY;function Eze(){if(tY)return Hc;tY=1,Object.defineProperty(Hc,"__esModule",{value:!0});class e extends Error{}class t extends e{constructor(I){super(`Invalid DateTime: ${I.toMessage()}`)}}class n extends e{constructor(I){super(`Invalid Interval: ${I.toMessage()}`)}}class r extends e{constructor(I){super(`Invalid Duration: ${I.toMessage()}`)}}class i extends e{}class a extends e{constructor(I){super(`Invalid unit ${I}`)}}class u extends e{}class l extends e{constructor(){super("Zone is an abstract class")}}const o="numeric",s="short",c="long",d={year:o,month:o,day:o},h={year:o,month:s,day:o},m={year:o,month:s,day:o,weekday:s},y={year:o,month:c,day:o},v={year:o,month:c,day:o,weekday:c},_={hour:o,minute:o},S={hour:o,minute:o,second:o},E={hour:o,minute:o,second:o,timeZoneName:s},C={hour:o,minute:o,second:o,timeZoneName:c},T={hour:o,minute:o,hourCycle:"h23"},R={hour:o,minute:o,second:o,hourCycle:"h23"},$={hour:o,minute:o,second:o,hourCycle:"h23",timeZoneName:s},k={hour:o,minute:o,second:o,hourCycle:"h23",timeZoneName:c},F={year:o,month:o,day:o,hour:o,minute:o},L={year:o,month:o,day:o,hour:o,minute:o,second:o},j={year:o,month:s,day:o,hour:o,minute:o},V={year:o,month:s,day:o,hour:o,minute:o,second:o},q={year:o,month:s,day:o,weekday:s,hour:o,minute:o},N={year:o,month:c,day:o,hour:o,minute:o,timeZoneName:s},U={year:o,month:c,day:o,hour:o,minute:o,second:o,timeZoneName:s},W={year:o,month:c,day:o,weekday:c,hour:o,minute:o,timeZoneName:c},G={year:o,month:c,day:o,weekday:c,hour:o,minute:o,second:o,timeZoneName:c};class J{get type(){throw new l}get name(){throw new l}get ianaName(){return this.name}get isUniversal(){throw new l}offsetName(I,re){throw new l}formatOffset(I,re){throw new l}offset(I){throw new l}equals(I){throw new l}get isValid(){throw new l}}let te=null;class H extends J{static get instance(){return te===null&&(te=new H),te}get type(){return"system"}get name(){return new Intl.DateTimeFormat().resolvedOptions().timeZone}get isUniversal(){return!1}offsetName(I,{format:re,locale:fe}){return mc(I,re,fe)}formatOffset(I,re){return Ds(this.offset(I),re)}offset(I){return-new Date(I).getTimezoneOffset()}equals(I){return I.type==="system"}get isValid(){return!0}}const M=new Map;function K(ue){let I=M.get(ue);return I===void 0&&(I=new Intl.DateTimeFormat("en-US",{hour12:!1,timeZone:ue,year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit",era:"short"}),M.set(ue,I)),I}const X={year:0,month:1,day:2,era:3,hour:4,minute:5,second:6};function B(ue,I){const re=ue.format(I).replace(/\u200E/g,""),fe=/(\d+)\/(\d+)\/(\d+) (AD|BC),? (\d+):(\d+):(\d+)/.exec(re),[,xe,Te,Qe,Be,je,Ct,Kt]=fe;return[Qe,xe,Te,Be,je,Ct,Kt]}function ne(ue,I){const re=ue.formatToParts(I),fe=[];for(let xe=0;xe<re.length;xe++){const{type:Te,value:Qe}=re[xe],Be=X[Te];Te==="era"?fe[Be]=Qe:Pt(Be)||(fe[Be]=parseInt(Qe,10))}return fe}const oe=new Map;class ie extends J{static create(I){let re=oe.get(I);return re===void 0&&oe.set(I,re=new ie(I)),re}static resetCache(){oe.clear(),M.clear()}static isValidSpecifier(I){return this.isValidZone(I)}static isValidZone(I){if(!I)return!1;try{return new Intl.DateTimeFormat("en-US",{timeZone:I}).format(),!0}catch{return!1}}constructor(I){super(),this.zoneName=I,this.valid=ie.isValidZone(I)}get type(){return"iana"}get name(){return this.zoneName}get isUniversal(){return!1}offsetName(I,{format:re,locale:fe}){return mc(I,re,fe,this.name)}formatOffset(I,re){return Ds(this.offset(I),re)}offset(I){if(!this.valid)return NaN;const re=new Date(I);if(isNaN(re))return NaN;const fe=K(this.name);let[xe,Te,Qe,Be,je,Ct,Kt]=fe.formatToParts?ne(fe,re):B(fe,re);Be==="BC"&&(xe=-Math.abs(xe)+1);const cn=Ha({year:xe,month:Te,day:Qe,hour:je===24?0:je,minute:Ct,second:Kt,millisecond:0});let vn=+re;const Di=vn%1e3;return vn-=Di>=0?Di:1e3+Di,(cn-vn)/(60*1e3)}equals(I){return I.type==="iana"&&I.name===this.name}get isValid(){return this.valid}}let de={};function be(ue,I={}){const re=JSON.stringify([ue,I]);let fe=de[re];return fe||(fe=new Intl.ListFormat(ue,I),de[re]=fe),fe}const ve=new Map;function pe(ue,I={}){const re=JSON.stringify([ue,I]);let fe=ve.get(re);return fe===void 0&&(fe=new Intl.DateTimeFormat(ue,I),ve.set(re,fe)),fe}const _e=new Map;function se(ue,I={}){const re=JSON.stringify([ue,I]);let fe=_e.get(re);return fe===void 0&&(fe=new Intl.NumberFormat(ue,I),_e.set(re,fe)),fe}const me=new Map;function ge(ue,I={}){const{base:re,...fe}=I,xe=JSON.stringify([ue,fe]);let Te=me.get(xe);return Te===void 0&&(Te=new Intl.RelativeTimeFormat(ue,I),me.set(xe,Te)),Te}let we=null;function Ne(){return we||(we=new Intl.DateTimeFormat().resolvedOptions().locale,we)}const Re=new Map;function et(ue){let I=Re.get(ue);return I===void 0&&(I=new Intl.DateTimeFormat(ue).resolvedOptions(),Re.set(ue,I)),I}const tt=new Map;function Oe(ue){let I=tt.get(ue);if(!I){const re=new Intl.Locale(ue);I="getWeekInfo"in re?re.getWeekInfo():re.weekInfo,"minimalDays"in I||(I={...Nt,...I}),tt.set(ue,I)}return I}function $e(ue){const I=ue.indexOf("-x-");I!==-1&&(ue=ue.substring(0,I));const re=ue.indexOf("-u-");if(re===-1)return[ue];{let fe,xe;try{fe=pe(ue).resolvedOptions(),xe=ue}catch{const je=ue.substring(0,re);fe=pe(je).resolvedOptions(),xe=je}const{numberingSystem:Te,calendar:Qe}=fe;return[xe,Te,Qe]}}function Ae(ue,I,re){return(re||I)&&(ue.includes("-u-")||(ue+="-u"),re&&(ue+=`-ca-${re}`),I&&(ue+=`-nu-${I}`)),ue}function Ue(ue){const I=[];for(let re=1;re<=12;re++){const fe=pn.utc(2009,re,1);I.push(ue(fe))}return I}function Ze(ue){const I=[];for(let re=1;re<=7;re++){const fe=pn.utc(2016,11,13+re);I.push(ue(fe))}return I}function Ye(ue,I,re,fe){const xe=ue.listingMode();return xe==="error"?null:xe==="en"?re(I):fe(I)}function Me(ue){return ue.numberingSystem&&ue.numberingSystem!=="latn"?!1:ue.numberingSystem==="latn"||!ue.locale||ue.locale.startsWith("en")||et(ue.locale).numberingSystem==="latn"}class ze{constructor(I,re,fe){this.padTo=fe.padTo||0,this.floor=fe.floor||!1;const{padTo:xe,floor:Te,...Qe}=fe;if(!re||Object.keys(Qe).length>0){const Be={useGrouping:!1,...fe};fe.padTo>0&&(Be.minimumIntegerDigits=fe.padTo),this.inf=se(I,Be)}}format(I){if(this.inf){const re=this.floor?Math.floor(I):I;return this.inf.format(re)}else{const re=this.floor?Math.floor(I):mf(I,3);return Fr(re,this.padTo)}}}class st{constructor(I,re,fe){this.opts=fe,this.originalZone=void 0;let xe;if(this.opts.timeZone)this.dt=I;else if(I.zone.type==="fixed"){const Qe=-1*(I.offset/60),Be=Qe>=0?`Etc/GMT+${Qe}`:`Etc/GMT${Qe}`;I.offset!==0&&ie.create(Be).valid?(xe=Be,this.dt=I):(xe="UTC",this.dt=I.offset===0?I:I.setZone("UTC").plus({minutes:I.offset}),this.originalZone=I.zone)}else I.zone.type==="system"?this.dt=I:I.zone.type==="iana"?(this.dt=I,xe=I.zone.name):(xe="UTC",this.dt=I.setZone("UTC").plus({minutes:I.offset}),this.originalZone=I.zone);const Te={...this.opts};Te.timeZone=Te.timeZone||xe,this.dtf=pe(re,Te)}format(){return this.originalZone?this.formatToParts().map(({value:I})=>I).join(""):this.dtf.format(this.dt.toJSDate())}formatToParts(){const I=this.dtf.formatToParts(this.dt.toJSDate());return this.originalZone?I.map(re=>{if(re.type==="timeZoneName"){const fe=this.originalZone.offsetName(this.dt.ts,{locale:this.dt.locale,format:this.opts.timeZoneName});return{...re,value:fe}}else return re}):I}resolvedOptions(){return this.dtf.resolvedOptions()}}class Ot{constructor(I,re,fe){this.opts={style:"long",...fe},!re&&uo()&&(this.rtf=ge(I,fe))}format(I,re){return this.rtf?this.rtf.format(I,re):yc(re,I,this.opts.numeric,this.opts.style!=="long")}formatToParts(I,re){return this.rtf?this.rtf.formatToParts(I,re):[]}}const Nt={firstDay:1,minimalDays:4,weekend:[6,7]};class gt{static fromOpts(I){return gt.create(I.locale,I.numberingSystem,I.outputCalendar,I.weekSettings,I.defaultToEN)}static create(I,re,fe,xe,Te=!1){const Qe=I||dt.defaultLocale,Be=Qe||(Te?"en-US":Ne()),je=re||dt.defaultNumberingSystem,Ct=fe||dt.defaultOutputCalendar,Kt=_s(xe)||dt.defaultWeekSettings;return new gt(Be,je,Ct,Kt,Qe)}static resetCache(){we=null,ve.clear(),_e.clear(),me.clear(),Re.clear(),tt.clear()}static fromObject({locale:I,numberingSystem:re,outputCalendar:fe,weekSettings:xe}={}){return gt.create(I,re,fe,xe)}constructor(I,re,fe,xe,Te){const[Qe,Be,je]=$e(I);this.locale=Qe,this.numberingSystem=re||Be||null,this.outputCalendar=fe||je||null,this.weekSettings=xe,this.intl=Ae(this.locale,this.numberingSystem,this.outputCalendar),this.weekdaysCache={format:{},standalone:{}},this.monthsCache={format:{},standalone:{}},this.meridiemCache=null,this.eraCache={},this.specifiedLocale=Te,this.fastNumbersCached=null}get fastNumbers(){return this.fastNumbersCached==null&&(this.fastNumbersCached=Me(this)),this.fastNumbersCached}listingMode(){const I=this.isEnglish(),re=(this.numberingSystem===null||this.numberingSystem==="latn")&&(this.outputCalendar===null||this.outputCalendar==="gregory");return I&&re?"en":"intl"}clone(I){return!I||Object.getOwnPropertyNames(I).length===0?this:gt.create(I.locale||this.specifiedLocale,I.numberingSystem||this.numberingSystem,I.outputCalendar||this.outputCalendar,_s(I.weekSettings)||this.weekSettings,I.defaultToEN||!1)}redefaultToEN(I={}){return this.clone({...I,defaultToEN:!0})}redefaultToSystem(I={}){return this.clone({...I,defaultToEN:!1})}months(I,re=!1){return Ye(this,I,xp,()=>{const fe=this.intl==="ja"||this.intl.startsWith("ja-");re&=!fe;const xe=re?{month:I,day:"numeric"}:{month:I},Te=re?"format":"standalone";if(!this.monthsCache[Te][I]){const Qe=fe?Be=>this.dtFormatter(Be,xe).format():Be=>this.extract(Be,xe,"month");this.monthsCache[Te][I]=Ue(Qe)}return this.monthsCache[Te][I]})}weekdays(I,re=!1){return Ye(this,I,ch,()=>{const fe=re?{weekday:I,year:"numeric",month:"long",day:"numeric"}:{weekday:I},xe=re?"format":"standalone";return this.weekdaysCache[xe][I]||(this.weekdaysCache[xe][I]=Ze(Te=>this.extract(Te,fe,"weekday"))),this.weekdaysCache[xe][I]})}meridiems(){return Ye(this,void 0,()=>Cs,()=>{if(!this.meridiemCache){const I={hour:"numeric",hourCycle:"h12"};this.meridiemCache=[pn.utc(2016,11,13,9),pn.utc(2016,11,13,19)].map(re=>this.extract(re,I,"dayperiod"))}return this.meridiemCache})}eras(I){return Ye(this,I,_p,()=>{const re={era:I};return this.eraCache[I]||(this.eraCache[I]=[pn.utc(-40,1,1),pn.utc(2017,1,1)].map(fe=>this.extract(fe,re,"era"))),this.eraCache[I]})}extract(I,re,fe){const xe=this.dtFormatter(I,re),Te=xe.formatToParts(),Qe=Te.find(Be=>Be.type.toLowerCase()===fe);return Qe?Qe.value:null}numberFormatter(I={}){return new ze(this.intl,I.forceSimple||this.fastNumbers,I)}dtFormatter(I,re={}){return new st(I,this.intl,re)}relFormatter(I={}){return new Ot(this.intl,this.isEnglish(),I)}listFormatter(I={}){return be(this.intl,I)}isEnglish(){return this.locale==="en"||this.locale.toLowerCase()==="en-us"||et(this.intl).locale.startsWith("en-us")}getWeekSettings(){return this.weekSettings?this.weekSettings:Xn()?Oe(this.locale):Nt}getStartOfWeek(){return this.getWeekSettings().firstDay}getMinDaysInFirstWeek(){return this.getWeekSettings().minimalDays}getWeekendDays(){return this.getWeekSettings().weekend}equals(I){return this.locale===I.locale&&this.numberingSystem===I.numberingSystem&&this.outputCalendar===I.outputCalendar}toString(){return`Locale(${this.locale}, ${this.numberingSystem}, ${this.outputCalendar})`}}let qt=null;class zt extends J{static get utcInstance(){return qt===null&&(qt=new zt(0)),qt}static instance(I){return I===0?zt.utcInstance:new zt(I)}static parseSpecifier(I){if(I){const re=I.match(/^utc(?:([+-]\d{1,2})(?::(\d{2}))?)?$/i);if(re)return new zt(gc(re[1],re[2]))}return null}constructor(I){super(),this.fixed=I}get type(){return"fixed"}get name(){return this.fixed===0?"UTC":`UTC${Ds(this.fixed,"narrow")}`}get ianaName(){return this.fixed===0?"Etc/UTC":`Etc/GMT${Ds(-this.fixed,"narrow")}`}offsetName(){return this.name}formatOffset(I,re){return Ds(this.fixed,re)}get isUniversal(){return!0}offset(){return this.fixed}equals(I){return I.type==="fixed"&&I.fixed===this.fixed}get isValid(){return!0}}class an extends J{constructor(I){super(),this.zoneName=I}get type(){return"invalid"}get name(){return this.zoneName}get isUniversal(){return!1}offsetName(){return null}formatOffset(){return""}offset(){return NaN}equals(){return!1}get isValid(){return!1}}function rn(ue,I){if(Pt(ue)||ue===null)return I;if(ue instanceof J)return ue;if(ti(ue)){const re=ue.toLowerCase();return re==="default"?I:re==="local"||re==="system"?H.instance:re==="utc"||re==="gmt"?zt.utcInstance:zt.parseSpecifier(re)||ie.create(ue)}else return ca(ue)?zt.instance(ue):typeof ue=="object"&&"offset"in ue&&typeof ue.offset=="function"?ue:new an(ue)}const Fe={arab:"[٠-٩]",arabext:"[۰-۹]",bali:"[᭐-᭙]",beng:"[০-৯]",deva:"[०-९]",fullwide:"[０-９]",gujr:"[૦-૯]",hanidec:"[〇|一|二|三|四|五|六|七|八|九]",khmr:"[០-៩]",knda:"[೦-೯]",laoo:"[໐-໙]",limb:"[᥆-᥏]",mlym:"[൦-൯]",mong:"[᠐-᠙]",mymr:"[၀-၉]",orya:"[୦-୯]",tamldec:"[௦-௯]",telu:"[౦-౯]",thai:"[๐-๙]",tibt:"[༠-༩]",latn:"\\d"},ht={arab:[1632,1641],arabext:[1776,1785],bali:[6992,7001],beng:[2534,2543],deva:[2406,2415],fullwide:[65296,65303],gujr:[2790,2799],khmr:[6112,6121],knda:[3302,3311],laoo:[3792,3801],limb:[6470,6479],mlym:[3430,3439],mong:[6160,6169],mymr:[4160,4169],orya:[2918,2927],tamldec:[3046,3055],telu:[3174,3183],thai:[3664,3673],tibt:[3872,3881]},Tt=Fe.hanidec.replace(/[\[|\]]/g,"").split("");function Qt(ue){let I=parseInt(ue,10);if(isNaN(I)){I="";for(let re=0;re<ue.length;re++){const fe=ue.charCodeAt(re);if(ue[re].search(Fe.hanidec)!==-1)I+=Tt.indexOf(ue[re]);else for(const xe in ht){const[Te,Qe]=ht[xe];fe>=Te&&fe<=Qe&&(I+=fe-Te)}}return parseInt(I,10)}else return I}const un=new Map;function Ln(){un.clear()}function ln({numberingSystem:ue},I=""){const re=ue||"latn";let fe=un.get(re);fe===void 0&&(fe=new Map,un.set(re,fe));let xe=fe.get(I);return xe===void 0&&(xe=new RegExp(`${Fe[re]}${I}`),fe.set(I,xe)),xe}let Zn=()=>Date.now(),cr="system",ur=null,Cr=null,Vr=null,ke=60,He,nt=null;class dt{static get now(){return Zn}static set now(I){Zn=I}static set defaultZone(I){cr=I}static get defaultZone(){return rn(cr,H.instance)}static get defaultLocale(){return ur}static set defaultLocale(I){ur=I}static get defaultNumberingSystem(){return Cr}static set defaultNumberingSystem(I){Cr=I}static get defaultOutputCalendar(){return Vr}static set defaultOutputCalendar(I){Vr=I}static get defaultWeekSettings(){return nt}static set defaultWeekSettings(I){nt=_s(I)}static get twoDigitCutoffYear(){return ke}static set twoDigitCutoffYear(I){ke=I%100}static get throwOnInvalid(){return He}static set throwOnInvalid(I){He=I}static resetCaches(){gt.resetCache(),ie.resetCache(),pn.resetCache(),Ln()}}class $t{constructor(I,re){this.reason=I,this.explanation=re}toMessage(){return this.explanation?`${this.reason}: ${this.explanation}`:this.reason}}const Ut=[0,31,59,90,120,151,181,212,243,273,304,334],Zt=[0,31,60,91,121,152,182,213,244,274,305,335];function Lt(ue,I){return new $t("unit out of range",`you specified ${I} (of type ${typeof I}) as a ${ue}, which is invalid`)}function Vt(ue,I,re){const fe=new Date(Date.UTC(ue,I-1,re));ue<100&&ue>=0&&fe.setUTCFullYear(fe.getUTCFullYear()-1900);const xe=fe.getUTCDay();return xe===0?7:xe}function tn(ue,I,re){return re+(Lo(ue)?Zt:Ut)[I-1]}function nn(ue,I){const re=Lo(ue)?Zt:Ut,fe=re.findIndex(Te=>Te<I),xe=I-re[fe];return{month:fe+1,day:xe}}function Rt(ue,I){return(ue-I+7)%7+1}function sn(ue,I=4,re=1){const{year:fe,month:xe,day:Te}=ue,Qe=tn(fe,xe,Te),Be=Rt(Vt(fe,xe,Te),re);let je=Math.floor((Qe-Be+14-I)/7),Ct;return je<1?(Ct=fe-1,je=Es(Ct,I,re)):je>Es(fe,I,re)?(Ct=fe+1,je=1):Ct=fe,{weekYear:Ct,weekNumber:je,weekday:Be,...$s(ue)}}function gr(ue,I=4,re=1){const{weekYear:fe,weekNumber:xe,weekday:Te}=ue,Qe=Rt(Vt(fe,1,I),re),Be=Tl(fe);let je=xe*7+Te-Qe-7+I,Ct;je<1?(Ct=fe-1,je+=Tl(Ct)):je>Be?(Ct=fe+1,je-=Tl(fe)):Ct=fe;const{month:Kt,day:Qn}=nn(Ct,je);return{year:Ct,month:Kt,day:Qn,...$s(ue)}}function Pi(ue){const{year:I,month:re,day:fe}=ue,xe=tn(I,re,fe);return{year:I,ordinal:xe,...$s(ue)}}function Da(ue){const{year:I,ordinal:re}=ue,{month:fe,day:xe}=nn(I,re);return{year:I,month:fe,day:xe,...$s(ue)}}function mi(ue,I){if(!Pt(ue.localWeekday)||!Pt(ue.localWeekNumber)||!Pt(ue.localWeekYear)){if(!Pt(ue.weekday)||!Pt(ue.weekNumber)||!Pt(ue.weekYear))throw new i("Cannot mix locale-based week fields with ISO-based week fields");return Pt(ue.localWeekday)||(ue.weekday=ue.localWeekday),Pt(ue.localWeekNumber)||(ue.weekNumber=ue.localWeekNumber),Pt(ue.localWeekYear)||(ue.weekYear=ue.localWeekYear),delete ue.localWeekday,delete ue.localWeekNumber,delete ue.localWeekYear,{minDaysInFirstWeek:I.getMinDaysInFirstWeek(),startOfWeek:I.getStartOfWeek()}}else return{minDaysInFirstWeek:4,startOfWeek:1}}function Ur(ue,I=4,re=1){const fe=Wi(ue.weekYear),xe=$a(ue.weekNumber,1,Es(ue.weekYear,I,re)),Te=$a(ue.weekday,1,7);return fe?xe?Te?!1:Lt("weekday",ue.weekday):Lt("week",ue.weekNumber):Lt("weekYear",ue.weekYear)}function wu(ue){const I=Wi(ue.year),re=$a(ue.ordinal,1,Tl(ue.year));return I?re?!1:Lt("ordinal",ue.ordinal):Lt("year",ue.year)}function Al(ue){const I=Wi(ue.year),re=$a(ue.month,1,12),fe=$a(ue.day,1,oh(ue.year,ue.month));return I?re?fe?!1:Lt("day",ue.day):Lt("month",ue.month):Lt("year",ue.year)}function Hr(ue){const{hour:I,minute:re,second:fe,millisecond:xe}=ue,Te=$a(I,0,23)||I===24&&re===0&&fe===0&&xe===0,Qe=$a(re,0,59),Be=$a(fe,0,59),je=$a(xe,0,999);return Te?Qe?Be?je?!1:Lt("millisecond",xe):Lt("second",fe):Lt("minute",re):Lt("hour",I)}function Pt(ue){return typeof ue>"u"}function ca(ue){return typeof ue=="number"}function Wi(ue){return typeof ue=="number"&&ue%1===0}function ti(ue){return typeof ue=="string"}function Ru(ue){return Object.prototype.toString.call(ue)==="[object Date]"}function uo(){try{return typeof Intl<"u"&&!!Intl.RelativeTimeFormat}catch{return!1}}function Xn(){try{return typeof Intl<"u"&&!!Intl.Locale&&("weekInfo"in Intl.Locale.prototype||"getWeekInfo"in Intl.Locale.prototype)}catch{return!1}}function gi(ue){return Array.isArray(ue)?ue:[ue]}function xs(ue,I,re){if(ue.length!==0)return ue.reduce((fe,xe)=>{const Te=[I(xe),xe];return fe&&re(fe[0],Te[0])===fe[0]?fe:Te},null)[1]}function Ss(ue,I){return I.reduce((re,fe)=>(re[fe]=ue[fe],re),{})}function ni(ue,I){return Object.prototype.hasOwnProperty.call(ue,I)}function _s(ue){if(ue==null)return null;if(typeof ue!="object")throw new u("Week settings must be an object");if(!$a(ue.firstDay,1,7)||!$a(ue.minimalDays,1,7)||!Array.isArray(ue.weekend)||ue.weekend.some(I=>!$a(I,1,7)))throw new u("Invalid week settings");return{firstDay:ue.firstDay,minimalDays:ue.minimalDays,weekend:Array.from(ue.weekend)}}function $a(ue,I,re){return Wi(ue)&&ue>=I&&ue<=re}function pc(ue,I){return ue-I*Math.floor(ue/I)}function Fr(ue,I=2){const re=ue<0;let fe;return re?fe="-"+(""+-ue).padStart(I,"0"):fe=(""+ue).padStart(I,"0"),fe}function Ji(ue){if(!(Pt(ue)||ue===null||ue===""))return parseInt(ue,10)}function Io(ue){if(!(Pt(ue)||ue===null||ue===""))return parseFloat(ue)}function Op(ue){if(!(Pt(ue)||ue===null||ue==="")){const I=parseFloat("0."+ue)*1e3;return Math.floor(I)}}function mf(ue,I,re="round"){const fe=10**I;switch(re){case"expand":return ue>0?Math.ceil(ue*fe)/fe:Math.floor(ue*fe)/fe;case"trunc":return Math.trunc(ue*fe)/fe;case"round":return Math.round(ue*fe)/fe;case"floor":return Math.floor(ue*fe)/fe;case"ceil":return Math.ceil(ue*fe)/fe;default:throw new RangeError(`Value rounding ${re} is out of range`)}}function Lo(ue){return ue%4===0&&(ue%100!==0||ue%400===0)}function Tl(ue){return Lo(ue)?366:365}function oh(ue,I){const re=pc(I-1,12)+1,fe=ue+(I-re)/12;return re===2?Lo(fe)?29:28:[31,null,31,30,31,30,31,31,30,31,30,31][re-1]}function Ha(ue){let I=Date.UTC(ue.year,ue.month-1,ue.day,ue.hour,ue.minute,ue.second,ue.millisecond);return ue.year<100&&ue.year>=0&&(I=new Date(I),I.setUTCFullYear(ue.year,ue.month-1,ue.day)),+I}function td(ue,I,re){return-Rt(Vt(ue,1,I),re)+I-1}function Es(ue,I=4,re=1){const fe=td(ue,I,re),xe=td(ue+1,I,re);return(Tl(ue)-fe+xe)/7}function nd(ue){return ue>99?ue:ue>dt.twoDigitCutoffYear?1900+ue:2e3+ue}function mc(ue,I,re,fe=null){const xe=new Date(ue),Te={hourCycle:"h23",year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit"};fe&&(Te.timeZone=fe);const Qe={timeZoneName:I,...Te},Be=new Intl.DateTimeFormat(re,Qe).formatToParts(xe).find(je=>je.type.toLowerCase()==="timezonename");return Be?Be.value:null}function gc(ue,I){let re=parseInt(ue,10);Number.isNaN(re)&&(re=0);const fe=parseInt(I,10)||0,xe=re<0||Object.is(re,-0)?-fe:fe;return re*60+xe}function Bo(ue){const I=Number(ue);if(typeof ue=="boolean"||ue===""||!Number.isFinite(I))throw new u(`Invalid unit value ${ue}`);return I}function Au(ue,I){const re={};for(const fe in ue)if(ni(ue,fe)){const xe=ue[fe];if(xe==null)continue;re[I(fe)]=Bo(xe)}return re}function Ds(ue,I){const re=Math.trunc(Math.abs(ue/60)),fe=Math.trunc(Math.abs(ue%60)),xe=ue>=0?"+":"-";switch(I){case"short":return`${xe}${Fr(re,2)}:${Fr(fe,2)}`;case"narrow":return`${xe}${re}${fe>0?`:${fe}`:""}`;case"techie":return`${xe}${Fr(re,2)}${Fr(fe,2)}`;default:throw new RangeError(`Value format ${I} is out of range for property format`)}}function $s(ue){return Ss(ue,["hour","minute","second","millisecond"])}const Z0=["January","February","March","April","May","June","July","August","September","October","November","December"],gf=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],H0=["J","F","M","A","M","J","J","A","S","O","N","D"];function xp(ue){switch(ue){case"narrow":return[...H0];case"short":return[...gf];case"long":return[...Z0];case"numeric":return["1","2","3","4","5","6","7","8","9","10","11","12"];case"2-digit":return["01","02","03","04","05","06","07","08","09","10","11","12"];default:return null}}const vf=["Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Sunday"],lo=["Mon","Tue","Wed","Thu","Fri","Sat","Sun"],sh=["M","T","W","T","F","S","S"];function ch(ue){switch(ue){case"narrow":return[...sh];case"short":return[...lo];case"long":return[...vf];case"numeric":return["1","2","3","4","5","6","7"];default:return null}}const Cs=["AM","PM"],vc=["Before Christ","Anno Domini"],X0=["BC","AD"],Sp=["B","A"];function _p(ue){switch(ue){case"narrow":return[...Sp];case"short":return[...X0];case"long":return[...vc];default:return null}}function ws(ue){return Cs[ue.hour<12?0:1]}function Qo(ue,I){return ch(I)[ue.weekday-1]}function Ep(ue,I){return xp(I)[ue.month-1]}function fh(ue,I){return _p(I)[ue.year<0?0:1]}function yc(ue,I,re="always",fe=!1){const xe={years:["year","yr."],quarters:["quarter","qtr."],months:["month","mo."],weeks:["week","wk."],days:["day","day","days"],hours:["hour","hr."],minutes:["minute","min."],seconds:["second","sec."]},Te=["hours","minutes","seconds"].indexOf(ue)===-1;if(re==="auto"&&Te){const Qn=ue==="days";switch(I){case 1:return Qn?"tomorrow":`next ${xe[ue][0]}`;case-1:return Qn?"yesterday":`last ${xe[ue][0]}`;case 0:return Qn?"today":`this ${xe[ue][0]}`}}const Qe=Object.is(I,-0)||I<0,Be=Math.abs(I),je=Be===1,Ct=xe[ue],Kt=fe?je?Ct[1]:Ct[2]||Ct[1]:je?xe[ue][0]:ue;return Qe?`${Be} ${Kt} ago`:`in ${Be} ${Kt}`}function dh(ue,I){let re="";for(const fe of ue)fe.literal?re+=fe.val:re+=I(fe.val);return re}const wr={D:d,DD:h,DDD:y,DDDD:v,t:_,tt:S,ttt:E,tttt:C,T,TT:R,TTT:$,TTTT:k,f:F,ff:j,fff:N,ffff:W,F:L,FF:V,FFF:U,FFFF:G};class Bn{static create(I,re={}){return new Bn(I,re)}static parseFormat(I){let re=null,fe="",xe=!1;const Te=[];for(let Qe=0;Qe<I.length;Qe++){const Be=I.charAt(Qe);Be==="'"?((fe.length>0||xe)&&Te.push({literal:xe||/^\s+$/.test(fe),val:fe===""?"'":fe}),re=null,fe="",xe=!xe):xe||Be===re?fe+=Be:(fe.length>0&&Te.push({literal:/^\s+$/.test(fe),val:fe}),fe=Be,re=Be)}return fe.length>0&&Te.push({literal:xe||/^\s+$/.test(fe),val:fe}),Te}static macroTokenToFormatOpts(I){return wr[I]}constructor(I,re){this.opts=re,this.loc=I,this.systemLoc=null}formatWithSystemDefault(I,re){return this.systemLoc===null&&(this.systemLoc=this.loc.redefaultToSystem()),this.systemLoc.dtFormatter(I,{...this.opts,...re}).format()}dtFormatter(I,re={}){return this.loc.dtFormatter(I,{...this.opts,...re})}formatDateTime(I,re){return this.dtFormatter(I,re).format()}formatDateTimeParts(I,re){return this.dtFormatter(I,re).formatToParts()}formatInterval(I,re){return this.dtFormatter(I.start,re).dtf.formatRange(I.start.toJSDate(),I.end.toJSDate())}resolvedOptions(I,re){return this.dtFormatter(I,re).resolvedOptions()}num(I,re=0,fe=void 0){if(this.opts.forceSimple)return Fr(I,re);const xe={...this.opts};return re>0&&(xe.padTo=re),fe&&(xe.signDisplay=fe),this.loc.numberFormatter(xe).format(I)}formatDateTimeFromString(I,re){const fe=this.loc.listingMode()==="en",xe=this.loc.outputCalendar&&this.loc.outputCalendar!=="gregory",Te=(vn,Di)=>this.loc.extract(I,vn,Di),Qe=vn=>I.isOffsetFixed&&I.offset===0&&vn.allowZ?"Z":I.isValid?I.zone.formatOffset(I.ts,vn.format):"",Be=()=>fe?ws(I):Te({hour:"numeric",hourCycle:"h12"},"dayperiod"),je=(vn,Di)=>fe?Ep(I,vn):Te(Di?{month:vn}:{month:vn,day:"numeric"},"month"),Ct=(vn,Di)=>fe?Qo(I,vn):Te(Di?{weekday:vn}:{weekday:vn,month:"long",day:"numeric"},"weekday"),Kt=vn=>{const Di=Bn.macroTokenToFormatOpts(vn);return Di?this.formatWithSystemDefault(I,Di):vn},Qn=vn=>fe?fh(I,vn):Te({era:vn},"era"),cn=vn=>{switch(vn){case"S":return this.num(I.millisecond);case"u":case"SSS":return this.num(I.millisecond,3);case"s":return this.num(I.second);case"ss":return this.num(I.second,2);case"uu":return this.num(Math.floor(I.millisecond/10),2);case"uuu":return this.num(Math.floor(I.millisecond/100));case"m":return this.num(I.minute);case"mm":return this.num(I.minute,2);case"h":return this.num(I.hour%12===0?12:I.hour%12);case"hh":return this.num(I.hour%12===0?12:I.hour%12,2);case"H":return this.num(I.hour);case"HH":return this.num(I.hour,2);case"Z":return Qe({format:"narrow",allowZ:this.opts.allowZ});case"ZZ":return Qe({format:"short",allowZ:this.opts.allowZ});case"ZZZ":return Qe({format:"techie",allowZ:this.opts.allowZ});case"ZZZZ":return I.zone.offsetName(I.ts,{format:"short",locale:this.loc.locale});case"ZZZZZ":return I.zone.offsetName(I.ts,{format:"long",locale:this.loc.locale});case"z":return I.zoneName;case"a":return Be();case"d":return xe?Te({day:"numeric"},"day"):this.num(I.day);case"dd":return xe?Te({day:"2-digit"},"day"):this.num(I.day,2);case"c":return this.num(I.weekday);case"ccc":return Ct("short",!0);case"cccc":return Ct("long",!0);case"ccccc":return Ct("narrow",!0);case"E":return this.num(I.weekday);case"EEE":return Ct("short",!1);case"EEEE":return Ct("long",!1);case"EEEEE":return Ct("narrow",!1);case"L":return xe?Te({month:"numeric",day:"numeric"},"month"):this.num(I.month);case"LL":return xe?Te({month:"2-digit",day:"numeric"},"month"):this.num(I.month,2);case"LLL":return je("short",!0);case"LLLL":return je("long",!0);case"LLLLL":return je("narrow",!0);case"M":return xe?Te({month:"numeric"},"month"):this.num(I.month);case"MM":return xe?Te({month:"2-digit"},"month"):this.num(I.month,2);case"MMM":return je("short",!1);case"MMMM":return je("long",!1);case"MMMMM":return je("narrow",!1);case"y":return xe?Te({year:"numeric"},"year"):this.num(I.year);case"yy":return xe?Te({year:"2-digit"},"year"):this.num(I.year.toString().slice(-2),2);case"yyyy":return xe?Te({year:"numeric"},"year"):this.num(I.year,4);case"yyyyyy":return xe?Te({year:"numeric"},"year"):this.num(I.year,6);case"G":return Qn("short");case"GG":return Qn("long");case"GGGGG":return Qn("narrow");case"kk":return this.num(I.weekYear.toString().slice(-2),2);case"kkkk":return this.num(I.weekYear,4);case"W":return this.num(I.weekNumber);case"WW":return this.num(I.weekNumber,2);case"n":return this.num(I.localWeekNumber);case"nn":return this.num(I.localWeekNumber,2);case"ii":return this.num(I.localWeekYear.toString().slice(-2),2);case"iiii":return this.num(I.localWeekYear,4);case"o":return this.num(I.ordinal);case"ooo":return this.num(I.ordinal,3);case"q":return this.num(I.quarter);case"qq":return this.num(I.quarter,2);case"X":return this.num(Math.floor(I.ts/1e3));case"x":return this.num(I.ts);default:return Kt(vn)}};return dh(Bn.parseFormat(re),cn)}formatDurationFromString(I,re){const fe=this.opts.signMode==="negativeLargestOnly"?-1:1,xe=Kt=>{switch(Kt[0]){case"S":return"milliseconds";case"s":return"seconds";case"m":return"minutes";case"h":return"hours";case"d":return"days";case"w":return"weeks";case"M":return"months";case"y":return"years";default:return null}},Te=(Kt,Qn)=>cn=>{const vn=xe(cn);if(vn){const Di=Qn.isNegativeDuration&&vn!==Qn.largestUnit?fe:1;let Qa;return this.opts.signMode==="negativeLargestOnly"&&vn!==Qn.largestUnit?Qa="never":this.opts.signMode==="all"?Qa="always":Qa="auto",this.num(Kt.get(vn)*Di,cn.length,Qa)}else return cn},Qe=Bn.parseFormat(re),Be=Qe.reduce((Kt,{literal:Qn,val:cn})=>Qn?Kt:Kt.concat(cn),[]),je=I.shiftTo(...Be.map(xe).filter(Kt=>Kt)),Ct={isNegativeDuration:je<0,largestUnit:Object.keys(je.values)[0]};return dh(Qe,Te(je,Ct))}}const bc=/[A-Za-z_+-]{1,256}(?::?\/[A-Za-z0-9_+-]{1,256}(?:\/[A-Za-z0-9_+-]{1,256})?)?/;function zo(...ue){const I=ue.reduce((re,fe)=>re+fe.source,"");return RegExp(`^${I}$`)}function Oc(...ue){return I=>ue.reduce(([re,fe,xe],Te)=>{const[Qe,Be,je]=Te(I,xe);return[{...re,...Qe},Be||fe,je]},[{},null,1]).slice(0,2)}function ea(ue,...I){if(ue==null)return[null,null];for(const[re,fe]of I){const xe=re.exec(ue);if(xe)return fe(xe)}return[null,null]}function Rs(...ue){return(I,re)=>{const fe={};let xe;for(xe=0;xe<ue.length;xe++)fe[ue[xe]]=Ji(I[re+xe]);return[fe,null,re+xe]}}const rd=/(?:([Zz])|([+-]\d\d)(?::?(\d\d))?)/,kl=`(?:${rd.source}?(?:\\[(${bc.source})\\])?)?`,id=/(\d\d)(?::?(\d\d)(?::?(\d\d)(?:[.,](\d{1,30}))?)?)?/,ta=RegExp(`${id.source}${kl}`),As=RegExp(`(?:[Tt]${ta.source})?`),Pl=/([+-]\d{6}|\d{4})(?:-?(\d\d)(?:-?(\d\d))?)?/,ad=/(\d{4})-?W(\d\d)(?:-?(\d))?/,Dp=/(\d{4})-?(\d{3})/,ri=Rs("weekYear","weekNumber","weekDay"),Y0=Rs("year","ordinal"),G0=/(\d{4})-(\d\d)-(\d\d)/,ud=RegExp(`${id.source} ?(?:${rd.source}|(${bc.source}))?`),K0=RegExp(`(?: ${ud.source})?`);function xc(ue,I,re){const fe=ue[I];return Pt(fe)?re:Ji(fe)}function ld(ue,I){return[{year:xc(ue,I),month:xc(ue,I+1,1),day:xc(ue,I+2,1)},null,I+3]}function fa(ue,I){return[{hours:xc(ue,I,0),minutes:xc(ue,I+1,0),seconds:xc(ue,I+2,0),milliseconds:Op(ue[I+3])},null,I+4]}function od(ue,I){const re=!ue[I]&&!ue[I+1],fe=gc(ue[I+1],ue[I+2]),xe=re?null:zt.instance(fe);return[{},xe,I+3]}function La(ue,I){const re=ue[I]?ie.create(ue[I]):null;return[{},re,I+1]}const _g=RegExp(`^T?${id.source}$`),$p=/^-?P(?:(?:(-?\d{1,20}(?:\.\d{1,20})?)Y)?(?:(-?\d{1,20}(?:\.\d{1,20})?)M)?(?:(-?\d{1,20}(?:\.\d{1,20})?)W)?(?:(-?\d{1,20}(?:\.\d{1,20})?)D)?(?:T(?:(-?\d{1,20}(?:\.\d{1,20})?)H)?(?:(-?\d{1,20}(?:\.\d{1,20})?)M)?(?:(-?\d{1,20})(?:[.,](-?\d{1,20}))?S)?)?)$/;function qo(ue){const[I,re,fe,xe,Te,Qe,Be,je,Ct]=ue,Kt=I[0]==="-",Qn=je&&je[0]==="-",cn=(vn,Di=!1)=>vn!==void 0&&(Di||vn&&Kt)?-vn:vn;return[{years:cn(Io(re)),months:cn(Io(fe)),weeks:cn(Io(xe)),days:cn(Io(Te)),hours:cn(Io(Qe)),minutes:cn(Io(Be)),seconds:cn(Io(je),je==="-0"),milliseconds:cn(Op(Ct),Qn)}]}const hh={GMT:0,EDT:-240,EST:-300,CDT:-300,CST:-360,MDT:-360,MST:-420,PDT:-420,PST:-480};function Ts(ue,I,re,fe,xe,Te,Qe){const Be={year:I.length===2?nd(Ji(I)):Ji(I),month:gf.indexOf(re)+1,day:Ji(fe),hour:Ji(xe),minute:Ji(Te)};return Qe&&(Be.second=Ji(Qe)),ue&&(Be.weekday=ue.length>3?vf.indexOf(ue)+1:lo.indexOf(ue)+1),Be}const vi=/^(?:(Mon|Tue|Wed|Thu|Fri|Sat|Sun),\s)?(\d{1,2})\s(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s(\d{2,4})\s(\d\d):(\d\d)(?::(\d\d))?\s(?:(UT|GMT|[ECMP][SD]T)|([Zz])|(?:([+-]\d\d)(\d\d)))$/;function Vo(ue){const[,I,re,fe,xe,Te,Qe,Be,je,Ct,Kt,Qn]=ue,cn=Ts(I,xe,fe,re,Te,Qe,Be);let vn;return je?vn=hh[je]:Ct?vn=0:vn=gc(Kt,Qn),[cn,new zt(vn)]}function Cp(ue){return ue.replace(/\([^()]*\)|[\n\t]/g," ").replace(/(\s\s+)/g," ").trim()}const wp=/^(Mon|Tue|Wed|Thu|Fri|Sat|Sun), (\d\d) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) (\d{4}) (\d\d):(\d\d):(\d\d) GMT$/,Rp=/^(Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday), (\d\d)-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-(\d\d) (\d\d):(\d\d):(\d\d) GMT$/,ks=/^(Mon|Tue|Wed|Thu|Fri|Sat|Sun) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) ( \d|\d\d) (\d\d):(\d\d):(\d\d) (\d{4})$/;function Ap(ue){const[,I,re,fe,xe,Te,Qe,Be]=ue;return[Ts(I,xe,fe,re,Te,Qe,Be),zt.utcInstance]}function Dy(ue){const[,I,re,fe,xe,Te,Qe,Be]=ue;return[Ts(I,Be,re,fe,xe,Te,Qe),zt.utcInstance]}const W0=zo(Pl,As),oo=zo(ad,As),Xu=zo(Dp,As),J0=zo(ta),ph=Oc(ld,fa,od,La),Sc=Oc(ri,fa,od,La),Uo=Oc(Y0,fa,od,La),Ps=Oc(fa,od,La);function Ba(ue){return ea(ue,[W0,ph],[oo,Sc],[Xu,Uo],[J0,Ps])}function mh(ue){return ea(Cp(ue),[vi,Vo])}function gh(ue){return ea(ue,[wp,Ap],[Rp,Ap],[ks,Dy])}function sd(ue){return ea(ue,[$p,qo])}const cd=Oc(fa);function Ms(ue){return ea(ue,[_g,cd])}const fu=zo(G0,K0),Tp=zo(ud),Xa=Oc(fa,od,La);function kp(ue){return ea(ue,[fu,ph],[Tp,Xa])}const fd="Invalid Duration",yf={weeks:{days:7,hours:168,minutes:10080,seconds:10080*60,milliseconds:10080*60*1e3},days:{hours:24,minutes:1440,seconds:1440*60,milliseconds:1440*60*1e3},hours:{minutes:60,seconds:3600,milliseconds:3600*1e3},minutes:{seconds:60,milliseconds:60*1e3},seconds:{milliseconds:1e3}},dd={years:{quarters:4,months:12,weeks:52,days:365,hours:365*24,minutes:365*24*60,seconds:365*24*60*60,milliseconds:365*24*60*60*1e3},quarters:{months:3,weeks:13,days:91,hours:2184,minutes:2184*60,seconds:2184*60*60,milliseconds:2184*60*60*1e3},months:{weeks:4,days:30,hours:720,minutes:720*60,seconds:720*60*60,milliseconds:720*60*60*1e3},...yf},Yu=146097/400,so=146097/4800,em={years:{quarters:4,months:12,weeks:Yu/7,days:Yu,hours:Yu*24,minutes:Yu*24*60,seconds:Yu*24*60*60,milliseconds:Yu*24*60*60*1e3},quarters:{months:3,weeks:Yu/28,days:Yu/4,hours:Yu*24/4,minutes:Yu*24*60/4,seconds:Yu*24*60*60/4,milliseconds:Yu*24*60*60*1e3/4},months:{weeks:so/7,days:so,hours:so*24,minutes:so*24*60,seconds:so*24*60*60,milliseconds:so*24*60*60*1e3},...yf},du=["years","quarters","months","weeks","days","hours","minutes","seconds","milliseconds"],bf=du.slice(0).reverse();function Sr(ue,I,re=!1){const fe={values:re?I.values:{...ue.values,...I.values||{}},loc:ue.loc.clone(I.loc),conversionAccuracy:I.conversionAccuracy||ue.conversionAccuracy,matrix:I.matrix||ue.matrix};return new Kn(fe)}function vh(ue,I){var re;let fe=(re=I.milliseconds)!=null?re:0;for(const xe of bf.slice(1))I[xe]&&(fe+=I[xe]*ue[xe].milliseconds);return fe}function Pp(ue,I){const re=vh(ue,I)<0?-1:1;du.reduceRight((fe,xe)=>{if(Pt(I[xe]))return fe;if(fe){const Te=I[fe]*re,Qe=ue[xe][fe],Be=Math.floor(Te/Qe);I[xe]+=Be*re,I[fe]-=Be*Qe*re}return xe},null),du.reduce((fe,xe)=>{if(Pt(I[xe]))return fe;if(fe){const Te=I[fe]%1;I[fe]-=Te,I[xe]+=Te*ue[fe][xe]}return xe},null)}function co(ue){const I={};for(const[re,fe]of Object.entries(ue))fe!==0&&(I[re]=fe);return I}class Kn{constructor(I){const re=I.conversionAccuracy==="longterm"||!1;let fe=re?em:dd;I.matrix&&(fe=I.matrix),this.values=I.values,this.loc=I.loc||gt.create(),this.conversionAccuracy=re?"longterm":"casual",this.invalid=I.invalid||null,this.matrix=fe,this.isLuxonDuration=!0}static fromMillis(I,re){return Kn.fromObject({milliseconds:I},re)}static fromObject(I,re={}){if(I==null||typeof I!="object")throw new u(`Duration.fromObject: argument expected to be an object, got ${I===null?"null":typeof I}`);return new Kn({values:Au(I,Kn.normalizeUnit),loc:gt.fromObject(re),conversionAccuracy:re.conversionAccuracy,matrix:re.matrix})}static fromDurationLike(I){if(ca(I))return Kn.fromMillis(I);if(Kn.isDuration(I))return I;if(typeof I=="object")return Kn.fromObject(I);throw new u(`Unknown duration argument ${I} of type ${typeof I}`)}static fromISO(I,re){const[fe]=sd(I);return fe?Kn.fromObject(fe,re):Kn.invalid("unparsable",`the input "${I}" can't be parsed as ISO 8601`)}static fromISOTime(I,re){const[fe]=Ms(I);return fe?Kn.fromObject(fe,re):Kn.invalid("unparsable",`the input "${I}" can't be parsed as ISO 8601`)}static invalid(I,re=null){if(!I)throw new u("need to specify a reason the Duration is invalid");const fe=I instanceof $t?I:new $t(I,re);if(dt.throwOnInvalid)throw new r(fe);return new Kn({invalid:fe})}static normalizeUnit(I){const re={year:"years",years:"years",quarter:"quarters",quarters:"quarters",month:"months",months:"months",week:"weeks",weeks:"weeks",day:"days",days:"days",hour:"hours",hours:"hours",minute:"minutes",minutes:"minutes",second:"seconds",seconds:"seconds",millisecond:"milliseconds",milliseconds:"milliseconds"}[I&&I.toLowerCase()];if(!re)throw new a(I);return re}static isDuration(I){return I&&I.isLuxonDuration||!1}get locale(){return this.isValid?this.loc.locale:null}get numberingSystem(){return this.isValid?this.loc.numberingSystem:null}toFormat(I,re={}){const fe={...re,floor:re.round!==!1&&re.floor!==!1};return this.isValid?Bn.create(this.loc,fe).formatDurationFromString(this,I):fd}toHuman(I={}){if(!this.isValid)return fd;const re=I.showZeros!==!1,fe=du.map(xe=>{const Te=this.values[xe];return Pt(Te)||Te===0&&!re?null:this.loc.numberFormatter({style:"unit",unitDisplay:"long",...I,unit:xe.slice(0,-1)}).format(Te)}).filter(xe=>xe);return this.loc.listFormatter({type:"conjunction",style:I.listStyle||"narrow",...I}).format(fe)}toObject(){return this.isValid?{...this.values}:{}}toISO(){if(!this.isValid)return null;let I="P";return this.years!==0&&(I+=this.years+"Y"),(this.months!==0||this.quarters!==0)&&(I+=this.months+this.quarters*3+"M"),this.weeks!==0&&(I+=this.weeks+"W"),this.days!==0&&(I+=this.days+"D"),(this.hours!==0||this.minutes!==0||this.seconds!==0||this.milliseconds!==0)&&(I+="T"),this.hours!==0&&(I+=this.hours+"H"),this.minutes!==0&&(I+=this.minutes+"M"),(this.seconds!==0||this.milliseconds!==0)&&(I+=mf(this.seconds+this.milliseconds/1e3,3)+"S"),I==="P"&&(I+="T0S"),I}toISOTime(I={}){if(!this.isValid)return null;const re=this.toMillis();return re<0||re>=864e5?null:(I={suppressMilliseconds:!1,suppressSeconds:!1,includePrefix:!1,format:"extended",...I,includeOffset:!1},pn.fromMillis(re,{zone:"UTC"}).toISOTime(I))}toJSON(){return this.toISO()}toString(){return this.toISO()}[Symbol.for("nodejs.util.inspect.custom")](){return this.isValid?`Duration { values: ${JSON.stringify(this.values)} }`:`Duration { Invalid, reason: ${this.invalidReason} }`}toMillis(){return this.isValid?vh(this.matrix,this.values):NaN}valueOf(){return this.toMillis()}plus(I){if(!this.isValid)return this;const re=Kn.fromDurationLike(I),fe={};for(const xe of du)(ni(re.values,xe)||ni(this.values,xe))&&(fe[xe]=re.get(xe)+this.get(xe));return Sr(this,{values:fe},!0)}minus(I){if(!this.isValid)return this;const re=Kn.fromDurationLike(I);return this.plus(re.negate())}mapUnits(I){if(!this.isValid)return this;const re={};for(const fe of Object.keys(this.values))re[fe]=Bo(I(this.values[fe],fe));return Sr(this,{values:re},!0)}get(I){return this[Kn.normalizeUnit(I)]}set(I){if(!this.isValid)return this;const re={...this.values,...Au(I,Kn.normalizeUnit)};return Sr(this,{values:re})}reconfigure({locale:I,numberingSystem:re,conversionAccuracy:fe,matrix:xe}={}){const Qe={loc:this.loc.clone({locale:I,numberingSystem:re}),matrix:xe,conversionAccuracy:fe};return Sr(this,Qe)}as(I){return this.isValid?this.shiftTo(I).get(I):NaN}normalize(){if(!this.isValid)return this;const I=this.toObject();return Pp(this.matrix,I),Sr(this,{values:I},!0)}rescale(){if(!this.isValid)return this;const I=co(this.normalize().shiftToAll().toObject());return Sr(this,{values:I},!0)}shiftTo(...I){if(!this.isValid)return this;if(I.length===0)return this;I=I.map(Qe=>Kn.normalizeUnit(Qe));const re={},fe={},xe=this.toObject();let Te;for(const Qe of du)if(I.indexOf(Qe)>=0){Te=Qe;let Be=0;for(const Ct in fe)Be+=this.matrix[Ct][Qe]*fe[Ct],fe[Ct]=0;ca(xe[Qe])&&(Be+=xe[Qe]);const je=Math.trunc(Be);re[Qe]=je,fe[Qe]=(Be*1e3-je*1e3)/1e3}else ca(xe[Qe])&&(fe[Qe]=xe[Qe]);for(const Qe in fe)fe[Qe]!==0&&(re[Te]+=Qe===Te?fe[Qe]:fe[Qe]/this.matrix[Te][Qe]);return Pp(this.matrix,re),Sr(this,{values:re},!0)}shiftToAll(){return this.isValid?this.shiftTo("years","months","weeks","days","hours","minutes","seconds","milliseconds"):this}negate(){if(!this.isValid)return this;const I={};for(const re of Object.keys(this.values))I[re]=this.values[re]===0?0:-this.values[re];return Sr(this,{values:I},!0)}removeZeros(){if(!this.isValid)return this;const I=co(this.values);return Sr(this,{values:I},!0)}get years(){return this.isValid?this.values.years||0:NaN}get quarters(){return this.isValid?this.values.quarters||0:NaN}get months(){return this.isValid?this.values.months||0:NaN}get weeks(){return this.isValid?this.values.weeks||0:NaN}get days(){return this.isValid?this.values.days||0:NaN}get hours(){return this.isValid?this.values.hours||0:NaN}get minutes(){return this.isValid?this.values.minutes||0:NaN}get seconds(){return this.isValid?this.values.seconds||0:NaN}get milliseconds(){return this.isValid?this.values.milliseconds||0:NaN}get isValid(){return this.invalid===null}get invalidReason(){return this.invalid?this.invalid.reason:null}get invalidExplanation(){return this.invalid?this.invalid.explanation:null}equals(I){if(!this.isValid||!I.isValid||!this.loc.equals(I.loc))return!1;function re(fe,xe){return fe===void 0||fe===0?xe===void 0||xe===0:fe===xe}for(const fe of du)if(!re(this.values[fe],I.values[fe]))return!1;return!0}}const yl="Invalid Interval";function Eg(ue,I){return!ue||!ue.isValid?Mi.invalid("missing or invalid start"):!I||!I.isValid?Mi.invalid("missing or invalid end"):I<ue?Mi.invalid("end before start",`The end of an interval must be after its start, but you had start=${ue.toISO()} and end=${I.toISO()}`):null}class Mi{constructor(I){this.s=I.start,this.e=I.end,this.invalid=I.invalid||null,this.isLuxonInterval=!0}static invalid(I,re=null){if(!I)throw new u("need to specify a reason the Interval is invalid");const fe=I instanceof $t?I:new $t(I,re);if(dt.throwOnInvalid)throw new n(fe);return new Mi({invalid:fe})}static fromDateTimes(I,re){const fe=Pu(I),xe=Pu(re),Te=Eg(fe,xe);return Te??new Mi({start:fe,end:xe})}static after(I,re){const fe=Kn.fromDurationLike(re),xe=Pu(I);return Mi.fromDateTimes(xe,xe.plus(fe))}static before(I,re){const fe=Kn.fromDurationLike(re),xe=Pu(I);return Mi.fromDateTimes(xe.minus(fe),xe)}static fromISO(I,re){const[fe,xe]=(I||"").split("/",2);if(fe&&xe){let Te,Qe;try{Te=pn.fromISO(fe,re),Qe=Te.isValid}catch{Qe=!1}let Be,je;try{Be=pn.fromISO(xe,re),je=Be.isValid}catch{je=!1}if(Qe&&je)return Mi.fromDateTimes(Te,Be);if(Qe){const Ct=Kn.fromISO(xe,re);if(Ct.isValid)return Mi.after(Te,Ct)}else if(je){const Ct=Kn.fromISO(fe,re);if(Ct.isValid)return Mi.before(Be,Ct)}}return Mi.invalid("unparsable",`the input "${I}" can't be parsed as ISO 8601`)}static isInterval(I){return I&&I.isLuxonInterval||!1}get start(){return this.isValid?this.s:null}get end(){return this.isValid?this.e:null}get lastDateTime(){return this.isValid&&this.e?this.e.minus(1):null}get isValid(){return this.invalidReason===null}get invalidReason(){return this.invalid?this.invalid.reason:null}get invalidExplanation(){return this.invalid?this.invalid.explanation:null}length(I="milliseconds"){return this.isValid?this.toDuration(I).get(I):NaN}count(I="milliseconds",re){if(!this.isValid)return NaN;const fe=this.start.startOf(I,re);let xe;return re!=null&&re.useLocaleWeeks?xe=this.end.reconfigure({locale:fe.locale}):xe=this.end,xe=xe.startOf(I,re),Math.floor(xe.diff(fe,I).get(I))+(xe.valueOf()!==this.end.valueOf())}hasSame(I){return this.isValid?this.isEmpty()||this.e.minus(1).hasSame(this.s,I):!1}isEmpty(){return this.s.valueOf()===this.e.valueOf()}isAfter(I){return this.isValid?this.s>I:!1}isBefore(I){return this.isValid?this.e<=I:!1}contains(I){return this.isValid?this.s<=I&&this.e>I:!1}set({start:I,end:re}={}){return this.isValid?Mi.fromDateTimes(I||this.s,re||this.e):this}splitAt(...I){if(!this.isValid)return[];const re=I.map(Pu).filter(Qe=>this.contains(Qe)).sort((Qe,Be)=>Qe.toMillis()-Be.toMillis()),fe=[];let{s:xe}=this,Te=0;for(;xe<this.e;){const Qe=re[Te]||this.e,Be=+Qe>+this.e?this.e:Qe;fe.push(Mi.fromDateTimes(xe,Be)),xe=Be,Te+=1}return fe}splitBy(I){const re=Kn.fromDurationLike(I);if(!this.isValid||!re.isValid||re.as("milliseconds")===0)return[];let{s:fe}=this,xe=1,Te;const Qe=[];for(;fe<this.e;){const Be=this.start.plus(re.mapUnits(je=>je*xe));Te=+Be>+this.e?this.e:Be,Qe.push(Mi.fromDateTimes(fe,Te)),fe=Te,xe+=1}return Qe}divideEqually(I){return this.isValid?this.splitBy(this.length()/I).slice(0,I):[]}overlaps(I){return this.e>I.s&&this.s<I.e}abutsStart(I){return this.isValid?+this.e==+I.s:!1}abutsEnd(I){return this.isValid?+I.e==+this.s:!1}engulfs(I){return this.isValid?this.s<=I.s&&this.e>=I.e:!1}equals(I){return!this.isValid||!I.isValid?!1:this.s.equals(I.s)&&this.e.equals(I.e)}intersection(I){if(!this.isValid)return this;const re=this.s>I.s?this.s:I.s,fe=this.e<I.e?this.e:I.e;return re>=fe?null:Mi.fromDateTimes(re,fe)}union(I){if(!this.isValid)return this;const re=this.s<I.s?this.s:I.s,fe=this.e>I.e?this.e:I.e;return Mi.fromDateTimes(re,fe)}static merge(I){const[re,fe]=I.sort((xe,Te)=>xe.s-Te.s).reduce(([xe,Te],Qe)=>Te?Te.overlaps(Qe)||Te.abutsStart(Qe)?[xe,Te.union(Qe)]:[xe.concat([Te]),Qe]:[xe,Qe],[[],null]);return fe&&re.push(fe),re}static xor(I){let re=null,fe=0;const xe=[],Te=I.map(je=>[{time:je.s,type:"s"},{time:je.e,type:"e"}]),Qe=Array.prototype.concat(...Te),Be=Qe.sort((je,Ct)=>je.time-Ct.time);for(const je of Be)fe+=je.type==="s"?1:-1,fe===1?re=je.time:(re&&+re!=+je.time&&xe.push(Mi.fromDateTimes(re,je.time)),re=null);return Mi.merge(xe)}difference(...I){return Mi.xor([this].concat(I)).map(re=>this.intersection(re)).filter(re=>re&&!re.isEmpty())}toString(){return this.isValid?`[${this.s.toISO()} – ${this.e.toISO()})`:yl}[Symbol.for("nodejs.util.inspect.custom")](){return this.isValid?`Interval { start: ${this.s.toISO()}, end: ${this.e.toISO()} }`:`Interval { Invalid, reason: ${this.invalidReason} }`}toLocaleString(I=d,re={}){return this.isValid?Bn.create(this.s.loc.clone(re),I).formatInterval(this):yl}toISO(I){return this.isValid?`${this.s.toISO(I)}/${this.e.toISO(I)}`:yl}toISODate(){return this.isValid?`${this.s.toISODate()}/${this.e.toISODate()}`:yl}toISOTime(I){return this.isValid?`${this.s.toISOTime(I)}/${this.e.toISOTime(I)}`:yl}toFormat(I,{separator:re=" – "}={}){return this.isValid?`${this.s.toFormat(I)}${re}${this.e.toFormat(I)}`:yl}toDuration(I,re){return this.isValid?this.e.diff(this.s,I,re):Kn.invalid(this.invalidReason)}mapEndpoints(I){return Mi.fromDateTimes(I(this.s),I(this.e))}}class hu{static hasDST(I=dt.defaultZone){const re=pn.now().setZone(I).set({month:12});return!I.isUniversal&&re.offset!==re.set({month:6}).offset}static isValidIANAZone(I){return ie.isValidZone(I)}static normalizeZone(I){return rn(I,dt.defaultZone)}static getStartOfWeek({locale:I=null,locObj:re=null}={}){return(re||gt.create(I)).getStartOfWeek()}static getMinimumDaysInFirstWeek({locale:I=null,locObj:re=null}={}){return(re||gt.create(I)).getMinDaysInFirstWeek()}static getWeekendWeekdays({locale:I=null,locObj:re=null}={}){return(re||gt.create(I)).getWeekendDays().slice()}static months(I="long",{locale:re=null,numberingSystem:fe=null,locObj:xe=null,outputCalendar:Te="gregory"}={}){return(xe||gt.create(re,fe,Te)).months(I)}static monthsFormat(I="long",{locale:re=null,numberingSystem:fe=null,locObj:xe=null,outputCalendar:Te="gregory"}={}){return(xe||gt.create(re,fe,Te)).months(I,!0)}static weekdays(I="long",{locale:re=null,numberingSystem:fe=null,locObj:xe=null}={}){return(xe||gt.create(re,fe,null)).weekdays(I)}static weekdaysFormat(I="long",{locale:re=null,numberingSystem:fe=null,locObj:xe=null}={}){return(xe||gt.create(re,fe,null)).weekdays(I,!0)}static meridiems({locale:I=null}={}){return gt.create(I).meridiems()}static eras(I="short",{locale:re=null}={}){return gt.create(re,null,"gregory").eras(I)}static features(){return{relative:uo(),localeWeek:Xn()}}}function fr(ue,I){const re=xe=>xe.toUTC(0,{keepLocalTime:!0}).startOf("day").valueOf(),fe=re(I)-re(ue);return Math.floor(Kn.fromMillis(fe).as("days"))}function Of(ue,I,re){const fe=[["years",(je,Ct)=>Ct.year-je.year],["quarters",(je,Ct)=>Ct.quarter-je.quarter+(Ct.year-je.year)*4],["months",(je,Ct)=>Ct.month-je.month+(Ct.year-je.year)*12],["weeks",(je,Ct)=>{const Kt=fr(je,Ct);return(Kt-Kt%7)/7}],["days",fr]],xe={},Te=ue;let Qe,Be;for(const[je,Ct]of fe)re.indexOf(je)>=0&&(Qe=je,xe[je]=Ct(ue,I),Be=Te.plus(xe),Be>I?(xe[je]--,ue=Te.plus(xe),ue>I&&(Be=ue,xe[je]--,ue=Te.plus(xe))):ue=Be);return[ue,xe,Be,Qe]}function tm(ue,I,re,fe){let[xe,Te,Qe,Be]=Of(ue,I,re);const je=I-xe,Ct=re.filter(Qn=>["hours","minutes","seconds","milliseconds"].indexOf(Qn)>=0);Ct.length===0&&(Qe<I&&(Qe=xe.plus({[Be]:1})),Qe!==xe&&(Te[Be]=(Te[Be]||0)+je/(Qe-xe)));const Kt=Kn.fromObject(Te,fe);return Ct.length>0?Kn.fromMillis(je,fe).shiftTo(...Ct).plus(Kt):Kt}const nm="missing Intl.DateTimeFormat.formatToParts support";function vr(ue,I=re=>re){return{regex:ue,deser:([re])=>I(Qt(re))}}const xf="[  ]",_c=new RegExp(xf,"g");function Xe(ue){return ue.replace(/\./g,"\\.?").replace(_c,xf)}function pt(ue){return ue.replace(/\./g,"").replace(_c," ").toLowerCase()}function rt(ue,I){return ue===null?null:{regex:RegExp(ue.map(Xe).join("|")),deser:([re])=>ue.findIndex(fe=>pt(re)===pt(fe))+I}}function Bt(ue,I){return{regex:ue,deser:([,re,fe])=>gc(re,fe),groups:I}}function Dn(ue){return{regex:ue,deser:([I])=>I}}function rr(ue){return ue.replace(/[\-\[\]{}()*+?.,\\\^$|#\s]/g,"\\$&")}function Fi(ue,I){const re=ln(I),fe=ln(I,"{2}"),xe=ln(I,"{3}"),Te=ln(I,"{4}"),Qe=ln(I,"{6}"),Be=ln(I,"{1,2}"),je=ln(I,"{1,3}"),Ct=ln(I,"{1,6}"),Kt=ln(I,"{1,9}"),Qn=ln(I,"{2,4}"),cn=ln(I,"{4,6}"),vn=Se=>({regex:RegExp(rr(Se.val)),deser:([bl])=>bl,literal:!0}),Qa=(Se=>{if(ue.literal)return vn(Se);switch(Se.val){case"G":return rt(I.eras("short"),0);case"GG":return rt(I.eras("long"),0);case"y":return vr(Ct);case"yy":return vr(Qn,nd);case"yyyy":return vr(Te);case"yyyyy":return vr(cn);case"yyyyyy":return vr(Qe);case"M":return vr(Be);case"MM":return vr(fe);case"MMM":return rt(I.months("short",!0),1);case"MMMM":return rt(I.months("long",!0),1);case"L":return vr(Be);case"LL":return vr(fe);case"LLL":return rt(I.months("short",!1),1);case"LLLL":return rt(I.months("long",!1),1);case"d":return vr(Be);case"dd":return vr(fe);case"o":return vr(je);case"ooo":return vr(xe);case"HH":return vr(fe);case"H":return vr(Be);case"hh":return vr(fe);case"h":return vr(Be);case"mm":return vr(fe);case"m":return vr(Be);case"q":return vr(Be);case"qq":return vr(fe);case"s":return vr(Be);case"ss":return vr(fe);case"S":return vr(je);case"SSS":return vr(xe);case"u":return Dn(Kt);case"uu":return Dn(Be);case"uuu":return vr(re);case"a":return rt(I.meridiems(),0);case"kkkk":return vr(Te);case"kk":return vr(Qn,nd);case"W":return vr(Be);case"WW":return vr(fe);case"E":case"c":return vr(re);case"EEE":return rt(I.weekdays("short",!1),1);case"EEEE":return rt(I.weekdays("long",!1),1);case"ccc":return rt(I.weekdays("short",!0),1);case"cccc":return rt(I.weekdays("long",!0),1);case"Z":case"ZZ":return Bt(new RegExp(`([+-]${Be.source})(?::(${fe.source}))?`),2);case"ZZZ":return Bt(new RegExp(`([+-]${Be.source})(${fe.source})?`),2);case"z":return Dn(/[a-z_+-/]{1,256}?/i);case" ":return Dn(/[^\S\n\r]/);default:return vn(Se)}})(ue)||{invalidReason:nm};return Qa.token=ue,Qa}const Nr={year:{"2-digit":"yy",numeric:"yyyyy"},month:{numeric:"M","2-digit":"MM",short:"MMM",long:"MMMM"},day:{numeric:"d","2-digit":"dd"},weekday:{short:"EEE",long:"EEEE"},dayperiod:"a",dayPeriod:"a",hour12:{numeric:"h","2-digit":"hh"},hour24:{numeric:"H","2-digit":"HH"},minute:{numeric:"m","2-digit":"mm"},second:{numeric:"s","2-digit":"ss"},timeZoneName:{long:"ZZZZZ",short:"ZZZ"}};function Ya(ue,I,re){const{type:fe,value:xe}=ue;if(fe==="literal"){const je=/^\s+$/.test(xe);return{literal:!je,val:je?" ":xe}}const Te=I[fe];let Qe=fe;fe==="hour"&&(I.hour12!=null?Qe=I.hour12?"hour12":"hour24":I.hourCycle!=null?I.hourCycle==="h11"||I.hourCycle==="h12"?Qe="hour12":Qe="hour24":Qe=re.hour12?"hour12":"hour24");let Be=Nr[Qe];if(typeof Be=="object"&&(Be=Be[Te]),Be)return{literal:!1,val:Be}}function Ec(ue){return[`^${ue.map(re=>re.regex).reduce((re,fe)=>`${re}(${fe.source})`,"")}$`,ue]}function _i(ue,I,re){const fe=ue.match(I);if(fe){const xe={};let Te=1;for(const Qe in re)if(ni(re,Qe)){const Be=re[Qe],je=Be.groups?Be.groups+1:1;!Be.literal&&Be.token&&(xe[Be.token.val[0]]=Be.deser(fe.slice(Te,Te+je))),Te+=je}return[fe,xe]}else return[fe,{}]}function hd(ue){const I=Te=>{switch(Te){case"S":return"millisecond";case"s":return"second";case"m":return"minute";case"h":case"H":return"hour";case"d":return"day";case"o":return"ordinal";case"L":case"M":return"month";case"y":return"year";case"E":case"c":return"weekday";case"W":return"weekNumber";case"k":return"weekYear";case"q":return"quarter";default:return null}};let re=null,fe;return Pt(ue.z)||(re=ie.create(ue.z)),Pt(ue.Z)||(re||(re=new zt(ue.Z)),fe=ue.Z),Pt(ue.q)||(ue.M=(ue.q-1)*3+1),Pt(ue.h)||(ue.h<12&&ue.a===1?ue.h+=12:ue.h===12&&ue.a===0&&(ue.h=0)),ue.G===0&&ue.y&&(ue.y=-ue.y),Pt(ue.u)||(ue.S=Op(ue.u)),[Object.keys(ue).reduce((Te,Qe)=>{const Be=I(Qe);return Be&&(Te[Be]=ue[Qe]),Te},{}),re,fe]}let Ml=null;function fo(){return Ml||(Ml=pn.fromMillis(1555555555555)),Ml}function ho(ue,I){if(ue.literal)return ue;const re=Bn.macroTokenToFormatOpts(ue.val),fe=da(re,I);return fe==null||fe.includes(void 0)?ue:fe}function Sf(ue,I){return Array.prototype.concat(...ue.map(re=>ho(re,I)))}class _r{constructor(I,re){if(this.locale=I,this.format=re,this.tokens=Sf(Bn.parseFormat(re),I),this.units=this.tokens.map(fe=>Fi(fe,I)),this.disqualifyingUnit=this.units.find(fe=>fe.invalidReason),!this.disqualifyingUnit){const[fe,xe]=Ec(this.units);this.regex=RegExp(fe,"i"),this.handlers=xe}}explainFromTokens(I){if(this.isValid){const[re,fe]=_i(I,this.regex,this.handlers),[xe,Te,Qe]=fe?hd(fe):[null,null,void 0];if(ni(fe,"a")&&ni(fe,"H"))throw new i("Can't include meridiem when specifying 24-hour format");return{input:I,tokens:this.tokens,regex:this.regex,rawMatches:re,matches:fe,result:xe,zone:Te,specificOffset:Qe}}else return{input:I,tokens:this.tokens,invalidReason:this.invalidReason}}get isValid(){return!this.disqualifyingUnit}get invalidReason(){return this.disqualifyingUnit?this.disqualifyingUnit.invalidReason:null}}function jo(ue,I,re){return new _r(ue,re).explainFromTokens(I)}function yh(ue,I,re){const{result:fe,zone:xe,specificOffset:Te,invalidReason:Qe}=jo(ue,I,re);return[fe,xe,Te,Qe]}function da(ue,I){if(!ue)return null;const fe=Bn.create(I,ue).dtFormatter(fo()),xe=fe.formatToParts(),Te=fe.resolvedOptions();return xe.map(Qe=>Ya(Qe,ue,Te))}const Zo="Invalid DateTime",Ca=864e13;function po(ue){return new $t("unsupported zone",`the zone "${ue.name}" is not supported`)}function Fs(ue){return ue.weekData===null&&(ue.weekData=sn(ue.c)),ue.weekData}function Ga(ue){return ue.localWeekData===null&&(ue.localWeekData=sn(ue.c,ue.loc.getMinDaysInFirstWeek(),ue.loc.getStartOfWeek())),ue.localWeekData}function Gu(ue,I){const re={ts:ue.ts,zone:ue.zone,c:ue.c,o:ue.o,loc:ue.loc,invalid:ue.invalid};return new pn({...re,...I,old:re})}function Dc(ue,I,re){let fe=ue-I*60*1e3;const xe=re.offset(fe);if(I===xe)return[fe,I];fe-=(xe-I)*60*1e3;const Te=re.offset(fe);return xe===Te?[fe,xe]:[ue-Math.min(xe,Te)*60*1e3,Math.max(xe,Te)]}function Ku(ue,I){ue+=I*60*1e3;const re=new Date(ue);return{year:re.getUTCFullYear(),month:re.getUTCMonth()+1,day:re.getUTCDate(),hour:re.getUTCHours(),minute:re.getUTCMinutes(),second:re.getUTCSeconds(),millisecond:re.getUTCMilliseconds()}}function $c(ue,I,re){return Dc(Ha(ue),I,re)}function Cc(ue,I){const re=ue.o,fe=ue.c.year+Math.trunc(I.years),xe=ue.c.month+Math.trunc(I.months)+Math.trunc(I.quarters)*3,Te={...ue.c,year:fe,month:xe,day:Math.min(ue.c.day,oh(fe,xe))+Math.trunc(I.days)+Math.trunc(I.weeks)*7},Qe=Kn.fromObject({years:I.years-Math.trunc(I.years),quarters:I.quarters-Math.trunc(I.quarters),months:I.months-Math.trunc(I.months),weeks:I.weeks-Math.trunc(I.weeks),days:I.days-Math.trunc(I.days),hours:I.hours,minutes:I.minutes,seconds:I.seconds,milliseconds:I.milliseconds}).as("milliseconds"),Be=Ha(Te);let[je,Ct]=Dc(Be,re,ue.zone);return Qe!==0&&(je+=Qe,Ct=ue.zone.offset(je)),{ts:je,o:Ct}}function pu(ue,I,re,fe,xe,Te){const{setZone:Qe,zone:Be}=re;if(ue&&Object.keys(ue).length!==0||I){const je=I||Be,Ct=pn.fromObject(ue,{...re,zone:je,specificOffset:Te});return Qe?Ct:Ct.setZone(Be)}else return pn.invalid(new $t("unparsable",`the input "${xe}" can't be parsed as ${fe}`))}function pd(ue,I,re=!0){return ue.isValid?Bn.create(gt.create("en-US"),{allowZ:re,forceSimple:!0}).formatDateTimeFromString(ue,I):null}function na(ue,I,re){const fe=ue.c.year>9999||ue.c.year<0;let xe="";if(fe&&ue.c.year>=0&&(xe+="+"),xe+=Fr(ue.c.year,fe?6:4),re==="year")return xe;if(I){if(xe+="-",xe+=Fr(ue.c.month),re==="month")return xe;xe+="-"}else if(xe+=Fr(ue.c.month),re==="month")return xe;return xe+=Fr(ue.c.day),xe}function Xi(ue,I,re,fe,xe,Te,Qe){let Be=!re||ue.c.millisecond!==0||ue.c.second!==0,je="";switch(Qe){case"day":case"month":case"year":break;default:if(je+=Fr(ue.c.hour),Qe==="hour")break;if(I){if(je+=":",je+=Fr(ue.c.minute),Qe==="minute")break;Be&&(je+=":",je+=Fr(ue.c.second))}else{if(je+=Fr(ue.c.minute),Qe==="minute")break;Be&&(je+=Fr(ue.c.second))}if(Qe==="second")break;Be&&(!fe||ue.c.millisecond!==0)&&(je+=".",je+=Fr(ue.c.millisecond,3))}return xe&&(ue.isOffsetFixed&&ue.offset===0&&!Te?je+="Z":ue.o<0?(je+="-",je+=Fr(Math.trunc(-ue.o/60)),je+=":",je+=Fr(Math.trunc(-ue.o%60))):(je+="+",je+=Fr(Math.trunc(ue.o/60)),je+=":",je+=Fr(Math.trunc(ue.o%60)))),Te&&(je+="["+ue.zone.ianaName+"]"),je}const Wu={month:1,day:1,hour:0,minute:0,second:0,millisecond:0},mu={weekNumber:1,weekday:1,hour:0,minute:0,second:0,millisecond:0},bh={ordinal:1,hour:0,minute:0,second:0,millisecond:0},Fl=["year","month","day","hour","minute","second","millisecond"],_f=["weekYear","weekNumber","weekday","hour","minute","second","millisecond"],Oh=["year","ordinal","hour","minute","second","millisecond"];function gu(ue){const I={year:"year",years:"year",month:"month",months:"month",day:"day",days:"day",hour:"hour",hours:"hour",minute:"minute",minutes:"minute",quarter:"quarter",quarters:"quarter",second:"second",seconds:"second",millisecond:"millisecond",milliseconds:"millisecond",weekday:"weekday",weekdays:"weekday",weeknumber:"weekNumber",weeksnumber:"weekNumber",weeknumbers:"weekNumber",weekyear:"weekYear",weekyears:"weekYear",ordinal:"ordinal"}[ue.toLowerCase()];if(!I)throw new a(ue);return I}function Mp(ue){switch(ue.toLowerCase()){case"localweekday":case"localweekdays":return"localWeekday";case"localweeknumber":case"localweeknumbers":return"localWeekNumber";case"localweekyear":case"localweekyears":return"localWeekYear";default:return gu(ue)}}function Tu(ue){if(Ei===void 0&&(Ei=dt.now()),ue.type!=="iana")return ue.offset(Ei);const I=ue.name;let re=ku.get(I);return re===void 0&&(re=ue.offset(Ei),ku.set(I,re)),re}function Nl(ue,I){const re=rn(I.zone,dt.defaultZone);if(!re.isValid)return pn.invalid(po(re));const fe=gt.fromObject(I);let xe,Te;if(Pt(ue.year))xe=dt.now();else{for(const je of Fl)Pt(ue[je])&&(ue[je]=Wu[je]);const Qe=Al(ue)||Hr(ue);if(Qe)return pn.invalid(Qe);const Be=Tu(re);[xe,Te]=$c(ue,Be,re)}return new pn({ts:xe,zone:re,loc:fe,o:Te})}function wc(ue,I,re){const fe=Pt(re.round)?!0:re.round,xe=Pt(re.rounding)?"trunc":re.rounding,Te=(Be,je)=>(Be=mf(Be,fe||re.calendary?0:2,re.calendary?"round":xe),I.loc.clone(re).relFormatter(re).format(Be,je)),Qe=Be=>re.calendary?I.hasSame(ue,Be)?0:I.startOf(Be).diff(ue.startOf(Be),Be).get(Be):I.diff(ue,Be).get(Be);if(re.unit)return Te(Qe(re.unit),re.unit);for(const Be of re.units){const je=Qe(Be);if(Math.abs(je)>=1)return Te(je,Be)}return Te(ue>I?-0:0,re.units[re.units.length-1])}function Ni(ue){let I={},re;return ue.length>0&&typeof ue[ue.length-1]=="object"?(I=ue[ue.length-1],re=Array.from(ue).slice(0,ue.length-1)):re=Array.from(ue),[I,re]}let Ei;const ku=new Map;class pn{constructor(I){const re=I.zone||dt.defaultZone;let fe=I.invalid||(Number.isNaN(I.ts)?new $t("invalid input"):null)||(re.isValid?null:po(re));this.ts=Pt(I.ts)?dt.now():I.ts;let xe=null,Te=null;if(!fe)if(I.old&&I.old.ts===this.ts&&I.old.zone.equals(re))[xe,Te]=[I.old.c,I.old.o];else{const Be=ca(I.o)&&!I.old?I.o:re.offset(this.ts);xe=Ku(this.ts,Be),fe=Number.isNaN(xe.year)?new $t("invalid input"):null,xe=fe?null:xe,Te=fe?null:Be}this._zone=re,this.loc=I.loc||gt.create(),this.invalid=fe,this.weekData=null,this.localWeekData=null,this.c=xe,this.o=Te,this.isLuxonDateTime=!0}static now(){return new pn({})}static local(){const[I,re]=Ni(arguments),[fe,xe,Te,Qe,Be,je,Ct]=re;return Nl({year:fe,month:xe,day:Te,hour:Qe,minute:Be,second:je,millisecond:Ct},I)}static utc(){const[I,re]=Ni(arguments),[fe,xe,Te,Qe,Be,je,Ct]=re;return I.zone=zt.utcInstance,Nl({year:fe,month:xe,day:Te,hour:Qe,minute:Be,second:je,millisecond:Ct},I)}static fromJSDate(I,re={}){const fe=Ru(I)?I.valueOf():NaN;if(Number.isNaN(fe))return pn.invalid("invalid input");const xe=rn(re.zone,dt.defaultZone);return xe.isValid?new pn({ts:fe,zone:xe,loc:gt.fromObject(re)}):pn.invalid(po(xe))}static fromMillis(I,re={}){if(ca(I))return I<-Ca||I>Ca?pn.invalid("Timestamp out of range"):new pn({ts:I,zone:rn(re.zone,dt.defaultZone),loc:gt.fromObject(re)});throw new u(`fromMillis requires a numerical input, but received a ${typeof I} with value ${I}`)}static fromSeconds(I,re={}){if(ca(I))return new pn({ts:I*1e3,zone:rn(re.zone,dt.defaultZone),loc:gt.fromObject(re)});throw new u("fromSeconds requires a numerical input")}static fromObject(I,re={}){I=I||{};const fe=rn(re.zone,dt.defaultZone);if(!fe.isValid)return pn.invalid(po(fe));const xe=gt.fromObject(re),Te=Au(I,Mp),{minDaysInFirstWeek:Qe,startOfWeek:Be}=mi(Te,xe),je=dt.now(),Ct=Pt(re.specificOffset)?fe.offset(je):re.specificOffset,Kt=!Pt(Te.ordinal),Qn=!Pt(Te.year),cn=!Pt(Te.month)||!Pt(Te.day),vn=Qn||cn,Di=Te.weekYear||Te.weekNumber;if((vn||Kt)&&Di)throw new i("Can't mix weekYear/weekNumber units with year/month/day or ordinals");if(cn&&Kt)throw new i("Can't mix ordinal dates with month/day");const Qa=Di||Te.weekday&&!vn;let Se,bl,Il=Ku(je,Ct);Qa?(Se=_f,bl=mu,Il=sn(Il,Qe,Be)):Kt?(Se=Oh,bl=bh,Il=Pi(Il)):(Se=Fl,bl=Wu);let Mu=!1;for(const Bl of Se){const md=Te[Bl];Pt(md)?Mu?Te[Bl]=bl[Bl]:Te[Bl]=Il[Bl]:Mu=!0}const zn=Qa?Ur(Te,Qe,Be):Kt?wu(Te):Al(Te),Ka=zn||Hr(Te);if(Ka)return pn.invalid(Ka);const Ns=Qa?gr(Te,Qe,Be):Kt?Da(Te):Te,[Ll,Fu]=$c(Ns,Ct,fe),Rc=new pn({ts:Ll,zone:fe,o:Fu,loc:xe});return Te.weekday&&vn&&I.weekday!==Rc.weekday?pn.invalid("mismatched weekday",`you can't specify both a weekday of ${Te.weekday} and a date of ${Rc.toISO()}`):Rc.isValid?Rc:pn.invalid(Rc.invalid)}static fromISO(I,re={}){const[fe,xe]=Ba(I);return pu(fe,xe,re,"ISO 8601",I)}static fromRFC2822(I,re={}){const[fe,xe]=mh(I);return pu(fe,xe,re,"RFC 2822",I)}static fromHTTP(I,re={}){const[fe,xe]=gh(I);return pu(fe,xe,re,"HTTP",re)}static fromFormat(I,re,fe={}){if(Pt(I)||Pt(re))throw new u("fromFormat requires an input string and a format");const{locale:xe=null,numberingSystem:Te=null}=fe,Qe=gt.fromOpts({locale:xe,numberingSystem:Te,defaultToEN:!0}),[Be,je,Ct,Kt]=yh(Qe,I,re);return Kt?pn.invalid(Kt):pu(Be,je,fe,`format ${re}`,I,Ct)}static fromString(I,re,fe={}){return pn.fromFormat(I,re,fe)}static fromSQL(I,re={}){const[fe,xe]=kp(I);return pu(fe,xe,re,"SQL",I)}static invalid(I,re=null){if(!I)throw new u("need to specify a reason the DateTime is invalid");const fe=I instanceof $t?I:new $t(I,re);if(dt.throwOnInvalid)throw new t(fe);return new pn({invalid:fe})}static isDateTime(I){return I&&I.isLuxonDateTime||!1}static parseFormatForOpts(I,re={}){const fe=da(I,gt.fromObject(re));return fe?fe.map(xe=>xe?xe.val:null).join(""):null}static expandFormat(I,re={}){return Sf(Bn.parseFormat(I),gt.fromObject(re)).map(xe=>xe.val).join("")}static resetCache(){Ei=void 0,ku.clear()}get(I){return this[I]}get isValid(){return this.invalid===null}get invalidReason(){return this.invalid?this.invalid.reason:null}get invalidExplanation(){return this.invalid?this.invalid.explanation:null}get locale(){return this.isValid?this.loc.locale:null}get numberingSystem(){return this.isValid?this.loc.numberingSystem:null}get outputCalendar(){return this.isValid?this.loc.outputCalendar:null}get zone(){return this._zone}get zoneName(){return this.isValid?this.zone.name:null}get year(){return this.isValid?this.c.year:NaN}get quarter(){return this.isValid?Math.ceil(this.c.month/3):NaN}get month(){return this.isValid?this.c.month:NaN}get day(){return this.isValid?this.c.day:NaN}get hour(){return this.isValid?this.c.hour:NaN}get minute(){return this.isValid?this.c.minute:NaN}get second(){return this.isValid?this.c.second:NaN}get millisecond(){return this.isValid?this.c.millisecond:NaN}get weekYear(){return this.isValid?Fs(this).weekYear:NaN}get weekNumber(){return this.isValid?Fs(this).weekNumber:NaN}get weekday(){return this.isValid?Fs(this).weekday:NaN}get isWeekend(){return this.isValid&&this.loc.getWeekendDays().includes(this.weekday)}get localWeekday(){return this.isValid?Ga(this).weekday:NaN}get localWeekNumber(){return this.isValid?Ga(this).weekNumber:NaN}get localWeekYear(){return this.isValid?Ga(this).weekYear:NaN}get ordinal(){return this.isValid?Pi(this.c).ordinal:NaN}get monthShort(){return this.isValid?hu.months("short",{locObj:this.loc})[this.month-1]:null}get monthLong(){return this.isValid?hu.months("long",{locObj:this.loc})[this.month-1]:null}get weekdayShort(){return this.isValid?hu.weekdays("short",{locObj:this.loc})[this.weekday-1]:null}get weekdayLong(){return this.isValid?hu.weekdays("long",{locObj:this.loc})[this.weekday-1]:null}get offset(){return this.isValid?+this.o:NaN}get offsetNameShort(){return this.isValid?this.zone.offsetName(this.ts,{format:"short",locale:this.locale}):null}get offsetNameLong(){return this.isValid?this.zone.offsetName(this.ts,{format:"long",locale:this.locale}):null}get isOffsetFixed(){return this.isValid?this.zone.isUniversal:null}get isInDST(){return this.isOffsetFixed?!1:this.offset>this.set({month:1,day:1}).offset||this.offset>this.set({month:5}).offset}getPossibleOffsets(){if(!this.isValid||this.isOffsetFixed)return[this];const I=864e5,re=6e4,fe=Ha(this.c),xe=this.zone.offset(fe-I),Te=this.zone.offset(fe+I),Qe=this.zone.offset(fe-xe*re),Be=this.zone.offset(fe-Te*re);if(Qe===Be)return[this];const je=fe-Qe*re,Ct=fe-Be*re,Kt=Ku(je,Qe),Qn=Ku(Ct,Be);return Kt.hour===Qn.hour&&Kt.minute===Qn.minute&&Kt.second===Qn.second&&Kt.millisecond===Qn.millisecond?[Gu(this,{ts:je}),Gu(this,{ts:Ct})]:[this]}get isInLeapYear(){return Lo(this.year)}get daysInMonth(){return oh(this.year,this.month)}get daysInYear(){return this.isValid?Tl(this.year):NaN}get weeksInWeekYear(){return this.isValid?Es(this.weekYear):NaN}get weeksInLocalWeekYear(){return this.isValid?Es(this.localWeekYear,this.loc.getMinDaysInFirstWeek(),this.loc.getStartOfWeek()):NaN}resolvedLocaleOptions(I={}){const{locale:re,numberingSystem:fe,calendar:xe}=Bn.create(this.loc.clone(I),I).resolvedOptions(this);return{locale:re,numberingSystem:fe,outputCalendar:xe}}toUTC(I=0,re={}){return this.setZone(zt.instance(I),re)}toLocal(){return this.setZone(dt.defaultZone)}setZone(I,{keepLocalTime:re=!1,keepCalendarTime:fe=!1}={}){if(I=rn(I,dt.defaultZone),I.equals(this.zone))return this;if(I.isValid){let xe=this.ts;if(re||fe){const Te=I.offset(this.ts),Qe=this.toObject();[xe]=$c(Qe,Te,I)}return Gu(this,{ts:xe,zone:I})}else return pn.invalid(po(I))}reconfigure({locale:I,numberingSystem:re,outputCalendar:fe}={}){const xe=this.loc.clone({locale:I,numberingSystem:re,outputCalendar:fe});return Gu(this,{loc:xe})}setLocale(I){return this.reconfigure({locale:I})}set(I){if(!this.isValid)return this;const re=Au(I,Mp),{minDaysInFirstWeek:fe,startOfWeek:xe}=mi(re,this.loc),Te=!Pt(re.weekYear)||!Pt(re.weekNumber)||!Pt(re.weekday),Qe=!Pt(re.ordinal),Be=!Pt(re.year),je=!Pt(re.month)||!Pt(re.day),Ct=Be||je,Kt=re.weekYear||re.weekNumber;if((Ct||Qe)&&Kt)throw new i("Can't mix weekYear/weekNumber units with year/month/day or ordinals");if(je&&Qe)throw new i("Can't mix ordinal dates with month/day");let Qn;Te?Qn=gr({...sn(this.c,fe,xe),...re},fe,xe):Pt(re.ordinal)?(Qn={...this.toObject(),...re},Pt(re.day)&&(Qn.day=Math.min(oh(Qn.year,Qn.month),Qn.day))):Qn=Da({...Pi(this.c),...re});const[cn,vn]=$c(Qn,this.o,this.zone);return Gu(this,{ts:cn,o:vn})}plus(I){if(!this.isValid)return this;const re=Kn.fromDurationLike(I);return Gu(this,Cc(this,re))}minus(I){if(!this.isValid)return this;const re=Kn.fromDurationLike(I).negate();return Gu(this,Cc(this,re))}startOf(I,{useLocaleWeeks:re=!1}={}){if(!this.isValid)return this;const fe={},xe=Kn.normalizeUnit(I);switch(xe){case"years":fe.month=1;case"quarters":case"months":fe.day=1;case"weeks":case"days":fe.hour=0;case"hours":fe.minute=0;case"minutes":fe.second=0;case"seconds":fe.millisecond=0;break}if(xe==="weeks")if(re){const Te=this.loc.getStartOfWeek(),{weekday:Qe}=this;Qe<Te&&(fe.weekNumber=this.weekNumber-1),fe.weekday=Te}else fe.weekday=1;if(xe==="quarters"){const Te=Math.ceil(this.month/3);fe.month=(Te-1)*3+1}return this.set(fe)}endOf(I,re){return this.isValid?this.plus({[I]:1}).startOf(I,re).minus(1):this}toFormat(I,re={}){return this.isValid?Bn.create(this.loc.redefaultToEN(re)).formatDateTimeFromString(this,I):Zo}toLocaleString(I=d,re={}){return this.isValid?Bn.create(this.loc.clone(re),I).formatDateTime(this):Zo}toLocaleParts(I={}){return this.isValid?Bn.create(this.loc.clone(I),I).formatDateTimeParts(this):[]}toISO({format:I="extended",suppressSeconds:re=!1,suppressMilliseconds:fe=!1,includeOffset:xe=!0,extendedZone:Te=!1,precision:Qe="milliseconds"}={}){if(!this.isValid)return null;Qe=gu(Qe);const Be=I==="extended";let je=na(this,Be,Qe);return Fl.indexOf(Qe)>=3&&(je+="T"),je+=Xi(this,Be,re,fe,xe,Te,Qe),je}toISODate({format:I="extended",precision:re="day"}={}){return this.isValid?na(this,I==="extended",gu(re)):null}toISOWeekDate(){return pd(this,"kkkk-'W'WW-c")}toISOTime({suppressMilliseconds:I=!1,suppressSeconds:re=!1,includeOffset:fe=!0,includePrefix:xe=!1,extendedZone:Te=!1,format:Qe="extended",precision:Be="milliseconds"}={}){return this.isValid?(Be=gu(Be),(xe&&Fl.indexOf(Be)>=3?"T":"")+Xi(this,Qe==="extended",re,I,fe,Te,Be)):null}toRFC2822(){return pd(this,"EEE, dd LLL yyyy HH:mm:ss ZZZ",!1)}toHTTP(){return pd(this.toUTC(),"EEE, dd LLL yyyy HH:mm:ss 'GMT'")}toSQLDate(){return this.isValid?na(this,!0):null}toSQLTime({includeOffset:I=!0,includeZone:re=!1,includeOffsetSpace:fe=!0}={}){let xe="HH:mm:ss.SSS";return(re||I)&&(fe&&(xe+=" "),re?xe+="z":I&&(xe+="ZZ")),pd(this,xe,!0)}toSQL(I={}){return this.isValid?`${this.toSQLDate()} ${this.toSQLTime(I)}`:null}toString(){return this.isValid?this.toISO():Zo}[Symbol.for("nodejs.util.inspect.custom")](){return this.isValid?`DateTime { ts: ${this.toISO()}, zone: ${this.zone.name}, locale: ${this.locale} }`:`DateTime { Invalid, reason: ${this.invalidReason} }`}valueOf(){return this.toMillis()}toMillis(){return this.isValid?this.ts:NaN}toSeconds(){return this.isValid?this.ts/1e3:NaN}toUnixInteger(){return this.isValid?Math.floor(this.ts/1e3):NaN}toJSON(){return this.toISO()}toBSON(){return this.toJSDate()}toObject(I={}){if(!this.isValid)return{};const re={...this.c};return I.includeConfig&&(re.outputCalendar=this.outputCalendar,re.numberingSystem=this.loc.numberingSystem,re.locale=this.loc.locale),re}toJSDate(){return new Date(this.isValid?this.ts:NaN)}diff(I,re="milliseconds",fe={}){if(!this.isValid||!I.isValid)return Kn.invalid("created by diffing an invalid DateTime");const xe={locale:this.locale,numberingSystem:this.numberingSystem,...fe},Te=gi(re).map(Kn.normalizeUnit),Qe=I.valueOf()>this.valueOf(),Be=Qe?this:I,je=Qe?I:this,Ct=tm(Be,je,Te,xe);return Qe?Ct.negate():Ct}diffNow(I="milliseconds",re={}){return this.diff(pn.now(),I,re)}until(I){return this.isValid?Mi.fromDateTimes(this,I):this}hasSame(I,re,fe){if(!this.isValid)return!1;const xe=I.valueOf(),Te=this.setZone(I.zone,{keepLocalTime:!0});return Te.startOf(re,fe)<=xe&&xe<=Te.endOf(re,fe)}equals(I){return this.isValid&&I.isValid&&this.valueOf()===I.valueOf()&&this.zone.equals(I.zone)&&this.loc.equals(I.loc)}toRelative(I={}){if(!this.isValid)return null;const re=I.base||pn.fromObject({},{zone:this.zone}),fe=I.padding?this<re?-I.padding:I.padding:0;let xe=["years","months","days","hours","minutes","seconds"],Te=I.unit;return Array.isArray(I.unit)&&(xe=I.unit,Te=void 0),wc(re,this.plus(fe),{...I,numeric:"always",units:xe,unit:Te})}toRelativeCalendar(I={}){return this.isValid?wc(I.base||pn.fromObject({},{zone:this.zone}),this,{...I,numeric:"auto",units:["years","months","days"],calendary:!0}):null}static min(...I){if(!I.every(pn.isDateTime))throw new u("min requires all arguments be DateTimes");return xs(I,re=>re.valueOf(),Math.min)}static max(...I){if(!I.every(pn.isDateTime))throw new u("max requires all arguments be DateTimes");return xs(I,re=>re.valueOf(),Math.max)}static fromFormatExplain(I,re,fe={}){const{locale:xe=null,numberingSystem:Te=null}=fe,Qe=gt.fromOpts({locale:xe,numberingSystem:Te,defaultToEN:!0});return jo(Qe,I,re)}static fromStringExplain(I,re,fe={}){return pn.fromFormatExplain(I,re,fe)}static buildFormatParser(I,re={}){const{locale:fe=null,numberingSystem:xe=null}=re,Te=gt.fromOpts({locale:fe,numberingSystem:xe,defaultToEN:!0});return new _r(Te,I)}static fromFormatParser(I,re,fe={}){if(Pt(I)||Pt(re))throw new u("fromFormatParser requires an input string and a format parser");const{locale:xe=null,numberingSystem:Te=null}=fe,Qe=gt.fromOpts({locale:xe,numberingSystem:Te,defaultToEN:!0});if(!Qe.equals(re.locale))throw new u(`fromFormatParser called with a locale of ${Qe}, but the format parser was created for ${re.locale}`);const{result:Be,zone:je,specificOffset:Ct,invalidReason:Kt}=re.explainFromTokens(I);return Kt?pn.invalid(Kt):pu(Be,je,fe,`format ${re.format}`,I,Ct)}static get DATE_SHORT(){return d}static get DATE_MED(){return h}static get DATE_MED_WITH_WEEKDAY(){return m}static get DATE_FULL(){return y}static get DATE_HUGE(){return v}static get TIME_SIMPLE(){return _}static get TIME_WITH_SECONDS(){return S}static get TIME_WITH_SHORT_OFFSET(){return E}static get TIME_WITH_LONG_OFFSET(){return C}static get TIME_24_SIMPLE(){return T}static get TIME_24_WITH_SECONDS(){return R}static get TIME_24_WITH_SHORT_OFFSET(){return $}static get TIME_24_WITH_LONG_OFFSET(){return k}static get DATETIME_SHORT(){return F}static get DATETIME_SHORT_WITH_SECONDS(){return L}static get DATETIME_MED(){return j}static get DATETIME_MED_WITH_SECONDS(){return V}static get DATETIME_MED_WITH_WEEKDAY(){return q}static get DATETIME_FULL(){return N}static get DATETIME_FULL_WITH_SECONDS(){return U}static get DATETIME_HUGE(){return W}static get DATETIME_HUGE_WITH_SECONDS(){return G}}function Pu(ue){if(pn.isDateTime(ue))return ue;if(ue&&ue.valueOf&&ca(ue.valueOf()))return pn.fromJSDate(ue);if(ue&&typeof ue=="object")return pn.fromObject(ue);throw new u(`Unknown datetime argument: ${ue}, of type ${typeof ue}`)}const Ho="3.7.1";return Hc.DateTime=pn,Hc.Duration=Kn,Hc.FixedOffsetZone=zt,Hc.IANAZone=ie,Hc.Info=hu,Hc.Interval=Mi,Hc.InvalidZone=an,Hc.Settings=dt,Hc.SystemZone=H,Hc.VERSION=Ho,Hc.Zone=J,Hc}var nY;function zw(){return nY||(nY=1,(function(e){var a,u,l,o,s,zM,d,gv;Object.defineProperty(e,"__esModule",{value:!0}),e.CronDate=e.DAYS_IN_MONTH=e.DateMathOp=e.TimeUnit=void 0;const t=Eze();var n;(function(y){y.Second="Second",y.Minute="Minute",y.Hour="Hour",y.Day="Day",y.Month="Month",y.Year="Year"})(n||(e.TimeUnit=n={}));var r;(function(y){y.Add="Add",y.Subtract="Subtract"})(r||(e.DateMathOp=r={})),e.DAYS_IN_MONTH=Object.freeze([31,29,31,30,31,30,31,31,30,31,30,31]);const m=class m{constructor(v,_){Ui(this,d);Ui(this,a);Ui(this,u,null);Ui(this,l,null);Ui(this,o,{add:{[n.Year]:this.addYear.bind(this),[n.Month]:this.addMonth.bind(this),[n.Day]:this.addDay.bind(this),[n.Hour]:this.addHour.bind(this),[n.Minute]:this.addMinute.bind(this),[n.Second]:this.addSecond.bind(this)},subtract:{[n.Year]:this.subtractYear.bind(this),[n.Month]:this.subtractMonth.bind(this),[n.Day]:this.subtractDay.bind(this),[n.Hour]:this.subtractHour.bind(this),[n.Minute]:this.subtractMinute.bind(this),[n.Second]:this.subtractSecond.bind(this)}});const S={zone:_};if(v?v instanceof m?(Rn(this,a,bt(v,a)),Rn(this,u,bt(v,u)),Rn(this,l,bt(v,l))):v instanceof Date?Rn(this,a,t.DateTime.fromJSDate(v,S)):typeof v=="number"?Rn(this,a,t.DateTime.fromMillis(v,S)):(Rn(this,a,t.DateTime.fromISO(v,S)),bt(this,a).isValid||Rn(this,a,t.DateTime.fromRFC2822(v,S)),bt(this,a).isValid||Rn(this,a,t.DateTime.fromSQL(v,S)),bt(this,a).isValid||Rn(this,a,t.DateTime.fromFormat(v,"EEE, d MMM yyyy HH:mm:ss",S))):Rn(this,a,t.DateTime.local()),!bt(this,a).isValid)throw new Error(`CronDate: unhandled timestamp: ${v}`);_&&_!==bt(this,a).zoneName&&Rn(this,a,bt(this,a).setZone(_))}get dstStart(){return bt(this,u)}set dstStart(v){Rn(this,u,v)}get dstEnd(){return bt(this,l)}set dstEnd(v){Rn(this,l,v)}addYear(){Rn(this,a,bt(this,a).plus({years:1}))}addMonth(){Rn(this,a,bt(this,a).plus({months:1}).startOf("month"))}addDay(){Rn(this,a,bt(this,a).plus({days:1}).startOf("day"))}addHour(){Rn(this,a,bt(this,a).plus({hours:1}).startOf("hour"))}addMinute(){Rn(this,a,bt(this,a).plus({minutes:1}).startOf("minute"))}addSecond(){Rn(this,a,bt(this,a).plus({seconds:1}))}subtractYear(){Rn(this,a,bt(this,a).minus({years:1}))}subtractMonth(){Rn(this,a,bt(this,a).minus({months:1}).endOf("month").startOf("second"))}subtractDay(){Rn(this,a,bt(this,a).minus({days:1}).endOf("day").startOf("second"))}subtractHour(){Rn(this,a,bt(this,a).minus({hours:1}).endOf("hour").startOf("second"))}subtractMinute(){Rn(this,a,bt(this,a).minus({minutes:1}).endOf("minute").startOf("second"))}subtractSecond(){Rn(this,a,bt(this,a).minus({seconds:1}))}addUnit(v){bt(this,o).add[v]()}subtractUnit(v){bt(this,o).subtract[v]()}invokeDateOperation(v,_){if(v===r.Add){this.addUnit(_);return}if(v===r.Subtract){this.subtractUnit(_);return}throw new Error(`Invalid verb: ${v}`)}getDate(){return bt(this,a).day}getFullYear(){return bt(this,a).year}getDay(){const v=bt(this,a).weekday;return v===7?0:v}getMonth(){return bt(this,a).month-1}getHours(){return bt(this,a).hour}getMinutes(){return bt(this,a).minute}getSeconds(){return bt(this,a).second}getMilliseconds(){return bt(this,a).millisecond}getTime(){return bt(this,a).valueOf()}getUTCDate(){return jn(this,d,gv).call(this).day}getUTCFullYear(){return jn(this,d,gv).call(this).year}getUTCDay(){const v=jn(this,d,gv).call(this).weekday;return v===7?0:v}getUTCMonth(){return jn(this,d,gv).call(this).month-1}getUTCHours(){return jn(this,d,gv).call(this).hour}getUTCMinutes(){return jn(this,d,gv).call(this).minute}getUTCSeconds(){return jn(this,d,gv).call(this).second}toISOString(){return bt(this,a).toUTC().toISO()}toJSON(){return bt(this,a).toJSON()}setDate(v){Rn(this,a,bt(this,a).set({day:v}))}setFullYear(v){Rn(this,a,bt(this,a).set({year:v}))}setDay(v){Rn(this,a,bt(this,a).set({weekday:v}))}setMonth(v){Rn(this,a,bt(this,a).set({month:v+1}))}setHours(v){Rn(this,a,bt(this,a).set({hour:v}))}setMinutes(v){Rn(this,a,bt(this,a).set({minute:v}))}setSeconds(v){Rn(this,a,bt(this,a).set({second:v}))}setMilliseconds(v){Rn(this,a,bt(this,a).set({millisecond:v}))}toString(){return this.toDate().toString()}toDate(){return bt(this,a).toJSDate()}isLastDayOfMonth(){var S;const{day:v,month:_}=bt(this,a);if(_===2){const E=jn(S=m,s,zM).call(S,bt(this,a).year);return v===e.DAYS_IN_MONTH[_-1]-(E?0:1)}return v===e.DAYS_IN_MONTH[_-1]}isLastWeekdayOfMonth(){var E;const{day:v,month:_}=bt(this,a);let S;return _===2?S=e.DAYS_IN_MONTH[_-1]-(jn(E=m,s,zM).call(E,bt(this,a).year)?0:1):S=e.DAYS_IN_MONTH[_-1],v>S-7}applyDateOperation(v,_,S){if(_===n.Month||_===n.Day){this.invokeDateOperation(v,_);return}const E=this.getHours();this.invokeDateOperation(v,_);const C=this.getHours(),T=C-E;T===2?S!==24&&(this.dstStart=C):T===0&&this.getMinutes()===0&&this.getSeconds()===0&&S!==24&&(this.dstEnd=C)}};a=new WeakMap,u=new WeakMap,l=new WeakMap,o=new WeakMap,s=new WeakSet,zM=function(v){return v%4===0&&v%100!==0||v%400===0},d=new WeakSet,gv=function(){return bt(this,a).toUTC()},Ui(m,s);let i=m;e.CronDate=i,e.default=i})(MP)),MP}var rY;function Dze(){if(rY)return v2;rY=1,Object.defineProperty(v2,"__esModule",{value:!0}),v2.CronMonth=void 0;const e=zw(),t=Pb(),n=1,r=12,i=Object.freeze([]);let a=class extends t.CronField{static get min(){return n}static get max(){return r}static get chars(){return i}static get daysInMonth(){return e.DAYS_IN_MONTH}constructor(l,o){super(l,o),this.validate()}get values(){return super.values}};return v2.CronMonth=a,v2}var y2={},iY;function $ze(){if(iY)return y2;iY=1,Object.defineProperty(y2,"__esModule",{value:!0}),y2.CronSecond=void 0;const e=Pb(),t=0,n=59,r=Object.freeze([]);let i=class extends e.CronField{static get min(){return t}static get max(){return n}static get chars(){return r}constructor(u,l){super(u,l),this.validate()}get values(){return super.values}};return y2.CronSecond=i,y2}var aY;function OL(){return aY||(aY=1,(function(e){var t=S1&&S1.__createBinding||(Object.create?(function(r,i,a,u){u===void 0&&(u=a);var l=Object.getOwnPropertyDescriptor(i,a);(!l||("get"in l?!i.__esModule:l.writable||l.configurable))&&(l={enumerable:!0,get:function(){return i[a]}}),Object.defineProperty(r,u,l)}):(function(r,i,a,u){u===void 0&&(u=a),r[u]=i[a]})),n=S1&&S1.__exportStar||function(r,i){for(var a in r)a!=="default"&&!Object.prototype.hasOwnProperty.call(i,a)&&t(i,r,a)};Object.defineProperty(e,"__esModule",{value:!0}),n(bze(),e),n(Oze(),e),n(xze(),e),n(Pb(),e),n(Sze(),e),n(_ze(),e),n(Dze(),e),n($ze(),e)})(S1)),S1}var uY;function Qge(){var n,r,i,a,u,l,o,s,Lge,Bge;if(uY)return f2;uY=1,Object.defineProperty(f2,"__esModule",{value:!0}),f2.CronFieldCollection=void 0;const e=OL();let t=(s=class{constructor({second:m,minute:y,hour:v,dayOfMonth:_,month:S,dayOfWeek:E}){Ui(this,n);Ui(this,r);Ui(this,i);Ui(this,a);Ui(this,u);Ui(this,l);if(!m)throw new Error("Validation error, Field second is missing");if(!y)throw new Error("Validation error, Field minute is missing");if(!v)throw new Error("Validation error, Field hour is missing");if(!_)throw new Error("Validation error, Field dayOfMonth is missing");if(!S)throw new Error("Validation error, Field month is missing");if(!E)throw new Error("Validation error, Field dayOfWeek is missing");if(S.values.length===1&&!_.hasLastChar&&!(parseInt(_.values[0],10)<=e.CronMonth.daysInMonth[S.values[0]-1]))throw new Error("Invalid explicit day of month definition");Rn(this,n,m),Rn(this,r,y),Rn(this,i,v),Rn(this,u,S),Rn(this,l,E),Rn(this,a,_)}static from(m,y){return new s({second:this.resolveField(e.CronSecond,m.second,y.second),minute:this.resolveField(e.CronMinute,m.minute,y.minute),hour:this.resolveField(e.CronHour,m.hour,y.hour),dayOfMonth:this.resolveField(e.CronDayOfMonth,m.dayOfMonth,y.dayOfMonth),month:this.resolveField(e.CronMonth,m.month,y.month),dayOfWeek:this.resolveField(e.CronDayOfWeek,m.dayOfWeek,y.dayOfWeek)})}static resolveField(m,y,v){return v?v instanceof e.CronField?v:new m(v):y}get second(){return bt(this,n)}get minute(){return bt(this,r)}get hour(){return bt(this,i)}get dayOfMonth(){return bt(this,a)}get month(){return bt(this,u)}get dayOfWeek(){return bt(this,l)}static compactField(m){if(m.length===0)return[];const y=[];let v;return m.forEach((_,S,E)=>{if(v===void 0){v={start:_,count:1};return}const C=E[S-1]||v.start,T=E[S+1];if(_==="L"||_==="W"){y.push(v),y.push({start:_,count:1}),v=void 0;return}if(v.step===void 0&&T!==void 0){const R=_-C,$=T-_;if(R<=$){v={...v,count:2,end:_,step:R};return}v.step=1}_-(v.end??0)===v.step?(v.count++,v.end=_):(v.count===1?y.push({start:v.start,count:1}):v.count===2?(y.push({start:v.start,count:1}),y.push({start:v.end??C,count:1})):y.push(v),v={start:_,count:1})}),v&&y.push(v),y}stringifyField(m){var S;let y=m.max,v=m.values;if(m instanceof e.CronDayOfWeek){y=6;const E=bt(this,l).values;v=E[E.length-1]===7?E.slice(0,-1):E}m instanceof e.CronDayOfMonth&&(y=bt(this,u).values.length===1?e.CronMonth.daysInMonth[bt(this,u).values[0]-1]:m.max);const _=s.compactField(v);if(_.length===1){const E=jn(S=s,o,Lge).call(S,m,_[0],y);if(E)return E}return _.map(E=>{var T;const C=E.count===1?E.start.toString():jn(T=s,o,Bge).call(T,E,y);return m instanceof e.CronDayOfWeek&&m.nthDay>0?`${C}#${m.nthDay}`:C}).join(",")}stringify(m=!1){const y=[];return m&&y.push(this.stringifyField(bt(this,n))),y.push(this.stringifyField(bt(this,r)),this.stringifyField(bt(this,i)),this.stringifyField(bt(this,a)),this.stringifyField(bt(this,u)),this.stringifyField(bt(this,l))),y.join(" ")}serialize(){return{second:bt(this,n).serialize(),minute:bt(this,r).serialize(),hour:bt(this,i).serialize(),dayOfMonth:bt(this,a).serialize(),month:bt(this,u).serialize(),dayOfWeek:bt(this,l).serialize()}}},n=new WeakMap,r=new WeakMap,i=new WeakMap,a=new WeakMap,u=new WeakMap,l=new WeakMap,o=new WeakSet,Lge=function(m,y,v){const _=y.step;return _?_===1&&y.start===m.min&&y.end&&y.end>=v?m.hasQuestionMarkChar?"?":"*":_!==1&&y.start===m.min&&y.end&&y.end>=v-_+1?`*/${_}`:null:null},Bge=function(m,y){const v=m.step;if(v===1)return`${m.start}-${m.end}`;const _=m.start===0?m.count-1:m.count;if(!v)throw new Error("Unexpected range step");if(!m.end)throw new Error("Unexpected range end");if(v*_>m.end){const S=(C,T)=>{if(typeof m.start!="number")throw new Error("Unexpected range start");return T%v===0?m.start+T:null};if(typeof m.start!="number")throw new Error("Unexpected range start");const E={length:m.end-m.start+1};return Array.from(E,S).filter(C=>C!==null).join(",")}return m.end===y-v+1?`${m.start}/${v}`:`${m.start}-${m.end}/${v}`},Ui(s,o),s);return f2.CronFieldCollection=t,f2}var $O={},lY;function Vge(){var r,i,a,u,l,o,s,c,vv,zge,m,qM,qge,BO;if(lY)return $O;lY=1,Object.defineProperty($O,"__esModule",{value:!0}),$O.CronExpression=void 0;const e=zw(),t=1e4;let n=(c=class{constructor(E,C){Ui(this,m);Ui(this,r);Ui(this,i);Ui(this,a);Ui(this,u);Ui(this,l);Ui(this,o);Rn(this,r,C),Rn(this,i,C.tz),Rn(this,a,new e.CronDate(C.currentDate,bt(this,i))),Rn(this,u,C.startDate?new e.CronDate(C.startDate,bt(this,i)):null),Rn(this,l,C.endDate?new e.CronDate(C.endDate,bt(this,i)):null),Rn(this,o,E)}get fields(){return bt(this,o)}static fieldsToExpression(E,C){return new c(E,C||{})}next(){return jn(this,m,BO).call(this)}prev(){return jn(this,m,BO).call(this,!0)}hasNext(){const E=bt(this,a);try{return jn(this,m,BO).call(this),!0}catch{return!1}finally{Rn(this,a,E)}}hasPrev(){const E=bt(this,a);try{return jn(this,m,BO).call(this,!0),!0}catch{return!1}finally{Rn(this,a,E)}}take(E){const C=[];if(E>=0)for(let T=0;T<E;T++)try{C.push(this.next())}catch{return C}else for(let T=0;T>E;T--)try{C.push(this.prev())}catch{return C}return C}reset(E){Rn(this,a,new e.CronDate(E||bt(this,r).currentDate))}stringify(E=!1){return bt(this,o).stringify(E)}includesDate(E){const{second:C,minute:T,hour:R,month:$}=bt(this,o),k=new e.CronDate(E,bt(this,i));return!(!C.values.includes(k.getSeconds())||!T.values.includes(k.getMinutes())||!R.values.includes(k.getHours())||!$.values.includes(k.getMonth()+1)||!jn(this,m,qM).call(this,k)||bt(this,o).dayOfWeek.nthDay>0&&Math.ceil(k.getDate()/7)!==bt(this,o).dayOfWeek.nthDay)}toString(){return bt(this,r).expression||this.stringify(!0)}[Symbol.iterator](){return{next:()=>({value:jn(this,m,BO).call(this),done:!this.hasNext()})}}},r=new WeakMap,i=new WeakMap,a=new WeakMap,u=new WeakMap,l=new WeakMap,o=new WeakMap,s=new WeakSet,vv=function(E,C){return C.some(T=>T===E)},zge=function(E,C){const T=C.isLastWeekdayOfMonth();return E.some(R=>{const $=parseInt(R.toString().charAt(0),10)%7;if(Number.isNaN($))throw new Error(`Invalid last weekday of the month expression: ${R}`);return C.getDay()===$&&T})},m=new WeakSet,qM=function(E){var L,j,V;const C=bt(this,o).dayOfMonth.isWildcard,T=!C,R=bt(this,o).dayOfWeek.isWildcard,$=!R,k=jn(L=c,s,vv).call(L,E.getDate(),bt(this,o).dayOfMonth.values)||bt(this,o).dayOfMonth.hasLastChar&&E.isLastDayOfMonth(),F=jn(j=c,s,vv).call(j,E.getDay(),bt(this,o).dayOfWeek.values)||bt(this,o).dayOfWeek.hasLastChar&&jn(V=c,s,zge).call(V,bt(this,o).dayOfWeek.values,E);return!!(T&&$&&(k||F)||k&&!$||C&&!R&&F)},qge=function(E,C,T){var L,j;const R=E.getHours(),$=jn(L=c,s,vv).call(L,R,bt(this,o).hour.values),k=E.dstStart===R,F=E.dstEnd===R;return!$&&!k?(E.dstStart=null,E.applyDateOperation(C,e.TimeUnit.Hour,bt(this,o).hour.values.length),!1):k&&!jn(j=c,s,vv).call(j,R-1,bt(this,o).hour.values)?(E.invokeDateOperation(C,e.TimeUnit.Hour),!1):F&&!T?(E.dstEnd=null,E.applyDateOperation(e.DateMathOp.Add,e.TimeUnit.Hour,bt(this,o).hour.values.length),!1):!0},BO=function(E=!1){var L,j,V;const C=E?e.DateMathOp.Subtract:e.DateMathOp.Add,T=new e.CronDate(bt(this,a)),R=bt(this,u),$=bt(this,l),k=T.getTime();let F=0;for(;F++<t;){if(F>t)throw new Error("Invalid expression, loop limit exceeded");if(E&&R&&R.getTime()>T.getTime())throw new Error("Out of the timespan range");if(!E&&$&&T.getTime()>$.getTime())throw new Error("Out of the timespan range");if(!jn(this,m,qM).call(this,T)){T.applyDateOperation(C,e.TimeUnit.Day,bt(this,o).hour.values.length);continue}if(!(bt(this,o).dayOfWeek.nthDay<=0||Math.ceil(T.getDate()/7)===bt(this,o).dayOfWeek.nthDay)){T.applyDateOperation(C,e.TimeUnit.Day,bt(this,o).hour.values.length);continue}if(!jn(L=c,s,vv).call(L,T.getMonth()+1,bt(this,o).month.values)){T.applyDateOperation(C,e.TimeUnit.Month,bt(this,o).hour.values.length);continue}if(jn(this,m,qge).call(this,T,C,E)){if(!jn(j=c,s,vv).call(j,T.getMinutes(),bt(this,o).minute.values)){T.applyDateOperation(C,e.TimeUnit.Minute,bt(this,o).hour.values.length);continue}if(!jn(V=c,s,vv).call(V,T.getSeconds(),bt(this,o).second.values)){T.applyDateOperation(C,e.TimeUnit.Second,bt(this,o).hour.values.length);continue}if(k===T.getTime()){(C==="Add"||T.getMilliseconds()===0)&&T.applyDateOperation(C,e.TimeUnit.Second,bt(this,o).hour.values.length);continue}break}}return T.getMilliseconds()!==0&&T.setMilliseconds(0),Rn(this,a,T),T},Ui(c,s),c);return $O.CronExpression=n,$O.default=n,$O}var SE={},oY;function Cze(){if(oY)return SE;oY=1,Object.defineProperty(SE,"__esModule",{value:!0}),SE.seededRandom=n;function e(r){let i=2166136261;for(let a=0;a<r.length;a++)i^=r.charCodeAt(a),i=Math.imul(i,16777619);return()=>i>>>0}function t(r){return()=>{let i=r+=1831565813;return i=Math.imul(i^i>>>15,i|1),i^=i+Math.imul(i^i>>>7,i|61),((i^i>>>14)>>>0)/4294967296}}function n(r){const i=r?e(r)():Math.floor(Math.random()*1e10);return t(i)}return SE}var sY;function UM(){var c,Uge,C1,jge,Zge,Hge,Xge,Yge,Gge,Kge,VM,Wge,Jge;if(sY)return Nf;sY=1,Object.defineProperty(Nf,"__esModule",{value:!0}),Nf.CronExpressionParser=Nf.DayOfWeek=Nf.Months=Nf.CronUnit=Nf.PredefinedExpressions=void 0;const e=Qge(),t=zw(),n=Vge(),r=Cze(),i=OL();var a;(function(F){F["@yearly"]="0 0 0 1 1 *",F["@annually"]="0 0 0 1 1 *",F["@monthly"]="0 0 0 1 * *",F["@weekly"]="0 0 0 * * 0",F["@daily"]="0 0 0 * * *",F["@hourly"]="0 0 * * * *",F["@minutely"]="0 * * * * *",F["@secondly"]="* * * * * *",F["@weekdays"]="0 0 0 * * 1-5",F["@weekends"]="0 0 0 * * 0,6"})(a||(Nf.PredefinedExpressions=a={}));var u;(function(F){F.Second="Second",F.Minute="Minute",F.Hour="Hour",F.DayOfMonth="DayOfMonth",F.Month="Month",F.DayOfWeek="DayOfWeek"})(u||(Nf.CronUnit=u={}));var l;(function(F){F[F.jan=1]="jan",F[F.feb=2]="feb",F[F.mar=3]="mar",F[F.apr=4]="apr",F[F.may=5]="may",F[F.jun=6]="jun",F[F.jul=7]="jul",F[F.aug=8]="aug",F[F.sep=9]="sep",F[F.oct=10]="oct",F[F.nov=11]="nov",F[F.dec=12]="dec"})(l||(Nf.Months=l={}));var o;(function(F){F[F.sun=0]="sun",F[F.mon=1]="mon",F[F.tue=2]="tue",F[F.wed=3]="wed",F[F.thu=4]="thu",F[F.fri=5]="fri",F[F.sat=6]="sat"})(o||(Nf.DayOfWeek=o={}));const k=class k{static parse(L,j={}){var ne,oe,ie,de,be,ve,pe,_e;const{strict:V=!1}=j,q=j.currentDate||new t.CronDate,N=(0,r.seededRandom)(j.hashSeed);L=a[L]||L;const U=jn(ne=k,c,Uge).call(ne,L,V);if(!(U.dayOfMonth==="*"||U.dayOfWeek==="*"||!V))throw new Error("Cannot use both dayOfMonth and dayOfWeek together in strict mode!");const W=jn(oe=k,c,C1).call(oe,u.Second,U.second,i.CronSecond.constraints,N),G=jn(ie=k,c,C1).call(ie,u.Minute,U.minute,i.CronMinute.constraints,N),J=jn(de=k,c,C1).call(de,u.Hour,U.hour,i.CronHour.constraints,N),te=jn(be=k,c,C1).call(be,u.Month,U.month,i.CronMonth.constraints,N),H=jn(ve=k,c,C1).call(ve,u.DayOfMonth,U.dayOfMonth,i.CronDayOfMonth.constraints,N),{dayOfWeek:M,nthDayOfWeek:K}=jn(pe=k,c,Wge).call(pe,U.dayOfWeek),X=jn(_e=k,c,C1).call(_e,u.DayOfWeek,M,i.CronDayOfWeek.constraints,N),B=new e.CronFieldCollection({second:new i.CronSecond(W,{rawValue:U.second}),minute:new i.CronMinute(G,{rawValue:U.minute}),hour:new i.CronHour(J,{rawValue:U.hour}),dayOfMonth:new i.CronDayOfMonth(H,{rawValue:U.dayOfMonth}),month:new i.CronMonth(te,{rawValue:U.month}),dayOfWeek:new i.CronDayOfWeek(X,{rawValue:U.dayOfWeek,nthDayOfWeek:K})});return new n.CronExpression(B,{...j,expression:L,currentDate:q})}};c=new WeakSet,Uge=function(L,j){if(j&&!L.length)throw new Error("Invalid cron expression");L=L||"0 * * * * *";const V=L.trim().split(/\s+/);if(j&&V.length<6)throw new Error("Invalid cron expression, expected 6 fields");if(V.length>6)throw new Error("Invalid cron expression, too many fields");const q=["*","*","*","*","*","0"];V.length<q.length&&V.unshift(...q.slice(V.length));const[N,U,W,G,J,te]=V;return{second:N,minute:U,hour:W,dayOfMonth:G,month:J,dayOfWeek:te}},C1=function(L,j,V,q){if((L===u.Month||L===u.DayOfWeek)&&(j=j.replace(/[a-z]{3}/gi,N=>{N=N.toLowerCase();const U=l[N]||o[N];if(U===void 0)throw new Error(`Validation error, cannot resolve alias "${N}"`);return U.toString()})),!V.validChars.test(j))throw new Error(`Invalid characters, got value: ${j}`);return j=jn(this,c,jge).call(this,j,V),j=jn(this,c,Zge).call(this,j,V,q),jn(this,c,Hge).call(this,L,j,V)},jge=function(L,j){return L.replace(/[*?]/g,j.min+"-"+j.max)},Zge=function(L,j,V){const q=V();return L.replace(/H(?:\((\d+)-(\d+)\))?(?:\/(\d+))?/g,(N,U,W,G)=>{if(U&&W&&G){const J=parseInt(U,10),te=parseInt(W,10),H=parseInt(G,10);if(J>te)throw new Error(`Invalid range: ${J}-${te}, min > max`);if(H<=0)throw new Error(`Invalid step: ${H}, must be positive`);const M=Math.max(J,j.min),K=Math.floor(q*H),X=[];for(let B=Math.floor(M/H)*H+K;B<=te;B+=H)B>=M&&X.push(B);return X.join(",")}else if(U&&W){const J=parseInt(U,10),te=parseInt(W,10);if(J>te)throw new Error(`Invalid range: ${J}-${te}, min > max`);return String(Math.floor(q*(te-J+1))+J)}else if(G){const J=parseInt(G,10);if(J<=0)throw new Error(`Invalid step: ${J}, must be positive`);const te=Math.floor(q*J),H=[];for(let M=Math.floor(j.min/J)*J+te;M<=j.max;M+=J)M>=j.min&&H.push(M);return H.join(",")}else return String(Math.floor(q*(j.max-j.min+1)+j.min))})},Hge=function(L,j,V){const q=[];function N(W,G){var J;if(Array.isArray(W))q.push(...W);else if(jn(J=k,c,Jge).call(J,G,W))q.push(W);else{const te=parseInt(W.toString(),10);if(!(te>=G.min&&te<=G.max))throw new Error(`Constraint error, got value ${W} expected range ${G.min}-${G.max}`);q.push(L===u.DayOfWeek?te%7:W)}}return j.split(",").forEach(W=>{var G;if(!(W.length>0))throw new Error("Invalid list value format");N(jn(G=k,c,Xge).call(G,L,W,V),V)}),q},Xge=function(L,j,V){var N,U;const q=j.split("/");if(q.length>2)throw new Error(`Invalid repeat: ${j}`);return q.length===2?(isNaN(parseInt(q[0],10))||(q[0]=`${q[0]}-${V.max}`),jn(N=k,c,VM).call(N,L,q[0],parseInt(q[1],10),V)):jn(U=k,c,VM).call(U,L,j,1,V)},Yge=function(L,j,V){if(!(!isNaN(L)&&!isNaN(j)&&L>=V.min&&j<=V.max))throw new Error(`Constraint error, got range ${L}-${j} expected range ${V.min}-${V.max}`);if(L>j)throw new Error(`Invalid range: ${L}-${j}, min(${L}) > max(${j})`)},Gge=function(L){if(!(!isNaN(L)&&L>0))throw new Error(`Constraint error, cannot repeat at every ${L} time.`)},Kge=function(L,j,V,q){const N=[];L===u.DayOfWeek&&V%7===0&&N.push(0);for(let U=j;U<=V;U+=q)N.indexOf(U)===-1&&N.push(U);return N},VM=function(L,j,V,q){const N=j.split("-");if(N.length<=1)return isNaN(+j)?j:+j;const[U,W]=N.map(G=>parseInt(G,10));return jn(this,c,Yge).call(this,U,W,q),jn(this,c,Gge).call(this,V),jn(this,c,Kge).call(this,L,U,W,V)},Wge=function(L){const j=L.split("#");if(j.length<=1)return{dayOfWeek:j[0]};const V=+j[j.length-1],q=L.match(/([,-/])/);if(q!==null)throw new Error(`Constraint error, invalid dayOfWeek \`#\` and \`${q==null?void 0:q[0]}\` special characters are incompatible`);if(!(j.length<=2&&!isNaN(V)&&V>=1&&V<=5))throw new Error("Constraint error, invalid dayOfWeek occurrence number (#)");return{dayOfWeek:j[0],nthDayOfWeek:V}},Jge=function(L,j){return L.chars.some(V=>j.toString().includes(V))},Ui(k,c);let s=k;return Nf.CronExpressionParser=s,Nf}var Hh={};const wze={},Rze=Object.freeze(Object.defineProperty({__proto__:null,default:wze},Symbol.toStringTag,{value:"Module"})),cY=DOe(Rze);var fY;function Aze(){var a,u,jM,eve;if(fY)return Hh;fY=1;var e=Hh&&Hh.__createBinding||(Object.create?(function(s,c,d,h){h===void 0&&(h=d);var m=Object.getOwnPropertyDescriptor(c,d);(!m||("get"in m?!c.__esModule:m.writable||m.configurable))&&(m={enumerable:!0,get:function(){return c[d]}}),Object.defineProperty(s,h,m)}):(function(s,c,d,h){h===void 0&&(h=d),s[h]=c[d]})),t=Hh&&Hh.__setModuleDefault||(Object.create?(function(s,c){Object.defineProperty(s,"default",{enumerable:!0,value:c})}):function(s,c){s.default=c}),n=Hh&&Hh.__importStar||(function(){var s=function(c){return s=Object.getOwnPropertyNames||function(d){var h=[];for(var m in d)Object.prototype.hasOwnProperty.call(d,m)&&(h[h.length]=m);return h},s(c)};return function(c){if(c&&c.__esModule)return c;var d={};if(c!=null)for(var h=s(c),m=0;m<h.length;m++)h[m]!=="default"&&e(d,c,h[m]);return t(d,c),d}})();Object.defineProperty(Hh,"__esModule",{value:!0}),Hh.CronFileParser=void 0;const r=UM();let i=(u=class{static async parseFile(c){var m;const{readFile:d}=await Promise.resolve().then(()=>n(cY)),h=await d(c,"utf8");return jn(m=u,a,jM).call(m,h)}static parseFileSync(c){var m;const{readFileSync:d}=cY,h=d(c,"utf8");return jn(m=u,a,jM).call(m,h)}},a=new WeakSet,jM=function(c){var m;const d=c.split(`
`),h={variables:{},expressions:[],errors:{}};for(const y of d){const v=y.trim();if(v.length===0||v.startsWith("#"))continue;const _=v.match(/^(.*)=(.*)$/);if(_){const[,S,E]=_;h.variables[S]=E.replace(/["']/g,"");continue}try{const S=jn(m=u,a,eve).call(m,v);h.expressions.push(S.interval)}catch(S){h.errors[v]=S}}return h},eve=function(c){const d=c.split(" ");return{interval:r.CronExpressionParser.parse(d.slice(0,5).join(" ")),command:d.slice(5,d.length)}},Ui(u,a),u);return Hh.CronFileParser=i,Hh}var dY;function Tze(){return dY||(dY=1,(function(e){var t=x1&&x1.__createBinding||(Object.create?(function(s,c,d,h){h===void 0&&(h=d);var m=Object.getOwnPropertyDescriptor(c,d);(!m||("get"in m?!c.__esModule:m.writable||m.configurable))&&(m={enumerable:!0,get:function(){return c[d]}}),Object.defineProperty(s,h,m)}):(function(s,c,d,h){h===void 0&&(h=d),s[h]=c[d]})),n=x1&&x1.__exportStar||function(s,c){for(var d in s)d!=="default"&&!Object.prototype.hasOwnProperty.call(c,d)&&t(c,s,d)};Object.defineProperty(e,"__esModule",{value:!0}),e.CronFileParser=e.CronExpressionParser=e.CronExpression=e.CronFieldCollection=e.CronDate=void 0;const r=UM();var i=zw();Object.defineProperty(e,"CronDate",{enumerable:!0,get:function(){return i.CronDate}});var a=Qge();Object.defineProperty(e,"CronFieldCollection",{enumerable:!0,get:function(){return a.CronFieldCollection}});var u=Vge();Object.defineProperty(e,"CronExpression",{enumerable:!0,get:function(){return u.CronExpression}});var l=UM();Object.defineProperty(e,"CronExpressionParser",{enumerable:!0,get:function(){return l.CronExpressionParser}});var o=Aze();Object.defineProperty(e,"CronFileParser",{enumerable:!0,get:function(){return o.CronFileParser}}),n(OL(),e),e.default=r.CronExpressionParser})(x1)),x1}var kze=Tze();const out=sa(kze);var FP={exports:{}},hY;function Pze(){return hY||(hY=1,(function(e,t){(function(r,i){e.exports=i()})(globalThis,()=>(()=>{var n={949:((u,l,o)=>{Object.defineProperty(l,"__esModule",{value:!0}),l.CronParser=void 0;var s=o(515),c=(function(){function d(h,m,y){m===void 0&&(m=!0),y===void 0&&(y=!1),this.expression=h,this.dayOfWeekStartIndexZero=m,this.monthStartIndexZero=y}return d.prototype.parse=function(){var h,m,y=(h=this.expression)!==null&&h!==void 0?h:"";if(y.startsWith("@")){var v=this.parseSpecial(this.expression);m=this.extractParts(v)}else m=this.extractParts(this.expression);return this.normalize(m),this.validate(m),m},d.prototype.parseSpecial=function(h){var m={"@yearly":"0 0 1 1 *","@annually":"0 0 1 1 *","@monthly":"0 0 1 * *","@weekly":"0 0 * * 0","@daily":"0 0 * * *","@midnight":"0 0 * * *","@hourly":"0 * * * *"},y=m[h];if(!y)throw new Error("Unknown special expression.");return y},d.prototype.extractParts=function(h){if(!this.expression)throw new Error("cron expression is empty");for(var m=h.trim().split(/[ ]+/),y=0;y<m.length;y++)if(m[y].includes(",")){var v=m[y].split(",").map(function(S){return S.trim()}).filter(function(S){return S!==""}).map(function(S){return isNaN(Number(S))?S:Number(S)}).filter(function(S){return S!==null&&S!==""});v.length===0&&v.push("*"),v.sort(function(S,E){return S!==null&&E!==null?S-E:0}),m[y]=v.map(function(S){return S!==null?S.toString():""}).join(",")}if(m.length<5)throw new Error("Expression has only ".concat(m.length," part").concat(m.length==1?"":"s",". At least 5 parts are required."));if(m.length==5)m.unshift(""),m.push("");else if(m.length==6){var _=/\d{4}$/.test(m[5])||m[4]=="?"||m[2]=="?";_?m.unshift(""):m.push("")}else if(m.length>7)throw new Error("Expression has ".concat(m.length," parts; too many!"));return m},d.prototype.normalize=function(h){var m=this;if(h[3]=h[3].replace("?","*"),h[5]=h[5].replace("?","*"),h[2]=h[2].replace("?","*"),h[0].indexOf("0/")==0&&(h[0]=h[0].replace("0/","*/")),h[1].indexOf("0/")==0&&(h[1]=h[1].replace("0/","*/")),h[2].indexOf("0/")==0&&(h[2]=h[2].replace("0/","*/")),h[3].indexOf("1/")==0&&(h[3]=h[3].replace("1/","*/")),h[4].indexOf("1/")==0&&(h[4]=h[4].replace("1/","*/")),h[6].indexOf("1/")==0&&(h[6]=h[6].replace("1/","*/")),h[5]=h[5].replace(/(^\d)|([^#/\s]\d)/g,function(R){var $=R.replace(/\D/,""),k=$;return m.dayOfWeekStartIndexZero?$=="7"&&(k="0"):k=(parseInt($)-1).toString(),R.replace($,k)}),h[5]=="L"&&(h[5]="6"),h[3]=="?"&&(h[3]="*"),h[3].indexOf("W")>-1&&(h[3].indexOf(",")>-1||h[3].indexOf("-")>-1))throw new Error("The 'W' character can be specified only when the day-of-month is a single day, not a range or list of days.");var y={SUN:0,MON:1,TUE:2,WED:3,THU:4,FRI:5,SAT:6};for(var v in y)h[5]=h[5].replace(new RegExp(v,"gi"),y[v].toString());h[4]=h[4].replace(/(^\d{1,2})|([^#/\s]\d{1,2})/g,function(R){var $=R.replace(/\D/,""),k=$;return m.monthStartIndexZero&&(k=(parseInt($)+1).toString()),R.replace($,k)});var _={JAN:1,FEB:2,MAR:3,APR:4,MAY:5,JUN:6,JUL:7,AUG:8,SEP:9,OCT:10,NOV:11,DEC:12};for(var S in _)h[4]=h[4].replace(new RegExp(S,"gi"),_[S].toString());h[0]=="0"&&(h[0]=""),!/\*|\-|\,|\//.test(h[2])&&(/\*|\//.test(h[1])||/\*|\//.test(h[0]))&&(h[2]+="-".concat(h[2]));for(var E=0;E<h.length;E++)if(h[E].indexOf(",")!=-1&&(h[E]=h[E].split(",").filter(function(R){return R!==""}).join(",")||"*"),h[E]=="*/1"&&(h[E]="*"),h[E].indexOf("/")>-1&&!/^\*|\-|\,/.test(h[E])){var C=null;switch(E){case 4:C="12";break;case 5:C="6";break;case 6:C="9999";break;default:C=null;break}if(C!==null){var T=h[E].split("/");h[E]="".concat(T[0],"-").concat(C,"/").concat(T[1])}}},d.prototype.validate=function(h){var m="0-9,\\-*/";this.validateOnlyExpectedCharactersFound(h[0],m),this.validateOnlyExpectedCharactersFound(h[1],m),this.validateOnlyExpectedCharactersFound(h[2],m),this.validateOnlyExpectedCharactersFound(h[3],"0-9,\\-*/LW"),this.validateOnlyExpectedCharactersFound(h[4],m),this.validateOnlyExpectedCharactersFound(h[5],"0-9,\\-*/L#"),this.validateOnlyExpectedCharactersFound(h[6],m),this.validateAnyRanges(h)},d.prototype.validateAnyRanges=function(h){s.default.secondRange(h[0]),s.default.minuteRange(h[1]),s.default.hourRange(h[2]),s.default.dayOfMonthRange(h[3]),s.default.monthRange(h[4],this.monthStartIndexZero),s.default.dayOfWeekRange(h[5],this.dayOfWeekStartIndexZero)},d.prototype.validateOnlyExpectedCharactersFound=function(h,m){var y=h.match(new RegExp("[^".concat(m,"]+"),"gi"));if(y&&y.length)throw new Error("Expression contains invalid values: '".concat(y.toString(),"'"))},d})();l.CronParser=c}),333:((u,l,o)=>{Object.defineProperty(l,"__esModule",{value:!0}),l.ExpressionDescriptor=void 0;var s=o(823),c=o(949),d=(function(){function h(m,y){if(this.expression=m,this.options=y,this.expressionParts=new Array(5),!this.options.locale&&h.defaultLocale&&(this.options.locale=h.defaultLocale),!h.locales[this.options.locale]){var v=Object.keys(h.locales)[0];console.warn("Locale '".concat(this.options.locale,"' could not be found; falling back to '").concat(v,"'.")),this.options.locale=v}this.i18n=h.locales[this.options.locale],y.use24HourTimeFormat===void 0&&(y.use24HourTimeFormat=this.i18n.use24HourTimeFormatByDefault())}return h.toString=function(m,y){var v=y===void 0?{}:y,_=v.throwExceptionOnParseError,S=_===void 0?!0:_,E=v.verbose,C=E===void 0?!1:E,T=v.dayOfWeekStartIndexZero,R=T===void 0?!0:T,$=v.monthStartIndexZero,k=$===void 0?!1:$,F=v.use24HourTimeFormat,L=v.locale,j=L===void 0?null:L,V=v.tzOffset,q=V===void 0?0:V,N={throwExceptionOnParseError:S,verbose:C,dayOfWeekStartIndexZero:R,monthStartIndexZero:k,use24HourTimeFormat:F,locale:j,tzOffset:q};N.tzOffset&&console.warn("'tzOffset' option has been deprecated and will be removed in a future release.");var U=new h(m,N);return U.getFullDescription()},h.initialize=function(m,y){y===void 0&&(y="en"),h.specialCharacters=["/","-",",","*"],h.defaultLocale=y,m.load(h.locales)},h.prototype.getFullDescription=function(){var m="";try{var y=new c.CronParser(this.expression,this.options.dayOfWeekStartIndexZero,this.options.monthStartIndexZero);this.expressionParts=y.parse();var v=this.getTimeOfDayDescription(),_=this.getDayOfMonthDescription(),S=this.getMonthDescription(),E=this.getDayOfWeekDescription(),C=this.getYearDescription();m+=v+_+E+S+C,m=this.transformVerbosity(m,!!this.options.verbose),m=m.charAt(0).toLocaleUpperCase()+m.substr(1)}catch(T){if(!this.options.throwExceptionOnParseError)m=this.i18n.anErrorOccuredWhenGeneratingTheExpressionD();else throw"".concat(T)}return m},h.prototype.getTimeOfDayDescription=function(){var m=this.expressionParts[0],y=this.expressionParts[1],v=this.expressionParts[2],_="";if(!s.StringUtilities.containsAny(y,h.specialCharacters)&&!s.StringUtilities.containsAny(v,h.specialCharacters)&&!s.StringUtilities.containsAny(m,h.specialCharacters))_+=this.i18n.atSpace()+this.formatTime(v,y,m);else if(!m&&y.indexOf("-")>-1&&!(y.indexOf(",")>-1)&&!(y.indexOf("/")>-1)&&!s.StringUtilities.containsAny(v,h.specialCharacters)){var S=y.split("-");_+=s.StringUtilities.format(this.i18n.everyMinuteBetweenX0AndX1(),this.formatTime(v,S[0],""),this.formatTime(v,S[1],""))}else if(!m&&v.indexOf(",")>-1&&v.indexOf("-")==-1&&v.indexOf("/")==-1&&!s.StringUtilities.containsAny(y,h.specialCharacters)){var E=v.split(",");_+=this.i18n.at();for(var C=0;C<E.length;C++)_+=" ",_+=this.formatTime(E[C],y,""),C<E.length-2&&(_+=","),C==E.length-2&&(_+=this.i18n.spaceAnd())}else{var T=this.getSecondsDescription(),R=this.getMinutesDescription(),$=this.getHoursDescription();if(_+=T,_&&R&&(_+=", "),_+=R,R===$)return _;_&&$&&(_+=", "),_+=$}return _},h.prototype.getSecondsDescription=function(){var m=this,y=this.getSegmentDescription(this.expressionParts[0],this.i18n.everySecond(),function(v){return v},function(v){return s.StringUtilities.format(m.i18n.everyX0Seconds(v),v)},function(v){return m.i18n.secondsX0ThroughX1PastTheMinute()},function(v){return v=="0"?"":parseInt(v)<20?m.i18n.atX0SecondsPastTheMinute(v):m.i18n.atX0SecondsPastTheMinuteGt20()||m.i18n.atX0SecondsPastTheMinute(v)});return y},h.prototype.getMinutesDescription=function(){var m=this,y=this.expressionParts[0],v=this.expressionParts[2],_=this.getSegmentDescription(this.expressionParts[1],this.i18n.everyMinute(),function(S){return S},function(S){return s.StringUtilities.format(m.i18n.everyX0Minutes(S),S)},function(S){return m.i18n.minutesX0ThroughX1PastTheHour()},function(S){try{return S=="0"&&v.indexOf("/")==-1&&y==""?m.i18n.everyHour():parseInt(S)<20?m.i18n.atX0MinutesPastTheHour(S):m.i18n.atX0MinutesPastTheHourGt20()||m.i18n.atX0MinutesPastTheHour(S)}catch{return m.i18n.atX0MinutesPastTheHour(S)}});return _},h.prototype.getHoursDescription=function(){var m=this,y=this.expressionParts[2],v=0,_=[];y.split("/")[0].split(",").forEach(function(C){var T=C.split("-");T.length===2&&_.push({value:T[1],index:v+1}),v+=T.length});var S=0,E=this.getSegmentDescription(y,this.i18n.everyHour(),function(C){var T=_.find(function($){return $.value===C&&$.index===S}),R=T&&m.expressionParts[1]!=="0";return S++,R?m.formatTime(C,"59",""):m.formatTime(C,"0","")},function(C){return s.StringUtilities.format(m.i18n.everyX0Hours(C),C)},function(C){return m.i18n.betweenX0AndX1()},function(C){return m.i18n.atX0()});return E},h.prototype.getDayOfWeekDescription=function(){var m=this,y=this.i18n.daysOfTheWeek(),v=null;return this.expressionParts[5]=="*"?v="":v=this.getSegmentDescription(this.expressionParts[5],this.i18n.commaEveryDay(),function(_,S){var E=_;_.indexOf("#")>-1?E=_.substring(0,_.indexOf("#")):_.indexOf("L")>-1&&(E=E.replace("L",""));var C=parseInt(E);if(m.options.tzOffset){var T=m.expressionParts[2],R=parseInt(T)+(m.options.tzOffset?m.options.tzOffset:0);R>=24?C++:R<0&&C--,C>6?C=0:C<0&&(C=6)}var $=m.i18n.daysOfTheWeekInCase?m.i18n.daysOfTheWeekInCase(S)[C]:y[C];if(_.indexOf("#")>-1){var k=null,F=_.substring(_.indexOf("#")+1),L=_.substring(0,_.indexOf("#"));switch(F){case"1":k=m.i18n.first(L);break;case"2":k=m.i18n.second(L);break;case"3":k=m.i18n.third(L);break;case"4":k=m.i18n.fourth(L);break;case"5":k=m.i18n.fifth(L);break}$=k+" "+$}return $},function(_){return parseInt(_)==1?"":s.StringUtilities.format(m.i18n.commaEveryX0DaysOfTheWeek(_),_)},function(_){var S=_.substring(0,_.indexOf("-")),E=m.expressionParts[3]!="*";return E?m.i18n.commaAndX0ThroughX1(S):m.i18n.commaX0ThroughX1(S)},function(_){var S=null;if(_.indexOf("#")>-1){var E=_.substring(_.indexOf("#")+1),C=_.substring(0,_.indexOf("#"));S=m.i18n.commaOnThe(E,C).trim()+m.i18n.spaceX0OfTheMonth()}else if(_.indexOf("L")>-1)S=m.i18n.commaOnTheLastX0OfTheMonth(_.replace("L",""));else{var T=m.expressionParts[3]!="*";S=T?m.i18n.commaAndOnX0():m.i18n.commaOnlyOnX0(_)}return S}),v},h.prototype.getMonthDescription=function(){var m=this,y=this.i18n.monthsOfTheYear(),v=this.getSegmentDescription(this.expressionParts[4],"",function(_,S){return S&&m.i18n.monthsOfTheYearInCase?m.i18n.monthsOfTheYearInCase(S)[parseInt(_)-1]:y[parseInt(_)-1]},function(_){return parseInt(_)==1?"":s.StringUtilities.format(m.i18n.commaEveryX0Months(_),_)},function(_){return m.i18n.commaMonthX0ThroughMonthX1()||m.i18n.commaX0ThroughX1()},function(_){return m.i18n.commaOnlyInMonthX0?m.i18n.commaOnlyInMonthX0():m.i18n.commaOnlyInX0()});return v},h.prototype.getDayOfMonthDescription=function(){var m=this,y=null,v=this.expressionParts[3];switch(v){case"L":y=this.i18n.commaOnTheLastDayOfTheMonth();break;case"WL":case"LW":y=this.i18n.commaOnTheLastWeekdayOfTheMonth();break;default:var _=v.match(/(\d{1,2}W)|(W\d{1,2})/);if(_){var S=parseInt(_[0].replace("W","")),E=S==1?this.i18n.firstWeekday():s.StringUtilities.format(this.i18n.weekdayNearestDayX0(),S.toString());y=s.StringUtilities.format(this.i18n.commaOnTheX0OfTheMonth(),E);break}else{var C=v.match(/L-(\d{1,2})/);if(C){var T=C[1];y=s.StringUtilities.format(this.i18n.commaDaysBeforeTheLastDayOfTheMonth(T),T);break}else{if(v=="*"&&this.expressionParts[5]!="*")return"";y=this.getSegmentDescription(v,this.i18n.commaEveryDay(),function(R){return R=="L"?m.i18n.lastDay():m.i18n.dayX0?s.StringUtilities.format(m.i18n.dayX0(),R):R},function(R){return R=="1"?m.i18n.commaEveryDay():m.i18n.commaEveryX0Days(R)},function(R){return m.i18n.commaBetweenDayX0AndX1OfTheMonth(R)},function(R){return m.i18n.commaOnDayX0OfTheMonth(R)})}break}}return y},h.prototype.getYearDescription=function(){var m=this,y=this.getSegmentDescription(this.expressionParts[6],"",function(v){return/^\d+$/.test(v)?new Date(parseInt(v),1).getFullYear().toString():v},function(v){return s.StringUtilities.format(m.i18n.commaEveryX0Years(v),v)},function(v){return m.i18n.commaYearX0ThroughYearX1()||m.i18n.commaX0ThroughX1()},function(v){return m.i18n.commaOnlyInYearX0?m.i18n.commaOnlyInYearX0():m.i18n.commaOnlyInX0()});return y},h.prototype.getSegmentDescription=function(m,y,v,_,S,E){var C=null,T=m.indexOf("/")>-1,R=m.indexOf("-")>-1,$=m.indexOf(",")>-1;if(!m)C="";else if(m==="*")C=y;else if(!T&&!R&&!$)C=s.StringUtilities.format(E(m),v(m));else if($){for(var k=m.split(","),F="",L=0;L<k.length;L++)if(L>0&&k.length>2&&(F+=",",L<k.length-1&&(F+=" ")),L>0&&k.length>1&&(L==k.length-1||k.length==2)&&(F+="".concat(this.i18n.spaceAnd()," ")),k[L].indexOf("/")>-1||k[L].indexOf("-")>-1){var j=k[L].indexOf("-")>-1&&k[L].indexOf("/")==-1,V=this.getSegmentDescription(k[L],y,v,_,j?this.i18n.commaX0ThroughX1:S,E);j&&(V=V.replace(", ","")),F+=V}else T?F+=this.getSegmentDescription(k[L],y,v,_,S,E):F+=v(k[L]);T?C=F:C=s.StringUtilities.format(E(m),F)}else if(T){var k=m.split("/");if(C=s.StringUtilities.format(_(k[1]),k[1]),k[0].indexOf("-")>-1){var q=this.generateRangeSegmentDescription(k[0],S,v);q.indexOf(", ")!=0&&(C+=", "),C+=q}else if(k[0].indexOf("*")==-1){var N=s.StringUtilities.format(E(k[0]),v(k[0]));N=N.replace(", ",""),C+=s.StringUtilities.format(this.i18n.commaStartingX0(),N)}}else R&&(C=this.generateRangeSegmentDescription(m,S,v));return C},h.prototype.generateRangeSegmentDescription=function(m,y,v){var _="",S=m.split("-"),E=v(S[0],1),C=v(S[1],2),T=y(m);return _+=s.StringUtilities.format(T,E,C),_},h.prototype.formatTime=function(m,y,v){var _=0,S=0;this.options.tzOffset&&(_=this.options.tzOffset>0?Math.floor(this.options.tzOffset):Math.ceil(this.options.tzOffset),S=parseFloat((this.options.tzOffset%1).toFixed(2)),S!=0&&(S*=60));var E=parseInt(m)+_,C=parseInt(y)+S;C>=60?(C-=60,E+=1):C<0&&(C+=60,E-=1),E>=24?E=E-24:E<0&&(E=24+E);var T="",R=!1;this.options.use24HourTimeFormat||(R=!!(this.i18n.setPeriodBeforeTime&&this.i18n.setPeriodBeforeTime()),T=R?"".concat(this.getPeriod(E)," "):" ".concat(this.getPeriod(E)),E>12&&(E-=12),E===0&&(E=12));var $="";return v&&($=":".concat(("00"+v).substring(v.length))),"".concat(R?T:"").concat(("00"+E.toString()).substring(E.toString().length),":").concat(("00"+C.toString()).substring(C.toString().length)).concat($).concat(R?"":T)},h.prototype.transformVerbosity=function(m,y){if(!y&&(m=m.replace(new RegExp(", ".concat(this.i18n.everyMinute()),"g"),""),m=m.replace(new RegExp(", ".concat(this.i18n.everyHour()),"g"),""),m=m.replace(new RegExp(this.i18n.commaEveryDay(),"g"),""),m=m.replace(/\, ?$/,""),this.i18n.conciseVerbosityReplacements))for(var v=0,_=Object.entries(this.i18n.conciseVerbosityReplacements());v<_.length;v++){var S=_[v],E=S[0],C=S[1];m=m.replace(new RegExp(E,"g"),C)}return m},h.prototype.getPeriod=function(m){return m>=12?this.i18n.pm&&this.i18n.pm()||"PM":this.i18n.am&&this.i18n.am()||"AM"},h.locales={},h})();l.ExpressionDescriptor=d}),747:((u,l,o)=>{Object.defineProperty(l,"__esModule",{value:!0}),l.enLocaleLoader=void 0;var s=o(486),c=(function(){function d(){}return d.prototype.load=function(h){h.en=new s.en},d})();l.enLocaleLoader=c}),486:((u,l)=>{Object.defineProperty(l,"__esModule",{value:!0}),l.en=void 0;var o=(function(){function s(){}return s.prototype.atX0SecondsPastTheMinuteGt20=function(){return null},s.prototype.atX0MinutesPastTheHourGt20=function(){return null},s.prototype.commaMonthX0ThroughMonthX1=function(){return null},s.prototype.commaYearX0ThroughYearX1=function(){return null},s.prototype.use24HourTimeFormatByDefault=function(){return!1},s.prototype.anErrorOccuredWhenGeneratingTheExpressionD=function(){return"An error occurred when generating the expression description. Check the cron expression syntax."},s.prototype.everyMinute=function(){return"every minute"},s.prototype.everyHour=function(){return"every hour"},s.prototype.atSpace=function(){return"At "},s.prototype.everyMinuteBetweenX0AndX1=function(){return"Every minute between %s and %s"},s.prototype.at=function(){return"At"},s.prototype.spaceAnd=function(){return" and"},s.prototype.everySecond=function(){return"every second"},s.prototype.everyX0Seconds=function(){return"every %s seconds"},s.prototype.secondsX0ThroughX1PastTheMinute=function(){return"seconds %s through %s past the minute"},s.prototype.atX0SecondsPastTheMinute=function(){return"at %s seconds past the minute"},s.prototype.everyX0Minutes=function(){return"every %s minutes"},s.prototype.minutesX0ThroughX1PastTheHour=function(){return"minutes %s through %s past the hour"},s.prototype.atX0MinutesPastTheHour=function(){return"at %s minutes past the hour"},s.prototype.everyX0Hours=function(){return"every %s hours"},s.prototype.betweenX0AndX1=function(){return"between %s and %s"},s.prototype.atX0=function(){return"at %s"},s.prototype.commaEveryDay=function(){return", every day"},s.prototype.commaEveryX0DaysOfTheWeek=function(){return", every %s days of the week"},s.prototype.commaX0ThroughX1=function(){return", %s through %s"},s.prototype.commaAndX0ThroughX1=function(){return", %s through %s"},s.prototype.first=function(){return"first"},s.prototype.second=function(){return"second"},s.prototype.third=function(){return"third"},s.prototype.fourth=function(){return"fourth"},s.prototype.fifth=function(){return"fifth"},s.prototype.commaOnThe=function(){return", on the "},s.prototype.spaceX0OfTheMonth=function(){return" %s of the month"},s.prototype.lastDay=function(){return"the last day"},s.prototype.commaOnTheLastX0OfTheMonth=function(){return", on the last %s of the month"},s.prototype.commaOnlyOnX0=function(){return", only on %s"},s.prototype.commaAndOnX0=function(){return", and on %s"},s.prototype.commaEveryX0Months=function(){return", every %s months"},s.prototype.commaOnlyInX0=function(){return", only in %s"},s.prototype.commaOnTheLastDayOfTheMonth=function(){return", on the last day of the month"},s.prototype.commaOnTheLastWeekdayOfTheMonth=function(){return", on the last weekday of the month"},s.prototype.commaDaysBeforeTheLastDayOfTheMonth=function(){return", %s days before the last day of the month"},s.prototype.firstWeekday=function(){return"first weekday"},s.prototype.weekdayNearestDayX0=function(){return"weekday nearest day %s"},s.prototype.commaOnTheX0OfTheMonth=function(){return", on the %s of the month"},s.prototype.commaEveryX0Days=function(){return", every %s days"},s.prototype.commaBetweenDayX0AndX1OfTheMonth=function(){return", between day %s and %s of the month"},s.prototype.commaOnDayX0OfTheMonth=function(){return", on day %s of the month"},s.prototype.commaEveryHour=function(){return", every hour"},s.prototype.commaEveryX0Years=function(){return", every %s years"},s.prototype.commaStartingX0=function(){return", starting %s"},s.prototype.daysOfTheWeek=function(){return["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"]},s.prototype.monthsOfTheYear=function(){return["January","February","March","April","May","June","July","August","September","October","November","December"]},s})();l.en=o}),515:((u,l)=>{Object.defineProperty(l,"__esModule",{value:!0});function o(c,d){if(!c)throw new Error(d)}var s=(function(){function c(){}return c.secondRange=function(d){for(var h=d.split(","),m=0;m<h.length;m++)if(!isNaN(parseInt(h[m],10))){var y=parseInt(h[m],10);o(y>=0&&y<=59,"seconds part must be >= 0 and <= 59")}},c.minuteRange=function(d){for(var h=d.split(","),m=0;m<h.length;m++)if(!isNaN(parseInt(h[m],10))){var y=parseInt(h[m],10);o(y>=0&&y<=59,"minutes part must be >= 0 and <= 59")}},c.hourRange=function(d){for(var h=d.split(","),m=0;m<h.length;m++)if(!isNaN(parseInt(h[m],10))){var y=parseInt(h[m],10);o(y>=0&&y<=23,"hours part must be >= 0 and <= 23")}},c.dayOfMonthRange=function(d){for(var h=d.split(","),m=0;m<h.length;m++)if(!isNaN(parseInt(h[m],10))){var y=parseInt(h[m],10);o(y>=1&&y<=31,"DOM part must be >= 1 and <= 31")}},c.monthRange=function(d,h){for(var m=d.split(","),y=0;y<m.length;y++)if(!isNaN(parseInt(m[y],10))){var v=parseInt(m[y],10);o(v>=1&&v<=12,h?"month part must be >= 0 and <= 11":"month part must be >= 1 and <= 12")}},c.dayOfWeekRange=function(d,h){for(var m=d.split(","),y=0;y<m.length;y++)if(!isNaN(parseInt(m[y],10))){var v=parseInt(m[y],10);o(v>=0&&v<=6,h?"DOW part must be >= 0 and <= 6":"DOW part must be >= 1 and <= 7")}},c})();l.default=s}),823:((u,l)=>{Object.defineProperty(l,"__esModule",{value:!0}),l.StringUtilities=void 0;var o=(function(){function s(){}return s.format=function(c){for(var d=[],h=1;h<arguments.length;h++)d[h-1]=arguments[h];return c.replace(/%s/g,function(m){return d.shift()})},s.containsAny=function(c,d){return d.some(function(h){return c.indexOf(h)>-1})},s})();l.StringUtilities=o})},r={};function i(u){var l=r[u];if(l!==void 0)return l.exports;var o=r[u]={exports:{}};return n[u](o,o.exports,i),o.exports}var a={};return(()=>{var u=a;Object.defineProperty(u,"__esModule",{value:!0}),u.toString=void 0;var l=i(333),o=i(747);l.ExpressionDescriptor.initialize(new o.enLocaleLoader),u.default=l.ExpressionDescriptor;var s=l.ExpressionDescriptor.toString;u.toString=s})(),a})())})(FP)),FP.exports}var Mze=Pze();const sut=sa(Mze);var NP={},IP={},pY;function Fze(){return pY||(pY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n==="__proto__"}e.isUnsafeProperty=t})(IP)),IP}var LP={},mY;function tve(){return mY||(mY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){switch(typeof n){case"number":case"symbol":return!1;case"string":return n.includes(".")||n.includes("[")||n.includes("]")}}e.isDeepKey=t})(LP)),LP}var BP={},gY;function nve(){return gY||(gY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){var r;return typeof n=="string"||typeof n=="symbol"?n:Object.is((r=n==null?void 0:n.valueOf)==null?void 0:r.call(n),-0)?"-0":String(n)}e.toKey=t})(BP)),BP}var QP={},vY;function xL(){return vY||(vY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){const r=[],i=n.length;if(i===0)return r;let a=0,u="",l="",o=!1;for(n.charCodeAt(0)===46&&(r.push(""),a++);a<i;){const s=n[a];l?s==="\\"&&a+1<i?(a++,u+=n[a]):s===l?l="":u+=s:o?s==='"'||s==="'"?l=s:s==="]"?(o=!1,r.push(u),u=""):u+=s:s==="["?(o=!0,u&&(r.push(u),u="")):s==="."?u&&(r.push(u),u=""):u+=s,a++}return u&&r.push(u),r}e.toPath=t})(QP)),QP}var yY;function SL(){return yY||(yY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Fze(),n=tve(),r=nve(),i=xL();function a(l,o,s){if(l==null)return s;switch(typeof o){case"string":{if(t.isUnsafeProperty(o))return s;const c=l[o];return c===void 0?n.isDeepKey(o)?a(l,i.toPath(o),s):s:c}case"number":case"symbol":{typeof o=="number"&&(o=r.toKey(o));const c=l[o];return c===void 0?s:c}default:{if(Array.isArray(o))return u(l,o,s);if(Object.is(o==null?void 0:o.valueOf(),-0)?o="-0":o=String(o),t.isUnsafeProperty(o))return s;const c=l[o];return c===void 0?s:c}}}function u(l,o,s){if(o.length===0)return s;let c=l;for(let d=0;d<o.length;d++){if(c==null||t.isUnsafeProperty(o[d]))return s;c=c[o[d]]}return c===void 0?s:c}e.get=a})(NP)),NP}var zP,bY;function Nze(){return bY||(bY=1,zP=SL().get),zP}var Ize=Nze();const cut=sa(Ize);var qP={exports:{}},Gi={};/** @license React v17.0.2
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var OY;function Lze(){if(OY)return Gi;OY=1;var e=60103,t=60106,n=60107,r=60108,i=60114,a=60109,u=60110,l=60112,o=60113,s=60120,c=60115,d=60116,h=60121,m=60122,y=60117,v=60129,_=60131;if(typeof Symbol=="function"&&Symbol.for){var S=Symbol.for;e=S("react.element"),t=S("react.portal"),n=S("react.fragment"),r=S("react.strict_mode"),i=S("react.profiler"),a=S("react.provider"),u=S("react.context"),l=S("react.forward_ref"),o=S("react.suspense"),s=S("react.suspense_list"),c=S("react.memo"),d=S("react.lazy"),h=S("react.block"),m=S("react.server.block"),y=S("react.fundamental"),v=S("react.debug_trace_mode"),_=S("react.legacy_hidden")}function E(N){if(typeof N=="object"&&N!==null){var U=N.$$typeof;switch(U){case e:switch(N=N.type,N){case n:case i:case r:case o:case s:return N;default:switch(N=N&&N.$$typeof,N){case u:case l:case d:case c:case a:return N;default:return U}}case t:return U}}}var C=a,T=e,R=l,$=n,k=d,F=c,L=t,j=i,V=r,q=o;return Gi.ContextConsumer=u,Gi.ContextProvider=C,Gi.Element=T,Gi.ForwardRef=R,Gi.Fragment=$,Gi.Lazy=k,Gi.Memo=F,Gi.Portal=L,Gi.Profiler=j,Gi.StrictMode=V,Gi.Suspense=q,Gi.isAsyncMode=function(){return!1},Gi.isConcurrentMode=function(){return!1},Gi.isContextConsumer=function(N){return E(N)===u},Gi.isContextProvider=function(N){return E(N)===a},Gi.isElement=function(N){return typeof N=="object"&&N!==null&&N.$$typeof===e},Gi.isForwardRef=function(N){return E(N)===l},Gi.isFragment=function(N){return E(N)===n},Gi.isLazy=function(N){return E(N)===d},Gi.isMemo=function(N){return E(N)===c},Gi.isPortal=function(N){return E(N)===t},Gi.isProfiler=function(N){return E(N)===i},Gi.isStrictMode=function(N){return E(N)===r},Gi.isSuspense=function(N){return E(N)===o},Gi.isValidElementType=function(N){return typeof N=="string"||typeof N=="function"||N===n||N===i||N===v||N===r||N===o||N===s||N===_||typeof N=="object"&&N!==null&&(N.$$typeof===d||N.$$typeof===c||N.$$typeof===a||N.$$typeof===u||N.$$typeof===l||N.$$typeof===y||N.$$typeof===h||N[0]===m)},Gi.typeOf=E,Gi}var xY;function Bze(){return xY||(xY=1,qP.exports=Lze()),qP.exports}var fut=Bze();function ba(e){return function(){return e}}const rve=Math.cos,N$=Math.sin,bp=Math.sqrt,I$=Math.PI,qw=2*I$,ZM=Math.PI,HM=2*ZM,w1=1e-6,Qze=HM-w1;function ive(e){this._+=e[0];for(let t=1,n=e.length;t<n;++t)this._+=arguments[t]+e[t]}function zze(e){let t=Math.floor(e);if(!(t>=0))throw new Error(`invalid digits: ${e}`);if(t>15)return ive;const n=10**t;return function(r){this._+=r[0];for(let i=1,a=r.length;i<a;++i)this._+=Math.round(arguments[i]*n)/n+r[i]}}class qze{constructor(t){this._x0=this._y0=this._x1=this._y1=null,this._="",this._append=t==null?ive:zze(t)}moveTo(t,n){this._append`M${this._x0=this._x1=+t},${this._y0=this._y1=+n}`}closePath(){this._x1!==null&&(this._x1=this._x0,this._y1=this._y0,this._append`Z`)}lineTo(t,n){this._append`L${this._x1=+t},${this._y1=+n}`}quadraticCurveTo(t,n,r,i){this._append`Q${+t},${+n},${this._x1=+r},${this._y1=+i}`}bezierCurveTo(t,n,r,i,a,u){this._append`C${+t},${+n},${+r},${+i},${this._x1=+a},${this._y1=+u}`}arcTo(t,n,r,i,a){if(t=+t,n=+n,r=+r,i=+i,a=+a,a<0)throw new Error(`negative radius: ${a}`);let u=this._x1,l=this._y1,o=r-t,s=i-n,c=u-t,d=l-n,h=c*c+d*d;if(this._x1===null)this._append`M${this._x1=t},${this._y1=n}`;else if(h>w1)if(!(Math.abs(d*o-s*c)>w1)||!a)this._append`L${this._x1=t},${this._y1=n}`;else{let m=r-u,y=i-l,v=o*o+s*s,_=m*m+y*y,S=Math.sqrt(v),E=Math.sqrt(h),C=a*Math.tan((ZM-Math.acos((v+h-_)/(2*S*E)))/2),T=C/E,R=C/S;Math.abs(T-1)>w1&&this._append`L${t+T*c},${n+T*d}`,this._append`A${a},${a},0,0,${+(d*m>c*y)},${this._x1=t+R*o},${this._y1=n+R*s}`}}arc(t,n,r,i,a,u){if(t=+t,n=+n,r=+r,u=!!u,r<0)throw new Error(`negative radius: ${r}`);let l=r*Math.cos(i),o=r*Math.sin(i),s=t+l,c=n+o,d=1^u,h=u?i-a:a-i;this._x1===null?this._append`M${s},${c}`:(Math.abs(this._x1-s)>w1||Math.abs(this._y1-c)>w1)&&this._append`L${s},${c}`,r&&(h<0&&(h=h%HM+HM),h>Qze?this._append`A${r},${r},0,1,${d},${t-l},${n-o}A${r},${r},0,1,${d},${this._x1=s},${this._y1=c}`:h>w1&&this._append`A${r},${r},0,${+(h>=ZM)},${d},${this._x1=t+r*Math.cos(a)},${this._y1=n+r*Math.sin(a)}`)}rect(t,n,r,i){this._append`M${this._x0=this._x1=+t},${this._y0=this._y1=+n}h${r=+r}v${+i}h${-r}Z`}toString(){return this._}}function _L(e){let t=3;return e.digits=function(n){if(!arguments.length)return t;if(n==null)t=null;else{const r=Math.floor(n);if(!(r>=0))throw new RangeError(`invalid digits: ${n}`);t=r}return e},()=>new qze(t)}function EL(e){return typeof e=="object"&&"length"in e?e:Array.from(e)}function ave(e){this._context=e}ave.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;default:this._context.lineTo(e,t);break}}};function uve(e){return new ave(e)}function lve(e){return e[0]}function ove(e){return e[1]}function Vze(e,t){var n=ba(!0),r=null,i=uve,a=null,u=_L(l);e=typeof e=="function"?e:e===void 0?lve:ba(e),t=typeof t=="function"?t:t===void 0?ove:ba(t);function l(o){var s,c=(o=EL(o)).length,d,h=!1,m;for(r==null&&(a=i(m=u())),s=0;s<=c;++s)!(s<c&&n(d=o[s],s,o))===h&&((h=!h)?a.lineStart():a.lineEnd()),h&&a.point(+e(d,s,o),+t(d,s,o));if(m)return a=null,m+""||null}return l.x=function(o){return arguments.length?(e=typeof o=="function"?o:ba(+o),l):e},l.y=function(o){return arguments.length?(t=typeof o=="function"?o:ba(+o),l):t},l.defined=function(o){return arguments.length?(n=typeof o=="function"?o:ba(!!o),l):n},l.curve=function(o){return arguments.length?(i=o,r!=null&&(a=i(r)),l):i},l.context=function(o){return arguments.length?(o==null?r=a=null:a=i(r=o),l):r},l}function dut(e,t,n){var r=null,i=ba(!0),a=null,u=uve,l=null,o=_L(s);e=typeof e=="function"?e:e===void 0?lve:ba(+e),t=typeof t=="function"?t:ba(t===void 0?0:+t),n=typeof n=="function"?n:n===void 0?ove:ba(+n);function s(d){var h,m,y,v=(d=EL(d)).length,_,S=!1,E,C=new Array(v),T=new Array(v);for(a==null&&(l=u(E=o())),h=0;h<=v;++h){if(!(h<v&&i(_=d[h],h,d))===S)if(S=!S)m=h,l.areaStart(),l.lineStart();else{for(l.lineEnd(),l.lineStart(),y=h-1;y>=m;--y)l.point(C[y],T[y]);l.lineEnd(),l.areaEnd()}S&&(C[h]=+e(_,h,d),T[h]=+t(_,h,d),l.point(r?+r(_,h,d):C[h],n?+n(_,h,d):T[h]))}if(E)return l=null,E+""||null}function c(){return Vze().defined(i).curve(u).context(a)}return s.x=function(d){return arguments.length?(e=typeof d=="function"?d:ba(+d),r=null,s):e},s.x0=function(d){return arguments.length?(e=typeof d=="function"?d:ba(+d),s):e},s.x1=function(d){return arguments.length?(r=d==null?null:typeof d=="function"?d:ba(+d),s):r},s.y=function(d){return arguments.length?(t=typeof d=="function"?d:ba(+d),n=null,s):t},s.y0=function(d){return arguments.length?(t=typeof d=="function"?d:ba(+d),s):t},s.y1=function(d){return arguments.length?(n=d==null?null:typeof d=="function"?d:ba(+d),s):n},s.lineX0=s.lineY0=function(){return c().x(e).y(t)},s.lineY1=function(){return c().x(e).y(n)},s.lineX1=function(){return c().x(r).y(t)},s.defined=function(d){return arguments.length?(i=typeof d=="function"?d:ba(!!d),s):i},s.curve=function(d){return arguments.length?(u=d,a!=null&&(l=u(a)),s):u},s.context=function(d){return arguments.length?(d==null?a=l=null:l=u(a=d),s):a},s}class sve{constructor(t,n){this._context=t,this._x=n}areaStart(){this._line=0}areaEnd(){this._line=NaN}lineStart(){this._point=0}lineEnd(){(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line}point(t,n){switch(t=+t,n=+n,this._point){case 0:{this._point=1,this._line?this._context.lineTo(t,n):this._context.moveTo(t,n);break}case 1:this._point=2;default:{this._x?this._context.bezierCurveTo(this._x0=(this._x0+t)/2,this._y0,this._x0,n,t,n):this._context.bezierCurveTo(this._x0,this._y0=(this._y0+n)/2,t,this._y0,t,n);break}}this._x0=t,this._y0=n}}function hut(e){return new sve(e,!0)}function put(e){return new sve(e,!1)}const Uze={draw(e,t){const n=bp(t/I$);e.moveTo(n,0),e.arc(0,0,n,0,qw)}},mut={draw(e,t){const n=bp(t/5)/2;e.moveTo(-3*n,-n),e.lineTo(-n,-n),e.lineTo(-n,-3*n),e.lineTo(n,-3*n),e.lineTo(n,-n),e.lineTo(3*n,-n),e.lineTo(3*n,n),e.lineTo(n,n),e.lineTo(n,3*n),e.lineTo(-n,3*n),e.lineTo(-n,n),e.lineTo(-3*n,n),e.closePath()}},cve=bp(1/3),jze=cve*2,gut={draw(e,t){const n=bp(t/jze),r=n*cve;e.moveTo(0,-n),e.lineTo(r,0),e.lineTo(0,n),e.lineTo(-r,0),e.closePath()}},vut={draw(e,t){const n=bp(t),r=-n/2;e.rect(r,r,n,n)}},Zze=.8908130915292852,fve=N$(I$/10)/N$(7*I$/10),Hze=N$(qw/10)*fve,Xze=-rve(qw/10)*fve,yut={draw(e,t){const n=bp(t*Zze),r=Hze*n,i=Xze*n;e.moveTo(0,-n),e.lineTo(r,i);for(let a=1;a<5;++a){const u=qw*a/5,l=rve(u),o=N$(u);e.lineTo(o*n,-l*n),e.lineTo(l*r-o*i,o*r+l*i)}e.closePath()}},VP=bp(3),but={draw(e,t){const n=-bp(t/(VP*3));e.moveTo(0,n*2),e.lineTo(-VP*n,-n),e.lineTo(VP*n,-n),e.closePath()}},Nd=-.5,Id=bp(3)/2,XM=1/bp(12),Yze=(XM/2+1)*3,Out={draw(e,t){const n=bp(t/Yze),r=n/2,i=n*XM,a=r,u=n*XM+n,l=-a,o=u;e.moveTo(r,i),e.lineTo(a,u),e.lineTo(l,o),e.lineTo(Nd*r-Id*i,Id*r+Nd*i),e.lineTo(Nd*a-Id*u,Id*a+Nd*u),e.lineTo(Nd*l-Id*o,Id*l+Nd*o),e.lineTo(Nd*r+Id*i,Nd*i-Id*r),e.lineTo(Nd*a+Id*u,Nd*u-Id*a),e.lineTo(Nd*l+Id*o,Nd*o-Id*l),e.closePath()}};function xut(e,t){let n=null,r=_L(i);e=typeof e=="function"?e:ba(e||Uze),t=typeof t=="function"?t:ba(t===void 0?64:+t);function i(){let a;if(n||(n=a=r()),e.apply(this,arguments).draw(n,+t.apply(this,arguments)),a)return n=null,a+""||null}return i.type=function(a){return arguments.length?(e=typeof a=="function"?a:ba(a),i):e},i.size=function(a){return arguments.length?(t=typeof a=="function"?a:ba(+a),i):t},i.context=function(a){return arguments.length?(n=a??null,i):n},i}function L$(){}function B$(e,t,n){e._context.bezierCurveTo((2*e._x0+e._x1)/3,(2*e._y0+e._y1)/3,(e._x0+2*e._x1)/3,(e._y0+2*e._y1)/3,(e._x0+4*e._x1+t)/6,(e._y0+4*e._y1+n)/6)}function dve(e){this._context=e}dve.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:B$(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1);break}(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:B$(this,e,t);break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t}};function Sut(e){return new dve(e)}function hve(e){this._context=e}hve.prototype={areaStart:L$,areaEnd:L$,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:{this._context.moveTo(this._x2,this._y2),this._context.closePath();break}case 2:{this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break}case 3:{this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4);break}}},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._x2=e,this._y2=t;break;case 1:this._point=2,this._x3=e,this._y3=t;break;case 2:this._point=3,this._x4=e,this._y4=t,this._context.moveTo((this._x0+4*this._x1+e)/6,(this._y0+4*this._y1+t)/6);break;default:B$(this,e,t);break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t}};function _ut(e){return new hve(e)}function pve(e){this._context=e}pve.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||this._line!==0&&this._point===3)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var n=(this._x0+4*this._x1+e)/6,r=(this._y0+4*this._y1+t)/6;this._line?this._context.lineTo(n,r):this._context.moveTo(n,r);break;case 3:this._point=4;default:B$(this,e,t);break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t}};function Eut(e){return new pve(e)}function mve(e){this._context=e}mve.prototype={areaStart:L$,areaEnd:L$,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(e,t){e=+e,t=+t,this._point?this._context.lineTo(e,t):(this._point=1,this._context.moveTo(e,t))}};function Dut(e){return new mve(e)}function SY(e){return e<0?-1:1}function _Y(e,t,n){var r=e._x1-e._x0,i=t-e._x1,a=(e._y1-e._y0)/(r||i<0&&-0),u=(n-e._y1)/(i||r<0&&-0),l=(a*i+u*r)/(r+i);return(SY(a)+SY(u))*Math.min(Math.abs(a),Math.abs(u),.5*Math.abs(l))||0}function EY(e,t){var n=e._x1-e._x0;return n?(3*(e._y1-e._y0)/n-t)/2:t}function UP(e,t,n){var r=e._x0,i=e._y0,a=e._x1,u=e._y1,l=(a-r)/3;e._context.bezierCurveTo(r+l,i+l*t,a-l,u-l*n,a,u)}function Q$(e){this._context=e}Q$.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:UP(this,this._t0,EY(this,this._t0));break}(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){var n=NaN;if(e=+e,t=+t,!(e===this._x1&&t===this._y1)){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;break;case 2:this._point=3,UP(this,EY(this,n=_Y(this,e,t)),n);break;default:UP(this,this._t0,n=_Y(this,e,t));break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t,this._t0=n}}};function gve(e){this._context=new vve(e)}(gve.prototype=Object.create(Q$.prototype)).point=function(e,t){Q$.prototype.point.call(this,t,e)};function vve(e){this._context=e}vve.prototype={moveTo:function(e,t){this._context.moveTo(t,e)},closePath:function(){this._context.closePath()},lineTo:function(e,t){this._context.lineTo(t,e)},bezierCurveTo:function(e,t,n,r,i,a){this._context.bezierCurveTo(t,e,r,n,a,i)}};function $ut(e){return new Q$(e)}function Cut(e){return new gve(e)}function yve(e){this._context=e}yve.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var e=this._x,t=this._y,n=e.length;if(n)if(this._line?this._context.lineTo(e[0],t[0]):this._context.moveTo(e[0],t[0]),n===2)this._context.lineTo(e[1],t[1]);else for(var r=DY(e),i=DY(t),a=0,u=1;u<n;++a,++u)this._context.bezierCurveTo(r[0][a],i[0][a],r[1][a],i[1][a],e[u],t[u]);(this._line||this._line!==0&&n===1)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(e,t){this._x.push(+e),this._y.push(+t)}};function DY(e){var t,n=e.length-1,r,i=new Array(n),a=new Array(n),u=new Array(n);for(i[0]=0,a[0]=2,u[0]=e[0]+2*e[1],t=1;t<n-1;++t)i[t]=1,a[t]=4,u[t]=4*e[t]+2*e[t+1];for(i[n-1]=2,a[n-1]=7,u[n-1]=8*e[n-1]+e[n],t=1;t<n;++t)r=i[t]/a[t-1],a[t]-=r,u[t]-=r*u[t-1];for(i[n-1]=u[n-1]/a[n-1],t=n-2;t>=0;--t)i[t]=(u[t]-i[t+1])/a[t];for(a[n-1]=(e[n]+i[n-1])/2,t=0;t<n-1;++t)a[t]=2*e[t+1]-i[t+1];return[i,a]}function wut(e){return new yve(e)}function Vw(e,t){this._context=e,this._t=t}Vw.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&this._point===2&&this._context.lineTo(this._x,this._y),(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;default:{if(this._t<=0)this._context.lineTo(this._x,t),this._context.lineTo(e,t);else{var n=this._x*(1-this._t)+e*this._t;this._context.lineTo(n,this._y),this._context.lineTo(n,t)}break}}this._x=e,this._y=t}};function Rut(e){return new Vw(e,.5)}function Aut(e){return new Vw(e,0)}function Tut(e){return new Vw(e,1)}function Vx(e,t){if((u=e.length)>1)for(var n=1,r,i,a=e[t[0]],u,l=a.length;n<u;++n)for(i=a,a=e[t[n]],r=0;r<l;++r)a[r][1]+=a[r][0]=isNaN(i[r][1])?i[r][0]:i[r][1]}function $Y(e){for(var t=e.length,n=new Array(t);--t>=0;)n[t]=t;return n}function Gze(e,t){return e[t]}function Kze(e){const t=[];return t.key=e,t}function kut(){var e=ba([]),t=$Y,n=Vx,r=Gze;function i(a){var u=Array.from(e.apply(this,arguments),Kze),l,o=u.length,s=-1,c;for(const d of a)for(l=0,++s;l<o;++l)(u[l][s]=[0,+r(d,u[l].key,s,a)]).data=d;for(l=0,c=EL(t(u));l<o;++l)u[c[l]].index=l;return n(u,c),u}return i.keys=function(a){return arguments.length?(e=typeof a=="function"?a:ba(Array.from(a)),i):e},i.value=function(a){return arguments.length?(r=typeof a=="function"?a:ba(+a),i):r},i.order=function(a){return arguments.length?(t=a==null?$Y:typeof a=="function"?a:ba(Array.from(a)),i):t},i.offset=function(a){return arguments.length?(n=a??Vx,i):n},i}function Put(e,t){if((r=e.length)>0){for(var n,r,i=0,a=e[0].length,u;i<a;++i){for(u=n=0;n<r;++n)u+=e[n][i][1]||0;if(u)for(n=0;n<r;++n)e[n][i][1]/=u}Vx(e,t)}}function Mut(e,t){if((i=e.length)>0){for(var n=0,r=e[t[0]],i,a=r.length;n<a;++n){for(var u=0,l=0;u<i;++u)l+=e[u][n][1]||0;r[n][1]+=r[n][0]=-l/2}Vx(e,t)}}function Fut(e,t){if(!(!((u=e.length)>0)||!((a=(i=e[t[0]]).length)>0))){for(var n=0,r=1,i,a,u;r<a;++r){for(var l=0,o=0,s=0;l<u;++l){for(var c=e[t[l]],d=c[r][1]||0,h=c[r-1][1]||0,m=(d-h)/2,y=0;y<l;++y){var v=e[t[y]],_=v[r][1]||0,S=v[r-1][1]||0;m+=_-S}o+=d,s+=m*d}i[r-1][1]+=i[r-1][0]=n,o&&(n-=s/o)}i[r-1][1]+=i[r-1][0]=n,Vx(e,t)}}var jP={},ZP={},CY;function Wze(){return CY||(CY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n,r){const i=new Map;for(let a=0;a<n.length;a++){const u=n[a],l=r(u);i.has(l)||i.set(l,u)}return Array.from(i.values())}e.uniqBy=t})(ZP)),ZP}var HP={},wY;function bve(){return wY||(wY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n}e.identity=t})(HP)),HP}var XP={},YP={},GP={},RY;function Jze(){return RY||(RY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return Number.isSafeInteger(n)&&n>=0}e.isLength=t})(GP)),GP}var AY;function DL(){return AY||(AY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Jze();function n(r){return r!=null&&typeof r!="function"&&t.isLength(r.length)}e.isArrayLike=n})(YP)),YP}var KP={},TY;function eqe(){return TY||(TY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return typeof n=="object"&&n!==null}e.isObjectLike=t})(KP)),KP}var kY;function tqe(){return kY||(kY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=DL(),n=eqe();function r(i){return n.isObjectLike(i)&&t.isArrayLike(i)}e.isArrayLikeObject=r})(XP)),XP}var WP={},JP={},PY;function nqe(){return PY||(PY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=SL();function n(r){return function(i){return t.get(i,r)}}e.property=n})(JP)),JP}var e8={},t8={},n8={},r8={},MY;function Ove(){return MY||(MY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n!==null&&(typeof n=="object"||typeof n=="function")}e.isObject=t})(r8)),r8}var i8={},FY;function xve(){return FY||(FY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n==null||typeof n!="object"&&typeof n!="function"}e.isPrimitive=t})(i8)),i8}var a8={},NY;function $L(){return NY||(NY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n,r){return n===r||Number.isNaN(n)&&Number.isNaN(r)}e.eq=t})(a8)),a8}var IY;function rqe(){return IY||(IY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=CL(),n=Ove(),r=xve(),i=$L();function a(d,h,m){return typeof m!="function"?t.isMatch(d,h):u(d,h,function y(v,_,S,E,C,T){const R=m(v,_,S,E,C,T);return R!==void 0?!!R:u(v,_,y,T)},new Map)}function u(d,h,m,y){if(h===d)return!0;switch(typeof h){case"object":return l(d,h,m,y);case"function":return Object.keys(h).length>0?u(d,{...h},m,y):i.eq(d,h);default:return n.isObject(d)?typeof h=="string"?h==="":!0:i.eq(d,h)}}function l(d,h,m,y){if(h==null)return!0;if(Array.isArray(h))return s(d,h,m,y);if(h instanceof Map)return o(d,h,m,y);if(h instanceof Set)return c(d,h,m,y);const v=Object.keys(h);if(d==null)return v.length===0;if(v.length===0)return!0;if(y&&y.has(h))return y.get(h)===d;y&&y.set(h,d);try{for(let _=0;_<v.length;_++){const S=v[_];if(!r.isPrimitive(d)&&!(S in d)||h[S]===void 0&&d[S]!==void 0||h[S]===null&&d[S]!==null||!m(d[S],h[S],S,d,h,y))return!1}return!0}finally{y&&y.delete(h)}}function o(d,h,m,y){if(h.size===0)return!0;if(!(d instanceof Map))return!1;for(const[v,_]of h.entries()){const S=d.get(v);if(m(S,_,v,d,h,y)===!1)return!1}return!0}function s(d,h,m,y){if(h.length===0)return!0;if(!Array.isArray(d))return!1;const v=new Set;for(let _=0;_<h.length;_++){const S=h[_];let E=!1;for(let C=0;C<d.length;C++){if(v.has(C))continue;const T=d[C];let R=!1;if(m(T,S,_,d,h,y)&&(R=!0),R){v.add(C),E=!0;break}}if(!E)return!1}return!0}function c(d,h,m,y){return h.size===0?!0:d instanceof Set?s([...d],[...h],m,y):!1}e.isMatchWith=a,e.isSetMatch=c})(n8)),n8}var LY;function CL(){return LY||(LY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=rqe();function n(r,i){return t.isMatchWith(r,i,()=>{})}e.isMatch=n})(t8)),t8}var u8={},l8={},o8={},BY;function Sve(){return BY||(BY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return Object.getOwnPropertySymbols(n).filter(r=>Object.prototype.propertyIsEnumerable.call(n,r))}e.getSymbols=t})(o8)),o8}var s8={},QY;function wL(){return QY||(QY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n==null?n===void 0?"[object Undefined]":"[object Null]":Object.prototype.toString.call(n)}e.getTag=t})(s8)),s8}var c8={},zY;function RL(){return zY||(zY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t="[object RegExp]",n="[object String]",r="[object Number]",i="[object Boolean]",a="[object Arguments]",u="[object Symbol]",l="[object Date]",o="[object Map]",s="[object Set]",c="[object Array]",d="[object Function]",h="[object ArrayBuffer]",m="[object Object]",y="[object Error]",v="[object DataView]",_="[object Uint8Array]",S="[object Uint8ClampedArray]",E="[object Uint16Array]",C="[object Uint32Array]",T="[object BigUint64Array]",R="[object Int8Array]",$="[object Int16Array]",k="[object Int32Array]",F="[object BigInt64Array]",L="[object Float32Array]",j="[object Float64Array]";e.argumentsTag=a,e.arrayBufferTag=h,e.arrayTag=c,e.bigInt64ArrayTag=F,e.bigUint64ArrayTag=T,e.booleanTag=i,e.dataViewTag=v,e.dateTag=l,e.errorTag=y,e.float32ArrayTag=L,e.float64ArrayTag=j,e.functionTag=d,e.int16ArrayTag=$,e.int32ArrayTag=k,e.int8ArrayTag=R,e.mapTag=o,e.numberTag=r,e.objectTag=m,e.regexpTag=t,e.setTag=s,e.stringTag=n,e.symbolTag=u,e.uint16ArrayTag=E,e.uint32ArrayTag=C,e.uint8ArrayTag=_,e.uint8ClampedArrayTag=S})(c8)),c8}var f8={},qY;function iqe(){return qY||(qY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return ArrayBuffer.isView(n)&&!(n instanceof DataView)}e.isTypedArray=t})(f8)),f8}var VY;function _ve(){return VY||(VY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Sve(),n=wL(),r=RL(),i=xve(),a=iqe();function u(c,d){return l(c,void 0,c,new Map,d)}function l(c,d,h,m=new Map,y=void 0){const v=y==null?void 0:y(c,d,h,m);if(v!=null)return v;if(i.isPrimitive(c))return c;if(m.has(c))return m.get(c);if(Array.isArray(c)){const _=new Array(c.length);m.set(c,_);for(let S=0;S<c.length;S++)_[S]=l(c[S],S,h,m,y);return Object.hasOwn(c,"index")&&(_.index=c.index),Object.hasOwn(c,"input")&&(_.input=c.input),_}if(c instanceof Date)return new Date(c.getTime());if(c instanceof RegExp){const _=new RegExp(c.source,c.flags);return _.lastIndex=c.lastIndex,_}if(c instanceof Map){const _=new Map;m.set(c,_);for(const[S,E]of c)_.set(S,l(E,S,h,m,y));return _}if(c instanceof Set){const _=new Set;m.set(c,_);for(const S of c)_.add(l(S,void 0,h,m,y));return _}if(typeof Buffer<"u"&&Buffer.isBuffer(c))return c.subarray();if(a.isTypedArray(c)){const _=new(Object.getPrototypeOf(c)).constructor(c.length);m.set(c,_);for(let S=0;S<c.length;S++)_[S]=l(c[S],S,h,m,y);return _}if(c instanceof ArrayBuffer||typeof SharedArrayBuffer<"u"&&c instanceof SharedArrayBuffer)return c.slice(0);if(c instanceof DataView){const _=new DataView(c.buffer.slice(0),c.byteOffset,c.byteLength);return m.set(c,_),o(_,c,h,m,y),_}if(typeof File<"u"&&c instanceof File){const _=new File([c],c.name,{type:c.type});return m.set(c,_),o(_,c,h,m,y),_}if(c instanceof Blob){const _=new Blob([c],{type:c.type});return m.set(c,_),o(_,c,h,m,y),_}if(c instanceof Error){const _=new c.constructor;return m.set(c,_),_.message=c.message,_.name=c.name,_.stack=c.stack,_.cause=c.cause,o(_,c,h,m,y),_}if(typeof c=="object"&&s(c)){const _=Object.create(Object.getPrototypeOf(c));return m.set(c,_),o(_,c,h,m,y),_}return c}function o(c,d,h=c,m,y){const v=[...Object.keys(d),...t.getSymbols(d)];for(let _=0;_<v.length;_++){const S=v[_],E=Object.getOwnPropertyDescriptor(c,S);(E==null||E.writable)&&(c[S]=l(d[S],S,h,m,y))}}function s(c){switch(n.getTag(c)){case r.argumentsTag:case r.arrayTag:case r.arrayBufferTag:case r.dataViewTag:case r.booleanTag:case r.dateTag:case r.float32ArrayTag:case r.float64ArrayTag:case r.int8ArrayTag:case r.int16ArrayTag:case r.int32ArrayTag:case r.mapTag:case r.numberTag:case r.objectTag:case r.regexpTag:case r.setTag:case r.stringTag:case r.symbolTag:case r.uint8ArrayTag:case r.uint8ClampedArrayTag:case r.uint16ArrayTag:case r.uint32ArrayTag:return!0;default:return!1}}e.cloneDeepWith=u,e.cloneDeepWithImpl=l,e.copyProperties=o})(l8)),l8}var UY;function aqe(){return UY||(UY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=_ve();function n(r){return t.cloneDeepWithImpl(r,void 0,r,new Map,void 0)}e.cloneDeep=n})(u8)),u8}var jY;function uqe(){return jY||(jY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=CL(),n=aqe();function r(i){return i=n.cloneDeep(i),a=>t.isMatch(a,i)}e.matches=r})(e8)),e8}var d8={},h8={},p8={},ZY;function lqe(){return ZY||(ZY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=_ve(),n=RL();function r(i,a){return t.cloneDeepWith(i,(u,l,o,s)=>{const c=a==null?void 0:a(u,l,o,s);if(c!=null)return c;if(typeof i=="object")switch(Object.prototype.toString.call(i)){case n.numberTag:case n.stringTag:case n.booleanTag:{const d=new i.constructor(i==null?void 0:i.valueOf());return t.copyProperties(d,i),d}case n.argumentsTag:{const d={};return t.copyProperties(d,i),d.length=i.length,d[Symbol.iterator]=i[Symbol.iterator],d}default:return}})}e.cloneDeepWith=r})(p8)),p8}var HY;function oqe(){return HY||(HY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=lqe();function n(r){return t.cloneDeepWith(r)}e.cloneDeep=n})(h8)),h8}var m8={},g8={},XY;function Eve(){return XY||(XY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=/^(?:0|[1-9]\d*)$/;function n(r,i=Number.MAX_SAFE_INTEGER){switch(typeof r){case"number":return Number.isInteger(r)&&r>=0&&r<i;case"symbol":return!1;case"string":return t.test(r)}}e.isIndex=n})(g8)),g8}var v8={},YY;function sqe(){return YY||(YY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=wL();function n(r){return r!==null&&typeof r=="object"&&t.getTag(r)==="[object Arguments]"}e.isArguments=n})(v8)),v8}var GY;function cqe(){return GY||(GY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=tve(),n=Eve(),r=sqe(),i=xL();function a(u,l){let o;if(Array.isArray(l)?o=l:typeof l=="string"&&t.isDeepKey(l)&&(u==null?void 0:u[l])==null?o=i.toPath(l):o=[l],o.length===0)return!1;let s=u;for(let c=0;c<o.length;c++){const d=o[c];if((s==null||!Object.hasOwn(s,d))&&!((Array.isArray(s)||r.isArguments(s))&&n.isIndex(d)&&d<s.length))return!1;s=s[d]}return!0}e.has=a})(m8)),m8}var KY;function fqe(){return KY||(KY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=CL(),n=nve(),r=oqe(),i=SL(),a=cqe();function u(l,o){switch(typeof l){case"object":{Object.is(l==null?void 0:l.valueOf(),-0)&&(l="-0");break}case"number":{l=n.toKey(l);break}}return o=r.cloneDeep(o),function(s){const c=i.get(s,l);return c===void 0?a.has(s,l):o===void 0?c===void 0:t.isMatch(c,o)}}e.matchesProperty=u})(d8)),d8}var WY;function dqe(){return WY||(WY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=bve(),n=nqe(),r=uqe(),i=fqe();function a(u){if(u==null)return t.identity;switch(typeof u){case"function":return u;case"object":return Array.isArray(u)&&u.length===2?i.matchesProperty(u[0],u[1]):r.matches(u);case"string":case"symbol":case"number":return n.property(u)}}e.iteratee=a})(WP)),WP}var JY;function hqe(){return JY||(JY=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Wze(),n=bve(),r=tqe(),i=dqe();function a(u,l=n.identity){return r.isArrayLikeObject(u)?t.uniqBy(Array.from(u),i.iteratee(l)):[]}e.uniqBy=a})(jP)),jP}var y8,eG;function pqe(){return eG||(eG=1,y8=hqe().uniqBy),y8}var mqe=pqe();const Nut=sa(mqe);function gqe(e,t=`expected a function, instead received ${typeof e}`){if(typeof e!="function")throw new TypeError(t)}function vqe(e,t=`expected an object, instead received ${typeof e}`){if(typeof e!="object")throw new TypeError(t)}function yqe(e,t="expected all items to be functions, instead received the following types: "){if(!e.every(n=>typeof n=="function")){const n=e.map(r=>typeof r=="function"?`function ${r.name||"unnamed"}()`:typeof r).join(", ");throw new TypeError(`${t}[${n}]`)}}var tG=e=>Array.isArray(e)?e:[e];function bqe(e){const t=Array.isArray(e[0])?e[0]:e;return yqe(t,"createSelector expects all input-selectors to be functions, but received the following types: "),t}function Oqe(e,t){const n=[],{length:r}=e;for(let i=0;i<r;i++)n.push(e[i].apply(null,t));return n}var xqe=class{constructor(e){this.value=e}deref(){return this.value}},Sqe=typeof WeakRef<"u"?WeakRef:xqe,_qe=0,nG=1;function _E(){return{s:_qe,v:void 0,o:null,p:null}}function Dve(e,t={}){let n=_E();const{resultEqualityCheck:r}=t;let i,a=0;function u(){var d;let l=n;const{length:o}=arguments;for(let h=0,m=o;h<m;h++){const y=arguments[h];if(typeof y=="function"||typeof y=="object"&&y!==null){let v=l.o;v===null&&(l.o=v=new WeakMap);const _=v.get(y);_===void 0?(l=_E(),v.set(y,l)):l=_}else{let v=l.p;v===null&&(l.p=v=new Map);const _=v.get(y);_===void 0?(l=_E(),v.set(y,l)):l=_}}const s=l;let c;if(l.s===nG)c=l.v;else if(c=e.apply(null,arguments),a++,r){const h=((d=i==null?void 0:i.deref)==null?void 0:d.call(i))??i;h!=null&&r(h,c)&&(c=h,a!==0&&a--),i=typeof c=="object"&&c!==null||typeof c=="function"?new Sqe(c):c}return s.s=nG,s.v=c,c}return u.clearCache=()=>{n=_E(),u.resetResultsCount()},u.resultsCount=()=>a,u.resetResultsCount=()=>{a=0},u}function Eqe(e,...t){const n=typeof e=="function"?{memoize:e,memoizeOptions:t}:e,r=(...i)=>{let a=0,u=0,l,o={},s=i.pop();typeof s=="object"&&(o=s,s=i.pop()),gqe(s,`createSelector expects an output function after the inputs, but received: [${typeof s}]`);const c={...n,...o},{memoize:d,memoizeOptions:h=[],argsMemoize:m=Dve,argsMemoizeOptions:y=[]}=c,v=tG(h),_=tG(y),S=bqe(i),E=d(function(){return a++,s.apply(null,arguments)},...v),C=m(function(){u++;const R=Oqe(S,arguments);return l=E.apply(null,R),l},..._);return Object.assign(C,{resultFunc:s,memoizedResultFunc:E,dependencies:S,dependencyRecomputations:()=>u,resetDependencyRecomputations:()=>{u=0},lastResult:()=>l,recomputations:()=>a,resetRecomputations:()=>{a=0},memoize:d,argsMemoize:m})};return Object.assign(r,{withTypes:()=>r}),r}var Dqe=Eqe(Dve),$qe=Object.assign((e,t=Dqe)=>{vqe(e,`createStructuredSelector expects first argument to be an object where each property is a selector, instead received a ${typeof e}`);const n=Object.keys(e),r=n.map(a=>e[a]);return t(r,(...a)=>a.reduce((u,l,o)=>(u[n[o]]=l,u),{}))},{withTypes:()=>$qe}),b8={},O8={},x8={},rG;function Cqe(){return rG||(rG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(r){return typeof r=="symbol"?1:r===null?2:r===void 0?3:r!==r?4:0}const n=(r,i,a)=>{if(r!==i){const u=t(r),l=t(i);if(u===l&&u===0){if(r<i)return a==="desc"?1:-1;if(r>i)return a==="desc"?-1:1}return a==="desc"?l-u:u-l}return 0};e.compareValues=n})(x8)),x8}var S8={},_8={},iG;function $ve(){return iG||(iG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return typeof n=="symbol"||n instanceof Symbol}e.isSymbol=t})(_8)),_8}var aG;function wqe(){return aG||(aG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=$ve(),n=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,r=/^\w*$/;function i(a,u){return Array.isArray(a)?!1:typeof a=="number"||typeof a=="boolean"||a==null||t.isSymbol(a)?!0:typeof a=="string"&&(r.test(a)||!n.test(a))||u!=null&&Object.hasOwn(u,a)}e.isKey=i})(S8)),S8}var uG;function Rqe(){return uG||(uG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Cqe(),n=wqe(),r=xL();function i(a,u,l,o){if(a==null)return[];l=o?void 0:l,Array.isArray(a)||(a=Object.values(a)),Array.isArray(u)||(u=u==null?[null]:[u]),u.length===0&&(u=[null]),Array.isArray(l)||(l=l==null?[]:[l]),l=l.map(m=>String(m));const s=(m,y)=>{let v=m;for(let _=0;_<y.length&&v!=null;++_)v=v[y[_]];return v},c=(m,y)=>y==null||m==null?y:typeof m=="object"&&"key"in m?Object.hasOwn(y,m.key)?y[m.key]:s(y,m.path):typeof m=="function"?m(y):Array.isArray(m)?s(y,m):typeof y=="object"?y[m]:y,d=u.map(m=>(Array.isArray(m)&&m.length===1&&(m=m[0]),m==null||typeof m=="function"||Array.isArray(m)||n.isKey(m)?m:{key:m,path:r.toPath(m)}));return a.map(m=>({original:m,criteria:d.map(y=>c(y,m))})).slice().sort((m,y)=>{for(let v=0;v<d.length;v++){const _=t.compareValues(m.criteria[v],y.criteria[v],l[v]);if(_!==0)return _}return 0}).map(m=>m.original)}e.orderBy=i})(O8)),O8}var E8={},lG;function Aqe(){return lG||(lG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n,r=1){const i=[],a=Math.floor(r),u=(l,o)=>{for(let s=0;s<l.length;s++){const c=l[s];Array.isArray(c)&&o<a?u(c,o+1):i.push(c)}};return u(n,0),i}e.flatten=t})(E8)),E8}var D8={},oG;function Cve(){return oG||(oG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Eve(),n=DL(),r=Ove(),i=$L();function a(u,l,o){return r.isObject(o)&&(typeof l=="number"&&n.isArrayLike(o)&&t.isIndex(l)&&l<o.length||typeof l=="string"&&l in o)?i.eq(o[l],u):!1}e.isIterateeCall=a})(D8)),D8}var sG;function Tqe(){return sG||(sG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Rqe(),n=Aqe(),r=Cve();function i(a,...u){const l=u.length;return l>1&&r.isIterateeCall(a,u[0],u[1])?u=[]:l>2&&r.isIterateeCall(u[0],u[1],u[2])&&(u=[u[0]]),t.orderBy(a,n.flatten(u),["asc"])}e.sortBy=i})(b8)),b8}var $8,cG;function kqe(){return cG||(cG=1,$8=Tqe().sortBy),$8}var Pqe=kqe();const Iut=sa(Pqe);function Ao(e){return`Minified Redux error #${e}; visit https://redux.js.org/Errors?code=${e} for the full message or use the non-minified dev environment for full errors. `}var Mqe=typeof Symbol=="function"&&Symbol.observable||"@@observable",fG=Mqe,C8=()=>Math.random().toString(36).substring(7).split("").join("."),Fqe={INIT:`@@redux/INIT${C8()}`,REPLACE:`@@redux/REPLACE${C8()}`,PROBE_UNKNOWN_ACTION:()=>`@@redux/PROBE_UNKNOWN_ACTION${C8()}`},z$=Fqe;function AL(e){if(typeof e!="object"||e===null)return!1;let t=e;for(;Object.getPrototypeOf(t)!==null;)t=Object.getPrototypeOf(t);return Object.getPrototypeOf(e)===t||Object.getPrototypeOf(e)===null}function wve(e,t,n){if(typeof e!="function")throw new Error(Ao(2));if(typeof t=="function"&&typeof n=="function"||typeof n=="function"&&typeof arguments[3]=="function")throw new Error(Ao(0));if(typeof t=="function"&&typeof n>"u"&&(n=t,t=void 0),typeof n<"u"){if(typeof n!="function")throw new Error(Ao(1));return n(wve)(e,t)}let r=e,i=t,a=new Map,u=a,l=0,o=!1;function s(){u===a&&(u=new Map,a.forEach((_,S)=>{u.set(S,_)}))}function c(){if(o)throw new Error(Ao(3));return i}function d(_){if(typeof _!="function")throw new Error(Ao(4));if(o)throw new Error(Ao(5));let S=!0;s();const E=l++;return u.set(E,_),function(){if(S){if(o)throw new Error(Ao(6));S=!1,s(),u.delete(E),a=null}}}function h(_){if(!AL(_))throw new Error(Ao(7));if(typeof _.type>"u")throw new Error(Ao(8));if(typeof _.type!="string")throw new Error(Ao(17));if(o)throw new Error(Ao(9));try{o=!0,i=r(i,_)}finally{o=!1}return(a=u).forEach(E=>{E()}),_}function m(_){if(typeof _!="function")throw new Error(Ao(10));r=_,h({type:z$.REPLACE})}function y(){const _=d;return{subscribe(S){if(typeof S!="object"||S===null)throw new Error(Ao(11));function E(){const T=S;T.next&&T.next(c())}return E(),{unsubscribe:_(E)}},[fG](){return this}}}return h({type:z$.INIT}),{dispatch:h,subscribe:d,getState:c,replaceReducer:m,[fG]:y}}function Nqe(e){Object.keys(e).forEach(t=>{const n=e[t];if(typeof n(void 0,{type:z$.INIT})>"u")throw new Error(Ao(12));if(typeof n(void 0,{type:z$.PROBE_UNKNOWN_ACTION()})>"u")throw new Error(Ao(13))})}function Iqe(e){const t=Object.keys(e),n={};for(let a=0;a<t.length;a++){const u=t[a];typeof e[u]=="function"&&(n[u]=e[u])}const r=Object.keys(n);let i;try{Nqe(n)}catch(a){i=a}return function(u={},l){if(i)throw i;let o=!1;const s={};for(let c=0;c<r.length;c++){const d=r[c],h=n[d],m=u[d],y=h(m,l);if(typeof y>"u")throw l&&l.type,new Error(Ao(14));s[d]=y,o=o||y!==m}return o=o||r.length!==Object.keys(u).length,o?s:u}}function q$(...e){return e.length===0?t=>t:e.length===1?e[0]:e.reduce((t,n)=>(...r)=>t(n(...r)))}function Lqe(...e){return t=>(n,r)=>{const i=t(n,r);let a=()=>{throw new Error(Ao(15))};const u={getState:i.getState,dispatch:(o,...s)=>a(o,...s)},l=e.map(o=>o(u));return a=q$(...l)(i.dispatch),{...i,dispatch:a}}}function Rve(e){return AL(e)&&"type"in e&&typeof e.type=="string"}var Ave=Symbol.for("immer-nothing"),dG=Symbol.for("immer-draftable"),Kf=Symbol.for("immer-state");function Jh(e,...t){throw new Error(`[Immer] minified error nr: ${e}. Full error at: https://bit.ly/3cXEKWf`)}var I3=Object.getPrototypeOf;function gb(e){return!!e&&!!e[Kf]}function dg(e){var t;return e?Tve(e)||Array.isArray(e)||!!e[dG]||!!((t=e.constructor)!=null&&t[dG])||jw(e)||Zw(e):!1}var Bqe=Object.prototype.constructor.toString();function Tve(e){if(!e||typeof e!="object")return!1;const t=I3(e);if(t===null)return!0;const n=Object.hasOwnProperty.call(t,"constructor")&&t.constructor;return n===Object?!0:typeof n=="function"&&Function.toString.call(n)===Bqe}function V$(e,t){Uw(e)===0?Reflect.ownKeys(e).forEach(n=>{t(n,e[n],e)}):e.forEach((n,r)=>t(r,n,e))}function Uw(e){const t=e[Kf];return t?t.type_:Array.isArray(e)?1:jw(e)?2:Zw(e)?3:0}function YM(e,t){return Uw(e)===2?e.has(t):Object.prototype.hasOwnProperty.call(e,t)}function kve(e,t,n){const r=Uw(e);r===2?e.set(t,n):r===3?e.add(n):e[t]=n}function Qqe(e,t){return e===t?e!==0||1/e===1/t:e!==e&&t!==t}function jw(e){return e instanceof Map}function Zw(e){return e instanceof Set}function R1(e){return e.copy_||e.base_}function GM(e,t){if(jw(e))return new Map(e);if(Zw(e))return new Set(e);if(Array.isArray(e))return Array.prototype.slice.call(e);const n=Tve(e);if(t===!0||t==="class_only"&&!n){const r=Object.getOwnPropertyDescriptors(e);delete r[Kf];let i=Reflect.ownKeys(r);for(let a=0;a<i.length;a++){const u=i[a],l=r[u];l.writable===!1&&(l.writable=!0,l.configurable=!0),(l.get||l.set)&&(r[u]={configurable:!0,writable:!0,enumerable:l.enumerable,value:e[u]})}return Object.create(I3(e),r)}else{const r=I3(e);if(r!==null&&n)return{...e};const i=Object.create(r);return Object.assign(i,e)}}function TL(e,t=!1){return Hw(e)||gb(e)||!dg(e)||(Uw(e)>1&&(e.set=e.add=e.clear=e.delete=zqe),Object.freeze(e),t&&Object.entries(e).forEach(([n,r])=>TL(r,!0))),e}function zqe(){Jh(2)}function Hw(e){return Object.isFrozen(e)}var qqe={};function vb(e){const t=qqe[e];return t||Jh(0,e),t}var Ux;function Pve(){return Ux}function Vqe(e,t){return{drafts_:[],parent_:e,immer_:t,canAutoFreeze_:!0,unfinalizedDrafts_:0}}function hG(e,t){t&&(vb("Patches"),e.patches_=[],e.inversePatches_=[],e.patchListener_=t)}function KM(e){WM(e),e.drafts_.forEach(Uqe),e.drafts_=null}function WM(e){e===Ux&&(Ux=e.parent_)}function pG(e){return Ux=Vqe(Ux,e)}function Uqe(e){const t=e[Kf];t.type_===0||t.type_===1?t.revoke_():t.revoked_=!0}function mG(e,t){t.unfinalizedDrafts_=t.drafts_.length;const n=t.drafts_[0];return e!==void 0&&e!==n?(n[Kf].modified_&&(KM(t),Jh(4)),dg(e)&&(e=U$(t,e),t.parent_||j$(t,e)),t.patches_&&vb("Patches").generateReplacementPatches_(n[Kf].base_,e,t.patches_,t.inversePatches_)):e=U$(t,n,[]),KM(t),t.patches_&&t.patchListener_(t.patches_,t.inversePatches_),e!==Ave?e:void 0}function U$(e,t,n){if(Hw(t))return t;const r=t[Kf];if(!r)return V$(t,(i,a)=>gG(e,r,t,i,a,n)),t;if(r.scope_!==e)return t;if(!r.modified_)return j$(e,r.base_,!0),r.base_;if(!r.finalized_){r.finalized_=!0,r.scope_.unfinalizedDrafts_--;const i=r.copy_;let a=i,u=!1;r.type_===3&&(a=new Set(i),i.clear(),u=!0),V$(a,(l,o)=>gG(e,r,i,l,o,n,u)),j$(e,i,!1),n&&e.patches_&&vb("Patches").generatePatches_(r,n,e.patches_,e.inversePatches_)}return r.copy_}function gG(e,t,n,r,i,a,u){if(gb(i)){const l=a&&t&&t.type_!==3&&!YM(t.assigned_,r)?a.concat(r):void 0,o=U$(e,i,l);if(kve(n,r,o),gb(o))e.canAutoFreeze_=!1;else return}else u&&n.add(i);if(dg(i)&&!Hw(i)){if(!e.immer_.autoFreeze_&&e.unfinalizedDrafts_<1)return;U$(e,i),(!t||!t.scope_.parent_)&&typeof r!="symbol"&&Object.prototype.propertyIsEnumerable.call(n,r)&&j$(e,i)}}function j$(e,t,n=!1){!e.parent_&&e.immer_.autoFreeze_&&e.canAutoFreeze_&&TL(t,n)}function jqe(e,t){const n=Array.isArray(e),r={type_:n?1:0,scope_:t?t.scope_:Pve(),modified_:!1,finalized_:!1,assigned_:{},parent_:t,base_:e,draft_:null,copy_:null,revoke_:null,isManual_:!1};let i=r,a=kL;n&&(i=[r],a=jx);const{revoke:u,proxy:l}=Proxy.revocable(i,a);return r.draft_=l,r.revoke_=u,l}var kL={get(e,t){if(t===Kf)return e;const n=R1(e);if(!YM(n,t))return Zqe(e,n,t);const r=n[t];return e.finalized_||!dg(r)?r:r===w8(e.base_,t)?(R8(e),e.copy_[t]=eF(r,e)):r},has(e,t){return t in R1(e)},ownKeys(e){return Reflect.ownKeys(R1(e))},set(e,t,n){const r=Mve(R1(e),t);if(r!=null&&r.set)return r.set.call(e.draft_,n),!0;if(!e.modified_){const i=w8(R1(e),t),a=i==null?void 0:i[Kf];if(a&&a.base_===n)return e.copy_[t]=n,e.assigned_[t]=!1,!0;if(Qqe(n,i)&&(n!==void 0||YM(e.base_,t)))return!0;R8(e),JM(e)}return e.copy_[t]===n&&(n!==void 0||t in e.copy_)||Number.isNaN(n)&&Number.isNaN(e.copy_[t])||(e.copy_[t]=n,e.assigned_[t]=!0),!0},deleteProperty(e,t){return w8(e.base_,t)!==void 0||t in e.base_?(e.assigned_[t]=!1,R8(e),JM(e)):delete e.assigned_[t],e.copy_&&delete e.copy_[t],!0},getOwnPropertyDescriptor(e,t){const n=R1(e),r=Reflect.getOwnPropertyDescriptor(n,t);return r&&{writable:!0,configurable:e.type_!==1||t!=="length",enumerable:r.enumerable,value:n[t]}},defineProperty(){Jh(11)},getPrototypeOf(e){return I3(e.base_)},setPrototypeOf(){Jh(12)}},jx={};V$(kL,(e,t)=>{jx[e]=function(){return arguments[0]=arguments[0][0],t.apply(this,arguments)}});jx.deleteProperty=function(e,t){return jx.set.call(this,e,t,void 0)};jx.set=function(e,t,n){return kL.set.call(this,e[0],t,n,e[0])};function w8(e,t){const n=e[Kf];return(n?R1(n):e)[t]}function Zqe(e,t,n){var i;const r=Mve(t,n);return r?"value"in r?r.value:(i=r.get)==null?void 0:i.call(e.draft_):void 0}function Mve(e,t){if(!(t in e))return;let n=I3(e);for(;n;){const r=Object.getOwnPropertyDescriptor(n,t);if(r)return r;n=I3(n)}}function JM(e){e.modified_||(e.modified_=!0,e.parent_&&JM(e.parent_))}function R8(e){e.copy_||(e.copy_=GM(e.base_,e.scope_.immer_.useStrictShallowCopy_))}var Hqe=class{constructor(e){this.autoFreeze_=!0,this.useStrictShallowCopy_=!1,this.produce=(t,n,r)=>{if(typeof t=="function"&&typeof n!="function"){const a=n;n=t;const u=this;return function(o=a,...s){return u.produce(o,c=>n.call(this,c,...s))}}typeof n!="function"&&Jh(6),r!==void 0&&typeof r!="function"&&Jh(7);let i;if(dg(t)){const a=pG(this),u=eF(t,void 0);let l=!0;try{i=n(u),l=!1}finally{l?KM(a):WM(a)}return hG(a,r),mG(i,a)}else if(!t||typeof t!="object"){if(i=n(t),i===void 0&&(i=t),i===Ave&&(i=void 0),this.autoFreeze_&&TL(i,!0),r){const a=[],u=[];vb("Patches").generateReplacementPatches_(t,i,a,u),r(a,u)}return i}else Jh(1,t)},this.produceWithPatches=(t,n)=>{if(typeof t=="function")return(u,...l)=>this.produceWithPatches(u,o=>t(o,...l));let r,i;return[this.produce(t,n,(u,l)=>{r=u,i=l}),r,i]},typeof(e==null?void 0:e.autoFreeze)=="boolean"&&this.setAutoFreeze(e.autoFreeze),typeof(e==null?void 0:e.useStrictShallowCopy)=="boolean"&&this.setUseStrictShallowCopy(e.useStrictShallowCopy)}createDraft(e){dg(e)||Jh(8),gb(e)&&(e=Xqe(e));const t=pG(this),n=eF(e,void 0);return n[Kf].isManual_=!0,WM(t),n}finishDraft(e,t){const n=e&&e[Kf];(!n||!n.isManual_)&&Jh(9);const{scope_:r}=n;return hG(r,t),mG(void 0,r)}setAutoFreeze(e){this.autoFreeze_=e}setUseStrictShallowCopy(e){this.useStrictShallowCopy_=e}applyPatches(e,t){let n;for(n=t.length-1;n>=0;n--){const i=t[n];if(i.path.length===0&&i.op==="replace"){e=i.value;break}}n>-1&&(t=t.slice(n+1));const r=vb("Patches").applyPatches_;return gb(e)?r(e,t):this.produce(e,i=>r(i,t))}};function eF(e,t){const n=jw(e)?vb("MapSet").proxyMap_(e,t):Zw(e)?vb("MapSet").proxySet_(e,t):jqe(e,t);return(t?t.scope_:Pve()).drafts_.push(n),n}function Xqe(e){return gb(e)||Jh(10,e),Fve(e)}function Fve(e){if(!dg(e)||Hw(e))return e;const t=e[Kf];let n;if(t){if(!t.modified_)return t.base_;t.finalized_=!0,n=GM(e,t.scope_.immer_.useStrictShallowCopy_)}else n=GM(e,!0);return V$(n,(r,i)=>{kve(n,r,Fve(i))}),t&&(t.finalized_=!1),n}var Wf=new Hqe,Nve=Wf.produce;Wf.produceWithPatches.bind(Wf);Wf.setAutoFreeze.bind(Wf);Wf.setUseStrictShallowCopy.bind(Wf);Wf.applyPatches.bind(Wf);Wf.createDraft.bind(Wf);Wf.finishDraft.bind(Wf);function Lut(e){return e}function Ive(e){return({dispatch:n,getState:r})=>i=>a=>typeof a=="function"?a(n,r,e):i(a)}var Yqe=Ive(),Gqe=Ive,Kqe=typeof window<"u"&&window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__?window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__:function(){if(arguments.length!==0)return typeof arguments[0]=="object"?q$:q$.apply(null,arguments)};function L3(e,t){function n(...r){if(t){let i=t(...r);if(!i)throw new Error(jf(0));return{type:e,payload:i.payload,..."meta"in i&&{meta:i.meta},..."error"in i&&{error:i.error}}}return{type:e,payload:r[0]}}return n.toString=()=>`${e}`,n.type=e,n.match=r=>Rve(r)&&r.type===e,n}var Lve=class L2 extends Array{constructor(...t){super(...t),Object.setPrototypeOf(this,L2.prototype)}static get[Symbol.species](){return L2}concat(...t){return super.concat.apply(this,t)}prepend(...t){return t.length===1&&Array.isArray(t[0])?new L2(...t[0].concat(this)):new L2(...t.concat(this))}};function vG(e){return dg(e)?Nve(e,()=>{}):e}function EE(e,t,n){return e.has(t)?e.get(t):e.set(t,n(t)).get(t)}function Wqe(e){return typeof e=="boolean"}var Jqe=()=>function(t){const{thunk:n=!0,immutableCheck:r=!0,serializableCheck:i=!0,actionCreatorCheck:a=!0}=t??{};let u=new Lve;return n&&(Wqe(n)?u.push(Yqe):u.push(Gqe(n.extraArgument))),u},eVe="RTK_autoBatch",yG=e=>t=>{setTimeout(t,e)},tVe=(e={type:"raf"})=>t=>(...n)=>{const r=t(...n);let i=!0,a=!1,u=!1;const l=new Set,o=e.type==="tick"?queueMicrotask:e.type==="raf"?typeof window<"u"&&window.requestAnimationFrame?window.requestAnimationFrame:yG(10):e.type==="callback"?e.queueNotification:yG(e.timeout),s=()=>{u=!1,a&&(a=!1,l.forEach(c=>c()))};return Object.assign({},r,{subscribe(c){const d=()=>i&&c(),h=r.subscribe(d);return l.add(c),()=>{h(),l.delete(c)}},dispatch(c){var d;try{return i=!((d=c==null?void 0:c.meta)!=null&&d[eVe]),a=!i,a&&(u||(u=!0,o(s))),r.dispatch(c)}finally{i=!0}}})},nVe=e=>function(n){const{autoBatch:r=!0}=n??{};let i=new Lve(e);return r&&i.push(tVe(typeof r=="object"?r:void 0)),i};function But(e){const t=Jqe(),{reducer:n=void 0,middleware:r,devTools:i=!0,preloadedState:a=void 0,enhancers:u=void 0}=e||{};let l;if(typeof n=="function")l=n;else if(AL(n))l=Iqe(n);else throw new Error(jf(1));let o;typeof r=="function"?o=r(t):o=t();let s=q$;i&&(s=Kqe({trace:!1,...typeof i=="object"&&i}));const c=Lqe(...o),d=nVe(c);let h=typeof u=="function"?u(d):d();const m=s(...h);return wve(l,a,m)}function Bve(e){const t={},n=[];let r;const i={addCase(a,u){const l=typeof a=="string"?a:a.type;if(!l)throw new Error(jf(28));if(l in t)throw new Error(jf(29));return t[l]=u,i},addMatcher(a,u){return n.push({matcher:a,reducer:u}),i},addDefaultCase(a){return r=a,i}};return e(i),[t,n,r]}function rVe(e){return typeof e=="function"}function iVe(e,t){let[n,r,i]=Bve(t),a;if(rVe(e))a=()=>vG(e());else{const l=vG(e);a=()=>l}function u(l=a(),o){let s=[n[o.type],...r.filter(({matcher:c})=>c(o)).map(({reducer:c})=>c)];return s.filter(c=>!!c).length===0&&(s=[i]),s.reduce((c,d)=>{if(d)if(gb(c)){const m=d(c,o);return m===void 0?c:m}else{if(dg(c))return Nve(c,h=>d(h,o));{const h=d(c,o);if(h===void 0){if(c===null)return c;throw Error("A case reducer on a non-draftable value must not return undefined")}return h}}return c},l)}return u.getInitialState=a,u}var aVe="ModuleSymbhasOwnPr-0123456789ABCDEFGHNRVfgctiUvz_KqYTJkLxpZXIjQW",uVe=(e=21)=>{let t="",n=e;for(;n--;)t+=aVe[Math.random()*64|0];return t},lVe=Symbol.for("rtk-slice-createasyncthunk");function oVe(e,t){return`${e}/${t}`}function sVe({creators:e}={}){var n;const t=(n=e==null?void 0:e.asyncThunk)==null?void 0:n[lVe];return function(i){const{name:a,reducerPath:u=a}=i;if(!a)throw new Error(jf(11));const l=(typeof i.reducers=="function"?i.reducers(fVe()):i.reducers)||{},o=Object.keys(l),s={sliceCaseReducersByName:{},sliceCaseReducersByType:{},actionCreators:{},sliceMatchers:[]},c={addCase(T,R){const $=typeof T=="string"?T:T.type;if(!$)throw new Error(jf(12));if($ in s.sliceCaseReducersByType)throw new Error(jf(13));return s.sliceCaseReducersByType[$]=R,c},addMatcher(T,R){return s.sliceMatchers.push({matcher:T,reducer:R}),c},exposeAction(T,R){return s.actionCreators[T]=R,c},exposeCaseReducer(T,R){return s.sliceCaseReducersByName[T]=R,c}};o.forEach(T=>{const R=l[T],$={reducerName:T,type:oVe(a,T),createNotation:typeof i.reducers=="function"};hVe(R)?mVe($,R,c,t):dVe($,R,c)});function d(){const[T={},R=[],$=void 0]=typeof i.extraReducers=="function"?Bve(i.extraReducers):[i.extraReducers],k={...T,...s.sliceCaseReducersByType};return iVe(i.initialState,F=>{for(let L in k)F.addCase(L,k[L]);for(let L of s.sliceMatchers)F.addMatcher(L.matcher,L.reducer);for(let L of R)F.addMatcher(L.matcher,L.reducer);$&&F.addDefaultCase($)})}const h=T=>T,m=new Map,y=new WeakMap;let v;function _(T,R){return v||(v=d()),v(T,R)}function S(){return v||(v=d()),v.getInitialState()}function E(T,R=!1){function $(F){let L=F[T];return typeof L>"u"&&R&&(L=EE(y,$,S)),L}function k(F=h){const L=EE(m,R,()=>new WeakMap);return EE(L,F,()=>{const j={};for(const[V,q]of Object.entries(i.selectors??{}))j[V]=cVe(q,F,()=>EE(y,F,S),R);return j})}return{reducerPath:T,getSelectors:k,get selectors(){return k($)},selectSlice:$}}const C={name:a,reducer:_,actions:s.actionCreators,caseReducers:s.sliceCaseReducersByName,getInitialState:S,...E(u),injectInto(T,{reducerPath:R,...$}={}){const k=R??u;return T.inject({reducerPath:k,reducer:_},$),{...C,...E(k,!0)}}};return C}}function cVe(e,t,n,r){function i(a,...u){let l=t(a);return typeof l>"u"&&r&&(l=n()),e(l,...u)}return i.unwrapped=e,i}var Qut=sVe();function fVe(){function e(t,n){return{_reducerDefinitionType:"asyncThunk",payloadCreator:t,...n}}return e.withTypes=()=>e,{reducer(t){return Object.assign({[t.name](...n){return t(...n)}}[t.name],{_reducerDefinitionType:"reducer"})},preparedReducer(t,n){return{_reducerDefinitionType:"reducerWithPrepare",prepare:t,reducer:n}},asyncThunk:e}}function dVe({type:e,reducerName:t,createNotation:n},r,i){let a,u;if("reducer"in r){if(n&&!pVe(r))throw new Error(jf(17));a=r.reducer,u=r.prepare}else a=r;i.addCase(e,a).exposeCaseReducer(t,a).exposeAction(t,u?L3(e,u):L3(e))}function hVe(e){return e._reducerDefinitionType==="asyncThunk"}function pVe(e){return e._reducerDefinitionType==="reducerWithPrepare"}function mVe({type:e,reducerName:t},n,r,i){if(!i)throw new Error(jf(18));const{payloadCreator:a,fulfilled:u,pending:l,rejected:o,settled:s,options:c}=n,d=i(e,a,c);r.exposeAction(t,d),u&&r.addCase(d.fulfilled,u),l&&r.addCase(d.pending,l),o&&r.addCase(d.rejected,o),s&&r.addMatcher(d.settled,s),r.exposeCaseReducer(t,{fulfilled:u||DE,pending:l||DE,rejected:o||DE,settled:s||DE})}function DE(){}var gVe="task",Qve="listener",zve="completed",PL="cancelled",vVe=`task-${PL}`,yVe=`task-${zve}`,tF=`${Qve}-${PL}`,bVe=`${Qve}-${zve}`,Xw=class{constructor(e){$_(this,"name","TaskAbortError");$_(this,"message");this.code=e,this.message=`${gVe} ${PL} (reason: ${e})`}},ML=(e,t)=>{if(typeof e!="function")throw new TypeError(jf(32))},Z$=()=>{},qve=(e,t=Z$)=>(e.catch(t),e),Vve=(e,t)=>(e.addEventListener("abort",t,{once:!0}),()=>e.removeEventListener("abort",t)),X1=(e,t)=>{const n=e.signal;n.aborted||("reason"in n||Object.defineProperty(n,"reason",{enumerable:!0,value:t,configurable:!0,writable:!0}),e.abort(t))},Y1=e=>{if(e.aborted){const{reason:t}=e;throw new Xw(t)}};function Uve(e,t){let n=Z$;return new Promise((r,i)=>{const a=()=>i(new Xw(e.reason));if(e.aborted){a();return}n=Vve(e,a),t.finally(()=>n()).then(r,i)}).finally(()=>{n=Z$})}var OVe=async(e,t)=>{try{return await Promise.resolve(),{status:"ok",value:await e()}}catch(n){return{status:n instanceof Xw?"cancelled":"rejected",error:n}}finally{t==null||t()}},H$=e=>t=>qve(Uve(e,t).then(n=>(Y1(e),n))),jve=e=>{const t=H$(e);return n=>t(new Promise(r=>setTimeout(r,n)))},{assign:b3}=Object,bG={},Yw="listenerMiddleware",xVe=(e,t)=>{const n=r=>Vve(e,()=>X1(r,e.reason));return(r,i)=>{ML(r);const a=new AbortController;n(a);const u=OVe(async()=>{Y1(e),Y1(a.signal);const l=await r({pause:H$(a.signal),delay:jve(a.signal),signal:a.signal});return Y1(a.signal),l},()=>X1(a,yVe));return i!=null&&i.autoJoin&&t.push(u.catch(Z$)),{result:H$(e)(u),cancel(){X1(a,vVe)}}}},SVe=(e,t)=>{const n=async(r,i)=>{Y1(t);let a=()=>{};const l=[new Promise((o,s)=>{let c=e({predicate:r,effect:(d,h)=>{h.unsubscribe(),o([d,h.getState(),h.getOriginalState()])}});a=()=>{c(),s()}})];i!=null&&l.push(new Promise(o=>setTimeout(o,i,null)));try{const o=await Uve(t,Promise.race(l));return Y1(t),o}finally{a()}};return(r,i)=>qve(n(r,i))},Zve=e=>{let{type:t,actionCreator:n,matcher:r,predicate:i,effect:a}=e;if(t)i=L3(t).match;else if(n)t=n.type,i=n.match;else if(r)i=r;else if(!i)throw new Error(jf(21));return ML(a),{predicate:i,type:t,effect:a}},Hve=b3(e=>{const{type:t,predicate:n,effect:r}=Zve(e);return{id:uVe(),effect:r,type:t,predicate:n,pending:new Set,unsubscribe:()=>{throw new Error(jf(22))}}},{withTypes:()=>Hve}),OG=(e,t)=>{const{type:n,effect:r,predicate:i}=Zve(t);return Array.from(e.values()).find(a=>(typeof n=="string"?a.type===n:a.predicate===i)&&a.effect===r)},nF=e=>{e.pending.forEach(t=>{X1(t,tF)})},_Ve=e=>()=>{e.forEach(nF),e.clear()},xG=(e,t,n)=>{try{e(t,n)}catch(r){setTimeout(()=>{throw r},0)}},Xve=b3(L3(`${Yw}/add`),{withTypes:()=>Xve}),EVe=L3(`${Yw}/removeAll`),Yve=b3(L3(`${Yw}/remove`),{withTypes:()=>Yve}),DVe=(...e)=>{console.error(`${Yw}/error`,...e)},zut=(e={})=>{const t=new Map,{extra:n,onError:r=DVe}=e;ML(r);const i=c=>(c.unsubscribe=()=>t.delete(c.id),t.set(c.id,c),d=>{c.unsubscribe(),d!=null&&d.cancelActive&&nF(c)}),a=c=>{const d=OG(t,c)??Hve(c);return i(d)};b3(a,{withTypes:()=>a});const u=c=>{const d=OG(t,c);return d&&(d.unsubscribe(),c.cancelActive&&nF(d)),!!d};b3(u,{withTypes:()=>u});const l=async(c,d,h,m)=>{const y=new AbortController,v=SVe(a,y.signal),_=[];try{c.pending.add(y),await Promise.resolve(c.effect(d,b3({},h,{getOriginalState:m,condition:(S,E)=>v(S,E).then(Boolean),take:v,delay:jve(y.signal),pause:H$(y.signal),extra:n,signal:y.signal,fork:xVe(y.signal,_),unsubscribe:c.unsubscribe,subscribe:()=>{t.set(c.id,c)},cancelActiveListeners:()=>{c.pending.forEach((S,E,C)=>{S!==y&&(X1(S,tF),C.delete(S))})},cancel:()=>{X1(y,tF),c.pending.delete(y)},throwIfCancelled:()=>{Y1(y.signal)}})))}catch(S){S instanceof Xw||xG(r,S,{raisedBy:"effect"})}finally{await Promise.all(_),X1(y,bVe),c.pending.delete(y)}},o=_Ve(t);return{middleware:c=>d=>h=>{if(!Rve(h))return d(h);if(Xve.match(h))return a(h.payload);if(EVe.match(h)){o();return}if(Yve.match(h))return u(h.payload);let m=c.getState();const y=()=>{if(m===bG)throw new Error(jf(23));return m};let v;try{if(v=d(h),t.size>0){const _=c.getState(),S=Array.from(t.values());for(const E of S){let C=!1;try{C=E.predicate(h,_,m)}catch(T){C=!1,xG(r,T,{raisedBy:"predicate"})}C&&l(E,h,c,y)}}}finally{m=bG}return v},startListening:a,stopListening:u,clearListeners:o}};function jf(e){return`Minified Redux Toolkit error #${e}; visit https://redux-toolkit.js.org/Errors?code=${e} for the full message or use the non-minified dev environment for full errors. `}var A8={},T8={},k8={},SG;function $Ve(){return SG||(SG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){if(!n||typeof n!="object")return!1;const r=Object.getPrototypeOf(n);return r===null||r===Object.prototype||Object.getPrototypeOf(r)===null?Object.prototype.toString.call(n)==="[object Object]":!1}e.isPlainObject=t})(k8)),k8}var _G;function CVe(){return _G||(_G=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=$Ve(),n=Sve(),r=wL(),i=RL(),a=$L();function u(s,c,d){return l(s,c,void 0,void 0,void 0,void 0,d)}function l(s,c,d,h,m,y,v){const _=v(s,c,d,h,m,y);if(_!==void 0)return _;if(typeof s==typeof c)switch(typeof s){case"bigint":case"string":case"boolean":case"symbol":case"undefined":return s===c;case"number":return s===c||Object.is(s,c);case"function":return s===c;case"object":return o(s,c,y,v)}return o(s,c,y,v)}function o(s,c,d,h){if(Object.is(s,c))return!0;let m=r.getTag(s),y=r.getTag(c);if(m===i.argumentsTag&&(m=i.objectTag),y===i.argumentsTag&&(y=i.objectTag),m!==y)return!1;switch(m){case i.stringTag:return s.toString()===c.toString();case i.numberTag:{const S=s.valueOf(),E=c.valueOf();return a.eq(S,E)}case i.booleanTag:case i.dateTag:case i.symbolTag:return Object.is(s.valueOf(),c.valueOf());case i.regexpTag:return s.source===c.source&&s.flags===c.flags;case i.functionTag:return s===c}d=d??new Map;const v=d.get(s),_=d.get(c);if(v!=null&&_!=null)return v===c;d.set(s,c),d.set(c,s);try{switch(m){case i.mapTag:{if(s.size!==c.size)return!1;for(const[S,E]of s.entries())if(!c.has(S)||!l(E,c.get(S),S,s,c,d,h))return!1;return!0}case i.setTag:{if(s.size!==c.size)return!1;const S=Array.from(s.values()),E=Array.from(c.values());for(let C=0;C<S.length;C++){const T=S[C],R=E.findIndex($=>l(T,$,void 0,s,c,d,h));if(R===-1)return!1;E.splice(R,1)}return!0}case i.arrayTag:case i.uint8ArrayTag:case i.uint8ClampedArrayTag:case i.uint16ArrayTag:case i.uint32ArrayTag:case i.bigUint64ArrayTag:case i.int8ArrayTag:case i.int16ArrayTag:case i.int32ArrayTag:case i.bigInt64ArrayTag:case i.float32ArrayTag:case i.float64ArrayTag:{if(typeof Buffer<"u"&&Buffer.isBuffer(s)!==Buffer.isBuffer(c)||s.length!==c.length)return!1;for(let S=0;S<s.length;S++)if(!l(s[S],c[S],S,s,c,d,h))return!1;return!0}case i.arrayBufferTag:return s.byteLength!==c.byteLength?!1:o(new Uint8Array(s),new Uint8Array(c),d,h);case i.dataViewTag:return s.byteLength!==c.byteLength||s.byteOffset!==c.byteOffset?!1:o(new Uint8Array(s),new Uint8Array(c),d,h);case i.errorTag:return s.name===c.name&&s.message===c.message;case i.objectTag:{if(!(o(s.constructor,c.constructor,d,h)||t.isPlainObject(s)&&t.isPlainObject(c)))return!1;const E=[...Object.keys(s),...n.getSymbols(s)],C=[...Object.keys(c),...n.getSymbols(c)];if(E.length!==C.length)return!1;for(let T=0;T<E.length;T++){const R=E[T],$=s[R];if(!Object.hasOwn(c,R))return!1;const k=c[R];if(!l($,k,R,s,c,d,h))return!1}return!0}default:return!1}}finally{d.delete(s),d.delete(c)}}e.isEqualWith=u})(T8)),T8}var P8={},EG;function wVe(){return EG||(EG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(){}e.noop=t})(P8)),P8}var DG;function RVe(){return DG||(DG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=CVe(),n=wVe();function r(i,a){return t.isEqualWith(i,a,n.noop)}e.isEqual=r})(A8)),A8}var M8,$G;function AVe(){return $G||($G=1,M8=RVe().isEqual),M8}var TVe=AVe();const qut=sa(TVe);var F8={},N8={},I8={},CG;function kVe(){return CG||(CG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=$ve();function n(r){return t.isSymbol(r)?NaN:Number(r)}e.toNumber=n})(I8)),I8}var wG;function PVe(){return wG||(wG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=kVe();function n(r){return r?(r=t.toNumber(r),r===1/0||r===-1/0?(r<0?-1:1)*Number.MAX_VALUE:r===r?r:0):r===0?r:0}e.toFinite=n})(N8)),N8}var RG;function MVe(){return RG||(RG=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Cve(),n=PVe();function r(i,a,u){u&&typeof u!="number"&&t.isIterateeCall(i,a,u)&&(a=u=void 0),i=n.toFinite(i),a===void 0?(a=i,i=0):a=n.toFinite(a),u=u===void 0?i<a?1:-1:n.toFinite(u);const l=Math.max(Math.ceil((a-i)/(u||1)),0),o=new Array(l);for(let s=0;s<l;s++)o[s]=i,i+=u;return o}e.range=r})(F8)),F8}var L8,AG;function FVe(){return AG||(AG=1,L8=MVe().range),L8}var NVe=FVe();const Vut=sa(NVe);function Hv(e,t){return e==null||t==null?NaN:e<t?-1:e>t?1:e>=t?0:NaN}function IVe(e,t){return e==null||t==null?NaN:t<e?-1:t>e?1:t>=e?0:NaN}function FL(e){let t,n,r;e.length!==2?(t=Hv,n=(l,o)=>Hv(e(l),o),r=(l,o)=>e(l)-o):(t=e===Hv||e===IVe?e:LVe,n=e,r=e);function i(l,o,s=0,c=l.length){if(s<c){if(t(o,o)!==0)return c;do{const d=s+c>>>1;n(l[d],o)<0?s=d+1:c=d}while(s<c)}return s}function a(l,o,s=0,c=l.length){if(s<c){if(t(o,o)!==0)return c;do{const d=s+c>>>1;n(l[d],o)<=0?s=d+1:c=d}while(s<c)}return s}function u(l,o,s=0,c=l.length){const d=i(l,o,s,c-1);return d>s&&r(l[d-1],o)>-r(l[d],o)?d-1:d}return{left:i,center:u,right:a}}function LVe(){return 0}function Gve(e){return e===null?NaN:+e}function*BVe(e,t){for(let n of e)n!=null&&(n=+n)>=n&&(yield n)}const QVe=FL(Hv),kS=QVe.right;FL(Gve).center;class TG extends Map{constructor(t,n=VVe){if(super(),Object.defineProperties(this,{_intern:{value:new Map},_key:{value:n}}),t!=null)for(const[r,i]of t)this.set(r,i)}get(t){return super.get(kG(this,t))}has(t){return super.has(kG(this,t))}set(t,n){return super.set(zVe(this,t),n)}delete(t){return super.delete(qVe(this,t))}}function kG({_intern:e,_key:t},n){const r=t(n);return e.has(r)?e.get(r):n}function zVe({_intern:e,_key:t},n){const r=t(n);return e.has(r)?e.get(r):(e.set(r,n),n)}function qVe({_intern:e,_key:t},n){const r=t(n);return e.has(r)&&(n=e.get(r),e.delete(r)),n}function VVe(e){return e!==null&&typeof e=="object"?e.valueOf():e}function UVe(e=Hv){if(e===Hv)return Kve;if(typeof e!="function")throw new TypeError("compare is not a function");return(t,n)=>{const r=e(t,n);return r||r===0?r:(e(n,n)===0)-(e(t,t)===0)}}function Kve(e,t){return(e==null||!(e>=e))-(t==null||!(t>=t))||(e<t?-1:e>t?1:0)}const jVe=Math.sqrt(50),ZVe=Math.sqrt(10),HVe=Math.sqrt(2);function X$(e,t,n){const r=(t-e)/Math.max(0,n),i=Math.floor(Math.log10(r)),a=r/Math.pow(10,i),u=a>=jVe?10:a>=ZVe?5:a>=HVe?2:1;let l,o,s;return i<0?(s=Math.pow(10,-i)/u,l=Math.round(e*s),o=Math.round(t*s),l/s<e&&++l,o/s>t&&--o,s=-s):(s=Math.pow(10,i)*u,l=Math.round(e/s),o=Math.round(t/s),l*s<e&&++l,o*s>t&&--o),o<l&&.5<=n&&n<2?X$(e,t,n*2):[l,o,s]}function rF(e,t,n){if(t=+t,e=+e,n=+n,!(n>0))return[];if(e===t)return[e];const r=t<e,[i,a,u]=r?X$(t,e,n):X$(e,t,n);if(!(a>=i))return[];const l=a-i+1,o=new Array(l);if(r)if(u<0)for(let s=0;s<l;++s)o[s]=(a-s)/-u;else for(let s=0;s<l;++s)o[s]=(a-s)*u;else if(u<0)for(let s=0;s<l;++s)o[s]=(i+s)/-u;else for(let s=0;s<l;++s)o[s]=(i+s)*u;return o}function iF(e,t,n){return t=+t,e=+e,n=+n,X$(e,t,n)[2]}function aF(e,t,n){t=+t,e=+e,n=+n;const r=t<e,i=r?iF(t,e,n):iF(e,t,n);return(r?-1:1)*(i<0?1/-i:i)}function PG(e,t){let n;for(const r of e)r!=null&&(n<r||n===void 0&&r>=r)&&(n=r);return n}function MG(e,t){let n;for(const r of e)r!=null&&(n>r||n===void 0&&r>=r)&&(n=r);return n}function Wve(e,t,n=0,r=1/0,i){if(t=Math.floor(t),n=Math.floor(Math.max(0,n)),r=Math.floor(Math.min(e.length-1,r)),!(n<=t&&t<=r))return e;for(i=i===void 0?Kve:UVe(i);r>n;){if(r-n>600){const o=r-n+1,s=t-n+1,c=Math.log(o),d=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*d*(o-d)/o)*(s-o/2<0?-1:1),m=Math.max(n,Math.floor(t-s*d/o+h)),y=Math.min(r,Math.floor(t+(o-s)*d/o+h));Wve(e,t,m,y,i)}const a=e[t];let u=n,l=r;for(b2(e,n,t),i(e[r],a)>0&&b2(e,n,r);u<l;){for(b2(e,u,l),++u,--l;i(e[u],a)<0;)++u;for(;i(e[l],a)>0;)--l}i(e[n],a)===0?b2(e,n,l):(++l,b2(e,l,r)),l<=t&&(n=l+1),t<=l&&(r=l-1)}return e}function b2(e,t,n){const r=e[t];e[t]=e[n],e[n]=r}function XVe(e,t,n){if(e=Float64Array.from(BVe(e)),!(!(r=e.length)||isNaN(t=+t))){if(t<=0||r<2)return MG(e);if(t>=1)return PG(e);var r,i=(r-1)*t,a=Math.floor(i),u=PG(Wve(e,a).subarray(0,a+1)),l=MG(e.subarray(a+1));return u+(l-u)*(i-a)}}function YVe(e,t,n=Gve){if(!(!(r=e.length)||isNaN(t=+t))){if(t<=0||r<2)return+n(e[0],0,e);if(t>=1)return+n(e[r-1],r-1,e);var r,i=(r-1)*t,a=Math.floor(i),u=+n(e[a],a,e),l=+n(e[a+1],a+1,e);return u+(l-u)*(i-a)}}function GVe(e,t,n){e=+e,t=+t,n=(i=arguments.length)<2?(t=e,e=0,1):i<3?1:+n;for(var r=-1,i=Math.max(0,Math.ceil((t-e)/n))|0,a=new Array(i);++r<i;)a[r]=e+r*n;return a}function lh(e,t){switch(arguments.length){case 0:break;case 1:this.range(e);break;default:this.range(t).domain(e);break}return this}function xg(e,t){switch(arguments.length){case 0:break;case 1:{typeof e=="function"?this.interpolator(e):this.range(e);break}default:{this.domain(e),typeof t=="function"?this.interpolator(t):this.range(t);break}}return this}const uF=Symbol("implicit");function NL(){var e=new TG,t=[],n=[],r=uF;function i(a){let u=e.get(a);if(u===void 0){if(r!==uF)return r;e.set(a,u=t.push(a)-1)}return n[u%n.length]}return i.domain=function(a){if(!arguments.length)return t.slice();t=[],e=new TG;for(const u of a)e.has(u)||e.set(u,t.push(u)-1);return i},i.range=function(a){return arguments.length?(n=Array.from(a),i):n.slice()},i.unknown=function(a){return arguments.length?(r=a,i):r},i.copy=function(){return NL(t,n).unknown(r)},lh.apply(i,arguments),i}function IL(){var e=NL().unknown(void 0),t=e.domain,n=e.range,r=0,i=1,a,u,l=!1,o=0,s=0,c=.5;delete e.unknown;function d(){var h=t().length,m=i<r,y=m?i:r,v=m?r:i;a=(v-y)/Math.max(1,h-o+s*2),l&&(a=Math.floor(a)),y+=(v-y-a*(h-o))*c,u=a*(1-o),l&&(y=Math.round(y),u=Math.round(u));var _=GVe(h).map(function(S){return y+a*S});return n(m?_.reverse():_)}return e.domain=function(h){return arguments.length?(t(h),d()):t()},e.range=function(h){return arguments.length?([r,i]=h,r=+r,i=+i,d()):[r,i]},e.rangeRound=function(h){return[r,i]=h,r=+r,i=+i,l=!0,d()},e.bandwidth=function(){return u},e.step=function(){return a},e.round=function(h){return arguments.length?(l=!!h,d()):l},e.padding=function(h){return arguments.length?(o=Math.min(1,s=+h),d()):o},e.paddingInner=function(h){return arguments.length?(o=Math.min(1,h),d()):o},e.paddingOuter=function(h){return arguments.length?(s=+h,d()):s},e.align=function(h){return arguments.length?(c=Math.max(0,Math.min(1,h)),d()):c},e.copy=function(){return IL(t(),[r,i]).round(l).paddingInner(o).paddingOuter(s).align(c)},lh.apply(d(),arguments)}function Jve(e){var t=e.copy;return e.padding=e.paddingOuter,delete e.paddingInner,delete e.paddingOuter,e.copy=function(){return Jve(t())},e}function KVe(){return Jve(IL.apply(null,arguments).paddingInner(1))}function WVe(e){return function(){return e}}function Y$(e){return+e}var FG=[0,1];function cc(e){return e}function lF(e,t){return(t-=e=+e)?function(n){return(n-e)/t}:WVe(isNaN(t)?NaN:.5)}function JVe(e,t){var n;return e>t&&(n=e,e=t,t=n),function(r){return Math.max(e,Math.min(t,r))}}function eUe(e,t,n){var r=e[0],i=e[1],a=t[0],u=t[1];return i<r?(r=lF(i,r),a=n(u,a)):(r=lF(r,i),a=n(a,u)),function(l){return a(r(l))}}function tUe(e,t,n){var r=Math.min(e.length,t.length)-1,i=new Array(r),a=new Array(r),u=-1;for(e[r]<e[0]&&(e=e.slice().reverse(),t=t.slice().reverse());++u<r;)i[u]=lF(e[u],e[u+1]),a[u]=n(t[u],t[u+1]);return function(l){var o=kS(e,l,1,r)-1;return a[o](i[o](l))}}function PS(e,t){return t.domain(e.domain()).range(e.range()).interpolate(e.interpolate()).clamp(e.clamp()).unknown(e.unknown())}function Gw(){var e=FG,t=FG,n=t4,r,i,a,u=cc,l,o,s;function c(){var h=Math.min(e.length,t.length);return u!==cc&&(u=JVe(e[0],e[h-1])),l=h>2?tUe:eUe,o=s=null,d}function d(h){return h==null||isNaN(h=+h)?a:(o||(o=l(e.map(r),t,n)))(r(u(h)))}return d.invert=function(h){return u(i((s||(s=l(t,e.map(r),m$)))(h)))},d.domain=function(h){return arguments.length?(e=Array.from(h,Y$),c()):e.slice()},d.range=function(h){return arguments.length?(t=Array.from(h),c()):t.slice()},d.rangeRound=function(h){return t=Array.from(h),n=MI,c()},d.clamp=function(h){return arguments.length?(u=h?!0:cc,c()):u!==cc},d.interpolate=function(h){return arguments.length?(n=h,c()):n},d.unknown=function(h){return arguments.length?(a=h,d):a},function(h,m){return r=h,i=m,c()}}function LL(){return Gw()(cc,cc)}function eye(e,t,n,r){var i=aF(e,t,n),a;switch(r=Rx(r??",f"),r.type){case"s":{var u=Math.max(Math.abs(e),Math.abs(t));return r.precision==null&&!isNaN(a=C8e(i,u))&&(r.precision=a),n0e(r,u)}case"":case"e":case"g":case"p":case"r":{r.precision==null&&!isNaN(a=w8e(i,Math.max(Math.abs(e),Math.abs(t))))&&(r.precision=a-(r.type==="e"));break}case"f":case"%":{r.precision==null&&!isNaN(a=$8e(i))&&(r.precision=a-(r.type==="%")*2);break}}return NI(r)}function Sy(e){var t=e.domain;return e.ticks=function(n){var r=t();return rF(r[0],r[r.length-1],n??10)},e.tickFormat=function(n,r){var i=t();return eye(i[0],i[i.length-1],n??10,r)},e.nice=function(n){n==null&&(n=10);var r=t(),i=0,a=r.length-1,u=r[i],l=r[a],o,s,c=10;for(l<u&&(s=u,u=l,l=s,s=i,i=a,a=s);c-- >0;){if(s=iF(u,l,n),s===o)return r[i]=u,r[a]=l,t(r);if(s>0)u=Math.floor(u/s)*s,l=Math.ceil(l/s)*s;else if(s<0)u=Math.ceil(u*s)/s,l=Math.floor(l*s)/s;else break;o=s}return e},e}function tye(){var e=LL();return e.copy=function(){return PS(e,tye())},lh.apply(e,arguments),Sy(e)}function nye(e){var t;function n(r){return r==null||isNaN(r=+r)?t:r}return n.invert=n,n.domain=n.range=function(r){return arguments.length?(e=Array.from(r,Y$),n):e.slice()},n.unknown=function(r){return arguments.length?(t=r,n):t},n.copy=function(){return nye(e).unknown(t)},e=arguments.length?Array.from(e,Y$):[0,1],Sy(n)}function rye(e,t){e=e.slice();var n=0,r=e.length-1,i=e[n],a=e[r],u;return a<i&&(u=n,n=r,r=u,u=i,i=a,a=u),e[n]=t.floor(i),e[r]=t.ceil(a),e}function NG(e){return Math.log(e)}function IG(e){return Math.exp(e)}function nUe(e){return-Math.log(-e)}function rUe(e){return-Math.exp(-e)}function iUe(e){return isFinite(e)?+("1e"+e):e<0?0:e}function aUe(e){return e===10?iUe:e===Math.E?Math.exp:t=>Math.pow(e,t)}function uUe(e){return e===Math.E?Math.log:e===10&&Math.log10||e===2&&Math.log2||(e=Math.log(e),t=>Math.log(t)/e)}function LG(e){return(t,n)=>-e(-t,n)}function BL(e){const t=e(NG,IG),n=t.domain;let r=10,i,a;function u(){return i=uUe(r),a=aUe(r),n()[0]<0?(i=LG(i),a=LG(a),e(nUe,rUe)):e(NG,IG),t}return t.base=function(l){return arguments.length?(r=+l,u()):r},t.domain=function(l){return arguments.length?(n(l),u()):n()},t.ticks=l=>{const o=n();let s=o[0],c=o[o.length-1];const d=c<s;d&&([s,c]=[c,s]);let h=i(s),m=i(c),y,v;const _=l==null?10:+l;let S=[];if(!(r%1)&&m-h<_){if(h=Math.floor(h),m=Math.ceil(m),s>0){for(;h<=m;++h)for(y=1;y<r;++y)if(v=h<0?y/a(-h):y*a(h),!(v<s)){if(v>c)break;S.push(v)}}else for(;h<=m;++h)for(y=r-1;y>=1;--y)if(v=h>0?y/a(-h):y*a(h),!(v<s)){if(v>c)break;S.push(v)}S.length*2<_&&(S=rF(s,c,_))}else S=rF(h,m,Math.min(m-h,_)).map(a);return d?S.reverse():S},t.tickFormat=(l,o)=>{if(l==null&&(l=10),o==null&&(o=r===10?"s":","),typeof o!="function"&&(!(r%1)&&(o=Rx(o)).precision==null&&(o.trim=!0),o=NI(o)),l===1/0)return o;const s=Math.max(1,r*l/t.ticks().length);return c=>{let d=c/a(Math.round(i(c)));return d*r<r-.5&&(d*=r),d<=s?o(c):""}},t.nice=()=>n(rye(n(),{floor:l=>a(Math.floor(i(l))),ceil:l=>a(Math.ceil(i(l)))})),t}function iye(){const e=BL(Gw()).domain([1,10]);return e.copy=()=>PS(e,iye()).base(e.base()),lh.apply(e,arguments),e}function BG(e){return function(t){return Math.sign(t)*Math.log1p(Math.abs(t/e))}}function QG(e){return function(t){return Math.sign(t)*Math.expm1(Math.abs(t))*e}}function QL(e){var t=1,n=e(BG(t),QG(t));return n.constant=function(r){return arguments.length?e(BG(t=+r),QG(t)):t},Sy(n)}function aye(){var e=QL(Gw());return e.copy=function(){return PS(e,aye()).constant(e.constant())},lh.apply(e,arguments)}function zG(e){return function(t){return t<0?-Math.pow(-t,e):Math.pow(t,e)}}function lUe(e){return e<0?-Math.sqrt(-e):Math.sqrt(e)}function oUe(e){return e<0?-e*e:e*e}function zL(e){var t=e(cc,cc),n=1;function r(){return n===1?e(cc,cc):n===.5?e(lUe,oUe):e(zG(n),zG(1/n))}return t.exponent=function(i){return arguments.length?(n=+i,r()):n},Sy(t)}function qL(){var e=zL(Gw());return e.copy=function(){return PS(e,qL()).exponent(e.exponent())},lh.apply(e,arguments),e}function sUe(){return qL.apply(null,arguments).exponent(.5)}function qG(e){return Math.sign(e)*e*e}function cUe(e){return Math.sign(e)*Math.sqrt(Math.abs(e))}function uye(){var e=LL(),t=[0,1],n=!1,r;function i(a){var u=cUe(e(a));return isNaN(u)?r:n?Math.round(u):u}return i.invert=function(a){return e.invert(qG(a))},i.domain=function(a){return arguments.length?(e.domain(a),i):e.domain()},i.range=function(a){return arguments.length?(e.range((t=Array.from(a,Y$)).map(qG)),i):t.slice()},i.rangeRound=function(a){return i.range(a).round(!0)},i.round=function(a){return arguments.length?(n=!!a,i):n},i.clamp=function(a){return arguments.length?(e.clamp(a),i):e.clamp()},i.unknown=function(a){return arguments.length?(r=a,i):r},i.copy=function(){return uye(e.domain(),t).round(n).clamp(e.clamp()).unknown(r)},lh.apply(i,arguments),Sy(i)}function lye(){var e=[],t=[],n=[],r;function i(){var u=0,l=Math.max(1,t.length);for(n=new Array(l-1);++u<l;)n[u-1]=YVe(e,u/l);return a}function a(u){return u==null||isNaN(u=+u)?r:t[kS(n,u)]}return a.invertExtent=function(u){var l=t.indexOf(u);return l<0?[NaN,NaN]:[l>0?n[l-1]:e[0],l<n.length?n[l]:e[e.length-1]]},a.domain=function(u){if(!arguments.length)return e.slice();e=[];for(let l of u)l!=null&&!isNaN(l=+l)&&e.push(l);return e.sort(Hv),i()},a.range=function(u){return arguments.length?(t=Array.from(u),i()):t.slice()},a.unknown=function(u){return arguments.length?(r=u,a):r},a.quantiles=function(){return n.slice()},a.copy=function(){return lye().domain(e).range(t).unknown(r)},lh.apply(a,arguments)}function oye(){var e=0,t=1,n=1,r=[.5],i=[0,1],a;function u(o){return o!=null&&o<=o?i[kS(r,o,0,n)]:a}function l(){var o=-1;for(r=new Array(n);++o<n;)r[o]=((o+1)*t-(o-n)*e)/(n+1);return u}return u.domain=function(o){return arguments.length?([e,t]=o,e=+e,t=+t,l()):[e,t]},u.range=function(o){return arguments.length?(n=(i=Array.from(o)).length-1,l()):i.slice()},u.invertExtent=function(o){var s=i.indexOf(o);return s<0?[NaN,NaN]:s<1?[e,r[0]]:s>=n?[r[n-1],t]:[r[s-1],r[s]]},u.unknown=function(o){return arguments.length&&(a=o),u},u.thresholds=function(){return r.slice()},u.copy=function(){return oye().domain([e,t]).range(i).unknown(a)},lh.apply(Sy(u),arguments)}function sye(){var e=[.5],t=[0,1],n,r=1;function i(a){return a!=null&&a<=a?t[kS(e,a,0,r)]:n}return i.domain=function(a){return arguments.length?(e=Array.from(a),r=Math.min(e.length,t.length-1),i):e.slice()},i.range=function(a){return arguments.length?(t=Array.from(a),r=Math.min(e.length,t.length-1),i):t.slice()},i.invertExtent=function(a){var u=t.indexOf(a);return[e[u-1],e[u]]},i.unknown=function(a){return arguments.length?(n=a,i):n},i.copy=function(){return sye().domain(e).range(t).unknown(n)},lh.apply(i,arguments)}const B8=new Date,Q8=new Date;function Rl(e,t,n,r){function i(a){return e(a=arguments.length===0?new Date:new Date(+a)),a}return i.floor=a=>(e(a=new Date(+a)),a),i.ceil=a=>(e(a=new Date(a-1)),t(a,1),e(a),a),i.round=a=>{const u=i(a),l=i.ceil(a);return a-u<l-a?u:l},i.offset=(a,u)=>(t(a=new Date(+a),u==null?1:Math.floor(u)),a),i.range=(a,u,l)=>{const o=[];if(a=i.ceil(a),l=l==null?1:Math.floor(l),!(a<u)||!(l>0))return o;let s;do o.push(s=new Date(+a)),t(a,l),e(a);while(s<a&&a<u);return o},i.filter=a=>Rl(u=>{if(u>=u)for(;e(u),!a(u);)u.setTime(u-1)},(u,l)=>{if(u>=u)if(l<0)for(;++l<=0;)for(;t(u,-1),!a(u););else for(;--l>=0;)for(;t(u,1),!a(u););}),n&&(i.count=(a,u)=>(B8.setTime(+a),Q8.setTime(+u),e(B8),e(Q8),Math.floor(n(B8,Q8))),i.every=a=>(a=Math.floor(a),!isFinite(a)||!(a>0)?null:a>1?i.filter(r?u=>r(u)%a===0:u=>i.count(0,u)%a===0):i)),i}const G$=Rl(()=>{},(e,t)=>{e.setTime(+e+t)},(e,t)=>t-e);G$.every=e=>(e=Math.floor(e),!isFinite(e)||!(e>0)?null:e>1?Rl(t=>{t.setTime(Math.floor(t/e)*e)},(t,n)=>{t.setTime(+t+n*e)},(t,n)=>(n-t)/e):G$);G$.range;const eg=1e3,Yd=eg*60,tg=Yd*60,hg=tg*24,VL=hg*7,VG=hg*30,z8=hg*365,U1=Rl(e=>{e.setTime(e-e.getMilliseconds())},(e,t)=>{e.setTime(+e+t*eg)},(e,t)=>(t-e)/eg,e=>e.getUTCSeconds());U1.range;const UL=Rl(e=>{e.setTime(e-e.getMilliseconds()-e.getSeconds()*eg)},(e,t)=>{e.setTime(+e+t*Yd)},(e,t)=>(t-e)/Yd,e=>e.getMinutes());UL.range;const jL=Rl(e=>{e.setUTCSeconds(0,0)},(e,t)=>{e.setTime(+e+t*Yd)},(e,t)=>(t-e)/Yd,e=>e.getUTCMinutes());jL.range;const ZL=Rl(e=>{e.setTime(e-e.getMilliseconds()-e.getSeconds()*eg-e.getMinutes()*Yd)},(e,t)=>{e.setTime(+e+t*tg)},(e,t)=>(t-e)/tg,e=>e.getHours());ZL.range;const HL=Rl(e=>{e.setUTCMinutes(0,0,0)},(e,t)=>{e.setTime(+e+t*tg)},(e,t)=>(t-e)/tg,e=>e.getUTCHours());HL.range;const MS=Rl(e=>e.setHours(0,0,0,0),(e,t)=>e.setDate(e.getDate()+t),(e,t)=>(t-e-(t.getTimezoneOffset()-e.getTimezoneOffset())*Yd)/hg,e=>e.getDate()-1);MS.range;const Kw=Rl(e=>{e.setUTCHours(0,0,0,0)},(e,t)=>{e.setUTCDate(e.getUTCDate()+t)},(e,t)=>(t-e)/hg,e=>e.getUTCDate()-1);Kw.range;const cye=Rl(e=>{e.setUTCHours(0,0,0,0)},(e,t)=>{e.setUTCDate(e.getUTCDate()+t)},(e,t)=>(t-e)/hg,e=>Math.floor(e/hg));cye.range;function Mb(e){return Rl(t=>{t.setDate(t.getDate()-(t.getDay()+7-e)%7),t.setHours(0,0,0,0)},(t,n)=>{t.setDate(t.getDate()+n*7)},(t,n)=>(n-t-(n.getTimezoneOffset()-t.getTimezoneOffset())*Yd)/VL)}const Ww=Mb(0),K$=Mb(1),fUe=Mb(2),dUe=Mb(3),B3=Mb(4),hUe=Mb(5),pUe=Mb(6);Ww.range;K$.range;fUe.range;dUe.range;B3.range;hUe.range;pUe.range;function Fb(e){return Rl(t=>{t.setUTCDate(t.getUTCDate()-(t.getUTCDay()+7-e)%7),t.setUTCHours(0,0,0,0)},(t,n)=>{t.setUTCDate(t.getUTCDate()+n*7)},(t,n)=>(n-t)/VL)}const Jw=Fb(0),W$=Fb(1),mUe=Fb(2),gUe=Fb(3),Q3=Fb(4),vUe=Fb(5),yUe=Fb(6);Jw.range;W$.range;mUe.range;gUe.range;Q3.range;vUe.range;yUe.range;const XL=Rl(e=>{e.setDate(1),e.setHours(0,0,0,0)},(e,t)=>{e.setMonth(e.getMonth()+t)},(e,t)=>t.getMonth()-e.getMonth()+(t.getFullYear()-e.getFullYear())*12,e=>e.getMonth());XL.range;const YL=Rl(e=>{e.setUTCDate(1),e.setUTCHours(0,0,0,0)},(e,t)=>{e.setUTCMonth(e.getUTCMonth()+t)},(e,t)=>t.getUTCMonth()-e.getUTCMonth()+(t.getUTCFullYear()-e.getUTCFullYear())*12,e=>e.getUTCMonth());YL.range;const pg=Rl(e=>{e.setMonth(0,1),e.setHours(0,0,0,0)},(e,t)=>{e.setFullYear(e.getFullYear()+t)},(e,t)=>t.getFullYear()-e.getFullYear(),e=>e.getFullYear());pg.every=e=>!isFinite(e=Math.floor(e))||!(e>0)?null:Rl(t=>{t.setFullYear(Math.floor(t.getFullYear()/e)*e),t.setMonth(0,1),t.setHours(0,0,0,0)},(t,n)=>{t.setFullYear(t.getFullYear()+n*e)});pg.range;const mg=Rl(e=>{e.setUTCMonth(0,1),e.setUTCHours(0,0,0,0)},(e,t)=>{e.setUTCFullYear(e.getUTCFullYear()+t)},(e,t)=>t.getUTCFullYear()-e.getUTCFullYear(),e=>e.getUTCFullYear());mg.every=e=>!isFinite(e=Math.floor(e))||!(e>0)?null:Rl(t=>{t.setUTCFullYear(Math.floor(t.getUTCFullYear()/e)*e),t.setUTCMonth(0,1),t.setUTCHours(0,0,0,0)},(t,n)=>{t.setUTCFullYear(t.getUTCFullYear()+n*e)});mg.range;function fye(e,t,n,r,i,a){const u=[[U1,1,eg],[U1,5,5*eg],[U1,15,15*eg],[U1,30,30*eg],[a,1,Yd],[a,5,5*Yd],[a,15,15*Yd],[a,30,30*Yd],[i,1,tg],[i,3,3*tg],[i,6,6*tg],[i,12,12*tg],[r,1,hg],[r,2,2*hg],[n,1,VL],[t,1,VG],[t,3,3*VG],[e,1,z8]];function l(s,c,d){const h=c<s;h&&([s,c]=[c,s]);const m=d&&typeof d.range=="function"?d:o(s,c,d),y=m?m.range(s,+c+1):[];return h?y.reverse():y}function o(s,c,d){const h=Math.abs(c-s)/d,m=FL(([,,_])=>_).right(u,h);if(m===u.length)return e.every(aF(s/z8,c/z8,d));if(m===0)return G$.every(Math.max(aF(s,c,d),1));const[y,v]=u[h/u[m-1][2]<u[m][2]/h?m-1:m];return y.every(v)}return[l,o]}const[bUe,OUe]=fye(mg,YL,Jw,cye,HL,jL),[xUe,SUe]=fye(pg,XL,Ww,MS,ZL,UL);function q8(e){if(0<=e.y&&e.y<100){var t=new Date(-1,e.m,e.d,e.H,e.M,e.S,e.L);return t.setFullYear(e.y),t}return new Date(e.y,e.m,e.d,e.H,e.M,e.S,e.L)}function V8(e){if(0<=e.y&&e.y<100){var t=new Date(Date.UTC(-1,e.m,e.d,e.H,e.M,e.S,e.L));return t.setUTCFullYear(e.y),t}return new Date(Date.UTC(e.y,e.m,e.d,e.H,e.M,e.S,e.L))}function O2(e,t,n){return{y:e,m:t,d:n,H:0,M:0,S:0,L:0}}function _Ue(e){var t=e.dateTime,n=e.date,r=e.time,i=e.periods,a=e.days,u=e.shortDays,l=e.months,o=e.shortMonths,s=x2(i),c=S2(i),d=x2(a),h=S2(a),m=x2(u),y=S2(u),v=x2(l),_=S2(l),S=x2(o),E=S2(o),C={a:J,A:te,b:H,B:M,c:null,d:YG,e:YG,f:ZUe,g:nje,G:ije,H:VUe,I:UUe,j:jUe,L:dye,m:HUe,M:XUe,p:K,q:X,Q:WG,s:JG,S:YUe,u:GUe,U:KUe,V:WUe,w:JUe,W:eje,x:null,X:null,y:tje,Y:rje,Z:aje,"%":KG},T={a:B,A:ne,b:oe,B:ie,c:null,d:GG,e:GG,f:sje,g:bje,G:xje,H:uje,I:lje,j:oje,L:pye,m:cje,M:fje,p:de,q:be,Q:WG,s:JG,S:dje,u:hje,U:pje,V:mje,w:gje,W:vje,x:null,X:null,y:yje,Y:Oje,Z:Sje,"%":KG},R={a:j,A:V,b:q,B:N,c:U,d:HG,e:HG,f:BUe,g:ZG,G:jG,H:XG,I:XG,j:FUe,L:LUe,m:MUe,M:NUe,p:L,q:PUe,Q:zUe,s:qUe,S:IUe,u:wUe,U:RUe,V:AUe,w:CUe,W:TUe,x:W,X:G,y:ZG,Y:jG,Z:kUe,"%":QUe};C.x=$(n,C),C.X=$(r,C),C.c=$(t,C),T.x=$(n,T),T.X=$(r,T),T.c=$(t,T);function $(ve,pe){return function(_e){var se=[],me=-1,ge=0,we=ve.length,Ne,Re,et;for(_e instanceof Date||(_e=new Date(+_e));++me<we;)ve.charCodeAt(me)===37&&(se.push(ve.slice(ge,me)),(Re=UG[Ne=ve.charAt(++me)])!=null?Ne=ve.charAt(++me):Re=Ne==="e"?" ":"0",(et=pe[Ne])&&(Ne=et(_e,Re)),se.push(Ne),ge=me+1);return se.push(ve.slice(ge,me)),se.join("")}}function k(ve,pe){return function(_e){var se=O2(1900,void 0,1),me=F(se,ve,_e+="",0),ge,we;if(me!=_e.length)return null;if("Q"in se)return new Date(se.Q);if("s"in se)return new Date(se.s*1e3+("L"in se?se.L:0));if(pe&&!("Z"in se)&&(se.Z=0),"p"in se&&(se.H=se.H%12+se.p*12),se.m===void 0&&(se.m="q"in se?se.q:0),"V"in se){if(se.V<1||se.V>53)return null;"w"in se||(se.w=1),"Z"in se?(ge=V8(O2(se.y,0,1)),we=ge.getUTCDay(),ge=we>4||we===0?W$.ceil(ge):W$(ge),ge=Kw.offset(ge,(se.V-1)*7),se.y=ge.getUTCFullYear(),se.m=ge.getUTCMonth(),se.d=ge.getUTCDate()+(se.w+6)%7):(ge=q8(O2(se.y,0,1)),we=ge.getDay(),ge=we>4||we===0?K$.ceil(ge):K$(ge),ge=MS.offset(ge,(se.V-1)*7),se.y=ge.getFullYear(),se.m=ge.getMonth(),se.d=ge.getDate()+(se.w+6)%7)}else("W"in se||"U"in se)&&("w"in se||(se.w="u"in se?se.u%7:"W"in se?1:0),we="Z"in se?V8(O2(se.y,0,1)).getUTCDay():q8(O2(se.y,0,1)).getDay(),se.m=0,se.d="W"in se?(se.w+6)%7+se.W*7-(we+5)%7:se.w+se.U*7-(we+6)%7);return"Z"in se?(se.H+=se.Z/100|0,se.M+=se.Z%100,V8(se)):q8(se)}}function F(ve,pe,_e,se){for(var me=0,ge=pe.length,we=_e.length,Ne,Re;me<ge;){if(se>=we)return-1;if(Ne=pe.charCodeAt(me++),Ne===37){if(Ne=pe.charAt(me++),Re=R[Ne in UG?pe.charAt(me++):Ne],!Re||(se=Re(ve,_e,se))<0)return-1}else if(Ne!=_e.charCodeAt(se++))return-1}return se}function L(ve,pe,_e){var se=s.exec(pe.slice(_e));return se?(ve.p=c.get(se[0].toLowerCase()),_e+se[0].length):-1}function j(ve,pe,_e){var se=m.exec(pe.slice(_e));return se?(ve.w=y.get(se[0].toLowerCase()),_e+se[0].length):-1}function V(ve,pe,_e){var se=d.exec(pe.slice(_e));return se?(ve.w=h.get(se[0].toLowerCase()),_e+se[0].length):-1}function q(ve,pe,_e){var se=S.exec(pe.slice(_e));return se?(ve.m=E.get(se[0].toLowerCase()),_e+se[0].length):-1}function N(ve,pe,_e){var se=v.exec(pe.slice(_e));return se?(ve.m=_.get(se[0].toLowerCase()),_e+se[0].length):-1}function U(ve,pe,_e){return F(ve,t,pe,_e)}function W(ve,pe,_e){return F(ve,n,pe,_e)}function G(ve,pe,_e){return F(ve,r,pe,_e)}function J(ve){return u[ve.getDay()]}function te(ve){return a[ve.getDay()]}function H(ve){return o[ve.getMonth()]}function M(ve){return l[ve.getMonth()]}function K(ve){return i[+(ve.getHours()>=12)]}function X(ve){return 1+~~(ve.getMonth()/3)}function B(ve){return u[ve.getUTCDay()]}function ne(ve){return a[ve.getUTCDay()]}function oe(ve){return o[ve.getUTCMonth()]}function ie(ve){return l[ve.getUTCMonth()]}function de(ve){return i[+(ve.getUTCHours()>=12)]}function be(ve){return 1+~~(ve.getUTCMonth()/3)}return{format:function(ve){var pe=$(ve+="",C);return pe.toString=function(){return ve},pe},parse:function(ve){var pe=k(ve+="",!1);return pe.toString=function(){return ve},pe},utcFormat:function(ve){var pe=$(ve+="",T);return pe.toString=function(){return ve},pe},utcParse:function(ve){var pe=k(ve+="",!0);return pe.toString=function(){return ve},pe}}}var UG={"-":"",_:" ",0:"0"},ao=/^\s*\d+/,EUe=/^%/,DUe=/[\\^$*+?|[\]().{}]/g;function Si(e,t,n){var r=e<0?"-":"",i=(r?-e:e)+"",a=i.length;return r+(a<n?new Array(n-a+1).join(t)+i:i)}function $Ue(e){return e.replace(DUe,"\\$&")}function x2(e){return new RegExp("^(?:"+e.map($Ue).join("|")+")","i")}function S2(e){return new Map(e.map((t,n)=>[t.toLowerCase(),n]))}function CUe(e,t,n){var r=ao.exec(t.slice(n,n+1));return r?(e.w=+r[0],n+r[0].length):-1}function wUe(e,t,n){var r=ao.exec(t.slice(n,n+1));return r?(e.u=+r[0],n+r[0].length):-1}function RUe(e,t,n){var r=ao.exec(t.slice(n,n+2));return r?(e.U=+r[0],n+r[0].length):-1}function AUe(e,t,n){var r=ao.exec(t.slice(n,n+2));return r?(e.V=+r[0],n+r[0].length):-1}function TUe(e,t,n){var r=ao.exec(t.slice(n,n+2));return r?(e.W=+r[0],n+r[0].length):-1}function jG(e,t,n){var r=ao.exec(t.slice(n,n+4));return r?(e.y=+r[0],n+r[0].length):-1}function ZG(e,t,n){var r=ao.exec(t.slice(n,n+2));return r?(e.y=+r[0]+(+r[0]>68?1900:2e3),n+r[0].length):-1}function kUe(e,t,n){var r=/^(Z)|([+-]\d\d)(?::?(\d\d))?/.exec(t.slice(n,n+6));return r?(e.Z=r[1]?0:-(r[2]+(r[3]||"00")),n+r[0].length):-1}function PUe(e,t,n){var r=ao.exec(t.slice(n,n+1));return r?(e.q=r[0]*3-3,n+r[0].length):-1}function MUe(e,t,n){var r=ao.exec(t.slice(n,n+2));return r?(e.m=r[0]-1,n+r[0].length):-1}function HG(e,t,n){var r=ao.exec(t.slice(n,n+2));return r?(e.d=+r[0],n+r[0].length):-1}function FUe(e,t,n){var r=ao.exec(t.slice(n,n+3));return r?(e.m=0,e.d=+r[0],n+r[0].length):-1}function XG(e,t,n){var r=ao.exec(t.slice(n,n+2));return r?(e.H=+r[0],n+r[0].length):-1}function NUe(e,t,n){var r=ao.exec(t.slice(n,n+2));return r?(e.M=+r[0],n+r[0].length):-1}function IUe(e,t,n){var r=ao.exec(t.slice(n,n+2));return r?(e.S=+r[0],n+r[0].length):-1}function LUe(e,t,n){var r=ao.exec(t.slice(n,n+3));return r?(e.L=+r[0],n+r[0].length):-1}function BUe(e,t,n){var r=ao.exec(t.slice(n,n+6));return r?(e.L=Math.floor(r[0]/1e3),n+r[0].length):-1}function QUe(e,t,n){var r=EUe.exec(t.slice(n,n+1));return r?n+r[0].length:-1}function zUe(e,t,n){var r=ao.exec(t.slice(n));return r?(e.Q=+r[0],n+r[0].length):-1}function qUe(e,t,n){var r=ao.exec(t.slice(n));return r?(e.s=+r[0],n+r[0].length):-1}function YG(e,t){return Si(e.getDate(),t,2)}function VUe(e,t){return Si(e.getHours(),t,2)}function UUe(e,t){return Si(e.getHours()%12||12,t,2)}function jUe(e,t){return Si(1+MS.count(pg(e),e),t,3)}function dye(e,t){return Si(e.getMilliseconds(),t,3)}function ZUe(e,t){return dye(e,t)+"000"}function HUe(e,t){return Si(e.getMonth()+1,t,2)}function XUe(e,t){return Si(e.getMinutes(),t,2)}function YUe(e,t){return Si(e.getSeconds(),t,2)}function GUe(e){var t=e.getDay();return t===0?7:t}function KUe(e,t){return Si(Ww.count(pg(e)-1,e),t,2)}function hye(e){var t=e.getDay();return t>=4||t===0?B3(e):B3.ceil(e)}function WUe(e,t){return e=hye(e),Si(B3.count(pg(e),e)+(pg(e).getDay()===4),t,2)}function JUe(e){return e.getDay()}function eje(e,t){return Si(K$.count(pg(e)-1,e),t,2)}function tje(e,t){return Si(e.getFullYear()%100,t,2)}function nje(e,t){return e=hye(e),Si(e.getFullYear()%100,t,2)}function rje(e,t){return Si(e.getFullYear()%1e4,t,4)}function ije(e,t){var n=e.getDay();return e=n>=4||n===0?B3(e):B3.ceil(e),Si(e.getFullYear()%1e4,t,4)}function aje(e){var t=e.getTimezoneOffset();return(t>0?"-":(t*=-1,"+"))+Si(t/60|0,"0",2)+Si(t%60,"0",2)}function GG(e,t){return Si(e.getUTCDate(),t,2)}function uje(e,t){return Si(e.getUTCHours(),t,2)}function lje(e,t){return Si(e.getUTCHours()%12||12,t,2)}function oje(e,t){return Si(1+Kw.count(mg(e),e),t,3)}function pye(e,t){return Si(e.getUTCMilliseconds(),t,3)}function sje(e,t){return pye(e,t)+"000"}function cje(e,t){return Si(e.getUTCMonth()+1,t,2)}function fje(e,t){return Si(e.getUTCMinutes(),t,2)}function dje(e,t){return Si(e.getUTCSeconds(),t,2)}function hje(e){var t=e.getUTCDay();return t===0?7:t}function pje(e,t){return Si(Jw.count(mg(e)-1,e),t,2)}function mye(e){var t=e.getUTCDay();return t>=4||t===0?Q3(e):Q3.ceil(e)}function mje(e,t){return e=mye(e),Si(Q3.count(mg(e),e)+(mg(e).getUTCDay()===4),t,2)}function gje(e){return e.getUTCDay()}function vje(e,t){return Si(W$.count(mg(e)-1,e),t,2)}function yje(e,t){return Si(e.getUTCFullYear()%100,t,2)}function bje(e,t){return e=mye(e),Si(e.getUTCFullYear()%100,t,2)}function Oje(e,t){return Si(e.getUTCFullYear()%1e4,t,4)}function xje(e,t){var n=e.getUTCDay();return e=n>=4||n===0?Q3(e):Q3.ceil(e),Si(e.getUTCFullYear()%1e4,t,4)}function Sje(){return"+0000"}function KG(){return"%"}function WG(e){return+e}function JG(e){return Math.floor(+e/1e3)}var CO,gye,vye;_je({dateTime:"%x, %X",date:"%-m/%-d/%Y",time:"%-I:%M:%S %p",periods:["AM","PM"],days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]});function _je(e){return CO=_Ue(e),gye=CO.format,CO.parse,vye=CO.utcFormat,CO.utcParse,CO}function Eje(e){return new Date(e)}function Dje(e){return e instanceof Date?+e:+new Date(+e)}function GL(e,t,n,r,i,a,u,l,o,s){var c=LL(),d=c.invert,h=c.domain,m=s(".%L"),y=s(":%S"),v=s("%I:%M"),_=s("%I %p"),S=s("%a %d"),E=s("%b %d"),C=s("%B"),T=s("%Y");function R($){return(o($)<$?m:l($)<$?y:u($)<$?v:a($)<$?_:r($)<$?i($)<$?S:E:n($)<$?C:T)($)}return c.invert=function($){return new Date(d($))},c.domain=function($){return arguments.length?h(Array.from($,Dje)):h().map(Eje)},c.ticks=function($){var k=h();return e(k[0],k[k.length-1],$??10)},c.tickFormat=function($,k){return k==null?R:s(k)},c.nice=function($){var k=h();return(!$||typeof $.range!="function")&&($=t(k[0],k[k.length-1],$??10)),$?h(rye(k,$)):c},c.copy=function(){return PS(c,GL(e,t,n,r,i,a,u,l,o,s))},c}function $je(){return lh.apply(GL(xUe,SUe,pg,XL,Ww,MS,ZL,UL,U1,gye).domain([new Date(2e3,0,1),new Date(2e3,0,2)]),arguments)}function Cje(){return lh.apply(GL(bUe,OUe,mg,YL,Jw,Kw,HL,jL,U1,vye).domain([Date.UTC(2e3,0,1),Date.UTC(2e3,0,2)]),arguments)}function e5(){var e=0,t=1,n,r,i,a,u=cc,l=!1,o;function s(d){return d==null||isNaN(d=+d)?o:u(i===0?.5:(d=(a(d)-n)*i,l?Math.max(0,Math.min(1,d)):d))}s.domain=function(d){return arguments.length?([e,t]=d,n=a(e=+e),r=a(t=+t),i=n===r?0:1/(r-n),s):[e,t]},s.clamp=function(d){return arguments.length?(l=!!d,s):l},s.interpolator=function(d){return arguments.length?(u=d,s):u};function c(d){return function(h){var m,y;return arguments.length?([m,y]=h,u=d(m,y),s):[u(0),u(1)]}}return s.range=c(t4),s.rangeRound=c(MI),s.unknown=function(d){return arguments.length?(o=d,s):o},function(d){return a=d,n=d(e),r=d(t),i=n===r?0:1/(r-n),s}}function _y(e,t){return t.domain(e.domain()).interpolator(e.interpolator()).clamp(e.clamp()).unknown(e.unknown())}function yye(){var e=Sy(e5()(cc));return e.copy=function(){return _y(e,yye())},xg.apply(e,arguments)}function bye(){var e=BL(e5()).domain([1,10]);return e.copy=function(){return _y(e,bye()).base(e.base())},xg.apply(e,arguments)}function Oye(){var e=QL(e5());return e.copy=function(){return _y(e,Oye()).constant(e.constant())},xg.apply(e,arguments)}function KL(){var e=zL(e5());return e.copy=function(){return _y(e,KL()).exponent(e.exponent())},xg.apply(e,arguments)}function wje(){return KL.apply(null,arguments).exponent(.5)}function xye(){var e=[],t=cc;function n(r){if(r!=null&&!isNaN(r=+r))return t((kS(e,r,1)-1)/(e.length-1))}return n.domain=function(r){if(!arguments.length)return e.slice();e=[];for(let i of r)i!=null&&!isNaN(i=+i)&&e.push(i);return e.sort(Hv),n},n.interpolator=function(r){return arguments.length?(t=r,n):t},n.range=function(){return e.map((r,i)=>t(i/(e.length-1)))},n.quantiles=function(r){return Array.from({length:r+1},(i,a)=>XVe(e,a/r))},n.copy=function(){return xye(t).domain(e)},xg.apply(n,arguments)}function t5(){var e=0,t=.5,n=1,r=1,i,a,u,l,o,s=cc,c,d=!1,h;function m(v){return isNaN(v=+v)?h:(v=.5+((v=+c(v))-a)*(r*v<r*a?l:o),s(d?Math.max(0,Math.min(1,v)):v))}m.domain=function(v){return arguments.length?([e,t,n]=v,i=c(e=+e),a=c(t=+t),u=c(n=+n),l=i===a?0:.5/(a-i),o=a===u?0:.5/(u-a),r=a<i?-1:1,m):[e,t,n]},m.clamp=function(v){return arguments.length?(d=!!v,m):d},m.interpolator=function(v){return arguments.length?(s=v,m):s};function y(v){return function(_){var S,E,C;return arguments.length?([S,E,C]=_,s=RPe(v,[S,E,C]),m):[s(0),s(.5),s(1)]}}return m.range=y(t4),m.rangeRound=y(MI),m.unknown=function(v){return arguments.length?(h=v,m):h},function(v){return c=v,i=v(e),a=v(t),u=v(n),l=i===a?0:.5/(a-i),o=a===u?0:.5/(u-a),r=a<i?-1:1,m}}function Sye(){var e=Sy(t5()(cc));return e.copy=function(){return _y(e,Sye())},xg.apply(e,arguments)}function _ye(){var e=BL(t5()).domain([.1,1,10]);return e.copy=function(){return _y(e,_ye()).base(e.base())},xg.apply(e,arguments)}function Eye(){var e=QL(t5());return e.copy=function(){return _y(e,Eye()).constant(e.constant())},xg.apply(e,arguments)}function WL(){var e=zL(t5());return e.copy=function(){return _y(e,WL()).exponent(e.exponent())},xg.apply(e,arguments)}function Rje(){return WL.apply(null,arguments).exponent(.5)}const Uut=Object.freeze(Object.defineProperty({__proto__:null,scaleBand:IL,scaleDiverging:Sye,scaleDivergingLog:_ye,scaleDivergingPow:WL,scaleDivergingSqrt:Rje,scaleDivergingSymlog:Eye,scaleIdentity:nye,scaleImplicit:uF,scaleLinear:tye,scaleLog:iye,scaleOrdinal:NL,scalePoint:KVe,scalePow:qL,scaleQuantile:lye,scaleQuantize:oye,scaleRadial:uye,scaleSequential:yye,scaleSequentialLog:bye,scaleSequentialPow:KL,scaleSequentialQuantile:xye,scaleSequentialSqrt:wje,scaleSequentialSymlog:Oye,scaleSqrt:sUe,scaleSymlog:aye,scaleThreshold:sye,scaleTime:$je,scaleUtc:Cje,tickFormat:eye},Symbol.toStringTag,{value:"Module"}));var f4=1e9,Aje={precision:20,rounding:4,toExpNeg:-7,toExpPos:21,LN10:"2.302585092994045684017991454684364207601101488628772976033327900967572609677352480235997205089598298341967784042286"},eB,ja=!0,eh="[DecimalError] ",G1=eh+"Invalid argument: ",JL=eh+"Exponent out of range: ",d4=Math.floor,A1=Math.pow,Tje=/^(\d+(\.\d*)?|\.\d+)(e[+-]?\d+)?$/i,qf,eo=1e7,Na=7,Dye=9007199254740991,J$=d4(Dye/Na),hn={};hn.absoluteValue=hn.abs=function(){var e=new this.constructor(this);return e.s&&(e.s=1),e};hn.comparedTo=hn.cmp=function(e){var t,n,r,i,a=this;if(e=new a.constructor(e),a.s!==e.s)return a.s||-e.s;if(a.e!==e.e)return a.e>e.e^a.s<0?1:-1;for(r=a.d.length,i=e.d.length,t=0,n=r<i?r:i;t<n;++t)if(a.d[t]!==e.d[t])return a.d[t]>e.d[t]^a.s<0?1:-1;return r===i?0:r>i^a.s<0?1:-1};hn.decimalPlaces=hn.dp=function(){var e=this,t=e.d.length-1,n=(t-e.e)*Na;if(t=e.d[t],t)for(;t%10==0;t/=10)n--;return n<0?0:n};hn.dividedBy=hn.div=function(e){return ug(this,new this.constructor(e))};hn.dividedToIntegerBy=hn.idiv=function(e){var t=this,n=t.constructor;return ua(ug(t,new n(e),0,1),n.precision)};hn.equals=hn.eq=function(e){return!this.cmp(e)};hn.exponent=function(){return vl(this)};hn.greaterThan=hn.gt=function(e){return this.cmp(e)>0};hn.greaterThanOrEqualTo=hn.gte=function(e){return this.cmp(e)>=0};hn.isInteger=hn.isint=function(){return this.e>this.d.length-2};hn.isNegative=hn.isneg=function(){return this.s<0};hn.isPositive=hn.ispos=function(){return this.s>0};hn.isZero=function(){return this.s===0};hn.lessThan=hn.lt=function(e){return this.cmp(e)<0};hn.lessThanOrEqualTo=hn.lte=function(e){return this.cmp(e)<1};hn.logarithm=hn.log=function(e){var t,n=this,r=n.constructor,i=r.precision,a=i+5;if(e===void 0)e=new r(10);else if(e=new r(e),e.s<1||e.eq(qf))throw Error(eh+"NaN");if(n.s<1)throw Error(eh+(n.s?"NaN":"-Infinity"));return n.eq(qf)?new r(0):(ja=!1,t=ug(Zx(n,a),Zx(e,a),a),ja=!0,ua(t,i))};hn.minus=hn.sub=function(e){var t=this;return e=new t.constructor(e),t.s==e.s?wye(t,e):$ye(t,(e.s=-e.s,e))};hn.modulo=hn.mod=function(e){var t,n=this,r=n.constructor,i=r.precision;if(e=new r(e),!e.s)throw Error(eh+"NaN");return n.s?(ja=!1,t=ug(n,e,0,1).times(e),ja=!0,n.minus(t)):ua(new r(n),i)};hn.naturalExponential=hn.exp=function(){return Cye(this)};hn.naturalLogarithm=hn.ln=function(){return Zx(this)};hn.negated=hn.neg=function(){var e=new this.constructor(this);return e.s=-e.s||0,e};hn.plus=hn.add=function(e){var t=this;return e=new t.constructor(e),t.s==e.s?$ye(t,e):wye(t,(e.s=-e.s,e))};hn.precision=hn.sd=function(e){var t,n,r,i=this;if(e!==void 0&&e!==!!e&&e!==1&&e!==0)throw Error(G1+e);if(t=vl(i)+1,r=i.d.length-1,n=r*Na+1,r=i.d[r],r){for(;r%10==0;r/=10)n--;for(r=i.d[0];r>=10;r/=10)n++}return e&&t>n?t:n};hn.squareRoot=hn.sqrt=function(){var e,t,n,r,i,a,u,l=this,o=l.constructor;if(l.s<1){if(!l.s)return new o(0);throw Error(eh+"NaN")}for(e=vl(l),ja=!1,i=Math.sqrt(+l),i==0||i==1/0?(t=E0(l.d),(t.length+e)%2==0&&(t+="0"),i=Math.sqrt(t),e=d4((e+1)/2)-(e<0||e%2),i==1/0?t="5e"+e:(t=i.toExponential(),t=t.slice(0,t.indexOf("e")+1)+e),r=new o(t)):r=new o(i.toString()),n=o.precision,i=u=n+3;;)if(a=r,r=a.plus(ug(l,a,u+2)).times(.5),E0(a.d).slice(0,u)===(t=E0(r.d)).slice(0,u)){if(t=t.slice(u-3,u+1),i==u&&t=="4999"){if(ua(a,n+1,0),a.times(a).eq(l)){r=a;break}}else if(t!="9999")break;u+=4}return ja=!0,ua(r,n)};hn.times=hn.mul=function(e){var t,n,r,i,a,u,l,o,s,c=this,d=c.constructor,h=c.d,m=(e=new d(e)).d;if(!c.s||!e.s)return new d(0);for(e.s*=c.s,n=c.e+e.e,o=h.length,s=m.length,o<s&&(a=h,h=m,m=a,u=o,o=s,s=u),a=[],u=o+s,r=u;r--;)a.push(0);for(r=s;--r>=0;){for(t=0,i=o+r;i>r;)l=a[i]+m[r]*h[i-r-1]+t,a[i--]=l%eo|0,t=l/eo|0;a[i]=(a[i]+t)%eo|0}for(;!a[--u];)a.pop();return t?++n:a.shift(),e.d=a,e.e=n,ja?ua(e,d.precision):e};hn.toDecimalPlaces=hn.todp=function(e,t){var n=this,r=n.constructor;return n=new r(n),e===void 0?n:(F0(e,0,f4),t===void 0?t=r.rounding:F0(t,0,8),ua(n,e+vl(n)+1,t))};hn.toExponential=function(e,t){var n,r=this,i=r.constructor;return e===void 0?n=yb(r,!0):(F0(e,0,f4),t===void 0?t=i.rounding:F0(t,0,8),r=ua(new i(r),e+1,t),n=yb(r,!0,e+1)),n};hn.toFixed=function(e,t){var n,r,i=this,a=i.constructor;return e===void 0?yb(i):(F0(e,0,f4),t===void 0?t=a.rounding:F0(t,0,8),r=ua(new a(i),e+vl(i)+1,t),n=yb(r.abs(),!1,e+vl(r)+1),i.isneg()&&!i.isZero()?"-"+n:n)};hn.toInteger=hn.toint=function(){var e=this,t=e.constructor;return ua(new t(e),vl(e)+1,t.rounding)};hn.toNumber=function(){return+this};hn.toPower=hn.pow=function(e){var t,n,r,i,a,u,l=this,o=l.constructor,s=12,c=+(e=new o(e));if(!e.s)return new o(qf);if(l=new o(l),!l.s){if(e.s<1)throw Error(eh+"Infinity");return l}if(l.eq(qf))return l;if(r=o.precision,e.eq(qf))return ua(l,r);if(t=e.e,n=e.d.length-1,u=t>=n,a=l.s,u){if((n=c<0?-c:c)<=Dye){for(i=new o(qf),t=Math.ceil(r/Na+4),ja=!1;n%2&&(i=i.times(l),tK(i.d,t)),n=d4(n/2),n!==0;)l=l.times(l),tK(l.d,t);return ja=!0,e.s<0?new o(qf).div(i):ua(i,r)}}else if(a<0)throw Error(eh+"NaN");return a=a<0&&e.d[Math.max(t,n)]&1?-1:1,l.s=1,ja=!1,i=e.times(Zx(l,r+s)),ja=!0,i=Cye(i),i.s=a,i};hn.toPrecision=function(e,t){var n,r,i=this,a=i.constructor;return e===void 0?(n=vl(i),r=yb(i,n<=a.toExpNeg||n>=a.toExpPos)):(F0(e,1,f4),t===void 0?t=a.rounding:F0(t,0,8),i=ua(new a(i),e,t),n=vl(i),r=yb(i,e<=n||n<=a.toExpNeg,e)),r};hn.toSignificantDigits=hn.tosd=function(e,t){var n=this,r=n.constructor;return e===void 0?(e=r.precision,t=r.rounding):(F0(e,1,f4),t===void 0?t=r.rounding:F0(t,0,8)),ua(new r(n),e,t)};hn.toString=hn.valueOf=hn.val=hn.toJSON=hn[Symbol.for("nodejs.util.inspect.custom")]=function(){var e=this,t=vl(e),n=e.constructor;return yb(e,t<=n.toExpNeg||t>=n.toExpPos)};function $ye(e,t){var n,r,i,a,u,l,o,s,c=e.constructor,d=c.precision;if(!e.s||!t.s)return t.s||(t=new c(e)),ja?ua(t,d):t;if(o=e.d,s=t.d,u=e.e,i=t.e,o=o.slice(),a=u-i,a){for(a<0?(r=o,a=-a,l=s.length):(r=s,i=u,l=o.length),u=Math.ceil(d/Na),l=u>l?u+1:l+1,a>l&&(a=l,r.length=1),r.reverse();a--;)r.push(0);r.reverse()}for(l=o.length,a=s.length,l-a<0&&(a=l,r=s,s=o,o=r),n=0;a;)n=(o[--a]=o[a]+s[a]+n)/eo|0,o[a]%=eo;for(n&&(o.unshift(n),++i),l=o.length;o[--l]==0;)o.pop();return t.d=o,t.e=i,ja?ua(t,d):t}function F0(e,t,n){if(e!==~~e||e<t||e>n)throw Error(G1+e)}function E0(e){var t,n,r,i=e.length-1,a="",u=e[0];if(i>0){for(a+=u,t=1;t<i;t++)r=e[t]+"",n=Na-r.length,n&&(a+=$v(n)),a+=r;u=e[t],r=u+"",n=Na-r.length,n&&(a+=$v(n))}else if(u===0)return"0";for(;u%10===0;)u/=10;return a+u}var ug=(function(){function e(r,i){var a,u=0,l=r.length;for(r=r.slice();l--;)a=r[l]*i+u,r[l]=a%eo|0,u=a/eo|0;return u&&r.unshift(u),r}function t(r,i,a,u){var l,o;if(a!=u)o=a>u?1:-1;else for(l=o=0;l<a;l++)if(r[l]!=i[l]){o=r[l]>i[l]?1:-1;break}return o}function n(r,i,a){for(var u=0;a--;)r[a]-=u,u=r[a]<i[a]?1:0,r[a]=u*eo+r[a]-i[a];for(;!r[0]&&r.length>1;)r.shift()}return function(r,i,a,u){var l,o,s,c,d,h,m,y,v,_,S,E,C,T,R,$,k,F,L=r.constructor,j=r.s==i.s?1:-1,V=r.d,q=i.d;if(!r.s)return new L(r);if(!i.s)throw Error(eh+"Division by zero");for(o=r.e-i.e,k=q.length,R=V.length,m=new L(j),y=m.d=[],s=0;q[s]==(V[s]||0);)++s;if(q[s]>(V[s]||0)&&--o,a==null?E=a=L.precision:u?E=a+(vl(r)-vl(i))+1:E=a,E<0)return new L(0);if(E=E/Na+2|0,s=0,k==1)for(c=0,q=q[0],E++;(s<R||c)&&E--;s++)C=c*eo+(V[s]||0),y[s]=C/q|0,c=C%q|0;else{for(c=eo/(q[0]+1)|0,c>1&&(q=e(q,c),V=e(V,c),k=q.length,R=V.length),T=k,v=V.slice(0,k),_=v.length;_<k;)v[_++]=0;F=q.slice(),F.unshift(0),$=q[0],q[1]>=eo/2&&++$;do c=0,l=t(q,v,k,_),l<0?(S=v[0],k!=_&&(S=S*eo+(v[1]||0)),c=S/$|0,c>1?(c>=eo&&(c=eo-1),d=e(q,c),h=d.length,_=v.length,l=t(d,v,h,_),l==1&&(c--,n(d,k<h?F:q,h))):(c==0&&(l=c=1),d=q.slice()),h=d.length,h<_&&d.unshift(0),n(v,d,_),l==-1&&(_=v.length,l=t(q,v,k,_),l<1&&(c++,n(v,k<_?F:q,_))),_=v.length):l===0&&(c++,v=[0]),y[s++]=c,l&&v[0]?v[_++]=V[T]||0:(v=[V[T]],_=1);while((T++<R||v[0]!==void 0)&&E--)}return y[0]||y.shift(),m.e=o,ua(m,u?a+vl(m)+1:a)}})();function Cye(e,t){var n,r,i,a,u,l,o=0,s=0,c=e.constructor,d=c.precision;if(vl(e)>16)throw Error(JL+vl(e));if(!e.s)return new c(qf);for(ja=!1,l=d,u=new c(.03125);e.abs().gte(.1);)e=e.times(u),s+=5;for(r=Math.log(A1(2,s))/Math.LN10*2+5|0,l+=r,n=i=a=new c(qf),c.precision=l;;){if(i=ua(i.times(e),l),n=n.times(++o),u=a.plus(ug(i,n,l)),E0(u.d).slice(0,l)===E0(a.d).slice(0,l)){for(;s--;)a=ua(a.times(a),l);return c.precision=d,t==null?(ja=!0,ua(a,d)):a}a=u}}function vl(e){for(var t=e.e*Na,n=e.d[0];n>=10;n/=10)t++;return t}function U8(e,t,n){if(t>e.LN10.sd())throw ja=!0,n&&(e.precision=n),Error(eh+"LN10 precision limit exceeded");return ua(new e(e.LN10),t)}function $v(e){for(var t="";e--;)t+="0";return t}function Zx(e,t){var n,r,i,a,u,l,o,s,c,d=1,h=10,m=e,y=m.d,v=m.constructor,_=v.precision;if(m.s<1)throw Error(eh+(m.s?"NaN":"-Infinity"));if(m.eq(qf))return new v(0);if(t==null?(ja=!1,s=_):s=t,m.eq(10))return t==null&&(ja=!0),U8(v,s);if(s+=h,v.precision=s,n=E0(y),r=n.charAt(0),a=vl(m),Math.abs(a)<15e14){for(;r<7&&r!=1||r==1&&n.charAt(1)>3;)m=m.times(e),n=E0(m.d),r=n.charAt(0),d++;a=vl(m),r>1?(m=new v("0."+n),a++):m=new v(r+"."+n.slice(1))}else return o=U8(v,s+2,_).times(a+""),m=Zx(new v(r+"."+n.slice(1)),s-h).plus(o),v.precision=_,t==null?(ja=!0,ua(m,_)):m;for(l=u=m=ug(m.minus(qf),m.plus(qf),s),c=ua(m.times(m),s),i=3;;){if(u=ua(u.times(c),s),o=l.plus(ug(u,new v(i),s)),E0(o.d).slice(0,s)===E0(l.d).slice(0,s))return l=l.times(2),a!==0&&(l=l.plus(U8(v,s+2,_).times(a+""))),l=ug(l,new v(d),s),v.precision=_,t==null?(ja=!0,ua(l,_)):l;l=o,i+=2}}function eK(e,t){var n,r,i;for((n=t.indexOf("."))>-1&&(t=t.replace(".","")),(r=t.search(/e/i))>0?(n<0&&(n=r),n+=+t.slice(r+1),t=t.substring(0,r)):n<0&&(n=t.length),r=0;t.charCodeAt(r)===48;)++r;for(i=t.length;t.charCodeAt(i-1)===48;)--i;if(t=t.slice(r,i),t){if(i-=r,n=n-r-1,e.e=d4(n/Na),e.d=[],r=(n+1)%Na,n<0&&(r+=Na),r<i){for(r&&e.d.push(+t.slice(0,r)),i-=Na;r<i;)e.d.push(+t.slice(r,r+=Na));t=t.slice(r),r=Na-t.length}else r-=i;for(;r--;)t+="0";if(e.d.push(+t),ja&&(e.e>J$||e.e<-J$))throw Error(JL+n)}else e.s=0,e.e=0,e.d=[0];return e}function ua(e,t,n){var r,i,a,u,l,o,s,c,d=e.d;for(u=1,a=d[0];a>=10;a/=10)u++;if(r=t-u,r<0)r+=Na,i=t,s=d[c=0];else{if(c=Math.ceil((r+1)/Na),a=d.length,c>=a)return e;for(s=a=d[c],u=1;a>=10;a/=10)u++;r%=Na,i=r-Na+u}if(n!==void 0&&(a=A1(10,u-i-1),l=s/a%10|0,o=t<0||d[c+1]!==void 0||s%a,o=n<4?(l||o)&&(n==0||n==(e.s<0?3:2)):l>5||l==5&&(n==4||o||n==6&&(r>0?i>0?s/A1(10,u-i):0:d[c-1])%10&1||n==(e.s<0?8:7))),t<1||!d[0])return o?(a=vl(e),d.length=1,t=t-a-1,d[0]=A1(10,(Na-t%Na)%Na),e.e=d4(-t/Na)||0):(d.length=1,d[0]=e.e=e.s=0),e;if(r==0?(d.length=c,a=1,c--):(d.length=c+1,a=A1(10,Na-r),d[c]=i>0?(s/A1(10,u-i)%A1(10,i)|0)*a:0),o)for(;;)if(c==0){(d[0]+=a)==eo&&(d[0]=1,++e.e);break}else{if(d[c]+=a,d[c]!=eo)break;d[c--]=0,a=1}for(r=d.length;d[--r]===0;)d.pop();if(ja&&(e.e>J$||e.e<-J$))throw Error(JL+vl(e));return e}function wye(e,t){var n,r,i,a,u,l,o,s,c,d,h=e.constructor,m=h.precision;if(!e.s||!t.s)return t.s?t.s=-t.s:t=new h(e),ja?ua(t,m):t;if(o=e.d,d=t.d,r=t.e,s=e.e,o=o.slice(),u=s-r,u){for(c=u<0,c?(n=o,u=-u,l=d.length):(n=d,r=s,l=o.length),i=Math.max(Math.ceil(m/Na),l)+2,u>i&&(u=i,n.length=1),n.reverse(),i=u;i--;)n.push(0);n.reverse()}else{for(i=o.length,l=d.length,c=i<l,c&&(l=i),i=0;i<l;i++)if(o[i]!=d[i]){c=o[i]<d[i];break}u=0}for(c&&(n=o,o=d,d=n,t.s=-t.s),l=o.length,i=d.length-l;i>0;--i)o[l++]=0;for(i=d.length;i>u;){if(o[--i]<d[i]){for(a=i;a&&o[--a]===0;)o[a]=eo-1;--o[a],o[i]+=eo}o[i]-=d[i]}for(;o[--l]===0;)o.pop();for(;o[0]===0;o.shift())--r;return o[0]?(t.d=o,t.e=r,ja?ua(t,m):t):new h(0)}function yb(e,t,n){var r,i=vl(e),a=E0(e.d),u=a.length;return t?(n&&(r=n-u)>0?a=a.charAt(0)+"."+a.slice(1)+$v(r):u>1&&(a=a.charAt(0)+"."+a.slice(1)),a=a+(i<0?"e":"e+")+i):i<0?(a="0."+$v(-i-1)+a,n&&(r=n-u)>0&&(a+=$v(r))):i>=u?(a+=$v(i+1-u),n&&(r=n-i-1)>0&&(a=a+"."+$v(r))):((r=i+1)<u&&(a=a.slice(0,r)+"."+a.slice(r)),n&&(r=n-u)>0&&(i+1===u&&(a+="."),a+=$v(r))),e.s<0?"-"+a:a}function tK(e,t){if(e.length>t)return e.length=t,!0}function Rye(e){var t,n,r;function i(a){var u=this;if(!(u instanceof i))return new i(a);if(u.constructor=i,a instanceof i){u.s=a.s,u.e=a.e,u.d=(a=a.d)?a.slice():a;return}if(typeof a=="number"){if(a*0!==0)throw Error(G1+a);if(a>0)u.s=1;else if(a<0)a=-a,u.s=-1;else{u.s=0,u.e=0,u.d=[0];return}if(a===~~a&&a<1e7){u.e=0,u.d=[a];return}return eK(u,a.toString())}else if(typeof a!="string")throw Error(G1+a);if(a.charCodeAt(0)===45?(a=a.slice(1),u.s=-1):u.s=1,Tje.test(a))eK(u,a);else throw Error(G1+a)}if(i.prototype=hn,i.ROUND_UP=0,i.ROUND_DOWN=1,i.ROUND_CEIL=2,i.ROUND_FLOOR=3,i.ROUND_HALF_UP=4,i.ROUND_HALF_DOWN=5,i.ROUND_HALF_EVEN=6,i.ROUND_HALF_CEIL=7,i.ROUND_HALF_FLOOR=8,i.clone=Rye,i.config=i.set=kje,e===void 0&&(e={}),e)for(r=["precision","rounding","toExpNeg","toExpPos","LN10"],t=0;t<r.length;)e.hasOwnProperty(n=r[t++])||(e[n]=this[n]);return i.config(e),i}function kje(e){if(!e||typeof e!="object")throw Error(eh+"Object expected");var t,n,r,i=["precision",1,f4,"rounding",0,8,"toExpNeg",-1/0,0,"toExpPos",0,1/0];for(t=0;t<i.length;t+=3)if((r=e[n=i[t]])!==void 0)if(d4(r)===r&&r>=i[t+1]&&r<=i[t+2])this[n]=r;else throw Error(G1+n+": "+r);if((r=e[n="LN10"])!==void 0)if(r==Math.LN10)this[n]=new this(r);else throw Error(G1+n+": "+r);return this}var eB=Rye(Aje);qf=new eB(1);const jut=eB;var j8={exports:{}},nK;function Pje(){return nK||(nK=1,(function(e){var t=Object.prototype.hasOwnProperty,n="~";function r(){}Object.create&&(r.prototype=Object.create(null),new r().__proto__||(n=!1));function i(o,s,c){this.fn=o,this.context=s,this.once=c||!1}function a(o,s,c,d,h){if(typeof c!="function")throw new TypeError("The listener must be a function");var m=new i(c,d||o,h),y=n?n+s:s;return o._events[y]?o._events[y].fn?o._events[y]=[o._events[y],m]:o._events[y].push(m):(o._events[y]=m,o._eventsCount++),o}function u(o,s){--o._eventsCount===0?o._events=new r:delete o._events[s]}function l(){this._events=new r,this._eventsCount=0}l.prototype.eventNames=function(){var s=[],c,d;if(this._eventsCount===0)return s;for(d in c=this._events)t.call(c,d)&&s.push(n?d.slice(1):d);return Object.getOwnPropertySymbols?s.concat(Object.getOwnPropertySymbols(c)):s},l.prototype.listeners=function(s){var c=n?n+s:s,d=this._events[c];if(!d)return[];if(d.fn)return[d.fn];for(var h=0,m=d.length,y=new Array(m);h<m;h++)y[h]=d[h].fn;return y},l.prototype.listenerCount=function(s){var c=n?n+s:s,d=this._events[c];return d?d.fn?1:d.length:0},l.prototype.emit=function(s,c,d,h,m,y){var v=n?n+s:s;if(!this._events[v])return!1;var _=this._events[v],S=arguments.length,E,C;if(_.fn){switch(_.once&&this.removeListener(s,_.fn,void 0,!0),S){case 1:return _.fn.call(_.context),!0;case 2:return _.fn.call(_.context,c),!0;case 3:return _.fn.call(_.context,c,d),!0;case 4:return _.fn.call(_.context,c,d,h),!0;case 5:return _.fn.call(_.context,c,d,h,m),!0;case 6:return _.fn.call(_.context,c,d,h,m,y),!0}for(C=1,E=new Array(S-1);C<S;C++)E[C-1]=arguments[C];_.fn.apply(_.context,E)}else{var T=_.length,R;for(C=0;C<T;C++)switch(_[C].once&&this.removeListener(s,_[C].fn,void 0,!0),S){case 1:_[C].fn.call(_[C].context);break;case 2:_[C].fn.call(_[C].context,c);break;case 3:_[C].fn.call(_[C].context,c,d);break;case 4:_[C].fn.call(_[C].context,c,d,h);break;default:if(!E)for(R=1,E=new Array(S-1);R<S;R++)E[R-1]=arguments[R];_[C].fn.apply(_[C].context,E)}}return!0},l.prototype.on=function(s,c,d){return a(this,s,c,d,!1)},l.prototype.once=function(s,c,d){return a(this,s,c,d,!0)},l.prototype.removeListener=function(s,c,d,h){var m=n?n+s:s;if(!this._events[m])return this;if(!c)return u(this,m),this;var y=this._events[m];if(y.fn)y.fn===c&&(!h||y.once)&&(!d||y.context===d)&&u(this,m);else{for(var v=0,_=[],S=y.length;v<S;v++)(y[v].fn!==c||h&&!y[v].once||d&&y[v].context!==d)&&_.push(y[v]);_.length?this._events[m]=_.length===1?_[0]:_:u(this,m)}return this},l.prototype.removeAllListeners=function(s){var c;return s?(c=n?n+s:s,this._events[c]&&u(this,c)):(this._events=new r,this._eventsCount=0),this},l.prototype.off=l.prototype.removeListener,l.prototype.addListener=l.prototype.on,l.prefixed=n,l.EventEmitter=l,e.exports=l})(j8)),j8.exports}var Mje=Pje();const Zut=sa(Mje);var Z8={},H8={},X8={},rK;function Fje(){return rK||(rK=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n,r,{signal:i,edges:a}={}){let u,l=null;const o=a!=null&&a.includes("leading"),s=a==null||a.includes("trailing"),c=()=>{l!==null&&(n.apply(u,l),u=void 0,l=null)},d=()=>{s&&c(),v()};let h=null;const m=()=>{h!=null&&clearTimeout(h),h=setTimeout(()=>{h=null,d()},r)},y=()=>{h!==null&&(clearTimeout(h),h=null)},v=()=>{y(),u=void 0,l=null},_=()=>{c()},S=function(...E){if(i!=null&&i.aborted)return;u=this,l=E;const C=h==null;m(),o&&C&&c()};return S.schedule=m,S.cancel=v,S.flush=_,i==null||i.addEventListener("abort",v,{once:!0}),S}e.debounce=t})(X8)),X8}var iK;function Nje(){return iK||(iK=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Fje();function n(r,i=0,a={}){typeof a!="object"&&(a={});const{leading:u=!1,trailing:l=!0,maxWait:o}=a,s=Array(2);u&&(s[0]="leading"),l&&(s[1]="trailing");let c,d=null;const h=t.debounce(function(...v){c=r.apply(this,v),d=null},i,{edges:s}),m=function(...v){return o!=null&&(d===null&&(d=Date.now()),Date.now()-d>=o)?(c=r.apply(this,v),d=Date.now(),h.cancel(),h.schedule(),c):(h.apply(this,v),c)},y=()=>(h.flush(),c);return m.cancel=h.cancel,m.flush=y,m}e.debounce=n})(H8)),H8}var aK;function Ije(){return aK||(aK=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Nje();function n(r,i=0,a={}){const{leading:u=!0,trailing:l=!0}=a;return t.debounce(r,i,{leading:u,maxWait:i,trailing:l})}e.throttle=n})(Z8)),Z8}var Y8,uK;function Lje(){return uK||(uK=1,Y8=Ije().throttle),Y8}var Bje=Lje();const Hut=sa(Bje);var G8={},K8={},lK;function Qje(){return lK||(lK=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return n[n.length-1]}e.last=t})(K8)),K8}var W8={},oK;function zje(){return oK||(oK=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){return Array.isArray(n)?n:Array.from(n)}e.toArray=t})(W8)),W8}var sK;function qje(){return sK||(sK=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});const t=Qje(),n=zje(),r=DL();function i(a){if(r.isArrayLike(a))return t.last(n.toArray(a))}e.last=i})(G8)),G8}var J8,cK;function Vje(){return cK||(cK=1,J8=qje().last),J8}var Uje=Vje();const Xut=sa(Uje);var e7={},fK;function jje(){return fK||(fK=1,(function(e){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"});function t(n){var i;if(typeof n!="object"||n==null)return!1;if(Object.getPrototypeOf(n)===null)return!0;if(Object.prototype.toString.call(n)!=="[object Object]"){const a=n[Symbol.toStringTag];return a==null||!((i=Object.getOwnPropertyDescriptor(n,Symbol.toStringTag))!=null&&i.writable)?!1:n.toString()===`[object ${a}]`}let r=n;for(;Object.getPrototypeOf(r)!==null;)r=Object.getPrototypeOf(r);return Object.getPrototypeOf(n)===r}e.isPlainObject=t})(e7)),e7}var t7,dK;function Zje(){return dK||(dK=1,t7=jje().isPlainObject),t7}var Hje=Zje();const Yut=sa(Hje);var n7={exports:{}},r7={};/**
 * @license React
 * use-sync-external-store-with-selector.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hK;function Xje(){if(hK)return r7;hK=1;var e=nr();function t(o,s){return o===s&&(o!==0||1/o===1/s)||o!==o&&s!==s}var n=typeof Object.is=="function"?Object.is:t,r=e.useSyncExternalStore,i=e.useRef,a=e.useEffect,u=e.useMemo,l=e.useDebugValue;return r7.useSyncExternalStoreWithSelector=function(o,s,c,d,h){var m=i(null);if(m.current===null){var y={hasValue:!1,value:null};m.current=y}else y=m.current;m=u(function(){function _(R){if(!S){if(S=!0,E=R,R=d(R),h!==void 0&&y.hasValue){var $=y.value;if(h($,R))return C=$}return C=R}if($=C,n(E,R))return $;var k=d(R);return h!==void 0&&h($,k)?(E=R,$):(E=R,C=k)}var S=!1,E,C,T=c===void 0?null:c;return[function(){return _(s())},T===null?void 0:function(){return _(T())}]},[s,c,d,h]);var v=r(o,m[0],m[1]);return a(function(){y.hasValue=!0,y.value=v},[v]),l(v),v},r7}var pK;function Yje(){return pK||(pK=1,n7.exports=Xje()),n7.exports}Yje();function Gje(e){e()}function Kje(){let e=null,t=null;return{clear(){e=null,t=null},notify(){Gje(()=>{let n=e;for(;n;)n.callback(),n=n.next})},get(){const n=[];let r=e;for(;r;)n.push(r),r=r.next;return n},subscribe(n){let r=!0;const i=t={callback:n,next:null,prev:t};return i.prev?i.prev.next=i:e=i,function(){!r||e===null||(r=!1,i.next?i.next.prev=i.prev:t=i.prev,i.prev?i.prev.next=i.next:e=i.next)}}}}var mK={notify(){},get:()=>[]};function Wje(e,t){let n,r=mK,i=0,a=!1;function u(v){c();const _=r.subscribe(v);let S=!1;return()=>{S||(S=!0,_(),d())}}function l(){r.notify()}function o(){y.onStateChange&&y.onStateChange()}function s(){return a}function c(){i++,n||(n=e.subscribe(o),r=Kje())}function d(){i--,n&&i===0&&(n(),n=void 0,r.clear(),r=mK)}function h(){a||(a=!0,c())}function m(){a&&(a=!1,d())}const y={addNestedSub:u,notifyNestedSubs:l,handleChangeWrapper:o,isSubscribed:s,trySubscribe:h,tryUnsubscribe:m,getListeners:()=>r};return y}var Jje=()=>typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u",eZe=Jje(),tZe=()=>typeof navigator<"u"&&navigator.product==="ReactNative",nZe=tZe(),rZe=()=>eZe||nZe?P.useLayoutEffect:P.useEffect,iZe=rZe(),i7=Symbol.for("react-redux-context"),a7=typeof globalThis<"u"?globalThis:{};function aZe(){if(!P.createContext)return{};const e=a7[i7]??(a7[i7]=new Map);let t=e.get(P.createContext);return t||(t=P.createContext(null),e.set(P.createContext,t)),t}var uZe=aZe();function lZe(e){const{children:t,context:n,serverState:r,store:i}=e,a=P.useMemo(()=>{const o=Wje(i);return{store:i,subscription:o,getServerState:r?()=>r:void 0}},[i,r]),u=P.useMemo(()=>i.getState(),[i]);iZe(()=>{const{subscription:o}=a;return o.onStateChange=o.notifyNestedSubs,o.trySubscribe(),u!==i.getState()&&o.notifyNestedSubs(),()=>{o.tryUnsubscribe(),o.onStateChange=void 0}},[a,u]);const l=n||uZe;return P.createElement(l.Provider,{value:a},t)}var Gut=lZe,B2={exports:{}};/**
 * @license
 * Lodash <https://lodash.com/>
 * Copyright OpenJS Foundation and other contributors <https://openjsf.org/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */var oZe=B2.exports,gK;function sZe(){return gK||(gK=1,(function(e,t){(function(){var n,r="4.17.21",i=200,a="Unsupported core-js use. Try https://npms.io/search?q=ponyfill.",u="Expected a function",l="Invalid `variable` option passed into `_.template`",o="__lodash_hash_undefined__",s=500,c="__lodash_placeholder__",d=1,h=2,m=4,y=1,v=2,_=1,S=2,E=4,C=8,T=16,R=32,$=64,k=128,F=256,L=512,j=30,V="...",q=800,N=16,U=1,W=2,G=3,J=1/0,te=9007199254740991,H=17976931348623157e292,M=NaN,K=4294967295,X=K-1,B=K>>>1,ne=[["ary",k],["bind",_],["bindKey",S],["curry",C],["curryRight",T],["flip",L],["partial",R],["partialRight",$],["rearg",F]],oe="[object Arguments]",ie="[object Array]",de="[object AsyncFunction]",be="[object Boolean]",ve="[object Date]",pe="[object DOMException]",_e="[object Error]",se="[object Function]",me="[object GeneratorFunction]",ge="[object Map]",we="[object Number]",Ne="[object Null]",Re="[object Object]",et="[object Promise]",tt="[object Proxy]",Oe="[object RegExp]",$e="[object Set]",Ae="[object String]",Ue="[object Symbol]",Ze="[object Undefined]",Ye="[object WeakMap]",Me="[object WeakSet]",ze="[object ArrayBuffer]",st="[object DataView]",Ot="[object Float32Array]",Nt="[object Float64Array]",gt="[object Int8Array]",qt="[object Int16Array]",zt="[object Int32Array]",an="[object Uint8Array]",rn="[object Uint8ClampedArray]",Fe="[object Uint16Array]",ht="[object Uint32Array]",Tt=/\b__p \+= '';/g,Qt=/\b(__p \+=) '' \+/g,un=/(__e\(.*?\)|\b__t\)) \+\n'';/g,Ln=/&(?:amp|lt|gt|quot|#39);/g,ln=/[&<>"']/g,Zn=RegExp(Ln.source),cr=RegExp(ln.source),ur=/<%-([\s\S]+?)%>/g,Cr=/<%([\s\S]+?)%>/g,Vr=/<%=([\s\S]+?)%>/g,ke=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,He=/^\w*$/,nt=/[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g,dt=/[\\^$.*+?()[\]{}|]/g,$t=RegExp(dt.source),Ut=/^\s+/,Zt=/\s/,Lt=/\{(?:\n\/\* \[wrapped with .+\] \*\/)?\n?/,Vt=/\{\n\/\* \[wrapped with (.+)\] \*/,tn=/,? & /,nn=/[^\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]+/g,Rt=/[()=,{}\[\]\/\s]/,sn=/\\(\\)?/g,gr=/\$\{([^\\}]*(?:\\.[^\\}]*)*)\}/g,Pi=/\w*$/,Da=/^[-+]0x[0-9a-f]+$/i,mi=/^0b[01]+$/i,Ur=/^\[object .+?Constructor\]$/,wu=/^0o[0-7]+$/i,Al=/^(?:0|[1-9]\d*)$/,Hr=/[\xc0-\xd6\xd8-\xf6\xf8-\xff\u0100-\u017f]/g,Pt=/($^)/,ca=/['\n\r\u2028\u2029\\]/g,Wi="\\ud800-\\udfff",ti="\\u0300-\\u036f",Ru="\\ufe20-\\ufe2f",uo="\\u20d0-\\u20ff",Xn=ti+Ru+uo,gi="\\u2700-\\u27bf",xs="a-z\\xdf-\\xf6\\xf8-\\xff",Ss="\\xac\\xb1\\xd7\\xf7",ni="\\x00-\\x2f\\x3a-\\x40\\x5b-\\x60\\x7b-\\xbf",_s="\\u2000-\\u206f",$a=" \\t\\x0b\\f\\xa0\\ufeff\\n\\r\\u2028\\u2029\\u1680\\u180e\\u2000\\u2001\\u2002\\u2003\\u2004\\u2005\\u2006\\u2007\\u2008\\u2009\\u200a\\u202f\\u205f\\u3000",pc="A-Z\\xc0-\\xd6\\xd8-\\xde",Fr="\\ufe0e\\ufe0f",Ji=Ss+ni+_s+$a,Io="['’]",Op="["+Wi+"]",mf="["+Ji+"]",Lo="["+Xn+"]",Tl="\\d+",oh="["+gi+"]",Ha="["+xs+"]",td="[^"+Wi+Ji+Tl+gi+xs+pc+"]",Es="\\ud83c[\\udffb-\\udfff]",nd="(?:"+Lo+"|"+Es+")",mc="[^"+Wi+"]",gc="(?:\\ud83c[\\udde6-\\uddff]){2}",Bo="[\\ud800-\\udbff][\\udc00-\\udfff]",Au="["+pc+"]",Ds="\\u200d",$s="(?:"+Ha+"|"+td+")",Z0="(?:"+Au+"|"+td+")",gf="(?:"+Io+"(?:d|ll|m|re|s|t|ve))?",H0="(?:"+Io+"(?:D|LL|M|RE|S|T|VE))?",xp=nd+"?",vf="["+Fr+"]?",lo="(?:"+Ds+"(?:"+[mc,gc,Bo].join("|")+")"+vf+xp+")*",sh="\\d*(?:1st|2nd|3rd|(?![123])\\dth)(?=\\b|[A-Z_])",ch="\\d*(?:1ST|2ND|3RD|(?![123])\\dTH)(?=\\b|[a-z_])",Cs=vf+xp+lo,vc="(?:"+[oh,gc,Bo].join("|")+")"+Cs,X0="(?:"+[mc+Lo+"?",Lo,gc,Bo,Op].join("|")+")",Sp=RegExp(Io,"g"),_p=RegExp(Lo,"g"),ws=RegExp(Es+"(?="+Es+")|"+X0+Cs,"g"),Qo=RegExp([Au+"?"+Ha+"+"+gf+"(?="+[mf,Au,"$"].join("|")+")",Z0+"+"+H0+"(?="+[mf,Au+$s,"$"].join("|")+")",Au+"?"+$s+"+"+gf,Au+"+"+H0,ch,sh,Tl,vc].join("|"),"g"),Ep=RegExp("["+Ds+Wi+Xn+Fr+"]"),fh=/[a-z][A-Z]|[A-Z]{2}[a-z]|[0-9][a-zA-Z]|[a-zA-Z][0-9]|[^a-zA-Z0-9 ]/,yc=["Array","Buffer","DataView","Date","Error","Float32Array","Float64Array","Function","Int8Array","Int16Array","Int32Array","Map","Math","Object","Promise","RegExp","Set","String","Symbol","TypeError","Uint8Array","Uint8ClampedArray","Uint16Array","Uint32Array","WeakMap","_","clearTimeout","isFinite","parseInt","setTimeout"],dh=-1,wr={};wr[Ot]=wr[Nt]=wr[gt]=wr[qt]=wr[zt]=wr[an]=wr[rn]=wr[Fe]=wr[ht]=!0,wr[oe]=wr[ie]=wr[ze]=wr[be]=wr[st]=wr[ve]=wr[_e]=wr[se]=wr[ge]=wr[we]=wr[Re]=wr[Oe]=wr[$e]=wr[Ae]=wr[Ye]=!1;var Bn={};Bn[oe]=Bn[ie]=Bn[ze]=Bn[st]=Bn[be]=Bn[ve]=Bn[Ot]=Bn[Nt]=Bn[gt]=Bn[qt]=Bn[zt]=Bn[ge]=Bn[we]=Bn[Re]=Bn[Oe]=Bn[$e]=Bn[Ae]=Bn[Ue]=Bn[an]=Bn[rn]=Bn[Fe]=Bn[ht]=!0,Bn[_e]=Bn[se]=Bn[Ye]=!1;var bc={À:"A",Á:"A",Â:"A",Ã:"A",Ä:"A",Å:"A",à:"a",á:"a",â:"a",ã:"a",ä:"a",å:"a",Ç:"C",ç:"c",Ð:"D",ð:"d",È:"E",É:"E",Ê:"E",Ë:"E",è:"e",é:"e",ê:"e",ë:"e",Ì:"I",Í:"I",Î:"I",Ï:"I",ì:"i",í:"i",î:"i",ï:"i",Ñ:"N",ñ:"n",Ò:"O",Ó:"O",Ô:"O",Õ:"O",Ö:"O",Ø:"O",ò:"o",ó:"o",ô:"o",õ:"o",ö:"o",ø:"o",Ù:"U",Ú:"U",Û:"U",Ü:"U",ù:"u",ú:"u",û:"u",ü:"u",Ý:"Y",ý:"y",ÿ:"y",Æ:"Ae",æ:"ae",Þ:"Th",þ:"th",ß:"ss",Ā:"A",Ă:"A",Ą:"A",ā:"a",ă:"a",ą:"a",Ć:"C",Ĉ:"C",Ċ:"C",Č:"C",ć:"c",ĉ:"c",ċ:"c",č:"c",Ď:"D",Đ:"D",ď:"d",đ:"d",Ē:"E",Ĕ:"E",Ė:"E",Ę:"E",Ě:"E",ē:"e",ĕ:"e",ė:"e",ę:"e",ě:"e",Ĝ:"G",Ğ:"G",Ġ:"G",Ģ:"G",ĝ:"g",ğ:"g",ġ:"g",ģ:"g",Ĥ:"H",Ħ:"H",ĥ:"h",ħ:"h",Ĩ:"I",Ī:"I",Ĭ:"I",Į:"I",İ:"I",ĩ:"i",ī:"i",ĭ:"i",į:"i",ı:"i",Ĵ:"J",ĵ:"j",Ķ:"K",ķ:"k",ĸ:"k",Ĺ:"L",Ļ:"L",Ľ:"L",Ŀ:"L",Ł:"L",ĺ:"l",ļ:"l",ľ:"l",ŀ:"l",ł:"l",Ń:"N",Ņ:"N",Ň:"N",Ŋ:"N",ń:"n",ņ:"n",ň:"n",ŋ:"n",Ō:"O",Ŏ:"O",Ő:"O",ō:"o",ŏ:"o",ő:"o",Ŕ:"R",Ŗ:"R",Ř:"R",ŕ:"r",ŗ:"r",ř:"r",Ś:"S",Ŝ:"S",Ş:"S",Š:"S",ś:"s",ŝ:"s",ş:"s",š:"s",Ţ:"T",Ť:"T",Ŧ:"T",ţ:"t",ť:"t",ŧ:"t",Ũ:"U",Ū:"U",Ŭ:"U",Ů:"U",Ű:"U",Ų:"U",ũ:"u",ū:"u",ŭ:"u",ů:"u",ű:"u",ų:"u",Ŵ:"W",ŵ:"w",Ŷ:"Y",ŷ:"y",Ÿ:"Y",Ź:"Z",Ż:"Z",Ž:"Z",ź:"z",ż:"z",ž:"z",Ĳ:"IJ",ĳ:"ij",Œ:"Oe",œ:"oe",ŉ:"'n",ſ:"s"},zo={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"},Oc={"&amp;":"&","&lt;":"<","&gt;":">","&quot;":'"',"&#39;":"'"},ea={"\\":"\\","'":"'","\n":"n","\r":"r","\u2028":"u2028","\u2029":"u2029"},Rs=parseFloat,rd=parseInt,kl=typeof Hd=="object"&&Hd&&Hd.Object===Object&&Hd,id=typeof self=="object"&&self&&self.Object===Object&&self,ta=kl||id||Function("return this")(),As=t&&!t.nodeType&&t,Pl=As&&!0&&e&&!e.nodeType&&e,ad=Pl&&Pl.exports===As,Dp=ad&&kl.process,ri=(function(){try{var Xe=Pl&&Pl.require&&Pl.require("util").types;return Xe||Dp&&Dp.binding&&Dp.binding("util")}catch{}})(),Y0=ri&&ri.isArrayBuffer,G0=ri&&ri.isDate,ud=ri&&ri.isMap,K0=ri&&ri.isRegExp,xc=ri&&ri.isSet,ld=ri&&ri.isTypedArray;function fa(Xe,pt,rt){switch(rt.length){case 0:return Xe.call(pt);case 1:return Xe.call(pt,rt[0]);case 2:return Xe.call(pt,rt[0],rt[1]);case 3:return Xe.call(pt,rt[0],rt[1],rt[2])}return Xe.apply(pt,rt)}function od(Xe,pt,rt,Bt){for(var Dn=-1,rr=Xe==null?0:Xe.length;++Dn<rr;){var Fi=Xe[Dn];pt(Bt,Fi,rt(Fi),Xe)}return Bt}function La(Xe,pt){for(var rt=-1,Bt=Xe==null?0:Xe.length;++rt<Bt&&pt(Xe[rt],rt,Xe)!==!1;);return Xe}function _g(Xe,pt){for(var rt=Xe==null?0:Xe.length;rt--&&pt(Xe[rt],rt,Xe)!==!1;);return Xe}function $p(Xe,pt){for(var rt=-1,Bt=Xe==null?0:Xe.length;++rt<Bt;)if(!pt(Xe[rt],rt,Xe))return!1;return!0}function qo(Xe,pt){for(var rt=-1,Bt=Xe==null?0:Xe.length,Dn=0,rr=[];++rt<Bt;){var Fi=Xe[rt];pt(Fi,rt,Xe)&&(rr[Dn++]=Fi)}return rr}function hh(Xe,pt){var rt=Xe==null?0:Xe.length;return!!rt&&Xu(Xe,pt,0)>-1}function Ts(Xe,pt,rt){for(var Bt=-1,Dn=Xe==null?0:Xe.length;++Bt<Dn;)if(rt(pt,Xe[Bt]))return!0;return!1}function vi(Xe,pt){for(var rt=-1,Bt=Xe==null?0:Xe.length,Dn=Array(Bt);++rt<Bt;)Dn[rt]=pt(Xe[rt],rt,Xe);return Dn}function Vo(Xe,pt){for(var rt=-1,Bt=pt.length,Dn=Xe.length;++rt<Bt;)Xe[Dn+rt]=pt[rt];return Xe}function Cp(Xe,pt,rt,Bt){var Dn=-1,rr=Xe==null?0:Xe.length;for(Bt&&rr&&(rt=Xe[++Dn]);++Dn<rr;)rt=pt(rt,Xe[Dn],Dn,Xe);return rt}function wp(Xe,pt,rt,Bt){var Dn=Xe==null?0:Xe.length;for(Bt&&Dn&&(rt=Xe[--Dn]);Dn--;)rt=pt(rt,Xe[Dn],Dn,Xe);return rt}function Rp(Xe,pt){for(var rt=-1,Bt=Xe==null?0:Xe.length;++rt<Bt;)if(pt(Xe[rt],rt,Xe))return!0;return!1}var ks=Uo("length");function Ap(Xe){return Xe.split("")}function Dy(Xe){return Xe.match(nn)||[]}function W0(Xe,pt,rt){var Bt;return rt(Xe,function(Dn,rr,Fi){if(pt(Dn,rr,Fi))return Bt=rr,!1}),Bt}function oo(Xe,pt,rt,Bt){for(var Dn=Xe.length,rr=rt+(Bt?1:-1);Bt?rr--:++rr<Dn;)if(pt(Xe[rr],rr,Xe))return rr;return-1}function Xu(Xe,pt,rt){return pt===pt?Eg(Xe,pt,rt):oo(Xe,ph,rt)}function J0(Xe,pt,rt,Bt){for(var Dn=rt-1,rr=Xe.length;++Dn<rr;)if(Bt(Xe[Dn],pt))return Dn;return-1}function ph(Xe){return Xe!==Xe}function Sc(Xe,pt){var rt=Xe==null?0:Xe.length;return rt?gh(Xe,pt)/rt:M}function Uo(Xe){return function(pt){return pt==null?n:pt[Xe]}}function Ps(Xe){return function(pt){return Xe==null?n:Xe[pt]}}function Ba(Xe,pt,rt,Bt,Dn){return Dn(Xe,function(rr,Fi,Nr){rt=Bt?(Bt=!1,rr):pt(rt,rr,Fi,Nr)}),rt}function mh(Xe,pt){var rt=Xe.length;for(Xe.sort(pt);rt--;)Xe[rt]=Xe[rt].value;return Xe}function gh(Xe,pt){for(var rt,Bt=-1,Dn=Xe.length;++Bt<Dn;){var rr=pt(Xe[Bt]);rr!==n&&(rt=rt===n?rr:rt+rr)}return rt}function sd(Xe,pt){for(var rt=-1,Bt=Array(Xe);++rt<Xe;)Bt[rt]=pt(rt);return Bt}function cd(Xe,pt){return vi(pt,function(rt){return[rt,Xe[rt]]})}function Ms(Xe){return Xe&&Xe.slice(0,Of(Xe)+1).replace(Ut,"")}function fu(Xe){return function(pt){return Xe(pt)}}function Tp(Xe,pt){return vi(pt,function(rt){return Xe[rt]})}function Xa(Xe,pt){return Xe.has(pt)}function kp(Xe,pt){for(var rt=-1,Bt=Xe.length;++rt<Bt&&Xu(pt,Xe[rt],0)>-1;);return rt}function fd(Xe,pt){for(var rt=Xe.length;rt--&&Xu(pt,Xe[rt],0)>-1;);return rt}function yf(Xe,pt){for(var rt=Xe.length,Bt=0;rt--;)Xe[rt]===pt&&++Bt;return Bt}var dd=Ps(bc),Yu=Ps(zo);function so(Xe){return"\\"+ea[Xe]}function em(Xe,pt){return Xe==null?n:Xe[pt]}function du(Xe){return Ep.test(Xe)}function bf(Xe){return fh.test(Xe)}function Sr(Xe){for(var pt,rt=[];!(pt=Xe.next()).done;)rt.push(pt.value);return rt}function vh(Xe){var pt=-1,rt=Array(Xe.size);return Xe.forEach(function(Bt,Dn){rt[++pt]=[Dn,Bt]}),rt}function Pp(Xe,pt){return function(rt){return Xe(pt(rt))}}function co(Xe,pt){for(var rt=-1,Bt=Xe.length,Dn=0,rr=[];++rt<Bt;){var Fi=Xe[rt];(Fi===pt||Fi===c)&&(Xe[rt]=c,rr[Dn++]=rt)}return rr}function Kn(Xe){var pt=-1,rt=Array(Xe.size);return Xe.forEach(function(Bt){rt[++pt]=Bt}),rt}function yl(Xe){var pt=-1,rt=Array(Xe.size);return Xe.forEach(function(Bt){rt[++pt]=[Bt,Bt]}),rt}function Eg(Xe,pt,rt){for(var Bt=rt-1,Dn=Xe.length;++Bt<Dn;)if(Xe[Bt]===pt)return Bt;return-1}function Mi(Xe,pt,rt){for(var Bt=rt+1;Bt--;)if(Xe[Bt]===pt)return Bt;return Bt}function hu(Xe){return du(Xe)?nm(Xe):ks(Xe)}function fr(Xe){return du(Xe)?vr(Xe):Ap(Xe)}function Of(Xe){for(var pt=Xe.length;pt--&&Zt.test(Xe.charAt(pt)););return pt}var tm=Ps(Oc);function nm(Xe){for(var pt=ws.lastIndex=0;ws.test(Xe);)++pt;return pt}function vr(Xe){return Xe.match(ws)||[]}function rm(Xe){return Xe.match(Qo)||[]}var xf=(function Xe(pt){pt=pt==null?ta:_c.defaults(ta.Object(),pt,_c.pick(ta,yc));var rt=pt.Array,Bt=pt.Date,Dn=pt.Error,rr=pt.Function,Fi=pt.Math,Nr=pt.Object,Ya=pt.RegExp,Ec=pt.String,_i=pt.TypeError,hd=rt.prototype,Ml=rr.prototype,fo=Nr.prototype,ho=pt["__core-js_shared__"],Sf=Ml.toString,_r=fo.hasOwnProperty,jo=0,yh=(function(){var x=/[^.]+$/.exec(ho&&ho.keys&&ho.keys.IE_PROTO||"");return x?"Symbol(src)_1."+x:""})(),da=fo.toString,Zo=Sf.call(Nr),Ca=ta._,po=Ya("^"+Sf.call(_r).replace(dt,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),Fs=ad?pt.Buffer:n,Ga=pt.Symbol,Gu=pt.Uint8Array,Dc=Fs?Fs.allocUnsafe:n,Ku=Pp(Nr.getPrototypeOf,Nr),$c=Nr.create,Cc=fo.propertyIsEnumerable,pu=hd.splice,pd=Ga?Ga.isConcatSpreadable:n,na=Ga?Ga.iterator:n,Xi=Ga?Ga.toStringTag:n,Wu=(function(){try{var x=nu(Nr,"defineProperty");return x({},"",{}),x}catch{}})(),mu=pt.clearTimeout!==ta.clearTimeout&&pt.clearTimeout,bh=Bt&&Bt.now!==ta.Date.now&&Bt.now,Fl=pt.setTimeout!==ta.setTimeout&&pt.setTimeout,_f=Fi.ceil,Oh=Fi.floor,gu=Nr.getOwnPropertySymbols,Mp=Fs?Fs.isBuffer:n,Tu=pt.isFinite,Nl=hd.join,wc=Pp(Nr.keys,Nr),Ni=Fi.max,Ei=Fi.min,ku=Bt.now,pn=pt.parseInt,Pu=Fi.random,Ho=hd.reverse,ue=nu(pt,"DataView"),I=nu(pt,"Map"),re=nu(pt,"Promise"),fe=nu(pt,"Set"),xe=nu(pt,"WeakMap"),Te=nu(Nr,"create"),Qe=xe&&new xe,Be={},je=iu(ue),Ct=iu(I),Kt=iu(re),Qn=iu(fe),cn=iu(xe),vn=Ga?Ga.prototype:n,Di=vn?vn.valueOf:n,Qa=vn?vn.toString:n;function Se(x){if(Ua(x)&&!Wn(x)&&!(x instanceof zn)){if(x instanceof Mu)return x;if(_r.call(x,"__wrapped__"))return _o(x)}return new Mu(x)}var bl=(function(){function x(){}return function(w){if(!va(w))return{};if($c)return $c(w);x.prototype=w;var Z=new x;return x.prototype=n,Z}})();function Il(){}function Mu(x,w){this.__wrapped__=x,this.__actions__=[],this.__chain__=!!w,this.__index__=0,this.__values__=n}Se.templateSettings={escape:ur,evaluate:Cr,interpolate:Vr,variable:"",imports:{_:Se}},Se.prototype=Il.prototype,Se.prototype.constructor=Se,Mu.prototype=bl(Il.prototype),Mu.prototype.constructor=Mu;function zn(x){this.__wrapped__=x,this.__actions__=[],this.__dir__=1,this.__filtered__=!1,this.__iteratees__=[],this.__takeCount__=K,this.__views__=[]}function Ka(){var x=new zn(this.__wrapped__);return x.__actions__=rl(this.__actions__),x.__dir__=this.__dir__,x.__filtered__=this.__filtered__,x.__iteratees__=rl(this.__iteratees__),x.__takeCount__=this.__takeCount__,x.__views__=rl(this.__views__),x}function Ns(){if(this.__filtered__){var x=new zn(this);x.__dir__=-1,x.__filtered__=!0}else x=this.clone(),x.__dir__*=-1;return x}function Ll(){var x=this.__wrapped__.value(),w=this.__dir__,Z=Wn(x),ae=w<0,he=Z?x.length:0,Ce=gm(0,he,this.__views__),Pe=Ce.start,qe=Ce.end,Je=qe-Pe,St=ae?qe:Pe-1,_t=this.__iteratees__,wt=_t.length,Jt=0,On=Ei(Je,this.__takeCount__);if(!Z||!ae&&he==Je&&On==Je)return zy(x,this.__actions__);var Vn=[];e:for(;Je--&&Jt<On;){St+=w;for(var br=-1,Un=x[St];++br<wt;){var Qr=_t[br],Wr=Qr.iteratee,Pf=Qr.type,Js=Wr(Un);if(Pf==W)Un=Js;else if(!Js){if(Pf==U)continue e;break e}}Vn[Jt++]=Un}return Vn}zn.prototype=bl(Il.prototype),zn.prototype.constructor=zn;function Fu(x){var w=-1,Z=x==null?0:x.length;for(this.clear();++w<Z;){var ae=x[w];this.set(ae[0],ae[1])}}function Rc(){this.__data__=Te?Te(null):{},this.size=0}function Bl(x){var w=this.has(x)&&delete this.__data__[x];return this.size-=w?1:0,w}function md(x){var w=this.__data__;if(Te){var Z=w[x];return Z===o?n:Z}return _r.call(w,x)?w[x]:n}function xh(x){var w=this.__data__;return Te?w[x]!==n:_r.call(w,x)}function vu(x,w){var Z=this.__data__;return this.size+=this.has(x)?0:1,Z[x]=Te&&w===n?o:w,this}Fu.prototype.clear=Rc,Fu.prototype.delete=Bl,Fu.prototype.get=md,Fu.prototype.has=xh,Fu.prototype.set=vu;function mo(x){var w=-1,Z=x==null?0:x.length;for(this.clear();++w<Z;){var ae=x[w];this.set(ae[0],ae[1])}}function $y(){this.__data__=[],this.size=0}function Nb(x){var w=this.__data__,Z=_n(w,x);if(Z<0)return!1;var ae=w.length-1;return Z==ae?w.pop():pu.call(w,Z,1),--this.size,!0}function Ib(x){var w=this.__data__,Z=_n(w,x);return Z<0?n:w[Z][1]}function Cy(x){return _n(this.__data__,x)>-1}function yn(x,w){var Z=this.__data__,ae=_n(Z,x);return ae<0?(++this.size,Z.push([x,w])):Z[ae][1]=w,this}mo.prototype.clear=$y,mo.prototype.delete=Nb,mo.prototype.get=Ib,mo.prototype.has=Cy,mo.prototype.set=yn;function Is(x){var w=-1,Z=x==null?0:x.length;for(this.clear();++w<Z;){var ae=x[w];this.set(ae[0],ae[1])}}function Nu(){this.size=0,this.__data__={hash:new Fu,map:new(I||mo),string:new Fu}}function Sh(x){var w=Rd(this,x).delete(x);return this.size-=w?1:0,w}function wy(x){return Rd(this,x).get(x)}function Ef(x){return Rd(this,x).has(x)}function Ls(x,w){var Z=Rd(this,x),ae=Z.size;return Z.set(x,w),this.size+=Z.size==ae?0:1,this}Is.prototype.clear=Nu,Is.prototype.delete=Sh,Is.prototype.get=wy,Is.prototype.has=Ef,Is.prototype.set=Ls;function Xo(x){var w=-1,Z=x==null?0:x.length;for(this.__data__=new Is;++w<Z;)this.add(x[w])}function Ry(x){return this.__data__.set(x,o),this}function Ay(x){return this.__data__.has(x)}Xo.prototype.add=Xo.prototype.push=Ry,Xo.prototype.has=Ay;function Yo(x){var w=this.__data__=new mo(x);this.size=w.size}function gd(){this.__data__=new mo,this.size=0}function Ac(x){var w=this.__data__,Z=w.delete(x);return this.size=w.size,Z}function Fp(x){return this.__data__.get(x)}function Dg(x){return this.__data__.has(x)}function vd(x,w){var Z=this.__data__;if(Z instanceof mo){var ae=Z.__data__;if(!I||ae.length<i-1)return ae.push([x,w]),this.size=++Z.size,this;Z=this.__data__=new Is(ae)}return Z.set(x,w),this.size=Z.size,this}Yo.prototype.clear=gd,Yo.prototype.delete=Ac,Yo.prototype.get=Fp,Yo.prototype.has=Dg,Yo.prototype.set=vd;function Np(x,w){var Z=Wn(x),ae=!Z&&Cm(x),he=!Z&&!ae&&Gp(x),Ce=!Z&&!ae&&!he&&Kp(x),Pe=Z||ae||he||Ce,qe=Pe?sd(x.length,Ec):[],Je=qe.length;for(var St in x)(w||_r.call(x,St))&&!(Pe&&(St=="length"||he&&(St=="offset"||St=="parent")||Ce&&(St=="buffer"||St=="byteLength"||St=="byteOffset")||Oo(St,Je)))&&qe.push(St);return qe}function Go(x){var w=x.length;return w?x[zp(0,w-1)]:n}function im(x,w){return Zs(rl(x),Qs(w,0,x.length))}function Lb(x){return Zs(rl(x))}function am(x,w,Z){(Z!==n&&!Gs(x[w],Z)||Z===n&&!(w in x))&&Ju(x,w,Z)}function Bs(x,w,Z){var ae=x[w];(!(_r.call(x,w)&&Gs(ae,Z))||Z===n&&!(w in x))&&Ju(x,w,Z)}function _n(x,w){for(var Z=x.length;Z--;)if(Gs(x[Z][0],w))return Z;return-1}function $g(x,w,Z,ae){return Tc(x,function(he,Ce,Pe){w(ae,he,Z(he),Pe)}),ae}function Cg(x,w){return x&&ts(w,fl(w),x)}function yd(x,w){return x&&ts(w,ss(w),x)}function Ju(x,w,Z){w=="__proto__"&&Wu?Wu(x,w,{configurable:!0,enumerable:!0,value:Z,writable:!0}):x[w]=Z}function Ip(x,w){for(var Z=-1,ae=w.length,he=rt(ae),Ce=x==null;++Z<ae;)he[Z]=Ce?n:Wp(x,w[Z]);return he}function Qs(x,w,Z){return x===x&&(Z!==n&&(x=x<=Z?x:Z),w!==n&&(x=x>=w?x:w)),x}function el(x,w,Z,ae,he,Ce){var Pe,qe=w&d,Je=w&h,St=w&m;if(Z&&(Pe=he?Z(x,ae,he,Ce):Z(x)),Pe!==n)return Pe;if(!va(x))return x;var _t=Wn(x);if(_t){if(Pe=ul(x),!qe)return rl(x,Pe)}else{var wt=Ir(x),Jt=wt==se||wt==me;if(Gp(x))return Uy(x,qe);if(wt==Re||wt==oe||Jt&&!he){if(Pe=Je||Jt?{}:xu(x),!qe)return Je?Zy(x,yd(Pe,x)):jy(x,Cg(Pe,x))}else{if(!Bn[wt])return he?x:{};Pe=Lr(x,wt,qe)}}Ce||(Ce=new Yo);var On=Ce.get(x);if(On)return On;Ce.set(x,Pe),l1(x)?x.forEach(function(Un){Pe.add(el(Un,w,Z,Un,x,Ce))}):YS(x)&&x.forEach(function(Un,Qr){Pe.set(Qr,el(Un,w,Z,Qr,x,Ce))});var Vn=St?Je?Ol:al:Je?ss:fl,br=_t?n:Vn(x);return La(br||x,function(Un,Qr){br&&(Qr=Un,Un=x[Qr]),Bs(Pe,Qr,el(Un,w,Z,Qr,x,Ce))}),Pe}function Lp(x){var w=fl(x);return function(Z){return bd(Z,x,w)}}function bd(x,w,Z){var ae=Z.length;if(x==null)return!ae;for(x=Nr(x);ae--;){var he=Z[ae],Ce=w[he],Pe=x[he];if(Pe===n&&!(he in x)||!Ce(Pe))return!1}return!0}function Ty(x,w,Z){if(typeof x!="function")throw new _i(u);return kd(function(){x.apply(n,Z)},w)}function Ko(x,w,Z,ae){var he=-1,Ce=hh,Pe=!0,qe=x.length,Je=[],St=w.length;if(!qe)return Je;Z&&(w=vi(w,fu(Z))),ae?(Ce=Ts,Pe=!1):w.length>=i&&(Ce=Xa,Pe=!1,w=new Xo(w));e:for(;++he<qe;){var _t=x[he],wt=Z==null?_t:Z(_t);if(_t=ae||_t!==0?_t:0,Pe&&wt===wt){for(var Jt=St;Jt--;)if(w[Jt]===wt)continue e;Je.push(_t)}else Ce(w,wt,ae)||Je.push(_t)}return Je}var Tc=Hy(Ja),wg=Hy(eu,!0);function kc(x,w){var Z=!0;return Tc(x,function(ae,he,Ce){return Z=!!w(ae,he,Ce),Z}),Z}function Wo(x,w,Z){for(var ae=-1,he=x.length;++ae<he;){var Ce=x[ae],Pe=w(Ce);if(Pe!=null&&(qe===n?Pe===Pe&&!os(Pe):Z(Pe,qe)))var qe=Pe,Je=Ce}return Je}function Od(x,w,Z,ae){var he=x.length;for(Z=qn(Z),Z<0&&(Z=-Z>he?0:he+Z),ae=ae===n||ae>he?he:qn(ae),ae<0&&(ae+=he),ae=Z>ae?0:M4(ae);Z<ae;)x[Z++]=w;return x}function um(x,w){var Z=[];return Tc(x,function(ae,he,Ce){w(ae,he,Ce)&&Z.push(ae)}),Z}function Wa(x,w,Z,ae,he){var Ce=-1,Pe=x.length;for(Z||(Z=rs),he||(he=[]);++Ce<Pe;){var qe=x[Ce];w>0&&Z(qe)?w>1?Wa(qe,w-1,Z,ae,he):Vo(he,qe):ae||(he[he.length]=qe)}return he}var _h=jg(),xd=jg(!0);function Ja(x,w){return x&&_h(x,w,fl)}function eu(x,w){return x&&xd(x,w,fl)}function tl(x,w){return qo(w,function(Z){return Ks(x[Z])})}function wa(x,w){w=vo(w,x);for(var Z=0,ae=w.length;x!=null&&Z<ae;)x=x[ru(w[Z++])];return Z&&Z==ae?x:n}function Rg(x,w,Z){var ae=w(x);return Wn(x)?ae:Vo(ae,Z(x))}function Iu(x){return x==null?x===n?Ze:Ne:Xi&&Xi in Nr(x)?Vs(x):Td(x)}function yu(x,w){return x>w}function tu(x,w){return x!=null&&_r.call(x,w)}function Jo(x,w){return x!=null&&w in Nr(x)}function Sd(x,w,Z){return x>=Ei(w,Z)&&x<Ni(w,Z)}function lm(x,w,Z){for(var ae=Z?Ts:hh,he=x[0].length,Ce=x.length,Pe=Ce,qe=rt(Ce),Je=1/0,St=[];Pe--;){var _t=x[Pe];Pe&&w&&(_t=vi(_t,fu(w))),Je=Ei(_t.length,Je),qe[Pe]=!Z&&(w||he>=120&&_t.length>=120)?new Xo(Pe&&_t):n}_t=x[0];var wt=-1,Jt=qe[0];e:for(;++wt<he&&St.length<Je;){var On=_t[wt],Vn=w?w(On):On;if(On=Z||On!==0?On:0,!(Jt?Xa(Jt,Vn):ae(St,Vn,Z))){for(Pe=Ce;--Pe;){var br=qe[Pe];if(!(br?Xa(br,Vn):ae(x[Pe],Vn,Z)))continue e}Jt&&Jt.push(Vn),St.push(On)}}return St}function Bb(x,w,Z,ae){return Ja(x,function(he,Ce,Pe){w(ae,Z(he),Ce,Pe)}),ae}function go(x,w,Z){w=vo(w,x),x=Ph(x,w);var ae=x==null?x:x[ru(Br(w))];return ae==null?n:fa(ae,x,Z)}function Ql(x){return Ua(x)&&Iu(x)==oe}function ha(x){return Ua(x)&&Iu(x)==ze}function Ag(x){return Ua(x)&&Iu(x)==ve}function bu(x,w,Z,ae,he){return x===w?!0:x==null||w==null||!Ua(x)&&!Ua(w)?x!==x&&w!==w:Tn(x,w,Z,ae,bu,he)}function Tn(x,w,Z,ae,he,Ce){var Pe=Wn(x),qe=Wn(w),Je=Pe?ie:Ir(x),St=qe?ie:Ir(w);Je=Je==oe?Re:Je,St=St==oe?Re:St;var _t=Je==Re,wt=St==Re,Jt=Je==St;if(Jt&&Gp(x)){if(!Gp(w))return!1;Pe=!0,_t=!1}if(Jt&&!_t)return Ce||(Ce=new Yo),Pe||Kp(x)?mm(x,w,Z,ae,he,Ce):Hb(x,w,Je,Z,ae,he,Ce);if(!(Z&y)){var On=_t&&_r.call(x,"__wrapped__"),Vn=wt&&_r.call(w,"__wrapped__");if(On||Vn){var br=On?x.value():x,Un=Vn?w.value():w;return Ce||(Ce=new Yo),he(br,Un,Z,ae,Ce)}}return Jt?(Ce||(Ce=new Yo),Wy(x,w,Z,ae,he,Ce)):!1}function yi(x){return Ua(x)&&Ir(x)==ge}function pa(x,w,Z,ae){var he=Z.length,Ce=he,Pe=!ae;if(x==null)return!Ce;for(x=Nr(x);he--;){var qe=Z[he];if(Pe&&qe[2]?qe[1]!==x[qe[0]]:!(qe[0]in x))return!1}for(;++he<Ce;){qe=Z[he];var Je=qe[0],St=x[Je],_t=qe[1];if(Pe&&qe[2]){if(St===n&&!(Je in x))return!1}else{var wt=new Yo;if(ae)var Jt=ae(St,_t,Je,x,w,wt);if(!(Jt===n?bu(_t,St,y|v,ae,wt):Jt))return!1}}return!0}function om(x){if(!va(x)||kh(x))return!1;var w=Ks(x)?po:Ur;return w.test(iu(x))}function Pc(x){return Ua(x)&&Iu(x)==Oe}function Eh(x){return Ua(x)&&Ir(x)==$e}function Tg(x){return Ua(x)&&eO(x.length)&&!!wr[Iu(x)]}function Bp(x){return typeof x=="function"?x:x==null?Co:typeof x=="object"?Wn(x)?ky(x[0],x[1]):Pg(x):Ee(x)}function es(x){if(!Df(x))return wc(x);var w=[];for(var Z in Nr(x))_r.call(x,Z)&&Z!="constructor"&&w.push(Z);return w}function y4(x){if(!va(x))return jl(x);var w=Df(x),Z=[];for(var ae in x)ae=="constructor"&&(w||!_r.call(x,ae))||Z.push(ae);return Z}function Yi(x,w){return x<w}function kg(x,w){var Z=-1,ae=ls(x)?rt(x.length):[];return Tc(x,function(he,Ce,Pe){ae[++Z]=w(he,Ce,Pe)}),ae}function Pg(x){var w=xl(x);return w.length==1&&w[0][2]?$f(w[0][0],w[0][1]):function(Z){return Z===x||pa(Z,x,w)}}function ky(x,w){return Ic(x)&&is(w)?$f(ru(x),w):function(Z){var ae=Wp(Z,x);return ae===n&&ae===w?N4(Z,x):bu(w,ae,y|v)}}function sm(x,w,Z,ae,he){x!==w&&_h(w,function(Ce,Pe){if(he||(he=new Yo),va(Ce))b4(x,w,Pe,Z,sm,ae,he);else{var qe=ae?ae(Xr(x,Pe),Ce,Pe+"",x,w,he):n;qe===n&&(qe=Ce),am(x,Pe,qe)}},ss)}function b4(x,w,Z,ae,he,Ce,Pe){var qe=Xr(x,Z),Je=Xr(w,Z),St=Pe.get(Je);if(St){am(x,Z,St);return}var _t=Ce?Ce(qe,Je,Z+"",x,w,Pe):n,wt=_t===n;if(wt){var Jt=Wn(Je),On=!Jt&&Gp(Je),Vn=!Jt&&!On&&Kp(Je);_t=Je,Jt||On||Vn?Wn(qe)?_t=qe:uu(qe)?_t=rl(qe):On?(wt=!1,_t=Uy(Je,!0)):Vn?(wt=!1,_t=Vl(Je,!0)):_t=[]:a1(Je)||Cm(Je)?(_t=qe,Cm(qe)?_t=tO(qe):(!va(qe)||Ks(qe))&&(_t=xu(Je))):wt=!1}wt&&(Pe.set(Je,_t),he(_t,Je,ae,Ce,Pe),Pe.delete(Je)),am(x,Z,_t)}function Mg(x,w){var Z=x.length;if(Z)return w+=w<0?Z:0,Oo(w,Z)?x[w]:n}function Fg(x,w,Z){w.length?w=vi(w,function(Ce){return Wn(Ce)?function(Pe){return wa(Pe,Ce.length===1?Ce[0]:Ce)}:Ce}):w=[Co];var ae=-1;w=vi(w,fu(Sn()));var he=kg(x,function(Ce,Pe,qe){var Je=vi(w,function(St){return St(Ce)});return{criteria:Je,index:++ae,value:Ce}});return mh(he,function(Ce,Pe){return qg(Ce,Pe,Z)})}function Py(x,w){return nl(x,w,function(Z,ae){return N4(x,ae)})}function nl(x,w,Z){for(var ae=-1,he=w.length,Ce={};++ae<he;){var Pe=w[ae],qe=wa(x,Pe);Z(qe,Pe)&&$h(Ce,vo(Pe,x),qe)}return Ce}function Ra(x){return function(w){return wa(w,x)}}function Dh(x,w,Z,ae){var he=ae?J0:Xu,Ce=-1,Pe=w.length,qe=x;for(x===w&&(w=rl(w)),Z&&(qe=vi(x,fu(Z)));++Ce<Pe;)for(var Je=0,St=w[Ce],_t=Z?Z(St):St;(Je=he(qe,_t,Je,ae))>-1;)qe!==x&&pu.call(qe,Je,1),pu.call(x,Je,1);return x}function Qp(x,w){for(var Z=x?w.length:0,ae=Z-1;Z--;){var he=w[Z];if(Z==ae||he!==Ce){var Ce=he;Oo(he)?pu.call(x,he,1):qp(x,he)}}return x}function zp(x,w){return x+Oh(Pu()*(w-x+1))}function My(x,w,Z,ae){for(var he=-1,Ce=Ni(_f((w-x)/(Z||1)),0),Pe=rt(Ce);Ce--;)Pe[ae?Ce:++he]=x,x+=Z;return Pe}function zs(x,w){var Z="";if(!x||w<1||w>te)return Z;do w%2&&(Z+=x),w=Oh(w/2),w&&(x+=x);while(w);return Z}function Jn(x,w){return Cf(Lc(x,w,Co),x+"")}function Fy(x){return Go(ov(x))}function Ng(x,w){var Z=ov(x);return Zs(Z,Qs(w,0,Z.length))}function $h(x,w,Z,ae){if(!va(x))return x;w=vo(w,x);for(var he=-1,Ce=w.length,Pe=Ce-1,qe=x;qe!=null&&++he<Ce;){var Je=ru(w[he]),St=Z;if(Je==="__proto__"||Je==="constructor"||Je==="prototype")return x;if(he!=Pe){var _t=qe[Je];St=ae?ae(_t,Je,qe):n,St===n&&(St=va(_t)?_t:Oo(w[he+1])?[]:{})}Bs(qe,Je,St),qe=qe[Je]}return x}var Ny=Qe?function(x,w){return Qe.set(x,w),x}:Co,Iy=Wu?function(x,w){return Wu(x,"toString",{configurable:!0,enumerable:!1,value:cv(w),writable:!0})}:Co;function Ly(x){return Zs(ov(x))}function zl(x,w,Z){var ae=-1,he=x.length;w<0&&(w=-w>he?0:he+w),Z=Z>he?he:Z,Z<0&&(Z+=he),he=w>Z?0:Z-w>>>0,w>>>=0;for(var Ce=rt(he);++ae<he;)Ce[ae]=x[ae+w];return Ce}function Ig(x,w){var Z;return Tc(x,function(ae,he,Ce){return Z=w(ae,he,Ce),!Z}),!!Z}function _d(x,w,Z){var ae=0,he=x==null?ae:x.length;if(typeof w=="number"&&w===w&&he<=B){for(;ae<he;){var Ce=ae+he>>>1,Pe=x[Ce];Pe!==null&&!os(Pe)&&(Z?Pe<=w:Pe<w)?ae=Ce+1:he=Ce}return he}return Lg(x,w,Co,Z)}function Lg(x,w,Z,ae){var he=0,Ce=x==null?0:x.length;if(Ce===0)return 0;w=Z(w);for(var Pe=w!==w,qe=w===null,Je=os(w),St=w===n;he<Ce;){var _t=Oh((he+Ce)/2),wt=Z(x[_t]),Jt=wt!==n,On=wt===null,Vn=wt===wt,br=os(wt);if(Pe)var Un=ae||Vn;else St?Un=Vn&&(ae||Jt):qe?Un=Vn&&Jt&&(ae||!On):Je?Un=Vn&&Jt&&!On&&(ae||!br):On||br?Un=!1:Un=ae?wt<=w:wt<w;Un?he=_t+1:Ce=_t}return Ei(Ce,X)}function Qb(x,w){for(var Z=-1,ae=x.length,he=0,Ce=[];++Z<ae;){var Pe=x[Z],qe=w?w(Pe):Pe;if(!Z||!Gs(qe,Je)){var Je=qe;Ce[he++]=Pe===0?0:Pe}}return Ce}function By(x){return typeof x=="number"?x:os(x)?M:+x}function ql(x){if(typeof x=="string")return x;if(Wn(x))return vi(x,ql)+"";if(os(x))return Qa?Qa.call(x):"";var w=x+"";return w=="0"&&1/x==-J?"-0":w}function Mc(x,w,Z){var ae=-1,he=hh,Ce=x.length,Pe=!0,qe=[],Je=qe;if(Z)Pe=!1,he=Ts;else if(Ce>=i){var St=w?null:Zb(x);if(St)return Kn(St);Pe=!1,he=Xa,Je=new Xo}else Je=w?[]:qe;e:for(;++ae<Ce;){var _t=x[ae],wt=w?w(_t):_t;if(_t=Z||_t!==0?_t:0,Pe&&wt===wt){for(var Jt=Je.length;Jt--;)if(Je[Jt]===wt)continue e;w&&Je.push(wt),qe.push(_t)}else he(Je,wt,Z)||(Je!==qe&&Je.push(wt),qe.push(_t))}return qe}function qp(x,w){return w=vo(w,x),x=Ph(x,w),x==null||delete x[ru(Br(w))]}function Qy(x,w,Z,ae){return $h(x,w,Z(wa(x,w)),ae)}function cm(x,w,Z,ae){for(var he=x.length,Ce=ae?he:-1;(ae?Ce--:++Ce<he)&&w(x[Ce],Ce,x););return Z?zl(x,ae?0:Ce,ae?Ce+1:he):zl(x,ae?Ce+1:0,ae?he:Ce)}function zy(x,w){var Z=x;return Z instanceof zn&&(Z=Z.value()),Cp(w,function(ae,he){return he.func.apply(he.thisArg,Vo([ae],he.args))},Z)}function Bg(x,w,Z){var ae=x.length;if(ae<2)return ae?Mc(x[0]):[];for(var he=-1,Ce=rt(ae);++he<ae;)for(var Pe=x[he],qe=-1;++qe<ae;)qe!=he&&(Ce[he]=Ko(Ce[he]||Pe,x[qe],w,Z));return Mc(Wa(Ce,1),w,Z)}function qy(x,w,Z){for(var ae=-1,he=x.length,Ce=w.length,Pe={};++ae<he;){var qe=ae<Ce?w[ae]:n;Z(Pe,x[ae],qe)}return Pe}function Vy(x){return uu(x)?x:[]}function Qg(x){return typeof x=="function"?x:Co}function vo(x,w){return Wn(x)?x:Ic(x,w)?[x]:Gg(xi(x))}var zb=Jn;function qs(x,w,Z){var ae=x.length;return Z=Z===n?ae:Z,!w&&Z>=ae?x:zl(x,w,Z)}var fm=mu||function(x){return ta.clearTimeout(x)};function Uy(x,w){if(w)return x.slice();var Z=x.length,ae=Dc?Dc(Z):new x.constructor(Z);return x.copy(ae),ae}function dm(x){var w=new x.constructor(x.byteLength);return new Gu(w).set(new Gu(x)),w}function qb(x,w){var Z=w?dm(x.buffer):x.buffer;return new x.constructor(Z,x.byteOffset,x.byteLength)}function Vb(x){var w=new x.constructor(x.source,Pi.exec(x));return w.lastIndex=x.lastIndex,w}function Ub(x){return Di?Nr(Di.call(x)):{}}function Vl(x,w){var Z=w?dm(x.buffer):x.buffer;return new x.constructor(Z,x.byteOffset,x.length)}function zg(x,w){if(x!==w){var Z=x!==n,ae=x===null,he=x===x,Ce=os(x),Pe=w!==n,qe=w===null,Je=w===w,St=os(w);if(!qe&&!St&&!Ce&&x>w||Ce&&Pe&&Je&&!qe&&!St||ae&&Pe&&Je||!Z&&Je||!he)return 1;if(!ae&&!Ce&&!St&&x<w||St&&Z&&he&&!ae&&!Ce||qe&&Z&&he||!Pe&&he||!Je)return-1}return 0}function qg(x,w,Z){for(var ae=-1,he=x.criteria,Ce=w.criteria,Pe=he.length,qe=Z.length;++ae<Pe;){var Je=zg(he[ae],Ce[ae]);if(Je){if(ae>=qe)return Je;var St=Z[ae];return Je*(St=="desc"?-1:1)}}return x.index-w.index}function hm(x,w,Z,ae){for(var he=-1,Ce=x.length,Pe=Z.length,qe=-1,Je=w.length,St=Ni(Ce-Pe,0),_t=rt(Je+St),wt=!ae;++qe<Je;)_t[qe]=w[qe];for(;++he<Pe;)(wt||he<Ce)&&(_t[Z[he]]=x[he]);for(;St--;)_t[qe++]=x[he++];return _t}function Vg(x,w,Z,ae){for(var he=-1,Ce=x.length,Pe=-1,qe=Z.length,Je=-1,St=w.length,_t=Ni(Ce-qe,0),wt=rt(_t+St),Jt=!ae;++he<_t;)wt[he]=x[he];for(var On=he;++Je<St;)wt[On+Je]=w[Je];for(;++Pe<qe;)(Jt||he<Ce)&&(wt[On+Z[Pe]]=x[he++]);return wt}function rl(x,w){var Z=-1,ae=x.length;for(w||(w=rt(ae));++Z<ae;)w[Z]=x[Z];return w}function ts(x,w,Z,ae){var he=!Z;Z||(Z={});for(var Ce=-1,Pe=w.length;++Ce<Pe;){var qe=w[Ce],Je=ae?ae(Z[qe],x[qe],qe,Z,x):n;Je===n&&(Je=x[qe]),he?Ju(Z,qe,Je):Bs(Z,qe,Je)}return Z}function jy(x,w){return ts(x,ns(x),w)}function Zy(x,w){return ts(x,yo(x),w)}function Ug(x,w){return function(Z,ae){var he=Wn(Z)?od:$g,Ce=w?w():{};return he(Z,x,Sn(ae,2),Ce)}}function Ed(x){return Jn(function(w,Z){var ae=-1,he=Z.length,Ce=he>1?Z[he-1]:n,Pe=he>2?Z[2]:n;for(Ce=x.length>3&&typeof Ce=="function"?(he--,Ce):n,Pe&&Ci(Z[0],Z[1],Pe)&&(Ce=he<3?n:Ce,he=1),w=Nr(w);++ae<he;){var qe=Z[ae];qe&&x(w,qe,ae,Ce)}return w})}function Hy(x,w){return function(Z,ae){if(Z==null)return Z;if(!ls(Z))return x(Z,ae);for(var he=Z.length,Ce=w?he:-1,Pe=Nr(Z);(w?Ce--:++Ce<he)&&ae(Pe[Ce],Ce,Pe)!==!1;);return Z}}function jg(x){return function(w,Z,ae){for(var he=-1,Ce=Nr(w),Pe=ae(w),qe=Pe.length;qe--;){var Je=Pe[x?qe:++he];if(Z(Ce[Je],Je,Ce)===!1)break}return w}}function Xy(x,w,Z){var ae=w&_,he=pm(x);function Ce(){var Pe=this&&this!==ta&&this instanceof Ce?he:x;return Pe.apply(ae?Z:this,arguments)}return Ce}function Ou(x){return function(w){w=xi(w);var Z=du(w)?fr(w):n,ae=Z?Z[0]:w.charAt(0),he=Z?qs(Z,1).join(""):w.slice(1);return ae[x]()+he}}function Dd(x){return function(w){return Cp(S_(sv(w).replace(Sp,"")),x,"")}}function pm(x){return function(){var w=arguments;switch(w.length){case 0:return new x;case 1:return new x(w[0]);case 2:return new x(w[0],w[1]);case 3:return new x(w[0],w[1],w[2]);case 4:return new x(w[0],w[1],w[2],w[3]);case 5:return new x(w[0],w[1],w[2],w[3],w[4]);case 6:return new x(w[0],w[1],w[2],w[3],w[4],w[5]);case 7:return new x(w[0],w[1],w[2],w[3],w[4],w[5],w[6])}var Z=bl(x.prototype),ae=x.apply(Z,w);return va(ae)?ae:Z}}function O4(x,w,Z){var ae=pm(x);function he(){for(var Ce=arguments.length,Pe=rt(Ce),qe=Ce,Je=$i(he);qe--;)Pe[qe]=arguments[qe];var St=Ce<3&&Pe[0]!==Je&&Pe[Ce-1]!==Je?[]:co(Pe,Je);if(Ce-=St.length,Ce<Z)return Rh(x,w,$d,he.placeholder,n,Pe,St,n,n,Z-Ce);var _t=this&&this!==ta&&this instanceof he?ae:x;return fa(_t,this,Pe)}return he}function Yy(x){return function(w,Z,ae){var he=Nr(w);if(!ls(w)){var Ce=Sn(Z,3);w=fl(w),Z=function(qe){return Ce(he[qe],qe,he)}}var Pe=x(w,Z,ae);return Pe>-1?he[Ce?w[Pe]:Pe]:n}}function Ch(x){return Ul(function(w){var Z=w.length,ae=Z,he=Mu.prototype.thru;for(x&&w.reverse();ae--;){var Ce=w[ae];if(typeof Ce!="function")throw new _i(u);if(he&&!Pe&&bi(Ce)=="wrapper")var Pe=new Mu([],!0)}for(ae=Pe?ae:Z;++ae<Z;){Ce=w[ae];var qe=bi(Ce),Je=qe=="wrapper"?Vp(Ce):n;Je&&Ad(Je[0])&&Je[1]==(k|C|R|F)&&!Je[4].length&&Je[9]==1?Pe=Pe[bi(Je[0])].apply(Pe,Je[3]):Pe=Ce.length==1&&Ad(Ce)?Pe[qe]():Pe.thru(Ce)}return function(){var St=arguments,_t=St[0];if(Pe&&St.length==1&&Wn(_t))return Pe.plant(_t).value();for(var wt=0,Jt=Z?w[wt].apply(this,St):_t;++wt<Z;)Jt=w[wt].call(this,Jt);return Jt}})}function $d(x,w,Z,ae,he,Ce,Pe,qe,Je,St){var _t=w&k,wt=w&_,Jt=w&S,On=w&(C|T),Vn=w&L,br=Jt?n:pm(x);function Un(){for(var Qr=arguments.length,Wr=rt(Qr),Pf=Qr;Pf--;)Wr[Pf]=arguments[Pf];if(On)var Js=$i(Un),Mf=yf(Wr,Js);if(ae&&(Wr=hm(Wr,ae,he,On)),Ce&&(Wr=Vg(Wr,Ce,Pe,On)),Qr-=Mf,On&&Qr<St){var Lu=co(Wr,Js);return Rh(x,w,$d,Un.placeholder,Z,Wr,Lu,qe,Je,St-Qr)}var Vh=wt?Z:this,Rm=Jt?Vh[x]:x;return Qr=Wr.length,qe?Wr=bm(Wr,qe):Vn&&Qr>1&&Wr.reverse(),_t&&Je<Qr&&(Wr.length=Je),this&&this!==ta&&this instanceof Un&&(Rm=br||pm(Rm)),Rm.apply(Vh,Wr)}return Un}function Fc(x,w){return function(Z,ae){return Bb(Z,x,w(ae),{})}}function Nc(x,w){return function(Z,ae){var he;if(Z===n&&ae===n)return w;if(Z!==n&&(he=Z),ae!==n){if(he===n)return ae;typeof Z=="string"||typeof ae=="string"?(Z=ql(Z),ae=ql(ae)):(Z=By(Z),ae=By(ae)),he=x(Z,ae)}return he}}function il(x){return Ul(function(w){return w=vi(w,fu(Sn())),Jn(function(Z){var ae=this;return x(w,function(he){return fa(he,ae,Z)})})})}function Cd(x,w){w=w===n?" ":ql(w);var Z=w.length;if(Z<2)return Z?zs(w,x):w;var ae=zs(w,_f(x/hu(w)));return du(w)?qs(fr(ae),0,x).join(""):ae.slice(0,x)}function jb(x,w,Z,ae){var he=w&_,Ce=pm(x);function Pe(){for(var qe=-1,Je=arguments.length,St=-1,_t=ae.length,wt=rt(_t+Je),Jt=this&&this!==ta&&this instanceof Pe?Ce:x;++St<_t;)wt[St]=ae[St];for(;Je--;)wt[St++]=arguments[++qe];return fa(Jt,he?Z:this,wt)}return Pe}function wh(x){return function(w,Z,ae){return ae&&typeof ae!="number"&&Ci(w,Z,ae)&&(Z=ae=n),w=zh(w),Z===n?(Z=w,w=0):Z=zh(Z),ae=ae===n?w<Z?1:-1:zh(ae),My(w,Z,ae,x)}}function wd(x){return function(w,Z){return typeof w=="string"&&typeof Z=="string"||(w=Ws(w),Z=Ws(Z)),x(w,Z)}}function Rh(x,w,Z,ae,he,Ce,Pe,qe,Je,St){var _t=w&C,wt=_t?Pe:n,Jt=_t?n:Pe,On=_t?Ce:n,Vn=_t?n:Ce;w|=_t?R:$,w&=~(_t?$:R),w&E||(w&=-4);var br=[x,w,he,On,wt,Vn,Jt,qe,Je,St],Un=Z.apply(n,br);return Ad(x)&&Yg(Un,br),Un.placeholder=ae,js(Un,x,w)}function Ah(x){var w=Fi[x];return function(Z,ae){if(Z=Ws(Z),ae=ae==null?0:Ei(qn(ae),292),ae&&Tu(Z)){var he=(xi(Z)+"e").split("e"),Ce=w(he[0]+"e"+(+he[1]+ae));return he=(xi(Ce)+"e").split("e"),+(he[0]+"e"+(+he[1]-ae))}return w(Z)}}var Zb=fe&&1/Kn(new fe([,-0]))[1]==J?function(x){return new fe(x)}:O;function Gy(x){return function(w){var Z=Ir(w);return Z==ge?vh(w):Z==$e?yl(w):cd(w,x(w))}}function qi(x,w,Z,ae,he,Ce,Pe,qe){var Je=w&S;if(!Je&&typeof x!="function")throw new _i(u);var St=ae?ae.length:0;if(St||(w&=-97,ae=he=n),Pe=Pe===n?Pe:Ni(qn(Pe),0),qe=qe===n?qe:qn(qe),St-=he?he.length:0,w&$){var _t=ae,wt=he;ae=he=n}var Jt=Je?n:Vp(x),On=[x,w,Z,ae,he,_t,wt,Ce,Pe,qe];if(Jt&&Xg(On,Jt),x=On[0],w=On[1],Z=On[2],ae=On[3],he=On[4],qe=On[9]=On[9]===n?Je?0:x.length:Ni(On[9]-St,0),!qe&&w&(C|T)&&(w&=-25),!w||w==_)var Vn=Xy(x,w,Z);else w==C||w==T?Vn=O4(x,w,qe):(w==R||w==(_|R))&&!he.length?Vn=jb(x,w,Z,ae):Vn=$d.apply(n,On);var br=Jt?Ny:Yg;return js(br(Vn,On),x,w)}function Zg(x,w,Z,ae){return x===n||Gs(x,fo[Z])&&!_r.call(ae,Z)?w:x}function Ky(x,w,Z,ae,he,Ce){return va(x)&&va(w)&&(Ce.set(w,x),sm(x,w,n,Ky,Ce),Ce.delete(w)),x}function Hg(x){return a1(x)?n:x}function mm(x,w,Z,ae,he,Ce){var Pe=Z&y,qe=x.length,Je=w.length;if(qe!=Je&&!(Pe&&Je>qe))return!1;var St=Ce.get(x),_t=Ce.get(w);if(St&&_t)return St==w&&_t==x;var wt=-1,Jt=!0,On=Z&v?new Xo:n;for(Ce.set(x,w),Ce.set(w,x);++wt<qe;){var Vn=x[wt],br=w[wt];if(ae)var Un=Pe?ae(br,Vn,wt,w,x,Ce):ae(Vn,br,wt,x,w,Ce);if(Un!==n){if(Un)continue;Jt=!1;break}if(On){if(!Rp(w,function(Qr,Wr){if(!Xa(On,Wr)&&(Vn===Qr||he(Vn,Qr,Z,ae,Ce)))return On.push(Wr)})){Jt=!1;break}}else if(!(Vn===br||he(Vn,br,Z,ae,Ce))){Jt=!1;break}}return Ce.delete(x),Ce.delete(w),Jt}function Hb(x,w,Z,ae,he,Ce,Pe){switch(Z){case st:if(x.byteLength!=w.byteLength||x.byteOffset!=w.byteOffset)return!1;x=x.buffer,w=w.buffer;case ze:return!(x.byteLength!=w.byteLength||!Ce(new Gu(x),new Gu(w)));case be:case ve:case we:return Gs(+x,+w);case _e:return x.name==w.name&&x.message==w.message;case Oe:case Ae:return x==w+"";case ge:var qe=vh;case $e:var Je=ae&y;if(qe||(qe=Kn),x.size!=w.size&&!Je)return!1;var St=Pe.get(x);if(St)return St==w;ae|=v,Pe.set(x,w);var _t=mm(qe(x),qe(w),ae,he,Ce,Pe);return Pe.delete(x),_t;case Ue:if(Di)return Di.call(x)==Di.call(w)}return!1}function Wy(x,w,Z,ae,he,Ce){var Pe=Z&y,qe=al(x),Je=qe.length,St=al(w),_t=St.length;if(Je!=_t&&!Pe)return!1;for(var wt=Je;wt--;){var Jt=qe[wt];if(!(Pe?Jt in w:_r.call(w,Jt)))return!1}var On=Ce.get(x),Vn=Ce.get(w);if(On&&Vn)return On==w&&Vn==x;var br=!0;Ce.set(x,w),Ce.set(w,x);for(var Un=Pe;++wt<Je;){Jt=qe[wt];var Qr=x[Jt],Wr=w[Jt];if(ae)var Pf=Pe?ae(Wr,Qr,Jt,w,x,Ce):ae(Qr,Wr,Jt,x,w,Ce);if(!(Pf===n?Qr===Wr||he(Qr,Wr,Z,ae,Ce):Pf)){br=!1;break}Un||(Un=Jt=="constructor")}if(br&&!Un){var Js=x.constructor,Mf=w.constructor;Js!=Mf&&"constructor"in x&&"constructor"in w&&!(typeof Js=="function"&&Js instanceof Js&&typeof Mf=="function"&&Mf instanceof Mf)&&(br=!1)}return Ce.delete(x),Ce.delete(w),br}function Ul(x){return Cf(Lc(x,n,Rr),x+"")}function al(x){return Rg(x,fl,ns)}function Ol(x){return Rg(x,ss,yo)}var Vp=Qe?function(x){return Qe.get(x)}:O;function bi(x){for(var w=x.name+"",Z=Be[w],ae=_r.call(Be,w)?Z.length:0;ae--;){var he=Z[ae],Ce=he.func;if(Ce==null||Ce==x)return he.name}return w}function $i(x){var w=_r.call(Se,"placeholder")?Se:x;return w.placeholder}function Sn(){var x=Se.iteratee||h1;return x=x===h1?Bp:x,arguments.length?x(arguments[0],arguments[1]):x}function Rd(x,w){var Z=x.__data__;return Up(w)?Z[typeof w=="string"?"string":"hash"]:Z.map}function xl(x){for(var w=fl(x),Z=w.length;Z--;){var ae=w[Z],he=x[ae];w[Z]=[ae,he,is(he)]}return w}function nu(x,w){var Z=em(x,w);return om(Z)?Z:n}function Vs(x){var w=_r.call(x,Xi),Z=x[Xi];try{x[Xi]=n;var ae=!0}catch{}var he=da.call(x);return ae&&(w?x[Xi]=Z:delete x[Xi]),he}var ns=gu?function(x){return x==null?[]:(x=Nr(x),qo(gu(x),function(w){return Cc.call(x,w)}))}:xt,yo=gu?function(x){for(var w=[];x;)Vo(w,ns(x)),x=Ku(x);return w}:xt,Ir=Iu;(ue&&Ir(new ue(new ArrayBuffer(1)))!=st||I&&Ir(new I)!=ge||re&&Ir(re.resolve())!=et||fe&&Ir(new fe)!=$e||xe&&Ir(new xe)!=Ye)&&(Ir=function(x){var w=Iu(x),Z=w==Re?x.constructor:n,ae=Z?iu(Z):"";if(ae)switch(ae){case je:return st;case Ct:return ge;case Kt:return et;case Qn:return $e;case cn:return Ye}return w});function gm(x,w,Z){for(var ae=-1,he=Z.length;++ae<he;){var Ce=Z[ae],Pe=Ce.size;switch(Ce.type){case"drop":x+=Pe;break;case"dropRight":w-=Pe;break;case"take":w=Ei(w,x+Pe);break;case"takeRight":x=Ni(x,w-Pe);break}}return{start:x,end:w}}function Us(x){var w=x.match(Vt);return w?w[1].split(tn):[]}function Th(x,w,Z){w=vo(w,x);for(var ae=-1,he=w.length,Ce=!1;++ae<he;){var Pe=ru(w[ae]);if(!(Ce=x!=null&&Z(x,Pe)))break;x=x[Pe]}return Ce||++ae!=he?Ce:(he=x==null?0:x.length,!!he&&eO(he)&&Oo(Pe,he)&&(Wn(x)||Cm(x)))}function ul(x){var w=x.length,Z=new x.constructor(w);return w&&typeof x[0]=="string"&&_r.call(x,"index")&&(Z.index=x.index,Z.input=x.input),Z}function xu(x){return typeof x.constructor=="function"&&!Df(x)?bl(Ku(x)):{}}function Lr(x,w,Z){var ae=x.constructor;switch(w){case ze:return dm(x);case be:case ve:return new ae(+x);case st:return qb(x,Z);case Ot:case Nt:case gt:case qt:case zt:case an:case rn:case Fe:case ht:return Vl(x,Z);case ge:return new ae;case we:case Ae:return new ae(x);case Oe:return Vb(x);case $e:return new ae;case Ue:return Ub(x)}}function bo(x,w){var Z=w.length;if(!Z)return x;var ae=Z-1;return w[ae]=(Z>1?"& ":"")+w[ae],w=w.join(Z>2?", ":" "),x.replace(Lt,`{
/* [wrapped with `+w+`] */
`)}function rs(x){return Wn(x)||Cm(x)||!!(pd&&x&&x[pd])}function Oo(x,w){var Z=typeof x;return w=w??te,!!w&&(Z=="number"||Z!="symbol"&&Al.test(x))&&x>-1&&x%1==0&&x<w}function Ci(x,w,Z){if(!va(Z))return!1;var ae=typeof w;return(ae=="number"?ls(Z)&&Oo(w,Z.length):ae=="string"&&w in Z)?Gs(Z[w],x):!1}function Ic(x,w){if(Wn(x))return!1;var Z=typeof x;return Z=="number"||Z=="symbol"||Z=="boolean"||x==null||os(x)?!0:He.test(x)||!ke.test(x)||w!=null&&x in Nr(w)}function Up(x){var w=typeof x;return w=="string"||w=="number"||w=="symbol"||w=="boolean"?x!=="__proto__":x===null}function Ad(x){var w=bi(x),Z=Se[w];if(typeof Z!="function"||!(w in zn.prototype))return!1;if(x===Z)return!0;var ae=Vp(Z);return!!ae&&x===ae[0]}function kh(x){return!!yh&&yh in x}var vm=ho?Ks:lt;function Df(x){var w=x&&x.constructor,Z=typeof w=="function"&&w.prototype||fo;return x===Z}function is(x){return x===x&&!va(x)}function $f(x,w){return function(Z){return Z==null?!1:Z[x]===w&&(w!==n||x in Nr(Z))}}function ym(x){var w=t1(x,function(ae){return Z.size===s&&Z.clear(),ae}),Z=w.cache;return w}function Xg(x,w){var Z=x[1],ae=w[1],he=Z|ae,Ce=he<(_|S|k),Pe=ae==k&&Z==C||ae==k&&Z==F&&x[7].length<=w[8]||ae==(k|F)&&w[7].length<=w[8]&&Z==C;if(!(Ce||Pe))return x;ae&_&&(x[2]=w[2],he|=Z&_?0:E);var qe=w[3];if(qe){var Je=x[3];x[3]=Je?hm(Je,qe,w[4]):qe,x[4]=Je?co(x[3],c):w[4]}return qe=w[5],qe&&(Je=x[5],x[5]=Je?Vg(Je,qe,w[6]):qe,x[6]=Je?co(x[5],c):w[6]),qe=w[7],qe&&(x[7]=qe),ae&k&&(x[8]=x[8]==null?w[8]:Ei(x[8],w[8])),x[9]==null&&(x[9]=w[9]),x[0]=w[0],x[1]=he,x}function jl(x){var w=[];if(x!=null)for(var Z in Nr(x))w.push(Z);return w}function Td(x){return da.call(x)}function Lc(x,w,Z){return w=Ni(w===n?x.length-1:w,0),function(){for(var ae=arguments,he=-1,Ce=Ni(ae.length-w,0),Pe=rt(Ce);++he<Ce;)Pe[he]=ae[w+he];he=-1;for(var qe=rt(w+1);++he<w;)qe[he]=ae[he];return qe[w]=Z(Pe),fa(x,this,qe)}}function Ph(x,w){return w.length<2?x:wa(x,zl(w,0,-1))}function bm(x,w){for(var Z=x.length,ae=Ei(w.length,Z),he=rl(x);ae--;){var Ce=w[ae];x[ae]=Oo(Ce,Z)?he[Ce]:n}return x}function Xr(x,w){if(!(w==="constructor"&&typeof x[w]=="function")&&w!="__proto__")return x[w]}var Yg=xo(Ny),kd=Fl||function(x,w){return ta.setTimeout(x,w)},Cf=xo(Iy);function js(x,w,Z){var ae=w+"";return Cf(x,bo(ae,So(Us(ae),Z)))}function xo(x){var w=0,Z=0;return function(){var ae=ku(),he=N-(ae-Z);if(Z=ae,he>0){if(++w>=q)return arguments[0]}else w=0;return x.apply(n,arguments)}}function Zs(x,w){var Z=-1,ae=x.length,he=ae-1;for(w=w===n?ae:w;++Z<w;){var Ce=zp(Z,he),Pe=x[Ce];x[Ce]=x[Z],x[Z]=Pe}return x.length=w,x}var Gg=ym(function(x){var w=[];return x.charCodeAt(0)===46&&w.push(""),x.replace(nt,function(Z,ae,he,Ce){w.push(he?Ce.replace(sn,"$1"):ae||Z)}),w});function ru(x){if(typeof x=="string"||os(x))return x;var w=x+"";return w=="0"&&1/x==-J?"-0":w}function iu(x){if(x!=null){try{return Sf.call(x)}catch{}try{return x+""}catch{}}return""}function So(x,w){return La(ne,function(Z){var ae="_."+Z[0];w&Z[1]&&!hh(x,ae)&&x.push(ae)}),x.sort()}function _o(x){if(x instanceof zn)return x.clone();var w=new Mu(x.__wrapped__,x.__chain__);return w.__actions__=rl(x.__actions__),w.__index__=x.__index__,w.__values__=x.__values__,w}function za(x,w,Z){(Z?Ci(x,w,Z):w===n)?w=1:w=Ni(qn(w),0);var ae=x==null?0:x.length;if(!ae||w<1)return[];for(var he=0,Ce=0,Pe=rt(_f(ae/w));he<ae;)Pe[Ce++]=zl(x,he,he+=w);return Pe}function Bc(x){for(var w=-1,Z=x==null?0:x.length,ae=0,he=[];++w<Z;){var Ce=x[w];Ce&&(he[ae++]=Ce)}return he}function er(){var x=arguments.length;if(!x)return[];for(var w=rt(x-1),Z=arguments[0],ae=x;ae--;)w[ae-1]=arguments[ae];return Vo(Wn(Z)?rl(Z):[Z],Wa(w,1))}var Yr=Jn(function(x,w){return uu(x)?Ko(x,Wa(w,1,uu,!0)):[]}),Aa=Jn(function(x,w){var Z=Br(w);return uu(Z)&&(Z=n),uu(x)?Ko(x,Wa(w,1,uu,!0),Sn(Z,2)):[]}),as=Jn(function(x,w){var Z=Br(w);return uu(Z)&&(Z=n),uu(x)?Ko(x,Wa(w,1,uu,!0),n,Z):[]});function Vi(x,w,Z){var ae=x==null?0:x.length;return ae?(w=Z||w===n?1:qn(w),zl(x,w<0?0:w,ae)):[]}function wf(x,w,Z){var ae=x==null?0:x.length;return ae?(w=Z||w===n?1:qn(w),w=ae-w,zl(x,0,w<0?0:w)):[]}function Om(x,w){return x&&x.length?cm(x,Sn(w,3),!0,!0):[]}function ma(x,w){return x&&x.length?cm(x,Sn(w,3),!0):[]}function jp(x,w,Z,ae){var he=x==null?0:x.length;return he?(Z&&typeof Z!="number"&&Ci(x,w,Z)&&(Z=0,ae=he),Od(x,w,Z,ae)):[]}function Jy(x,w,Z){var ae=x==null?0:x.length;if(!ae)return-1;var he=Z==null?0:qn(Z);return he<0&&(he=Ni(ae+he,0)),oo(x,Sn(w,3),he)}function xm(x,w,Z){var ae=x==null?0:x.length;if(!ae)return-1;var he=ae-1;return Z!==n&&(he=qn(Z),he=Z<0?Ni(ae+he,0):Ei(he,ae-1)),oo(x,Sn(w,3),he,!0)}function Rr(x){var w=x==null?0:x.length;return w?Wa(x,1):[]}function qa(x){var w=x==null?0:x.length;return w?Wa(x,J):[]}function ll(x,w){var Z=x==null?0:x.length;return Z?(w=w===n?1:qn(w),Wa(x,w)):[]}function Pd(x){for(var w=-1,Z=x==null?0:x.length,ae={};++w<Z;){var he=x[w];ae[he[0]]=he[1]}return ae}function Sm(x){return x&&x.length?x[0]:n}function e1(x,w,Z){var ae=x==null?0:x.length;if(!ae)return-1;var he=Z==null?0:qn(Z);return he<0&&(he=Ni(ae+he,0)),Xu(x,w,he)}function Xb(x){var w=x==null?0:x.length;return w?zl(x,0,-1):[]}var Ta=Jn(function(x){var w=vi(x,Vy);return w.length&&w[0]===x[0]?lm(w):[]}),ol=Jn(function(x){var w=Br(x),Z=vi(x,Vy);return w===Br(Z)?w=n:Z.pop(),Z.length&&Z[0]===x[0]?lm(Z,Sn(w,2)):[]}),Zl=Jn(function(x){var w=Br(x),Z=vi(x,Vy);return w=typeof w=="function"?w:n,w&&Z.pop(),Z.length&&Z[0]===x[0]?lm(Z,n,w):[]});function Md(x,w){return x==null?"":Nl.call(x,w)}function Br(x){var w=x==null?0:x.length;return w?x[w-1]:n}function Yb(x,w,Z){var ae=x==null?0:x.length;if(!ae)return-1;var he=ae;return Z!==n&&(he=qn(Z),he=he<0?Ni(ae+he,0):Ei(he,ae-1)),w===w?Mi(x,w,he):oo(x,ph,he,!0)}function Rf(x,w){return x&&x.length?Mg(x,qn(w)):n}var Mh=Jn(Gr);function Gr(x,w){return x&&x.length&&w&&w.length?Dh(x,w):x}function Kg(x,w,Z){return x&&x.length&&w&&w.length?Dh(x,w,Sn(Z,2)):x}function Af(x,w,Z){return x&&x.length&&w&&w.length?Dh(x,w,n,Z):x}var au=Ul(function(x,w){var Z=x==null?0:x.length,ae=Ip(x,w);return Qp(x,vi(w,function(he){return Oo(he,Z)?+he:he}).sort(zg)),ae});function ra(x,w){var Z=[];if(!(x&&x.length))return Z;var ae=-1,he=[],Ce=x.length;for(w=Sn(w,3);++ae<Ce;){var Pe=x[ae];w(Pe,ae,x)&&(Z.push(Pe),he.push(ae))}return Qp(x,he),Z}function Qc(x){return x==null?x:Ho.call(x)}function Zp(x,w,Z){var ae=x==null?0:x.length;return ae?(Z&&typeof Z!="number"&&Ci(x,w,Z)?(w=0,Z=ae):(w=w==null?0:qn(w),Z=Z===n?ae:qn(Z)),zl(x,w,Z)):[]}function ga(x,w){return _d(x,w)}function Fh(x,w,Z){return Lg(x,w,Sn(Z,2))}function ka(x,w){var Z=x==null?0:x.length;if(Z){var ae=_d(x,w);if(ae<Z&&Gs(x[ae],w))return ae}return-1}function Hl(x,w){return _d(x,w,!0)}function Sl(x,w,Z){return Lg(x,w,Sn(Z,2),!0)}function Nh(x,w){var Z=x==null?0:x.length;if(Z){var ae=_d(x,w,!0)-1;if(Gs(x[ae],w))return ae}return-1}function Wg(x){return x&&x.length?Qb(x):[]}function _m(x,w){return x&&x.length?Qb(x,Sn(w,2)):[]}function Jg(x){var w=x==null?0:x.length;return w?zl(x,1,w):[]}function ev(x,w,Z){return x&&x.length?(w=Z||w===n?1:qn(w),zl(x,0,w<0?0:w)):[]}function Ar(x,w,Z){var ae=x==null?0:x.length;return ae?(w=Z||w===n?1:qn(w),w=ae-w,zl(x,w<0?0:w,ae)):[]}function ii(x,w){return x&&x.length?cm(x,Sn(w,3),!1,!0):[]}function tr(x,w){return x&&x.length?cm(x,Sn(w,3)):[]}var yr=Jn(function(x){return Mc(Wa(x,1,uu,!0))}),bn=Jn(function(x){var w=Br(x);return uu(w)&&(w=n),Mc(Wa(x,1,uu,!0),Sn(w,2))}),dr=Jn(function(x){var w=Br(x);return w=typeof w=="function"?w:n,Mc(Wa(x,1,uu,!0),n,w)});function Yn(x){return x&&x.length?Mc(x):[]}function lr(x,w){return x&&x.length?Mc(x,Sn(w,2)):[]}function Oi(x,w){return w=typeof w=="function"?w:n,x&&x.length?Mc(x,n,w):[]}function ia(x){if(!(x&&x.length))return[];var w=0;return x=qo(x,function(Z){if(uu(Z))return w=Ni(Z.length,w),!0}),sd(w,function(Z){return vi(x,Uo(Z))})}function Kr(x,w){if(!(x&&x.length))return[];var Z=ia(x);return w==null?Z:vi(Z,function(ae){return fa(w,n,ae)})}var Eo=Jn(function(x,w){return uu(x)?Ko(x,w):[]}),Tf=Jn(function(x){return Bg(qo(x,uu))}),Hs=Jn(function(x){var w=Br(x);return uu(w)&&(w=n),Bg(qo(x,uu),Sn(w,2))}),Tr=Jn(function(x){var w=Br(x);return w=typeof w=="function"?w:n,Bg(qo(x,uu),n,w)}),Do=Jn(ia);function Xs(x,w){return qy(x||[],w||[],Bs)}function sl(x,w){return qy(x||[],w||[],$h)}var Xl=Jn(function(x){var w=x.length,Z=w>1?x[w-1]:n;return Z=typeof Z=="function"?(x.pop(),Z):n,Kr(x,Z)});function zc(x){var w=Se(x);return w.__chain__=!0,w}function Hp(x,w){return w(x),x}function cl(x,w){return w(x)}var Xp=Ul(function(x){var w=x.length,Z=w?x[0]:0,ae=this.__wrapped__,he=function(Ce){return Ip(Ce,x)};return w>1||this.__actions__.length||!(ae instanceof zn)||!Oo(Z)?this.thru(he):(ae=ae.slice(Z,+Z+(w?1:0)),ae.__actions__.push({func:cl,args:[he],thisArg:n}),new Mu(ae,this.__chain__).thru(function(Ce){return w&&!Ce.length&&Ce.push(n),Ce}))});function qc(){return zc(this)}function aa(){return new Mu(this.value(),this.__chain__)}function Ys(){this.__values__===n&&(this.__values__=e_(this.value()));var x=this.__index__>=this.__values__.length,w=x?n:this.__values__[this.__index__++];return{done:x,value:w}}function $o(){return this}function us(x){for(var w,Z=this;Z instanceof Il;){var ae=_o(Z);ae.__index__=0,ae.__values__=n,w?he.__wrapped__=ae:w=ae;var he=ae;Z=Z.__wrapped__}return he.__wrapped__=x,w}function kf(){var x=this.__wrapped__;if(x instanceof zn){var w=x;return this.__actions__.length&&(w=new zn(this)),w=w.reverse(),w.__actions__.push({func:cl,args:[Qc],thisArg:n}),new Mu(w,this.__chain__)}return this.thru(Qc)}function Ih(){return zy(this.__wrapped__,this.__actions__)}var tv=Ug(function(x,w,Z){_r.call(x,Z)?++x[Z]:Ju(x,Z,1)});function Lh(x,w,Z){var ae=Wn(x)?$p:kc;return Z&&Ci(x,w,Z)&&(w=n),ae(x,Sn(w,3))}function Bh(x,w){var Z=Wn(x)?qo:um;return Z(x,Sn(w,3))}var _l=Yy(Jy),g=Yy(xm);function b(x,w){return Wa(kt(x,w),1)}function A(x,w){return Wa(kt(x,w),J)}function z(x,w,Z){return Z=Z===n?1:qn(Z),Wa(kt(x,w),Z)}function ee(x,w){var Z=Wn(x)?La:Tc;return Z(x,Sn(w,3))}function le(x,w){var Z=Wn(x)?_g:wg;return Z(x,Sn(w,3))}var De=Ug(function(x,w,Z){_r.call(x,Z)?x[Z].push(w):Ju(x,Z,[w])});function Ie(x,w,Z,ae){x=ls(x)?x:ov(x),Z=Z&&!ae?qn(Z):0;var he=x.length;return Z<0&&(Z=Ni(he+Z,0)),o1(x)?Z<=he&&x.indexOf(w,Z)>-1:!!he&&Xu(x,w,Z)>-1}var We=Jn(function(x,w,Z){var ae=-1,he=typeof w=="function",Ce=ls(x)?rt(x.length):[];return Tc(x,function(Pe){Ce[++ae]=he?fa(w,Pe,Z):go(Pe,w,Z)}),Ce}),vt=Ug(function(x,w,Z){Ju(x,Z,w)});function kt(x,w){var Z=Wn(x)?vi:kg;return Z(x,Sn(w,3))}function Ht(x,w,Z,ae){return x==null?[]:(Wn(w)||(w=w==null?[]:[w]),Z=ae?n:Z,Wn(Z)||(Z=Z==null?[]:[Z]),Fg(x,w,Z))}var Wt=Ug(function(x,w,Z){x[Z?0:1].push(w)},function(){return[[],[]]});function Hn(x,w,Z){var ae=Wn(x)?Cp:Ba,he=arguments.length<3;return ae(x,Sn(w,4),Z,he,Tc)}function Yl(x,w,Z){var ae=Wn(x)?wp:Ba,he=arguments.length<3;return ae(x,Sn(w,4),Z,he,wg)}function Em(x,w){var Z=Wn(x)?qo:um;return Z(x,Gb(Sn(w,3)))}function Qh(x){var w=Wn(x)?Go:Fy;return w(x)}function ut(x,w,Z){(Z?Ci(x,w,Z):w===n)?w=1:w=qn(w);var ae=Wn(x)?im:Ng;return ae(x,w)}function Ge(x){var w=Wn(x)?Lb:Ly;return w(x)}function ct(x){if(x==null)return 0;if(ls(x))return o1(x)?hu(x):x.length;var w=Ir(x);return w==ge||w==$e?x.size:es(x).length}function At(x,w,Z){var ae=Wn(x)?Rp:Ig;return Z&&Ci(x,w,Z)&&(w=n),ae(x,Sn(w,3))}var gn=Jn(function(x,w){if(x==null)return[];var Z=w.length;return Z>1&&Ci(x,w[0],w[1])?w=[]:Z>2&&Ci(w[0],w[1],w[2])&&(w=[w[0]]),Fg(x,Wa(w,1),[])}),fi=bh||function(){return ta.Date.now()};function kn(x,w){if(typeof w!="function")throw new _i(u);return x=qn(x),function(){if(--x<1)return w.apply(this,arguments)}}function kr(x,w,Z){return w=Z?n:w,w=x&&w==null?x.length:w,qi(x,k,n,n,n,n,w)}function Va(x,w){var Z;if(typeof w!="function")throw new _i(u);return x=qn(x),function(){return--x>0&&(Z=w.apply(this,arguments)),x<=1&&(w=n),Z}}var Er=Jn(function(x,w,Z){var ae=_;if(Z.length){var he=co(Z,$i(Er));ae|=R}return qi(x,ae,w,Z,he)}),Vc=Jn(function(x,w,Z){var ae=_|S;if(Z.length){var he=co(Z,$i(Vc));ae|=R}return qi(w,ae,x,Z,he)});function Dm(x,w,Z){w=Z?n:w;var ae=qi(x,C,n,n,n,n,n,w);return ae.placeholder=Dm.placeholder,ae}function x4(x,w,Z){w=Z?n:w;var ae=qi(x,T,n,n,n,n,n,w);return ae.placeholder=x4.placeholder,ae}function S4(x,w,Z){var ae,he,Ce,Pe,qe,Je,St=0,_t=!1,wt=!1,Jt=!0;if(typeof x!="function")throw new _i(u);w=Ws(w)||0,va(Z)&&(_t=!!Z.leading,wt="maxWait"in Z,Ce=wt?Ni(Ws(Z.maxWait)||0,w):Ce,Jt="trailing"in Z?!!Z.trailing:Jt);function On(Lu){var Vh=ae,Rm=he;return ae=he=n,St=Lu,Pe=x.apply(Rm,Vh),Pe}function Vn(Lu){return St=Lu,qe=kd(Qr,w),_t?On(Lu):Pe}function br(Lu){var Vh=Lu-Je,Rm=Lu-St,PB=w-Vh;return wt?Ei(PB,Ce-Rm):PB}function Un(Lu){var Vh=Lu-Je,Rm=Lu-St;return Je===n||Vh>=w||Vh<0||wt&&Rm>=Ce}function Qr(){var Lu=fi();if(Un(Lu))return Wr(Lu);qe=kd(Qr,br(Lu))}function Wr(Lu){return qe=n,Jt&&ae?On(Lu):(ae=he=n,Pe)}function Pf(){qe!==n&&fm(qe),St=0,ae=Je=he=qe=n}function Js(){return qe===n?Pe:Wr(fi())}function Mf(){var Lu=fi(),Vh=Un(Lu);if(ae=arguments,he=this,Je=Lu,Vh){if(qe===n)return Vn(Je);if(wt)return fm(qe),qe=kd(Qr,w),On(Je)}return qe===n&&(qe=kd(Qr,w)),Pe}return Mf.cancel=Pf,Mf.flush=Js,Mf}var wi=Jn(function(x,w){return Ty(x,1,w)}),_4=Jn(function(x,w,Z){return Ty(x,Ws(w)||0,Z)});function v5(x){return qi(x,L)}function t1(x,w){if(typeof x!="function"||w!=null&&typeof w!="function")throw new _i(u);var Z=function(){var ae=arguments,he=w?w.apply(this,ae):ae[0],Ce=Z.cache;if(Ce.has(he))return Ce.get(he);var Pe=x.apply(this,ae);return Z.cache=Ce.set(he,Pe)||Ce,Pe};return Z.cache=new(t1.Cache||Is),Z}t1.Cache=Is;function Gb(x){if(typeof x!="function")throw new _i(u);return function(){var w=arguments;switch(w.length){case 0:return!x.call(this);case 1:return!x.call(this,w[0]);case 2:return!x.call(this,w[0],w[1]);case 3:return!x.call(this,w[0],w[1],w[2])}return!x.apply(this,w)}}function y5(x){return Va(2,x)}var b5=zb(function(x,w){w=w.length==1&&Wn(w[0])?vi(w[0],fu(Sn())):vi(Wa(w,1),fu(Sn()));var Z=w.length;return Jn(function(ae){for(var he=-1,Ce=Ei(ae.length,Z);++he<Ce;)ae[he]=w[he].call(this,ae[he]);return fa(x,this,ae)})}),nv=Jn(function(x,w){var Z=co(w,$i(nv));return qi(x,R,n,w,Z)}),$m=Jn(function(x,w){var Z=co(w,$i($m));return qi(x,$,n,w,Z)}),E4=Ul(function(x,w){return qi(x,F,n,n,n,w)});function Kb(x,w){if(typeof x!="function")throw new _i(u);return w=w===n?w:qn(w),Jn(x,w)}function D4(x,w){if(typeof x!="function")throw new _i(u);return w=w==null?0:Ni(qn(w),0),Jn(function(Z){var ae=Z[w],he=qs(Z,0,w);return ae&&Vo(he,ae),fa(x,this,he)})}function Yp(x,w,Z){var ae=!0,he=!0;if(typeof x!="function")throw new _i(u);return va(Z)&&(ae="leading"in Z?!!Z.leading:ae,he="trailing"in Z?!!Z.trailing:he),S4(x,w,{leading:ae,maxWait:w,trailing:he})}function Fd(x){return kr(x,1)}function n1(x,w){return nv(Qg(w),x)}function O5(){if(!arguments.length)return[];var x=arguments[0];return Wn(x)?x:[x]}function qS(x){return el(x,m)}function VS(x,w){return w=typeof w=="function"?w:n,el(x,m,w)}function US(x){return el(x,d|m)}function jS(x,w){return w=typeof w=="function"?w:n,el(x,d|m,w)}function x5(x,w){return w==null||bd(x,w,fl(w))}function Gs(x,w){return x===w||x!==x&&w!==w}var ZS=wd(yu),HS=wd(function(x,w){return x>=w}),Cm=Ql((function(){return arguments})())?Ql:function(x){return Ua(x)&&_r.call(x,"callee")&&!Cc.call(x,"callee")},Wn=rt.isArray,$4=Y0?fu(Y0):ha;function ls(x){return x!=null&&eO(x.length)&&!Ks(x)}function uu(x){return Ua(x)&&ls(x)}function r1(x){return x===!0||x===!1||Ua(x)&&Iu(x)==be}var Gp=Mp||lt,XS=G0?fu(G0):Ag;function Dr(x){return Ua(x)&&x.nodeType===1&&!a1(x)}function C4(x){if(x==null)return!0;if(ls(x)&&(Wn(x)||typeof x=="string"||typeof x.splice=="function"||Gp(x)||Kp(x)||Cm(x)))return!x.length;var w=Ir(x);if(w==ge||w==$e)return!x.size;if(Df(x))return!es(x).length;for(var Z in x)if(_r.call(x,Z))return!1;return!0}function Wb(x,w){return bu(x,w)}function w4(x,w,Z){Z=typeof Z=="function"?Z:n;var ae=Z?Z(x,w):n;return ae===n?bu(x,w,n,Z):!!ae}function Jb(x){if(!Ua(x))return!1;var w=Iu(x);return w==_e||w==pe||typeof x.message=="string"&&typeof x.name=="string"&&!a1(x)}function R4(x){return typeof x=="number"&&Tu(x)}function Ks(x){if(!va(x))return!1;var w=Iu(x);return w==se||w==me||w==de||w==tt}function i1(x){return typeof x=="number"&&x==qn(x)}function eO(x){return typeof x=="number"&&x>-1&&x%1==0&&x<=te}function va(x){var w=typeof x;return x!=null&&(w=="object"||w=="function")}function Ua(x){return x!=null&&typeof x=="object"}var YS=ud?fu(ud):yi;function GS(x,w){return x===w||pa(x,w,xl(w))}function KS(x,w,Z){return Z=typeof Z=="function"?Z:n,pa(x,w,xl(w),Z)}function Ii(x){return T4(x)&&x!=+x}function A4(x){if(vm(x))throw new Dn(a);return om(x)}function El(x){return x===null}function S5(x){return x==null}function T4(x){return typeof x=="number"||Ua(x)&&Iu(x)==we}function a1(x){if(!Ua(x)||Iu(x)!=Re)return!1;var w=Ku(x);if(w===null)return!0;var Z=_r.call(w,"constructor")&&w.constructor;return typeof Z=="function"&&Z instanceof Z&&Sf.call(Z)==Zo}var u1=K0?fu(K0):Pc;function k4(x){return i1(x)&&x>=-te&&x<=te}var l1=xc?fu(xc):Eh;function o1(x){return typeof x=="string"||!Wn(x)&&Ua(x)&&Iu(x)==Ae}function os(x){return typeof x=="symbol"||Ua(x)&&Iu(x)==Ue}var Kp=ld?fu(ld):Tg;function P4(x){return x===n}function _5(x){return Ua(x)&&Ir(x)==Ye}function WS(x){return Ua(x)&&Iu(x)==Me}var E5=wd(Yi),JS=wd(function(x,w){return x<=w});function e_(x){if(!x)return[];if(ls(x))return o1(x)?fr(x):rl(x);if(na&&x[na])return Sr(x[na]());var w=Ir(x),Z=w==ge?vh:w==$e?Kn:ov;return Z(x)}function zh(x){if(!x)return x===0?x:0;if(x=Ws(x),x===J||x===-J){var w=x<0?-1:1;return w*H}return x===x?x:0}function qn(x){var w=zh(x),Z=w%1;return w===w?Z?w-Z:w:0}function M4(x){return x?Qs(qn(x),0,K):0}function Ws(x){if(typeof x=="number")return x;if(os(x))return M;if(va(x)){var w=typeof x.valueOf=="function"?x.valueOf():x;x=va(w)?w+"":w}if(typeof x!="string")return x===0?x:+x;x=Ms(x);var Z=mi.test(x);return Z||wu.test(x)?rd(x.slice(2),Z?2:8):Da.test(x)?M:+x}function tO(x){return ts(x,ss(x))}function D5(x){return x?Qs(qn(x),-te,te):x===0?x:0}function xi(x){return x==null?"":ql(x)}var t_=Ed(function(x,w){if(Df(w)||ls(w)){ts(w,fl(w),x);return}for(var Z in w)_r.call(w,Z)&&Bs(x,Z,w[Z])}),nO=Ed(function(x,w){ts(w,ss(w),x)}),rv=Ed(function(x,w,Z,ae){ts(w,ss(w),x,ae)}),$5=Ed(function(x,w,Z,ae){ts(w,fl(w),x,ae)}),Uc=Ul(Ip);function F4(x,w){var Z=bl(x);return w==null?Z:Cg(Z,w)}var n_=Jn(function(x,w){x=Nr(x);var Z=-1,ae=w.length,he=ae>2?w[2]:n;for(he&&Ci(w[0],w[1],he)&&(ae=1);++Z<ae;)for(var Ce=w[Z],Pe=ss(Ce),qe=-1,Je=Pe.length;++qe<Je;){var St=Pe[qe],_t=x[St];(_t===n||Gs(_t,fo[St])&&!_r.call(x,St))&&(x[St]=Ce[St])}return x}),r_=Jn(function(x){return x.push(n,Ky),fa(av,n,x)});function i_(x,w){return W0(x,Sn(w,3),Ja)}function s1(x,w){return W0(x,Sn(w,3),eu)}function jc(x,w){return x==null?x:_h(x,Sn(w,3),ss)}function a_(x,w){return x==null?x:xd(x,Sn(w,3),ss)}function rO(x,w){return x&&Ja(x,Sn(w,3))}function qh(x,w){return x&&eu(x,Sn(w,3))}function C5(x){return x==null?[]:tl(x,fl(x))}function w5(x){return x==null?[]:tl(x,ss(x))}function Wp(x,w,Z){var ae=x==null?n:wa(x,w);return ae===n?Z:ae}function u_(x,w){return x!=null&&Th(x,w,tu)}function N4(x,w){return x!=null&&Th(x,w,Jo)}var R5=Fc(function(x,w,Z){w!=null&&typeof w.toString!="function"&&(w=da.call(w)),x[w]=Z},cv(Co)),A5=Fc(function(x,w,Z){w!=null&&typeof w.toString!="function"&&(w=da.call(w)),_r.call(x,w)?x[w].push(Z):x[w]=[Z]},Sn),T5=Jn(go);function fl(x){return ls(x)?Np(x):es(x)}function ss(x){return ls(x)?Np(x,!0):y4(x)}function k5(x,w){var Z={};return w=Sn(w,3),Ja(x,function(ae,he,Ce){Ju(Z,w(ae,he,Ce),ae)}),Z}function l_(x,w){var Z={};return w=Sn(w,3),Ja(x,function(ae,he,Ce){Ju(Z,he,w(ae,he,Ce))}),Z}var iv=Ed(function(x,w,Z){sm(x,w,Z)}),av=Ed(function(x,w,Z,ae){sm(x,w,Z,ae)}),o_=Ul(function(x,w){var Z={};if(x==null)return Z;var ae=!1;w=vi(w,function(Ce){return Ce=vo(Ce,x),ae||(ae=Ce.length>1),Ce}),ts(x,Ol(x),Z),ae&&(Z=el(Z,d|h|m,Hg));for(var he=w.length;he--;)qp(Z,w[he]);return Z});function P5(x,w){return lv(x,Gb(Sn(w)))}var uv=Ul(function(x,w){return x==null?{}:Py(x,w)});function lv(x,w){if(x==null)return{};var Z=vi(Ol(x),function(ae){return[ae]});return w=Sn(w),nl(x,Z,function(ae,he){return w(ae,he[0])})}function s_(x,w,Z){w=vo(w,x);var ae=-1,he=w.length;for(he||(he=1,x=n);++ae<he;){var Ce=x==null?n:x[ru(w[ae])];Ce===n&&(ae=he,Ce=Z),x=Ks(Ce)?Ce.call(x):Ce}return x}function iO(x,w,Z){return x==null?x:$h(x,w,Z)}function I4(x,w,Z,ae){return ae=typeof ae=="function"?ae:n,x==null?x:$h(x,w,Z,ae)}var aO=Gy(fl),c1=Gy(ss);function c_(x,w,Z){var ae=Wn(x),he=ae||Gp(x)||Kp(x);if(w=Sn(w,4),Z==null){var Ce=x&&x.constructor;he?Z=ae?new Ce:[]:va(x)?Z=Ks(Ce)?bl(Ku(x)):{}:Z={}}return(he?La:Ja)(x,function(Pe,qe,Je){return w(Z,Pe,qe,Je)}),Z}function f_(x,w){return x==null?!0:qp(x,w)}function M5(x,w,Z){return x==null?x:Qy(x,w,Qg(Z))}function d_(x,w,Z,ae){return ae=typeof ae=="function"?ae:n,x==null?x:Qy(x,w,Qg(Z),ae)}function ov(x){return x==null?[]:Tp(x,fl(x))}function L4(x){return x==null?[]:Tp(x,ss(x))}function F5(x,w,Z){return Z===n&&(Z=w,w=n),Z!==n&&(Z=Ws(Z),Z=Z===Z?Z:0),w!==n&&(w=Ws(w),w=w===w?w:0),Qs(Ws(x),w,Z)}function uO(x,w,Z){return w=zh(w),Z===n?(Z=w,w=0):Z=zh(Z),x=Ws(x),Sd(x,w,Z)}function lO(x,w,Z){if(Z&&typeof Z!="boolean"&&Ci(x,w,Z)&&(w=Z=n),Z===n&&(typeof w=="boolean"?(Z=w,w=n):typeof x=="boolean"&&(Z=x,x=n)),x===n&&w===n?(x=0,w=1):(x=zh(x),w===n?(w=x,x=0):w=zh(w)),x>w){var ae=x;x=w,w=ae}if(Z||x%1||w%1){var he=Pu();return Ei(x+he*(w-x+Rs("1e-"+((he+"").length-1))),w)}return zp(x,w)}var oO=Dd(function(x,w,Z){return w=w.toLowerCase(),x+(Z?h_(w):w)});function h_(x){return wm(xi(x).toLowerCase())}function sv(x){return x=xi(x),x&&x.replace(Hr,dd).replace(_p,"")}function N5(x,w,Z){x=xi(x),w=ql(w);var ae=x.length;Z=Z===n?ae:Qs(qn(Z),0,ae);var he=Z;return Z-=w.length,Z>=0&&x.slice(Z,he)==w}function p_(x){return x=xi(x),x&&cr.test(x)?x.replace(ln,Yu):x}function m_(x){return x=xi(x),x&&$t.test(x)?x.replace(dt,"\\$&"):x}var g_=Dd(function(x,w,Z){return x+(Z?"-":"")+w.toLowerCase()}),v_=Dd(function(x,w,Z){return x+(Z?" ":"")+w.toLowerCase()}),B4=Ou("toLowerCase");function y_(x,w,Z){x=xi(x),w=qn(w);var ae=w?hu(x):0;if(!w||ae>=w)return x;var he=(w-ae)/2;return Cd(Oh(he),Z)+x+Cd(_f(he),Z)}function b_(x,w,Z){x=xi(x),w=qn(w);var ae=w?hu(x):0;return w&&ae<w?x+Cd(w-ae,Z):x}function sO(x,w,Z){x=xi(x),w=qn(w);var ae=w?hu(x):0;return w&&ae<w?Cd(w-ae,Z)+x:x}function I5(x,w,Z){return Z||w==null?w=0:w&&(w=+w),pn(xi(x).replace(Ut,""),w||0)}function L5(x,w,Z){return(Z?Ci(x,w,Z):w===n)?w=1:w=qn(w),zs(xi(x),w)}function Q4(){var x=arguments,w=xi(x[0]);return x.length<3?w:w.replace(x[1],x[2])}var z4=Dd(function(x,w,Z){return x+(Z?"_":"")+w.toLowerCase()});function cO(x,w,Z){return Z&&typeof Z!="number"&&Ci(x,w,Z)&&(w=Z=n),Z=Z===n?K:Z>>>0,Z?(x=xi(x),x&&(typeof w=="string"||w!=null&&!u1(w))&&(w=ql(w),!w&&du(x))?qs(fr(x),0,Z):x.split(w,Z)):[]}var q4=Dd(function(x,w,Z){return x+(Z?" ":"")+wm(w)});function O_(x,w,Z){return x=xi(x),Z=Z==null?0:Qs(qn(Z),0,x.length),w=ql(w),x.slice(Z,Z+w.length)==w}function V4(x,w,Z){var ae=Se.templateSettings;Z&&Ci(x,w,Z)&&(w=n),x=xi(x),w=rv({},w,ae,Zg);var he=rv({},w.imports,ae.imports,Zg),Ce=fl(he),Pe=Tp(he,Ce),qe,Je,St=0,_t=w.interpolate||Pt,wt="__p += '",Jt=Ya((w.escape||Pt).source+"|"+_t.source+"|"+(_t===Vr?gr:Pt).source+"|"+(w.evaluate||Pt).source+"|$","g"),On="//# sourceURL="+(_r.call(w,"sourceURL")?(w.sourceURL+"").replace(/\s/g," "):"lodash.templateSources["+ ++dh+"]")+`
`;x.replace(Jt,function(Un,Qr,Wr,Pf,Js,Mf){return Wr||(Wr=Pf),wt+=x.slice(St,Mf).replace(ca,so),Qr&&(qe=!0,wt+=`' +
__e(`+Qr+`) +
'`),Js&&(Je=!0,wt+=`';
`+Js+`;
__p += '`),Wr&&(wt+=`' +
((__t = (`+Wr+`)) == null ? '' : __t) +
'`),St=Mf+Un.length,Un}),wt+=`';
`;var Vn=_r.call(w,"variable")&&w.variable;if(!Vn)wt=`with (obj) {
`+wt+`
}
`;else if(Rt.test(Vn))throw new Dn(l);wt=(Je?wt.replace(Tt,""):wt).replace(Qt,"$1").replace(un,"$1;"),wt="function("+(Vn||"obj")+`) {
`+(Vn?"":`obj || (obj = {});
`)+"var __t, __p = ''"+(qe?", __e = _.escape":"")+(Je?`, __j = Array.prototype.join;
function print() { __p += __j.call(arguments, '') }
`:`;
`)+wt+`return __p
}`;var br=U4(function(){return rr(Ce,On+"return "+wt).apply(n,Pe)});if(br.source=wt,Jb(br))throw br;return br}function Jp(x){return xi(x).toLowerCase()}function e0(x){return xi(x).toUpperCase()}function t0(x,w,Z){if(x=xi(x),x&&(Z||w===n))return Ms(x);if(!x||!(w=ql(w)))return x;var ae=fr(x),he=fr(w),Ce=kp(ae,he),Pe=fd(ae,he)+1;return qs(ae,Ce,Pe).join("")}function f1(x,w,Z){if(x=xi(x),x&&(Z||w===n))return x.slice(0,Of(x)+1);if(!x||!(w=ql(w)))return x;var ae=fr(x),he=fd(ae,fr(w))+1;return qs(ae,0,he).join("")}function d1(x,w,Z){if(x=xi(x),x&&(Z||w===n))return x.replace(Ut,"");if(!x||!(w=ql(w)))return x;var ae=fr(x),he=kp(ae,fr(w));return qs(ae,he).join("")}function n0(x,w){var Z=j,ae=V;if(va(w)){var he="separator"in w?w.separator:he;Z="length"in w?qn(w.length):Z,ae="omission"in w?ql(w.omission):ae}x=xi(x);var Ce=x.length;if(du(x)){var Pe=fr(x);Ce=Pe.length}if(Z>=Ce)return x;var qe=Z-hu(ae);if(qe<1)return ae;var Je=Pe?qs(Pe,0,qe).join(""):x.slice(0,qe);if(he===n)return Je+ae;if(Pe&&(qe+=Je.length-qe),u1(he)){if(x.slice(qe).search(he)){var St,_t=Je;for(he.global||(he=Ya(he.source,xi(Pi.exec(he))+"g")),he.lastIndex=0;St=he.exec(_t);)var wt=St.index;Je=Je.slice(0,wt===n?qe:wt)}}else if(x.indexOf(ql(he),qe)!=qe){var Jt=Je.lastIndexOf(he);Jt>-1&&(Je=Je.slice(0,Jt))}return Je+ae}function B5(x){return x=xi(x),x&&Zn.test(x)?x.replace(Ln,tm):x}var x_=Dd(function(x,w,Z){return x+(Z?" ":"")+w.toUpperCase()}),wm=Ou("toUpperCase");function S_(x,w,Z){return x=xi(x),w=Z?n:w,w===n?bf(x)?rm(x):Dy(x):x.match(w)||[]}var U4=Jn(function(x,w){try{return fa(x,n,w)}catch(Z){return Jb(Z)?Z:new Dn(Z)}}),fO=Ul(function(x,w){return La(w,function(Z){Z=ru(Z),Ju(x,Z,Er(x[Z],x))}),x});function __(x){var w=x==null?0:x.length,Z=Sn();return x=w?vi(x,function(ae){if(typeof ae[1]!="function")throw new _i(u);return[Z(ae[0]),ae[1]]}):[],Jn(function(ae){for(var he=-1;++he<w;){var Ce=x[he];if(fa(Ce[0],this,ae))return fa(Ce[1],this,ae)}})}function Q5(x){return Lp(el(x,d))}function cv(x){return function(){return x}}function dO(x,w){return x==null||x!==x?w:x}var E_=Ch(),fv=Ch(!0);function Co(x){return x}function h1(x){return Bp(typeof x=="function"?x:el(x,d))}function hO(x){return Pg(el(x,d))}function D_(x,w){return ky(x,el(w,d))}var z5=Jn(function(x,w){return function(Z){return go(Z,x,w)}}),pO=Jn(function(x,w){return function(Z){return go(x,Z,w)}});function f(x,w,Z){var ae=fl(w),he=tl(w,ae);Z==null&&!(va(w)&&(he.length||!ae.length))&&(Z=w,w=x,x=this,he=tl(w,fl(w)));var Ce=!(va(Z)&&"chain"in Z)||!!Z.chain,Pe=Ks(x);return La(he,function(qe){var Je=w[qe];x[qe]=Je,Pe&&(x.prototype[qe]=function(){var St=this.__chain__;if(Ce||St){var _t=x(this.__wrapped__),wt=_t.__actions__=rl(this.__actions__);return wt.push({func:Je,args:arguments,thisArg:x}),_t.__chain__=St,_t}return Je.apply(x,Vo([this.value()],arguments))})}),x}function p(){return ta._===this&&(ta._=Ca),this}function O(){}function D(x){return x=qn(x),Jn(function(w){return Mg(w,x)})}var Q=il(vi),Y=il($p),ce=il(Rp);function Ee(x){return Ic(x)?Uo(ru(x)):Ra(x)}function Le(x){return function(w){return x==null?n:wa(x,w)}}var at=wh(),mt=wh(!0);function xt(){return[]}function lt(){return!1}function ft(){return{}}function fn(){return""}function An(){return!0}function Li(x,w){if(x=qn(x),x<1||x>te)return[];var Z=K,ae=Ei(x,K);w=Sn(w),x-=K;for(var he=sd(ae,w);++Z<x;)w(Z);return he}function Ke(x){return Wn(x)?vi(x,ru):os(x)?[x]:rl(Gg(xi(x)))}function Ve(x){var w=++jo;return xi(x)+w}var it=Nc(function(x,w){return x+w},0),yt=Ah("ceil"),En=Nc(function(x,w){return x/w},1),ai=Ah("floor");function mn(x){return x&&x.length?Wo(x,Co,yu):n}function or(x,w){return x&&x.length?Wo(x,Sn(w,2),yu):n}function Pr(x){return Sc(x,Co)}function ui(x,w){return Sc(x,Sn(w,2))}function r0(x){return x&&x.length?Wo(x,Co,Yi):n}function q5(x,w){return x&&x.length?Wo(x,Sn(w,2),Yi):n}var zbe=Nc(function(x,w){return x*w},1),qbe=Ah("round"),Vbe=Nc(function(x,w){return x-w},0);function Ube(x){return x&&x.length?gh(x,Co):0}function jbe(x,w){return x&&x.length?gh(x,Sn(w,2)):0}return Se.after=kn,Se.ary=kr,Se.assign=t_,Se.assignIn=nO,Se.assignInWith=rv,Se.assignWith=$5,Se.at=Uc,Se.before=Va,Se.bind=Er,Se.bindAll=fO,Se.bindKey=Vc,Se.castArray=O5,Se.chain=zc,Se.chunk=za,Se.compact=Bc,Se.concat=er,Se.cond=__,Se.conforms=Q5,Se.constant=cv,Se.countBy=tv,Se.create=F4,Se.curry=Dm,Se.curryRight=x4,Se.debounce=S4,Se.defaults=n_,Se.defaultsDeep=r_,Se.defer=wi,Se.delay=_4,Se.difference=Yr,Se.differenceBy=Aa,Se.differenceWith=as,Se.drop=Vi,Se.dropRight=wf,Se.dropRightWhile=Om,Se.dropWhile=ma,Se.fill=jp,Se.filter=Bh,Se.flatMap=b,Se.flatMapDeep=A,Se.flatMapDepth=z,Se.flatten=Rr,Se.flattenDeep=qa,Se.flattenDepth=ll,Se.flip=v5,Se.flow=E_,Se.flowRight=fv,Se.fromPairs=Pd,Se.functions=C5,Se.functionsIn=w5,Se.groupBy=De,Se.initial=Xb,Se.intersection=Ta,Se.intersectionBy=ol,Se.intersectionWith=Zl,Se.invert=R5,Se.invertBy=A5,Se.invokeMap=We,Se.iteratee=h1,Se.keyBy=vt,Se.keys=fl,Se.keysIn=ss,Se.map=kt,Se.mapKeys=k5,Se.mapValues=l_,Se.matches=hO,Se.matchesProperty=D_,Se.memoize=t1,Se.merge=iv,Se.mergeWith=av,Se.method=z5,Se.methodOf=pO,Se.mixin=f,Se.negate=Gb,Se.nthArg=D,Se.omit=o_,Se.omitBy=P5,Se.once=y5,Se.orderBy=Ht,Se.over=Q,Se.overArgs=b5,Se.overEvery=Y,Se.overSome=ce,Se.partial=nv,Se.partialRight=$m,Se.partition=Wt,Se.pick=uv,Se.pickBy=lv,Se.property=Ee,Se.propertyOf=Le,Se.pull=Mh,Se.pullAll=Gr,Se.pullAllBy=Kg,Se.pullAllWith=Af,Se.pullAt=au,Se.range=at,Se.rangeRight=mt,Se.rearg=E4,Se.reject=Em,Se.remove=ra,Se.rest=Kb,Se.reverse=Qc,Se.sampleSize=ut,Se.set=iO,Se.setWith=I4,Se.shuffle=Ge,Se.slice=Zp,Se.sortBy=gn,Se.sortedUniq=Wg,Se.sortedUniqBy=_m,Se.split=cO,Se.spread=D4,Se.tail=Jg,Se.take=ev,Se.takeRight=Ar,Se.takeRightWhile=ii,Se.takeWhile=tr,Se.tap=Hp,Se.throttle=Yp,Se.thru=cl,Se.toArray=e_,Se.toPairs=aO,Se.toPairsIn=c1,Se.toPath=Ke,Se.toPlainObject=tO,Se.transform=c_,Se.unary=Fd,Se.union=yr,Se.unionBy=bn,Se.unionWith=dr,Se.uniq=Yn,Se.uniqBy=lr,Se.uniqWith=Oi,Se.unset=f_,Se.unzip=ia,Se.unzipWith=Kr,Se.update=M5,Se.updateWith=d_,Se.values=ov,Se.valuesIn=L4,Se.without=Eo,Se.words=S_,Se.wrap=n1,Se.xor=Tf,Se.xorBy=Hs,Se.xorWith=Tr,Se.zip=Do,Se.zipObject=Xs,Se.zipObjectDeep=sl,Se.zipWith=Xl,Se.entries=aO,Se.entriesIn=c1,Se.extend=nO,Se.extendWith=rv,f(Se,Se),Se.add=it,Se.attempt=U4,Se.camelCase=oO,Se.capitalize=h_,Se.ceil=yt,Se.clamp=F5,Se.clone=qS,Se.cloneDeep=US,Se.cloneDeepWith=jS,Se.cloneWith=VS,Se.conformsTo=x5,Se.deburr=sv,Se.defaultTo=dO,Se.divide=En,Se.endsWith=N5,Se.eq=Gs,Se.escape=p_,Se.escapeRegExp=m_,Se.every=Lh,Se.find=_l,Se.findIndex=Jy,Se.findKey=i_,Se.findLast=g,Se.findLastIndex=xm,Se.findLastKey=s1,Se.floor=ai,Se.forEach=ee,Se.forEachRight=le,Se.forIn=jc,Se.forInRight=a_,Se.forOwn=rO,Se.forOwnRight=qh,Se.get=Wp,Se.gt=ZS,Se.gte=HS,Se.has=u_,Se.hasIn=N4,Se.head=Sm,Se.identity=Co,Se.includes=Ie,Se.indexOf=e1,Se.inRange=uO,Se.invoke=T5,Se.isArguments=Cm,Se.isArray=Wn,Se.isArrayBuffer=$4,Se.isArrayLike=ls,Se.isArrayLikeObject=uu,Se.isBoolean=r1,Se.isBuffer=Gp,Se.isDate=XS,Se.isElement=Dr,Se.isEmpty=C4,Se.isEqual=Wb,Se.isEqualWith=w4,Se.isError=Jb,Se.isFinite=R4,Se.isFunction=Ks,Se.isInteger=i1,Se.isLength=eO,Se.isMap=YS,Se.isMatch=GS,Se.isMatchWith=KS,Se.isNaN=Ii,Se.isNative=A4,Se.isNil=S5,Se.isNull=El,Se.isNumber=T4,Se.isObject=va,Se.isObjectLike=Ua,Se.isPlainObject=a1,Se.isRegExp=u1,Se.isSafeInteger=k4,Se.isSet=l1,Se.isString=o1,Se.isSymbol=os,Se.isTypedArray=Kp,Se.isUndefined=P4,Se.isWeakMap=_5,Se.isWeakSet=WS,Se.join=Md,Se.kebabCase=g_,Se.last=Br,Se.lastIndexOf=Yb,Se.lowerCase=v_,Se.lowerFirst=B4,Se.lt=E5,Se.lte=JS,Se.max=mn,Se.maxBy=or,Se.mean=Pr,Se.meanBy=ui,Se.min=r0,Se.minBy=q5,Se.stubArray=xt,Se.stubFalse=lt,Se.stubObject=ft,Se.stubString=fn,Se.stubTrue=An,Se.multiply=zbe,Se.nth=Rf,Se.noConflict=p,Se.noop=O,Se.now=fi,Se.pad=y_,Se.padEnd=b_,Se.padStart=sO,Se.parseInt=I5,Se.random=lO,Se.reduce=Hn,Se.reduceRight=Yl,Se.repeat=L5,Se.replace=Q4,Se.result=s_,Se.round=qbe,Se.runInContext=Xe,Se.sample=Qh,Se.size=ct,Se.snakeCase=z4,Se.some=At,Se.sortedIndex=ga,Se.sortedIndexBy=Fh,Se.sortedIndexOf=ka,Se.sortedLastIndex=Hl,Se.sortedLastIndexBy=Sl,Se.sortedLastIndexOf=Nh,Se.startCase=q4,Se.startsWith=O_,Se.subtract=Vbe,Se.sum=Ube,Se.sumBy=jbe,Se.template=V4,Se.times=Li,Se.toFinite=zh,Se.toInteger=qn,Se.toLength=M4,Se.toLower=Jp,Se.toNumber=Ws,Se.toSafeInteger=D5,Se.toString=xi,Se.toUpper=e0,Se.trim=t0,Se.trimEnd=f1,Se.trimStart=d1,Se.truncate=n0,Se.unescape=B5,Se.uniqueId=Ve,Se.upperCase=x_,Se.upperFirst=wm,Se.each=ee,Se.eachRight=le,Se.first=Sm,f(Se,(function(){var x={};return Ja(Se,function(w,Z){_r.call(Se.prototype,Z)||(x[Z]=w)}),x})(),{chain:!1}),Se.VERSION=r,La(["bind","bindKey","curry","curryRight","partial","partialRight"],function(x){Se[x].placeholder=Se}),La(["drop","take"],function(x,w){zn.prototype[x]=function(Z){Z=Z===n?1:Ni(qn(Z),0);var ae=this.__filtered__&&!w?new zn(this):this.clone();return ae.__filtered__?ae.__takeCount__=Ei(Z,ae.__takeCount__):ae.__views__.push({size:Ei(Z,K),type:x+(ae.__dir__<0?"Right":"")}),ae},zn.prototype[x+"Right"]=function(Z){return this.reverse()[x](Z).reverse()}}),La(["filter","map","takeWhile"],function(x,w){var Z=w+1,ae=Z==U||Z==G;zn.prototype[x]=function(he){var Ce=this.clone();return Ce.__iteratees__.push({iteratee:Sn(he,3),type:Z}),Ce.__filtered__=Ce.__filtered__||ae,Ce}}),La(["head","last"],function(x,w){var Z="take"+(w?"Right":"");zn.prototype[x]=function(){return this[Z](1).value()[0]}}),La(["initial","tail"],function(x,w){var Z="drop"+(w?"":"Right");zn.prototype[x]=function(){return this.__filtered__?new zn(this):this[Z](1)}}),zn.prototype.compact=function(){return this.filter(Co)},zn.prototype.find=function(x){return this.filter(x).head()},zn.prototype.findLast=function(x){return this.reverse().find(x)},zn.prototype.invokeMap=Jn(function(x,w){return typeof x=="function"?new zn(this):this.map(function(Z){return go(Z,x,w)})}),zn.prototype.reject=function(x){return this.filter(Gb(Sn(x)))},zn.prototype.slice=function(x,w){x=qn(x);var Z=this;return Z.__filtered__&&(x>0||w<0)?new zn(Z):(x<0?Z=Z.takeRight(-x):x&&(Z=Z.drop(x)),w!==n&&(w=qn(w),Z=w<0?Z.dropRight(-w):Z.take(w-x)),Z)},zn.prototype.takeRightWhile=function(x){return this.reverse().takeWhile(x).reverse()},zn.prototype.toArray=function(){return this.take(K)},Ja(zn.prototype,function(x,w){var Z=/^(?:filter|find|map|reject)|While$/.test(w),ae=/^(?:head|last)$/.test(w),he=Se[ae?"take"+(w=="last"?"Right":""):w],Ce=ae||/^find/.test(w);he&&(Se.prototype[w]=function(){var Pe=this.__wrapped__,qe=ae?[1]:arguments,Je=Pe instanceof zn,St=qe[0],_t=Je||Wn(Pe),wt=function(Qr){var Wr=he.apply(Se,Vo([Qr],qe));return ae&&Jt?Wr[0]:Wr};_t&&Z&&typeof St=="function"&&St.length!=1&&(Je=_t=!1);var Jt=this.__chain__,On=!!this.__actions__.length,Vn=Ce&&!Jt,br=Je&&!On;if(!Ce&&_t){Pe=br?Pe:new zn(this);var Un=x.apply(Pe,qe);return Un.__actions__.push({func:cl,args:[wt],thisArg:n}),new Mu(Un,Jt)}return Vn&&br?x.apply(this,qe):(Un=this.thru(wt),Vn?ae?Un.value()[0]:Un.value():Un)})}),La(["pop","push","shift","sort","splice","unshift"],function(x){var w=hd[x],Z=/^(?:push|sort|unshift)$/.test(x)?"tap":"thru",ae=/^(?:pop|shift)$/.test(x);Se.prototype[x]=function(){var he=arguments;if(ae&&!this.__chain__){var Ce=this.value();return w.apply(Wn(Ce)?Ce:[],he)}return this[Z](function(Pe){return w.apply(Wn(Pe)?Pe:[],he)})}}),Ja(zn.prototype,function(x,w){var Z=Se[w];if(Z){var ae=Z.name+"";_r.call(Be,ae)||(Be[ae]=[]),Be[ae].push({name:w,func:Z})}}),Be[$d(n,S).name]=[{name:"wrapper",func:n}],zn.prototype.clone=Ka,zn.prototype.reverse=Ns,zn.prototype.value=Ll,Se.prototype.at=Xp,Se.prototype.chain=qc,Se.prototype.commit=aa,Se.prototype.next=Ys,Se.prototype.plant=us,Se.prototype.reverse=kf,Se.prototype.toJSON=Se.prototype.valueOf=Se.prototype.value=Ih,Se.prototype.first=Se.prototype.head,na&&(Se.prototype[na]=$o),Se}),_c=xf();Pl?((Pl.exports=_c)._=_c,As._=_c):ta._=_c}).call(oZe)})(B2,B2.exports)),B2.exports}var Kut=sZe(),cZe=yI();const Wut=sa(cZe),n5=P.createContext(null);n5.displayName="PanelGroupContext";const Su={group:"data-panel-group",groupDirection:"data-panel-group-direction",groupId:"data-panel-group-id",panel:"data-panel",panelCollapsible:"data-panel-collapsible",panelId:"data-panel-id",panelSize:"data-panel-size",resizeHandle:"data-resize-handle",resizeHandleActive:"data-resize-handle-active",resizeHandleEnabled:"data-panel-resize-handle-enabled",resizeHandleId:"data-panel-resize-handle-id",resizeHandleState:"data-resize-handle-state"},tB=10,K1=P.useLayoutEffect,vK=Y7.useId,fZe=typeof vK=="function"?vK:()=>null;let dZe=0;function nB(e=null){const t=fZe(),n=P.useRef(e||t||null);return n.current===null&&(n.current=""+dZe++),e??n.current}function Aye({children:e,className:t="",collapsedSize:n,collapsible:r,defaultSize:i,forwardedRef:a,id:u,maxSize:l,minSize:o,onCollapse:s,onExpand:c,onResize:d,order:h,style:m,tagName:y="div",...v}){const _=P.useContext(n5);if(_===null)throw Error("Panel components must be rendered within a PanelGroup container");const{collapsePanel:S,expandPanel:E,getPanelSize:C,getPanelStyle:T,groupId:R,isPanelCollapsed:$,reevaluatePanelConstraints:k,registerPanel:F,resizePanel:L,unregisterPanel:j}=_,V=nB(u),q=P.useRef({callbacks:{onCollapse:s,onExpand:c,onResize:d},constraints:{collapsedSize:n,collapsible:r,defaultSize:i,maxSize:l,minSize:o},id:V,idIsFromProps:u!==void 0,order:h});P.useRef({didLogMissingDefaultSizeWarning:!1}),K1(()=>{const{callbacks:U,constraints:W}=q.current,G={...W};q.current.id=V,q.current.idIsFromProps=u!==void 0,q.current.order=h,U.onCollapse=s,U.onExpand=c,U.onResize=d,W.collapsedSize=n,W.collapsible=r,W.defaultSize=i,W.maxSize=l,W.minSize=o,(G.collapsedSize!==W.collapsedSize||G.collapsible!==W.collapsible||G.maxSize!==W.maxSize||G.minSize!==W.minSize)&&k(q.current,G)}),K1(()=>{const U=q.current;return F(U),()=>{j(U)}},[h,V,F,j]),P.useImperativeHandle(a,()=>({collapse:()=>{S(q.current)},expand:U=>{E(q.current,U)},getId(){return V},getSize(){return C(q.current)},isCollapsed(){return $(q.current)},isExpanded(){return!$(q.current)},resize:U=>{L(q.current,U)}}),[S,E,C,$,V,L]);const N=T(q.current,i);return P.createElement(y,{...v,children:e,className:t,id:V,style:{...N,...m},[Su.groupId]:R,[Su.panel]:"",[Su.panelCollapsible]:r||void 0,[Su.panelId]:V,[Su.panelSize]:parseFloat(""+N.flexGrow).toFixed(1)})}const hZe=P.forwardRef((e,t)=>P.createElement(Aye,{...e,forwardedRef:t}));Aye.displayName="Panel";hZe.displayName="forwardRef(Panel)";let oF=null,gD=-1,kv=null;function pZe(e,t){if(t){const n=(t&Fye)!==0,r=(t&Nye)!==0,i=(t&Iye)!==0,a=(t&Lye)!==0;if(n)return i?"se-resize":a?"ne-resize":"e-resize";if(r)return i?"sw-resize":a?"nw-resize":"w-resize";if(i)return"s-resize";if(a)return"n-resize"}switch(e){case"horizontal":return"ew-resize";case"intersection":return"move";case"vertical":return"ns-resize"}}function mZe(){kv!==null&&(document.head.removeChild(kv),oF=null,kv=null,gD=-1)}function u7(e,t){var n,r;const i=pZe(e,t);if(oF!==i){if(oF=i,kv===null&&(kv=document.createElement("style"),document.head.appendChild(kv)),gD>=0){var a;(a=kv.sheet)===null||a===void 0||a.removeRule(gD)}gD=(n=(r=kv.sheet)===null||r===void 0?void 0:r.insertRule(`*{cursor: ${i} !important;}`))!==null&&n!==void 0?n:-1}}function Tye(e){return e.type==="keydown"}function kye(e){return e.type.startsWith("pointer")}function Pye(e){return e.type.startsWith("mouse")}function r5(e){if(kye(e)){if(e.isPrimary)return{x:e.clientX,y:e.clientY}}else if(Pye(e))return{x:e.clientX,y:e.clientY};return{x:1/0,y:1/0}}function gZe(){if(typeof matchMedia=="function")return matchMedia("(pointer:coarse)").matches?"coarse":"fine"}function vZe(e,t,n){return e.x<t.x+t.width&&e.x+e.width>t.x&&e.y<t.y+t.height&&e.y+e.height>t.y}function yZe(e,t){if(e===t)throw new Error("Cannot compare node with itself");const n={a:OK(e),b:OK(t)};let r;for(;n.a.at(-1)===n.b.at(-1);)e=n.a.pop(),t=n.b.pop(),r=e;xr(r,"Stacking order can only be calculated for elements with a common ancestor");const i={a:bK(yK(n.a)),b:bK(yK(n.b))};if(i.a===i.b){const a=r.childNodes,u={a:n.a.at(-1),b:n.b.at(-1)};let l=a.length;for(;l--;){const o=a[l];if(o===u.a)return 1;if(o===u.b)return-1}}return Math.sign(i.a-i.b)}const bZe=/\b(?:position|zIndex|opacity|transform|webkitTransform|mixBlendMode|filter|webkitFilter|isolation)\b/;function OZe(e){var t;const n=getComputedStyle((t=Mye(e))!==null&&t!==void 0?t:e).display;return n==="flex"||n==="inline-flex"}function xZe(e){const t=getComputedStyle(e);return!!(t.position==="fixed"||t.zIndex!=="auto"&&(t.position!=="static"||OZe(e))||+t.opacity<1||"transform"in t&&t.transform!=="none"||"webkitTransform"in t&&t.webkitTransform!=="none"||"mixBlendMode"in t&&t.mixBlendMode!=="normal"||"filter"in t&&t.filter!=="none"||"webkitFilter"in t&&t.webkitFilter!=="none"||"isolation"in t&&t.isolation==="isolate"||bZe.test(t.willChange)||t.webkitOverflowScrolling==="touch")}function yK(e){let t=e.length;for(;t--;){const n=e[t];if(xr(n,"Missing node"),xZe(n))return n}return null}function bK(e){return e&&Number(getComputedStyle(e).zIndex)||0}function OK(e){const t=[];for(;e;)t.push(e),e=Mye(e);return t}function Mye(e){const{parentNode:t}=e;return t&&t instanceof ShadowRoot?t.host:t}const Fye=1,Nye=2,Iye=4,Lye=8,SZe=gZe()==="coarse";let ip=[],O3=!1,M1=new Map,i5=new Map;const Hx=new Set;function _Ze(e,t,n,r,i){var a;const{ownerDocument:u}=t,l={direction:n,element:t,hitAreaMargins:r,setResizeHandlerState:i},o=(a=M1.get(u))!==null&&a!==void 0?a:0;return M1.set(u,o+1),Hx.add(l),eC(),function(){var c;i5.delete(e),Hx.delete(l);const d=(c=M1.get(u))!==null&&c!==void 0?c:1;if(M1.set(u,d-1),eC(),d===1&&M1.delete(u),ip.includes(l)){const h=ip.indexOf(l);h>=0&&ip.splice(h,1),iB(),i("up",!0,null)}}}function EZe(e){const{target:t}=e,{x:n,y:r}=r5(e);O3=!0,rB({target:t,x:n,y:r}),eC(),ip.length>0&&(tC("down",e),e.preventDefault(),Bye(t)||e.stopImmediatePropagation())}function l7(e){const{x:t,y:n}=r5(e);if(O3&&e.buttons===0&&(O3=!1,tC("up",e)),!O3){const{target:r}=e;rB({target:r,x:t,y:n})}tC("move",e),iB(),ip.length>0&&e.preventDefault()}function o7(e){const{target:t}=e,{x:n,y:r}=r5(e);i5.clear(),O3=!1,ip.length>0&&(e.preventDefault(),Bye(t)||e.stopImmediatePropagation()),tC("up",e),rB({target:t,x:n,y:r}),iB(),eC()}function Bye(e){let t=e;for(;t;){if(t.hasAttribute(Su.resizeHandle))return!0;t=t.parentElement}return!1}function rB({target:e,x:t,y:n}){ip.splice(0);let r=null;(e instanceof HTMLElement||e instanceof SVGElement)&&(r=e),Hx.forEach(i=>{const{element:a,hitAreaMargins:u}=i,l=a.getBoundingClientRect(),{bottom:o,left:s,right:c,top:d}=l,h=SZe?u.coarse:u.fine;if(t>=s-h&&t<=c+h&&n>=d-h&&n<=o+h){if(r!==null&&document.contains(r)&&a!==r&&!a.contains(r)&&!r.contains(a)&&yZe(r,a)>0){let y=r,v=!1;for(;y&&!y.contains(a);){if(vZe(y.getBoundingClientRect(),l)){v=!0;break}y=y.parentElement}if(v)return}ip.push(i)}})}function s7(e,t){i5.set(e,t)}function iB(){let e=!1,t=!1;ip.forEach(r=>{const{direction:i}=r;i==="horizontal"?e=!0:t=!0});let n=0;i5.forEach(r=>{n|=r}),e&&t?u7("intersection",n):e?u7("horizontal",n):t?u7("vertical",n):mZe()}let c7=new AbortController;function eC(){c7.abort(),c7=new AbortController;const e={capture:!0,signal:c7.signal};Hx.size&&(O3?(ip.length>0&&M1.forEach((t,n)=>{const{body:r}=n;t>0&&(r.addEventListener("contextmenu",o7,e),r.addEventListener("pointerleave",l7,e),r.addEventListener("pointermove",l7,e))}),window.addEventListener("pointerup",o7,e),window.addEventListener("pointercancel",o7,e)):M1.forEach((t,n)=>{const{body:r}=n;t>0&&(r.addEventListener("pointerdown",EZe,e),r.addEventListener("pointermove",l7,e))}))}function tC(e,t){Hx.forEach(n=>{const{setResizeHandlerState:r}=n,i=ip.includes(n);r(e,i,t)})}function DZe(){const[e,t]=P.useState(0);return P.useCallback(()=>t(n=>n+1),[])}function xr(e,t){if(!e)throw console.error(t),Error(t)}function bb(e,t,n=tB){return e.toFixed(n)===t.toFixed(n)?0:e>t?1:-1}function Ym(e,t,n=tB){return bb(e,t,n)===0}function Lf(e,t,n){return bb(e,t,n)===0}function $Ze(e,t,n){if(e.length!==t.length)return!1;for(let r=0;r<e.length;r++){const i=e[r],a=t[r];if(!Lf(i,a,n))return!1}return!0}function GO({panelConstraints:e,panelIndex:t,size:n}){const r=e[t];xr(r!=null,`Panel constraints not found for index ${t}`);let{collapsedSize:i=0,collapsible:a,maxSize:u=100,minSize:l=0}=r;if(bb(n,l)<0)if(a){const o=(i+l)/2;bb(n,o)<0?n=i:n=l}else n=l;return n=Math.min(u,n),n=parseFloat(n.toFixed(tB)),n}function Q2({delta:e,initialLayout:t,panelConstraints:n,pivotIndices:r,prevLayout:i,trigger:a}){if(Lf(e,0))return t;const u=[...t],[l,o]=r;xr(l!=null,"Invalid first pivot index"),xr(o!=null,"Invalid second pivot index");let s=0;if(a==="keyboard"){{const d=e<0?o:l,h=n[d];xr(h,`Panel constraints not found for index ${d}`);const{collapsedSize:m=0,collapsible:y,minSize:v=0}=h;if(y){const _=t[d];if(xr(_!=null,`Previous layout not found for panel index ${d}`),Lf(_,m)){const S=v-_;bb(S,Math.abs(e))>0&&(e=e<0?0-S:S)}}}{const d=e<0?l:o,h=n[d];xr(h,`No panel constraints found for index ${d}`);const{collapsedSize:m=0,collapsible:y,minSize:v=0}=h;if(y){const _=t[d];if(xr(_!=null,`Previous layout not found for panel index ${d}`),Lf(_,v)){const S=_-m;bb(S,Math.abs(e))>0&&(e=e<0?0-S:S)}}}}{const d=e<0?1:-1;let h=e<0?o:l,m=0;for(;;){const v=t[h];xr(v!=null,`Previous layout not found for panel index ${h}`);const S=GO({panelConstraints:n,panelIndex:h,size:100})-v;if(m+=S,h+=d,h<0||h>=n.length)break}const y=Math.min(Math.abs(e),Math.abs(m));e=e<0?0-y:y}{let h=e<0?l:o;for(;h>=0&&h<n.length;){const m=Math.abs(e)-Math.abs(s),y=t[h];xr(y!=null,`Previous layout not found for panel index ${h}`);const v=y-m,_=GO({panelConstraints:n,panelIndex:h,size:v});if(!Lf(y,_)&&(s+=y-_,u[h]=_,s.toPrecision(3).localeCompare(Math.abs(e).toPrecision(3),void 0,{numeric:!0})>=0))break;e<0?h--:h++}}if($Ze(i,u))return i;{const d=e<0?o:l,h=t[d];xr(h!=null,`Previous layout not found for panel index ${d}`);const m=h+s,y=GO({panelConstraints:n,panelIndex:d,size:m});if(u[d]=y,!Lf(y,m)){let v=m-y,S=e<0?o:l;for(;S>=0&&S<n.length;){const E=u[S];xr(E!=null,`Previous layout not found for panel index ${S}`);const C=E+v,T=GO({panelConstraints:n,panelIndex:S,size:C});if(Lf(E,T)||(v-=T-E,u[S]=T),Lf(v,0))break;e>0?S--:S++}}}const c=u.reduce((d,h)=>h+d,0);return Lf(c,100)?u:i}function CZe({layout:e,panelsArray:t,pivotIndices:n}){let r=0,i=100,a=0,u=0;const l=n[0];xr(l!=null,"No pivot index found"),t.forEach((d,h)=>{const{constraints:m}=d,{maxSize:y=100,minSize:v=0}=m;h===l?(r=v,i=y):(a+=v,u+=y)});const o=Math.min(i,100-a),s=Math.max(r,100-u),c=e[l];return{valueMax:o,valueMin:s,valueNow:c}}function Xx(e,t=document){return Array.from(t.querySelectorAll(`[${Su.resizeHandleId}][data-panel-group-id="${e}"]`))}function Qye(e,t,n=document){const i=Xx(e,n).findIndex(a=>a.getAttribute(Su.resizeHandleId)===t);return i??null}function zye(e,t,n){const r=Qye(e,t,n);return r!=null?[r,r+1]:[-1,-1]}function qye(e,t=document){var n;if(t instanceof HTMLElement&&(t==null||(n=t.dataset)===null||n===void 0?void 0:n.panelGroupId)==e)return t;const r=t.querySelector(`[data-panel-group][data-panel-group-id="${e}"]`);return r||null}function a5(e,t=document){const n=t.querySelector(`[${Su.resizeHandleId}="${e}"]`);return n||null}function wZe(e,t,n,r=document){var i,a,u,l;const o=a5(t,r),s=Xx(e,r),c=o?s.indexOf(o):-1,d=(i=(a=n[c])===null||a===void 0?void 0:a.id)!==null&&i!==void 0?i:null,h=(u=(l=n[c+1])===null||l===void 0?void 0:l.id)!==null&&u!==void 0?u:null;return[d,h]}function RZe({committedValuesRef:e,eagerValuesRef:t,groupId:n,layout:r,panelDataArray:i,panelGroupElement:a,setLayout:u}){P.useRef({didWarnAboutMissingResizeHandle:!1}),K1(()=>{if(!a)return;const l=Xx(n,a);for(let o=0;o<i.length-1;o++){const{valueMax:s,valueMin:c,valueNow:d}=CZe({layout:r,panelsArray:i,pivotIndices:[o,o+1]}),h=l[o];if(h!=null){const m=i[o];xr(m,`No panel data found for index "${o}"`),h.setAttribute("aria-controls",m.id),h.setAttribute("aria-valuemax",""+Math.round(s)),h.setAttribute("aria-valuemin",""+Math.round(c)),h.setAttribute("aria-valuenow",d!=null?""+Math.round(d):"")}}return()=>{l.forEach((o,s)=>{o.removeAttribute("aria-controls"),o.removeAttribute("aria-valuemax"),o.removeAttribute("aria-valuemin"),o.removeAttribute("aria-valuenow")})}},[n,r,i,a]),P.useEffect(()=>{if(!a)return;const l=t.current;xr(l,"Eager values not found");const{panelDataArray:o}=l,s=qye(n,a);xr(s!=null,`No group found for id "${n}"`);const c=Xx(n,a);xr(c,`No resize handles found for group id "${n}"`);const d=c.map(h=>{const m=h.getAttribute(Su.resizeHandleId);xr(m,"Resize handle element has no handle id attribute");const[y,v]=wZe(n,m,o,a);if(y==null||v==null)return()=>{};const _=S=>{if(!S.defaultPrevented)switch(S.key){case"Enter":{S.preventDefault();const E=o.findIndex(C=>C.id===y);if(E>=0){const C=o[E];xr(C,`No panel data found for index ${E}`);const T=r[E],{collapsedSize:R=0,collapsible:$,minSize:k=0}=C.constraints;if(T!=null&&$){const F=Q2({delta:Lf(T,R)?k-R:R-T,initialLayout:r,panelConstraints:o.map(L=>L.constraints),pivotIndices:zye(n,m,a),prevLayout:r,trigger:"keyboard"});r!==F&&u(F)}}break}}};return h.addEventListener("keydown",_),()=>{h.removeEventListener("keydown",_)}});return()=>{d.forEach(h=>h())}},[a,e,t,n,r,i,u])}function xK(e,t){if(e.length!==t.length)return!1;for(let n=0;n<e.length;n++)if(e[n]!==t[n])return!1;return!0}function Vye(e,t){const n=e==="horizontal",{x:r,y:i}=r5(t);return n?r:i}function AZe(e,t,n,r,i){const a=n==="horizontal",u=a5(t,i);xr(u,`No resize handle element found for id "${t}"`);const l=u.getAttribute(Su.groupId);xr(l,"Resize handle element has no group id attribute");let{initialCursorPosition:o}=r;const s=Vye(n,e),c=qye(l,i);xr(c,`No group element found for id "${l}"`);const d=c.getBoundingClientRect(),h=a?d.width:d.height;return(s-o)/h*100}function TZe(e,t,n,r,i,a){if(Tye(e)){const u=n==="horizontal";let l=0;e.shiftKey?l=100:i!=null?l=i:l=10;let o=0;switch(e.key){case"ArrowDown":o=u?0:l;break;case"ArrowLeft":o=u?-l:0;break;case"ArrowRight":o=u?l:0;break;case"ArrowUp":o=u?0:-l;break;case"End":o=100;break;case"Home":o=-100;break}return o}else return r==null?0:AZe(e,t,n,r,a)}function kZe({panelDataArray:e}){const t=Array(e.length),n=e.map(a=>a.constraints);let r=0,i=100;for(let a=0;a<e.length;a++){const u=n[a];xr(u,`Panel constraints not found for index ${a}`);const{defaultSize:l}=u;l!=null&&(r++,t[a]=l,i-=l)}for(let a=0;a<e.length;a++){const u=n[a];xr(u,`Panel constraints not found for index ${a}`);const{defaultSize:l}=u;if(l!=null)continue;const o=e.length-r,s=i/o;r++,t[a]=s,i-=s}return t}function wO(e,t,n){t.forEach((r,i)=>{const a=e[i];xr(a,`Panel data not found for index ${i}`);const{callbacks:u,constraints:l,id:o}=a,{collapsedSize:s=0,collapsible:c}=l,d=n[o];if(d==null||r!==d){n[o]=r;const{onCollapse:h,onExpand:m,onResize:y}=u;y&&y(r,d),c&&(h||m)&&(m&&(d==null||Ym(d,s))&&!Ym(r,s)&&m(),h&&(d==null||!Ym(d,s))&&Ym(r,s)&&h())}})}function $E(e,t){if(e.length!==t.length)return!1;for(let n=0;n<e.length;n++)if(e[n]!=t[n])return!1;return!0}function PZe({defaultSize:e,dragState:t,layout:n,panelData:r,panelIndex:i,precision:a=3}){const u=n[i];let l;return u==null?l=e!=null?e.toPrecision(a):"1":r.length===1?l="1":l=u.toPrecision(a),{flexBasis:0,flexGrow:l,flexShrink:1,overflow:"hidden",pointerEvents:t!==null?"none":void 0}}function MZe(e,t=10){let n=null;return(...i)=>{n!==null&&clearTimeout(n),n=setTimeout(()=>{e(...i)},t)}}function SK(e){try{if(typeof localStorage<"u")e.getItem=t=>localStorage.getItem(t),e.setItem=(t,n)=>{localStorage.setItem(t,n)};else throw new Error("localStorage not supported in this environment")}catch(t){console.error(t),e.getItem=()=>null,e.setItem=()=>{}}}function Uye(e){return`react-resizable-panels:${e}`}function jye(e){return e.map(t=>{const{constraints:n,id:r,idIsFromProps:i,order:a}=t;return i?r:a?`${a}:${JSON.stringify(n)}`:JSON.stringify(n)}).sort((t,n)=>t.localeCompare(n)).join(",")}function Zye(e,t){try{const n=Uye(e),r=t.getItem(n);if(r){const i=JSON.parse(r);if(typeof i=="object"&&i!=null)return i}}catch{}return null}function FZe(e,t,n){var r,i;const a=(r=Zye(e,n))!==null&&r!==void 0?r:{},u=jye(t);return(i=a[u])!==null&&i!==void 0?i:null}function NZe(e,t,n,r,i){var a;const u=Uye(e),l=jye(t),o=(a=Zye(e,i))!==null&&a!==void 0?a:{};o[l]={expandToSizes:Object.fromEntries(n.entries()),layout:r};try{i.setItem(u,JSON.stringify(o))}catch(s){console.error(s)}}function _K({layout:e,panelConstraints:t}){const n=[...e],r=n.reduce((a,u)=>a+u,0);if(n.length!==t.length)throw Error(`Invalid ${t.length} panel layout: ${n.map(a=>`${a}%`).join(", ")}`);if(!Lf(r,100)&&n.length>0)for(let a=0;a<t.length;a++){const u=n[a];xr(u!=null,`No layout data found for index ${a}`);const l=100/r*u;n[a]=l}let i=0;for(let a=0;a<t.length;a++){const u=n[a];xr(u!=null,`No layout data found for index ${a}`);const l=GO({panelConstraints:t,panelIndex:a,size:u});u!=l&&(i+=u-l,n[a]=l)}if(!Lf(i,0))for(let a=0;a<t.length;a++){const u=n[a];xr(u!=null,`No layout data found for index ${a}`);const l=u+i,o=GO({panelConstraints:t,panelIndex:a,size:l});if(u!==o&&(i-=o-u,n[a]=o,Lf(i,0)))break}return n}const IZe=100,z2={getItem:e=>(SK(z2),z2.getItem(e)),setItem:(e,t)=>{SK(z2),z2.setItem(e,t)}},EK={};function Hye({autoSaveId:e=null,children:t,className:n="",direction:r,forwardedRef:i,id:a=null,onLayout:u=null,keyboardResizeBy:l=null,storage:o=z2,style:s,tagName:c="div",...d}){const h=nB(a),m=P.useRef(null),[y,v]=P.useState(null),[_,S]=P.useState([]),E=DZe(),C=P.useRef({}),T=P.useRef(new Map),R=P.useRef(0),$=P.useRef({autoSaveId:e,direction:r,dragState:y,id:h,keyboardResizeBy:l,onLayout:u,storage:o}),k=P.useRef({layout:_,panelDataArray:[],panelDataArrayChanged:!1});P.useRef({didLogIdAndOrderWarning:!1,didLogPanelConstraintsWarning:!1,prevPanelIds:[]}),P.useImperativeHandle(i,()=>({getId:()=>$.current.id,getLayout:()=>{const{layout:B}=k.current;return B},setLayout:B=>{const{onLayout:ne}=$.current,{layout:oe,panelDataArray:ie}=k.current,de=_K({layout:B,panelConstraints:ie.map(be=>be.constraints)});xK(oe,de)||(S(de),k.current.layout=de,ne&&ne(de),wO(ie,de,C.current))}}),[]),K1(()=>{$.current.autoSaveId=e,$.current.direction=r,$.current.dragState=y,$.current.id=h,$.current.onLayout=u,$.current.storage=o}),RZe({committedValuesRef:$,eagerValuesRef:k,groupId:h,layout:_,panelDataArray:k.current.panelDataArray,setLayout:S,panelGroupElement:m.current}),P.useEffect(()=>{const{panelDataArray:B}=k.current;if(e){if(_.length===0||_.length!==B.length)return;let ne=EK[e];ne==null&&(ne=MZe(NZe,IZe),EK[e]=ne);const oe=[...B],ie=new Map(T.current);ne(e,oe,ie,_,o)}},[e,_,o]),P.useEffect(()=>{});const F=P.useCallback(B=>{const{onLayout:ne}=$.current,{layout:oe,panelDataArray:ie}=k.current;if(B.constraints.collapsible){const de=ie.map(_e=>_e.constraints),{collapsedSize:be=0,panelSize:ve,pivotIndices:pe}=_1(ie,B,oe);if(xr(ve!=null,`Panel size not found for panel "${B.id}"`),!Ym(ve,be)){T.current.set(B.id,ve);const se=QO(ie,B)===ie.length-1?ve-be:be-ve,me=Q2({delta:se,initialLayout:oe,panelConstraints:de,pivotIndices:pe,prevLayout:oe,trigger:"imperative-api"});$E(oe,me)||(S(me),k.current.layout=me,ne&&ne(me),wO(ie,me,C.current))}}},[]),L=P.useCallback((B,ne)=>{const{onLayout:oe}=$.current,{layout:ie,panelDataArray:de}=k.current;if(B.constraints.collapsible){const be=de.map(ge=>ge.constraints),{collapsedSize:ve=0,panelSize:pe=0,minSize:_e=0,pivotIndices:se}=_1(de,B,ie),me=ne??_e;if(Ym(pe,ve)){const ge=T.current.get(B.id),we=ge!=null&&ge>=me?ge:me,Re=QO(de,B)===de.length-1?pe-we:we-pe,et=Q2({delta:Re,initialLayout:ie,panelConstraints:be,pivotIndices:se,prevLayout:ie,trigger:"imperative-api"});$E(ie,et)||(S(et),k.current.layout=et,oe&&oe(et),wO(de,et,C.current))}}},[]),j=P.useCallback(B=>{const{layout:ne,panelDataArray:oe}=k.current,{panelSize:ie}=_1(oe,B,ne);return xr(ie!=null,`Panel size not found for panel "${B.id}"`),ie},[]),V=P.useCallback((B,ne)=>{const{panelDataArray:oe}=k.current,ie=QO(oe,B);return PZe({defaultSize:ne,dragState:y,layout:_,panelData:oe,panelIndex:ie})},[y,_]),q=P.useCallback(B=>{const{layout:ne,panelDataArray:oe}=k.current,{collapsedSize:ie=0,collapsible:de,panelSize:be}=_1(oe,B,ne);return xr(be!=null,`Panel size not found for panel "${B.id}"`),de===!0&&Ym(be,ie)},[]),N=P.useCallback(B=>{const{layout:ne,panelDataArray:oe}=k.current,{collapsedSize:ie=0,collapsible:de,panelSize:be}=_1(oe,B,ne);return xr(be!=null,`Panel size not found for panel "${B.id}"`),!de||bb(be,ie)>0},[]),U=P.useCallback(B=>{const{panelDataArray:ne}=k.current;ne.push(B),ne.sort((oe,ie)=>{const de=oe.order,be=ie.order;return de==null&&be==null?0:de==null?-1:be==null?1:de-be}),k.current.panelDataArrayChanged=!0,E()},[E]);K1(()=>{if(k.current.panelDataArrayChanged){k.current.panelDataArrayChanged=!1;const{autoSaveId:B,onLayout:ne,storage:oe}=$.current,{layout:ie,panelDataArray:de}=k.current;let be=null;if(B){const pe=FZe(B,de,oe);pe&&(T.current=new Map(Object.entries(pe.expandToSizes)),be=pe.layout)}be==null&&(be=kZe({panelDataArray:de}));const ve=_K({layout:be,panelConstraints:de.map(pe=>pe.constraints)});xK(ie,ve)||(S(ve),k.current.layout=ve,ne&&ne(ve),wO(de,ve,C.current))}}),K1(()=>{const B=k.current;return()=>{B.layout=[]}},[]);const W=P.useCallback(B=>{let ne=!1;const oe=m.current;return oe&&window.getComputedStyle(oe,null).getPropertyValue("direction")==="rtl"&&(ne=!0),function(de){de.preventDefault();const be=m.current;if(!be)return()=>null;const{direction:ve,dragState:pe,id:_e,keyboardResizeBy:se,onLayout:me}=$.current,{layout:ge,panelDataArray:we}=k.current,{initialLayout:Ne}=pe??{},Re=zye(_e,B,be);let et=TZe(de,B,ve,pe,se,be);const tt=ve==="horizontal";tt&&ne&&(et=-et);const Oe=we.map(Ue=>Ue.constraints),$e=Q2({delta:et,initialLayout:Ne??ge,panelConstraints:Oe,pivotIndices:Re,prevLayout:ge,trigger:Tye(de)?"keyboard":"mouse-or-touch"}),Ae=!$E(ge,$e);(kye(de)||Pye(de))&&R.current!=et&&(R.current=et,!Ae&&et!==0?tt?s7(B,et<0?Fye:Nye):s7(B,et<0?Iye:Lye):s7(B,0)),Ae&&(S($e),k.current.layout=$e,me&&me($e),wO(we,$e,C.current))}},[]),G=P.useCallback((B,ne)=>{const{onLayout:oe}=$.current,{layout:ie,panelDataArray:de}=k.current,be=de.map(ge=>ge.constraints),{panelSize:ve,pivotIndices:pe}=_1(de,B,ie);xr(ve!=null,`Panel size not found for panel "${B.id}"`);const se=QO(de,B)===de.length-1?ve-ne:ne-ve,me=Q2({delta:se,initialLayout:ie,panelConstraints:be,pivotIndices:pe,prevLayout:ie,trigger:"imperative-api"});$E(ie,me)||(S(me),k.current.layout=me,oe&&oe(me),wO(de,me,C.current))},[]),J=P.useCallback((B,ne)=>{const{layout:oe,panelDataArray:ie}=k.current,{collapsedSize:de=0,collapsible:be}=ne,{collapsedSize:ve=0,collapsible:pe,maxSize:_e=100,minSize:se=0}=B.constraints,{panelSize:me}=_1(ie,B,oe);me!=null&&(be&&pe&&Ym(me,de)?Ym(de,ve)||G(B,ve):me<se?G(B,se):me>_e&&G(B,_e))},[G]),te=P.useCallback((B,ne)=>{const{direction:oe}=$.current,{layout:ie}=k.current;if(!m.current)return;const de=a5(B,m.current);xr(de,`Drag handle element not found for id "${B}"`);const be=Vye(oe,ne);v({dragHandleId:B,dragHandleRect:de.getBoundingClientRect(),initialCursorPosition:be,initialLayout:ie})},[]),H=P.useCallback(()=>{v(null)},[]),M=P.useCallback(B=>{const{panelDataArray:ne}=k.current,oe=QO(ne,B);oe>=0&&(ne.splice(oe,1),delete C.current[B.id],k.current.panelDataArrayChanged=!0,E())},[E]),K=P.useMemo(()=>({collapsePanel:F,direction:r,dragState:y,expandPanel:L,getPanelSize:j,getPanelStyle:V,groupId:h,isPanelCollapsed:q,isPanelExpanded:N,reevaluatePanelConstraints:J,registerPanel:U,registerResizeHandle:W,resizePanel:G,startDragging:te,stopDragging:H,unregisterPanel:M,panelGroupElement:m.current}),[F,y,r,L,j,V,h,q,N,J,U,W,G,te,H,M]),X={display:"flex",flexDirection:r==="horizontal"?"row":"column",height:"100%",overflow:"hidden",width:"100%"};return P.createElement(n5.Provider,{value:K},P.createElement(c,{...d,children:t,className:n,id:a,ref:m,style:{...X,...s},[Su.group]:"",[Su.groupDirection]:r,[Su.groupId]:h}))}const LZe=P.forwardRef((e,t)=>P.createElement(Hye,{...e,forwardedRef:t}));Hye.displayName="PanelGroup";LZe.displayName="forwardRef(PanelGroup)";function QO(e,t){return e.findIndex(n=>n===t||n.id===t.id)}function _1(e,t,n){const r=QO(e,t),a=r===e.length-1?[r-1,r]:[r,r+1],u=n[r];return{...t.constraints,panelSize:u,pivotIndices:a}}function BZe({disabled:e,handleId:t,resizeHandler:n,panelGroupElement:r}){P.useEffect(()=>{if(e||n==null||r==null)return;const i=a5(t,r);if(i==null)return;const a=u=>{if(!u.defaultPrevented)switch(u.key){case"ArrowDown":case"ArrowLeft":case"ArrowRight":case"ArrowUp":case"End":case"Home":{u.preventDefault(),n(u);break}case"F6":{u.preventDefault();const l=i.getAttribute(Su.groupId);xr(l,`No group element found for id "${l}"`);const o=Xx(l,r),s=Qye(l,t,r);xr(s!==null,`No resize element found for id "${t}"`);const c=u.shiftKey?s>0?s-1:o.length-1:s+1<o.length?s+1:0;o[c].focus();break}}};return i.addEventListener("keydown",a),()=>{i.removeEventListener("keydown",a)}},[r,e,t,n])}function QZe({children:e=null,className:t="",disabled:n=!1,hitAreaMargins:r,id:i,onBlur:a,onClick:u,onDragging:l,onFocus:o,onPointerDown:s,onPointerUp:c,style:d={},tabIndex:h=0,tagName:m="div",...y}){var v,_;const S=P.useRef(null),E=P.useRef({onClick:u,onDragging:l,onPointerDown:s,onPointerUp:c});P.useEffect(()=>{E.current.onClick=u,E.current.onDragging=l,E.current.onPointerDown=s,E.current.onPointerUp=c});const C=P.useContext(n5);if(C===null)throw Error("PanelResizeHandle components must be rendered within a PanelGroup container");const{direction:T,groupId:R,registerResizeHandle:$,startDragging:k,stopDragging:F,panelGroupElement:L}=C,j=nB(i),[V,q]=P.useState("inactive"),[N,U]=P.useState(!1),[W,G]=P.useState(null),J=P.useRef({state:V});K1(()=>{J.current.state=V}),P.useEffect(()=>{if(n)G(null);else{const K=$(j);G(()=>K)}},[n,j,$]);const te=(v=r==null?void 0:r.coarse)!==null&&v!==void 0?v:15,H=(_=r==null?void 0:r.fine)!==null&&_!==void 0?_:5;P.useEffect(()=>{if(n||W==null)return;const K=S.current;xr(K,"Element ref not attached");let X=!1;return _Ze(j,K,T,{coarse:te,fine:H},(ne,oe,ie)=>{if(!oe){q("inactive");return}switch(ne){case"down":{q("drag"),X=!1,xr(ie,'Expected event to be defined for "down" action'),k(j,ie);const{onDragging:de,onPointerDown:be}=E.current;de==null||de(!0),be==null||be();break}case"move":{const{state:de}=J.current;X=!0,de!=="drag"&&q("hover"),xr(ie,'Expected event to be defined for "move" action'),W(ie);break}case"up":{q("hover"),F();const{onClick:de,onDragging:be,onPointerUp:ve}=E.current;be==null||be(!1),ve==null||ve(),X||de==null||de();break}}})},[te,T,n,H,$,j,W,k,F]),BZe({disabled:n,handleId:j,resizeHandler:W,panelGroupElement:L});const M={touchAction:"none",userSelect:"none"};return P.createElement(m,{...y,children:e,className:t,id:i,onBlur:()=>{U(!1),a==null||a()},onFocus:()=>{U(!0),o==null||o()},ref:S,role:"separator",style:{...M,...d},tabIndex:h,[Su.groupDirection]:T,[Su.groupId]:R,[Su.resizeHandle]:"",[Su.resizeHandleActive]:V==="drag"?"pointer":N?"keyboard":void 0,[Su.resizeHandleEnabled]:!n,[Su.resizeHandleId]:j,[Su.resizeHandleState]:V})}QZe.displayName="PanelResizeHandle";function RO(e,t,n){let r=n.initialDeps??[],i;function a(){var u,l,o,s;let c;n.key&&((u=n.debug)!=null&&u.call(n))&&(c=Date.now());const d=e();if(!(d.length!==r.length||d.some((y,v)=>r[v]!==y)))return i;r=d;let m;if(n.key&&((l=n.debug)!=null&&l.call(n))&&(m=Date.now()),i=t(...d),n.key&&((o=n.debug)!=null&&o.call(n))){const y=Math.round((Date.now()-c)*100)/100,v=Math.round((Date.now()-m)*100)/100,_=v/16,S=(E,C)=>{for(E=String(E);E.length<C;)E=" "+E;return E};console.info(`%c⏱ ${S(v,5)} /${S(y,5)} ms`,`
            font-size: .6rem;
            font-weight: bold;
            color: hsl(${Math.max(0,Math.min(120-120*_,120))}deg 100% 31%);`,n==null?void 0:n.key)}return(s=n==null?void 0:n.onChange)==null||s.call(n,i),i}return a.updateDeps=u=>{r=u},a}function DK(e,t){if(e===void 0)throw new Error("Unexpected undefined");return e}const zZe=(e,t)=>Math.abs(e-t)<1.01,qZe=(e,t,n)=>{let r;return function(...i){e.clearTimeout(r),r=e.setTimeout(()=>t.apply(this,i),n)}},$K=e=>{const{offsetWidth:t,offsetHeight:n}=e;return{width:t,height:n}},VZe=e=>e,UZe=e=>{const t=Math.max(e.startIndex-e.overscan,0),n=Math.min(e.endIndex+e.overscan,e.count-1),r=[];for(let i=t;i<=n;i++)r.push(i);return r},jZe=(e,t)=>{const n=e.scrollElement;if(!n)return;const r=e.targetWindow;if(!r)return;const i=u=>{const{width:l,height:o}=u;t({width:Math.round(l),height:Math.round(o)})};if(i($K(n)),!r.ResizeObserver)return()=>{};const a=new r.ResizeObserver(u=>{const l=()=>{const o=u[0];if(o!=null&&o.borderBoxSize){const s=o.borderBoxSize[0];if(s){i({width:s.inlineSize,height:s.blockSize});return}}i($K(n))};e.options.useAnimationFrameWithResizeObserver?requestAnimationFrame(l):l()});return a.observe(n,{box:"border-box"}),()=>{a.unobserve(n)}},CK={passive:!0},wK=typeof window>"u"?!0:"onscrollend"in window,ZZe=(e,t)=>{const n=e.scrollElement;if(!n)return;const r=e.targetWindow;if(!r)return;let i=0;const a=e.options.useScrollendEvent&&wK?()=>{}:qZe(r,()=>{t(i,!1)},e.options.isScrollingResetDelay),u=c=>()=>{const{horizontal:d,isRtl:h}=e.options;i=d?n.scrollLeft*(h&&-1||1):n.scrollTop,a(),t(i,c)},l=u(!0),o=u(!1);o(),n.addEventListener("scroll",l,CK);const s=e.options.useScrollendEvent&&wK;return s&&n.addEventListener("scrollend",o,CK),()=>{n.removeEventListener("scroll",l),s&&n.removeEventListener("scrollend",o)}},HZe=(e,t,n)=>{if(t!=null&&t.borderBoxSize){const r=t.borderBoxSize[0];if(r)return Math.round(r[n.options.horizontal?"inlineSize":"blockSize"])}return e[n.options.horizontal?"offsetWidth":"offsetHeight"]},XZe=(e,{adjustments:t=0,behavior:n},r)=>{var i,a;const u=e+t;(a=(i=r.scrollElement)==null?void 0:i.scrollTo)==null||a.call(i,{[r.options.horizontal?"left":"top"]:u,behavior:n})};class YZe{constructor(t){this.unsubs=[],this.scrollElement=null,this.targetWindow=null,this.isScrolling=!1,this.measurementsCache=[],this.itemSizeCache=new Map,this.pendingMeasuredCacheIndexes=[],this.scrollRect=null,this.scrollOffset=null,this.scrollDirection=null,this.scrollAdjustments=0,this.elementsCache=new Map,this.observer=(()=>{let n=null;const r=()=>n||(!this.targetWindow||!this.targetWindow.ResizeObserver?null:n=new this.targetWindow.ResizeObserver(i=>{i.forEach(a=>{const u=()=>{this._measureElement(a.target,a)};this.options.useAnimationFrameWithResizeObserver?requestAnimationFrame(u):u()})}));return{disconnect:()=>{var i;(i=r())==null||i.disconnect(),n=null},observe:i=>{var a;return(a=r())==null?void 0:a.observe(i,{box:"border-box"})},unobserve:i=>{var a;return(a=r())==null?void 0:a.unobserve(i)}}})(),this.range=null,this.setOptions=n=>{Object.entries(n).forEach(([r,i])=>{typeof i>"u"&&delete n[r]}),this.options={debug:!1,initialOffset:0,overscan:1,paddingStart:0,paddingEnd:0,scrollPaddingStart:0,scrollPaddingEnd:0,horizontal:!1,getItemKey:VZe,rangeExtractor:UZe,onChange:()=>{},measureElement:HZe,initialRect:{width:0,height:0},scrollMargin:0,gap:0,indexAttribute:"data-index",initialMeasurementsCache:[],lanes:1,isScrollingResetDelay:150,enabled:!0,isRtl:!1,useScrollendEvent:!1,useAnimationFrameWithResizeObserver:!1,...n}},this.notify=n=>{var r,i;(i=(r=this.options).onChange)==null||i.call(r,this,n)},this.maybeNotify=RO(()=>(this.calculateRange(),[this.isScrolling,this.range?this.range.startIndex:null,this.range?this.range.endIndex:null]),n=>{this.notify(n)},{key:!1,debug:()=>this.options.debug,initialDeps:[this.isScrolling,this.range?this.range.startIndex:null,this.range?this.range.endIndex:null]}),this.cleanup=()=>{this.unsubs.filter(Boolean).forEach(n=>n()),this.unsubs=[],this.observer.disconnect(),this.scrollElement=null,this.targetWindow=null},this._didMount=()=>()=>{this.cleanup()},this._willUpdate=()=>{var n;const r=this.options.enabled?this.options.getScrollElement():null;if(this.scrollElement!==r){if(this.cleanup(),!r){this.maybeNotify();return}this.scrollElement=r,this.scrollElement&&"ownerDocument"in this.scrollElement?this.targetWindow=this.scrollElement.ownerDocument.defaultView:this.targetWindow=((n=this.scrollElement)==null?void 0:n.window)??null,this.elementsCache.forEach(i=>{this.observer.observe(i)}),this._scrollToOffset(this.getScrollOffset(),{adjustments:void 0,behavior:void 0}),this.unsubs.push(this.options.observeElementRect(this,i=>{this.scrollRect=i,this.maybeNotify()})),this.unsubs.push(this.options.observeElementOffset(this,(i,a)=>{this.scrollAdjustments=0,this.scrollDirection=a?this.getScrollOffset()<i?"forward":"backward":null,this.scrollOffset=i,this.isScrolling=a,this.maybeNotify()}))}},this.getSize=()=>this.options.enabled?(this.scrollRect=this.scrollRect??this.options.initialRect,this.scrollRect[this.options.horizontal?"width":"height"]):(this.scrollRect=null,0),this.getScrollOffset=()=>this.options.enabled?(this.scrollOffset=this.scrollOffset??(typeof this.options.initialOffset=="function"?this.options.initialOffset():this.options.initialOffset),this.scrollOffset):(this.scrollOffset=null,0),this.getFurthestMeasurement=(n,r)=>{const i=new Map,a=new Map;for(let u=r-1;u>=0;u--){const l=n[u];if(i.has(l.lane))continue;const o=a.get(l.lane);if(o==null||l.end>o.end?a.set(l.lane,l):l.end<o.end&&i.set(l.lane,!0),i.size===this.options.lanes)break}return a.size===this.options.lanes?Array.from(a.values()).sort((u,l)=>u.end===l.end?u.index-l.index:u.end-l.end)[0]:void 0},this.getMeasurementOptions=RO(()=>[this.options.count,this.options.paddingStart,this.options.scrollMargin,this.options.getItemKey,this.options.enabled],(n,r,i,a,u)=>(this.pendingMeasuredCacheIndexes=[],{count:n,paddingStart:r,scrollMargin:i,getItemKey:a,enabled:u}),{key:!1}),this.getMeasurements=RO(()=>[this.getMeasurementOptions(),this.itemSizeCache],({count:n,paddingStart:r,scrollMargin:i,getItemKey:a,enabled:u},l)=>{if(!u)return this.measurementsCache=[],this.itemSizeCache.clear(),[];this.measurementsCache.length===0&&(this.measurementsCache=this.options.initialMeasurementsCache,this.measurementsCache.forEach(c=>{this.itemSizeCache.set(c.key,c.size)}));const o=this.pendingMeasuredCacheIndexes.length>0?Math.min(...this.pendingMeasuredCacheIndexes):0;this.pendingMeasuredCacheIndexes=[];const s=this.measurementsCache.slice(0,o);for(let c=o;c<n;c++){const d=a(c),h=this.options.lanes===1?s[c-1]:this.getFurthestMeasurement(s,c),m=h?h.end+this.options.gap:r+i,y=l.get(d),v=typeof y=="number"?y:this.options.estimateSize(c),_=m+v,S=h?h.lane:c%this.options.lanes;s[c]={index:c,start:m,size:v,end:_,key:d,lane:S}}return this.measurementsCache=s,s},{key:!1,debug:()=>this.options.debug}),this.calculateRange=RO(()=>[this.getMeasurements(),this.getSize(),this.getScrollOffset(),this.options.lanes],(n,r,i,a)=>this.range=n.length>0&&r>0?GZe({measurements:n,outerSize:r,scrollOffset:i,lanes:a}):null,{key:!1,debug:()=>this.options.debug}),this.getVirtualIndexes=RO(()=>{let n=null,r=null;const i=this.calculateRange();return i&&(n=i.startIndex,r=i.endIndex),this.maybeNotify.updateDeps([this.isScrolling,n,r]),[this.options.rangeExtractor,this.options.overscan,this.options.count,n,r]},(n,r,i,a,u)=>a===null||u===null?[]:n({startIndex:a,endIndex:u,overscan:r,count:i}),{key:!1,debug:()=>this.options.debug}),this.indexFromElement=n=>{const r=this.options.indexAttribute,i=n.getAttribute(r);return i?parseInt(i,10):(console.warn(`Missing attribute name '${r}={index}' on measured element.`),-1)},this._measureElement=(n,r)=>{const i=this.indexFromElement(n),a=this.measurementsCache[i];if(!a)return;const u=a.key,l=this.elementsCache.get(u);l!==n&&(l&&this.observer.unobserve(l),this.observer.observe(n),this.elementsCache.set(u,n)),n.isConnected&&this.resizeItem(i,this.options.measureElement(n,r,this))},this.resizeItem=(n,r)=>{const i=this.measurementsCache[n];if(!i)return;const a=this.itemSizeCache.get(i.key)??i.size,u=r-a;u!==0&&((this.shouldAdjustScrollPositionOnItemSizeChange!==void 0?this.shouldAdjustScrollPositionOnItemSizeChange(i,u,this):i.start<this.getScrollOffset()+this.scrollAdjustments)&&this._scrollToOffset(this.getScrollOffset(),{adjustments:this.scrollAdjustments+=u,behavior:void 0}),this.pendingMeasuredCacheIndexes.push(i.index),this.itemSizeCache=new Map(this.itemSizeCache.set(i.key,r)),this.notify(!1))},this.measureElement=n=>{if(!n){this.elementsCache.forEach((r,i)=>{r.isConnected||(this.observer.unobserve(r),this.elementsCache.delete(i))});return}this._measureElement(n,void 0)},this.getVirtualItems=RO(()=>[this.getVirtualIndexes(),this.getMeasurements()],(n,r)=>{const i=[];for(let a=0,u=n.length;a<u;a++){const l=n[a],o=r[l];i.push(o)}return i},{key:!1,debug:()=>this.options.debug}),this.getVirtualItemForOffset=n=>{const r=this.getMeasurements();if(r.length!==0)return DK(r[Xye(0,r.length-1,i=>DK(r[i]).start,n)])},this.getOffsetForAlignment=(n,r,i=0)=>{const a=this.getSize(),u=this.getScrollOffset();r==="auto"&&(r=n>=u+a?"end":"start"),r==="center"?n+=(i-a)/2:r==="end"&&(n-=a);const l=this.getTotalSize()+this.options.scrollMargin-a;return Math.max(Math.min(l,n),0)},this.getOffsetForIndex=(n,r="auto")=>{n=Math.max(0,Math.min(n,this.options.count-1));const i=this.measurementsCache[n];if(!i)return;const a=this.getSize(),u=this.getScrollOffset();if(r==="auto")if(i.end>=u+a-this.options.scrollPaddingEnd)r="end";else if(i.start<=u+this.options.scrollPaddingStart)r="start";else return[u,r];const l=r==="end"?i.end+this.options.scrollPaddingEnd:i.start-this.options.scrollPaddingStart;return[this.getOffsetForAlignment(l,r,i.size),r]},this.isDynamicMode=()=>this.elementsCache.size>0,this.scrollToOffset=(n,{align:r="start",behavior:i}={})=>{i==="smooth"&&this.isDynamicMode()&&console.warn("The `smooth` scroll behavior is not fully supported with dynamic size."),this._scrollToOffset(this.getOffsetForAlignment(n,r),{adjustments:void 0,behavior:i})},this.scrollToIndex=(n,{align:r="auto",behavior:i}={})=>{i==="smooth"&&this.isDynamicMode()&&console.warn("The `smooth` scroll behavior is not fully supported with dynamic size."),n=Math.max(0,Math.min(n,this.options.count-1));let a=0;const u=10,l=s=>{if(!this.targetWindow)return;const c=this.getOffsetForIndex(n,s);if(!c){console.warn("Failed to get offset for index:",n);return}const[d,h]=c;this._scrollToOffset(d,{adjustments:void 0,behavior:i}),this.targetWindow.requestAnimationFrame(()=>{const m=this.getScrollOffset(),y=this.getOffsetForIndex(n,h);if(!y){console.warn("Failed to get offset for index:",n);return}zZe(y[0],m)||o(h)})},o=s=>{this.targetWindow&&(a++,a<u?this.targetWindow.requestAnimationFrame(()=>l(s)):console.warn(`Failed to scroll to index ${n} after ${u} attempts.`))};l(r)},this.scrollBy=(n,{behavior:r}={})=>{r==="smooth"&&this.isDynamicMode()&&console.warn("The `smooth` scroll behavior is not fully supported with dynamic size."),this._scrollToOffset(this.getScrollOffset()+n,{adjustments:void 0,behavior:r})},this.getTotalSize=()=>{var n;const r=this.getMeasurements();let i;if(r.length===0)i=this.options.paddingStart;else if(this.options.lanes===1)i=((n=r[r.length-1])==null?void 0:n.end)??0;else{const a=Array(this.options.lanes).fill(null);let u=r.length-1;for(;u>=0&&a.some(l=>l===null);){const l=r[u];a[l.lane]===null&&(a[l.lane]=l.end),u--}i=Math.max(...a.filter(l=>l!==null))}return Math.max(i-this.options.scrollMargin+this.options.paddingEnd,0)},this._scrollToOffset=(n,{adjustments:r,behavior:i})=>{this.options.scrollToFn(n,{behavior:i,adjustments:r},this)},this.measure=()=>{this.itemSizeCache=new Map,this.notify(!1)},this.setOptions(t)}}const Xye=(e,t,n,r)=>{for(;e<=t;){const i=(e+t)/2|0,a=n(i);if(a<r)e=i+1;else if(a>r)t=i-1;else return i}return e>0?e-1:0};function GZe({measurements:e,outerSize:t,scrollOffset:n,lanes:r}){const i=e.length-1,a=o=>e[o].start;if(e.length<=r)return{startIndex:0,endIndex:i};let u=Xye(0,i,a,n),l=u;if(r===1)for(;l<i&&e[l].end<n+t;)l++;else if(r>1){const o=Array(r).fill(0);for(;l<i&&o.some(c=>c<n+t);){const c=e[l];o[c.lane]=c.end,l++}const s=Array(r).fill(n+t);for(;u>=0&&s.some(c=>c>=n);){const c=e[u];s[c.lane]=c.start,u--}u=Math.max(0,u-u%r),l=Math.min(i,l+(r-1-l%r))}return{startIndex:u,endIndex:l}}const RK=typeof document<"u"?P.useLayoutEffect:P.useEffect;function KZe(e){const t=P.useReducer(()=>({}),{})[1],n={...e,onChange:(i,a)=>{var u;a?Vf.flushSync(t):t(),(u=e.onChange)==null||u.call(e,i,a)}},[r]=P.useState(()=>new YZe(n));return r.setOptions(n),RK(()=>r._didMount(),[]),RK(()=>r._willUpdate()),r}function Jut(e){return KZe({observeElementRect:jZe,observeElementOffset:ZZe,scrollToFn:XZe,...e})}const WZe=/^[$_\p{ID_Start}][$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,JZe=/^[$_\p{ID_Start}][-$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,eHe={};function AK(e,t){return(eHe.jsx?JZe:WZe).test(e)}var AO={},f7,TK;function tHe(){if(TK)return f7;TK=1;var e=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,t=/\n/g,n=/^\s*/,r=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,i=/^:\s*/,a=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,u=/^[;\s]*/,l=/^\s+|\s+$/g,o=`
`,s="/",c="*",d="",h="comment",m="declaration";f7=function(v,_){if(typeof v!="string")throw new TypeError("First argument must be a string");if(!v)return[];_=_||{};var S=1,E=1;function C(N){var U=N.match(t);U&&(S+=U.length);var W=N.lastIndexOf(o);E=~W?N.length-W:E+N.length}function T(){var N={line:S,column:E};return function(U){return U.position=new R(N),F(),U}}function R(N){this.start=N,this.end={line:S,column:E},this.source=_.source}R.prototype.content=v;function $(N){var U=new Error(_.source+":"+S+":"+E+": "+N);if(U.reason=N,U.filename=_.source,U.line=S,U.column=E,U.source=v,!_.silent)throw U}function k(N){var U=N.exec(v);if(U){var W=U[0];return C(W),v=v.slice(W.length),U}}function F(){k(n)}function L(N){var U;for(N=N||[];U=j();)U!==!1&&N.push(U);return N}function j(){var N=T();if(!(s!=v.charAt(0)||c!=v.charAt(1))){for(var U=2;d!=v.charAt(U)&&(c!=v.charAt(U)||s!=v.charAt(U+1));)++U;if(U+=2,d===v.charAt(U-1))return $("End of comment missing");var W=v.slice(2,U-2);return E+=2,C(W),v=v.slice(U),E+=2,N({type:h,comment:W})}}function V(){var N=T(),U=k(r);if(U){if(j(),!k(i))return $("property missing ':'");var W=k(a),G=N({type:m,property:y(U[0].replace(e,d)),value:W?y(W[0].replace(e,d)):d});return k(u),G}}function q(){var N=[];L(N);for(var U;U=V();)U!==!1&&(N.push(U),L(N));return N}return F(),q()};function y(v){return v?v.replace(l,d):d}return f7}var kK;function nHe(){if(kK)return AO;kK=1;var e=AO&&AO.__importDefault||function(r){return r&&r.__esModule?r:{default:r}};Object.defineProperty(AO,"__esModule",{value:!0}),AO.default=n;var t=e(tHe());function n(r,i){var a=null;if(!r||typeof r!="string")return a;var u=(0,t.default)(r),l=typeof i=="function";return u.forEach(function(o){if(o.type==="declaration"){var s=o.property,c=o.value;l?i(s,c,o):c&&(a=a||{},a[s]=c)}}),a}return AO}var _2={},PK;function rHe(){if(PK)return _2;PK=1,Object.defineProperty(_2,"__esModule",{value:!0}),_2.camelCase=void 0;var e=/^--[a-zA-Z0-9_-]+$/,t=/-([a-z])/g,n=/^[^-]+$/,r=/^-(webkit|moz|ms|o|khtml)-/,i=/^-(ms)-/,a=function(s){return!s||n.test(s)||e.test(s)},u=function(s,c){return c.toUpperCase()},l=function(s,c){return"".concat(c,"-")},o=function(s,c){return c===void 0&&(c={}),a(s)?s:(s=s.toLowerCase(),c.reactCompat?s=s.replace(i,l):s=s.replace(r,l),s.replace(t,u))};return _2.camelCase=o,_2}var E2,MK;function iHe(){if(MK)return E2;MK=1;var e=E2&&E2.__importDefault||function(i){return i&&i.__esModule?i:{default:i}},t=e(nHe()),n=rHe();function r(i,a){var u={};return!i||typeof i!="string"||(0,t.default)(i,function(l,o){l&&o&&(u[(0,n.camelCase)(l,a)]=o)}),u}return r.default=r,E2=r,E2}var aHe=iHe();const uHe=sa(aHe),Yye=Gye("end"),aB=Gye("start");function Gye(e){return t;function t(n){const r=n&&n.position&&n.position[e]||{};if(typeof r.line=="number"&&r.line>0&&typeof r.column=="number"&&r.column>0)return{line:r.line,column:r.column,offset:typeof r.offset=="number"&&r.offset>-1?r.offset:void 0}}}function lHe(e){const t=aB(e),n=Yye(e);if(t&&n)return{start:t,end:n}}function G2(e){return!e||typeof e!="object"?"":"position"in e||"type"in e?FK(e.position):"start"in e||"end"in e?FK(e):"line"in e||"column"in e?sF(e):""}function sF(e){return NK(e&&e.line)+":"+NK(e&&e.column)}function FK(e){return sF(e&&e.start)+"-"+sF(e&&e.end)}function NK(e){return e&&typeof e=="number"?e:1}class Os extends Error{constructor(t,n,r){super(),typeof n=="string"&&(r=n,n=void 0);let i="",a={},u=!1;if(n&&("line"in n&&"column"in n?a={place:n}:"start"in n&&"end"in n?a={place:n}:"type"in n?a={ancestors:[n],place:n.position}:a={...n}),typeof t=="string"?i=t:!a.cause&&t&&(u=!0,i=t.message,a.cause=t),!a.ruleId&&!a.source&&typeof r=="string"){const o=r.indexOf(":");o===-1?a.ruleId=r:(a.source=r.slice(0,o),a.ruleId=r.slice(o+1))}if(!a.place&&a.ancestors&&a.ancestors){const o=a.ancestors[a.ancestors.length-1];o&&(a.place=o.position)}const l=a.place&&"start"in a.place?a.place.start:a.place;this.ancestors=a.ancestors||void 0,this.cause=a.cause||void 0,this.column=l?l.column:void 0,this.fatal=void 0,this.file="",this.message=i,this.line=l?l.line:void 0,this.name=G2(a.place)||"1:1",this.place=a.place||void 0,this.reason=this.message,this.ruleId=a.ruleId||void 0,this.source=a.source||void 0,this.stack=u&&a.cause&&typeof a.cause.stack=="string"?a.cause.stack:"",this.actual=void 0,this.expected=void 0,this.note=void 0,this.url=void 0}}Os.prototype.file="";Os.prototype.name="";Os.prototype.reason="";Os.prototype.message="";Os.prototype.stack="";Os.prototype.column=void 0;Os.prototype.line=void 0;Os.prototype.ancestors=void 0;Os.prototype.cause=void 0;Os.prototype.fatal=void 0;Os.prototype.place=void 0;Os.prototype.ruleId=void 0;Os.prototype.source=void 0;const uB={}.hasOwnProperty,oHe=new Map,sHe=/[A-Z]/g,cHe=new Set(["table","tbody","thead","tfoot","tr"]),fHe=new Set(["td","th"]),Kye="https://github.com/syntax-tree/hast-util-to-jsx-runtime";function dHe(e,t){if(!t||t.Fragment===void 0)throw new TypeError("Expected `Fragment` in options");const n=t.filePath||void 0;let r;if(t.development){if(typeof t.jsxDEV!="function")throw new TypeError("Expected `jsxDEV` in options when `development: true`");r=OHe(n,t.jsxDEV)}else{if(typeof t.jsx!="function")throw new TypeError("Expected `jsx` in production options");if(typeof t.jsxs!="function")throw new TypeError("Expected `jsxs` in production options");r=bHe(n,t.jsx,t.jsxs)}const i={Fragment:t.Fragment,ancestors:[],components:t.components||{},create:r,elementAttributeNameCase:t.elementAttributeNameCase||"react",evaluater:t.createEvaluater?t.createEvaluater():void 0,filePath:n,ignoreInvalidStyle:t.ignoreInvalidStyle||!1,passKeys:t.passKeys!==!1,passNode:t.passNode||!1,schema:t.space==="svg"?wS:Eme,stylePropertyNameCase:t.stylePropertyNameCase||"dom",tableCellAlignToStyle:t.tableCellAlignToStyle!==!1},a=Wye(i,e,void 0);return a&&typeof a!="string"?a:i.create(e,i.Fragment,{children:a||void 0},void 0)}function Wye(e,t,n){if(t.type==="element")return hHe(e,t,n);if(t.type==="mdxFlowExpression"||t.type==="mdxTextExpression")return pHe(e,t);if(t.type==="mdxJsxFlowElement"||t.type==="mdxJsxTextElement")return gHe(e,t,n);if(t.type==="mdxjsEsm")return mHe(e,t);if(t.type==="root")return vHe(e,t,n);if(t.type==="text")return yHe(e,t)}function hHe(e,t,n){const r=e.schema;let i=r;t.tagName.toLowerCase()==="svg"&&r.space==="html"&&(i=wS,e.schema=i),e.ancestors.push(t);const a=e1e(e,t.tagName,!1),u=xHe(e,t);let l=oB(e,t);return cHe.has(t.tagName)&&(l=l.filter(function(o){return typeof o=="string"?!Ew(o):!0})),Jye(e,u,a,t),lB(u,l),e.ancestors.pop(),e.schema=r,e.create(t,a,u,n)}function pHe(e,t){if(t.data&&t.data.estree&&e.evaluater){const r=t.data.estree.body[0];return r.type,e.evaluater.evaluateExpression(r.expression)}Yx(e,t.position)}function mHe(e,t){if(t.data&&t.data.estree&&e.evaluater)return e.evaluater.evaluateProgram(t.data.estree);Yx(e,t.position)}function gHe(e,t,n){const r=e.schema;let i=r;t.name==="svg"&&r.space==="html"&&(i=wS,e.schema=i),e.ancestors.push(t);const a=t.name===null?e.Fragment:e1e(e,t.name,!0),u=SHe(e,t),l=oB(e,t);return Jye(e,u,a,t),lB(u,l),e.ancestors.pop(),e.schema=r,e.create(t,a,u,n)}function vHe(e,t,n){const r={};return lB(r,oB(e,t)),e.create(t,e.Fragment,r,n)}function yHe(e,t){return t.value}function Jye(e,t,n,r){typeof n!="string"&&n!==e.Fragment&&e.passNode&&(t.node=r)}function lB(e,t){if(t.length>0){const n=t.length>1?t:t[0];n&&(e.children=n)}}function bHe(e,t,n){return r;function r(i,a,u,l){const s=Array.isArray(u.children)?n:t;return l?s(a,u,l):s(a,u)}}function OHe(e,t){return n;function n(r,i,a,u){const l=Array.isArray(a.children),o=aB(r);return t(i,a,u,l,{columnNumber:o?o.column-1:void 0,fileName:e,lineNumber:o?o.line:void 0},void 0)}}function xHe(e,t){const n={};let r,i;for(i in t.properties)if(i!=="children"&&uB.call(t.properties,i)){const a=_He(e,i,t.properties[i]);if(a){const[u,l]=a;e.tableCellAlignToStyle&&u==="align"&&typeof l=="string"&&fHe.has(t.tagName)?r=l:n[u]=l}}if(r){const a=n.style||(n.style={});a[e.stylePropertyNameCase==="css"?"text-align":"textAlign"]=r}return n}function SHe(e,t){const n={};for(const r of t.attributes)if(r.type==="mdxJsxExpressionAttribute")if(r.data&&r.data.estree&&e.evaluater){const a=r.data.estree.body[0];a.type;const u=a.expression;u.type;const l=u.properties[0];l.type,Object.assign(n,e.evaluater.evaluateExpression(l.argument))}else Yx(e,t.position);else{const i=r.name;let a;if(r.value&&typeof r.value=="object")if(r.value.data&&r.value.data.estree&&e.evaluater){const l=r.value.data.estree.body[0];l.type,a=e.evaluater.evaluateExpression(l.expression)}else Yx(e,t.position);else a=r.value===null?!0:r.value;n[i]=a}return n}function oB(e,t){const n=[];let r=-1;const i=e.passKeys?new Map:oHe;for(;++r<t.children.length;){const a=t.children[r];let u;if(e.passKeys){const o=a.type==="element"?a.tagName:a.type==="mdxJsxFlowElement"||a.type==="mdxJsxTextElement"?a.name:void 0;if(o){const s=i.get(o)||0;u=o+"-"+s,i.set(o,s+1)}}const l=Wye(e,a,u);l!==void 0&&n.push(l)}return n}function _He(e,t,n){const r=_me(e.schema,t);if(!(n==null||typeof n=="number"&&Number.isNaN(n))){if(Array.isArray(n)&&(n=r.commaSeparated?$me(n):Cme(n)),r.property==="style"){let i=typeof n=="object"?n:EHe(e,String(n));return e.stylePropertyNameCase==="css"&&(i=DHe(i)),["style",i]}return[e.elementAttributeNameCase==="react"&&r.space?uIe[r.property]||r.property:r.attribute,n]}}function EHe(e,t){try{return uHe(t,{reactCompat:!0})}catch(n){if(e.ignoreInvalidStyle)return{};const r=n,i=new Os("Cannot parse `style` attribute",{ancestors:e.ancestors,cause:r,ruleId:"style",source:"hast-util-to-jsx-runtime"});throw i.file=e.filePath||void 0,i.url=Kye+"#cannot-parse-style-attribute",i}}function e1e(e,t,n){let r;if(!n)r={type:"Literal",value:t};else if(t.includes(".")){const i=t.split(".");let a=-1,u;for(;++a<i.length;){const l=AK(i[a])?{type:"Identifier",name:i[a]}:{type:"Literal",value:i[a]};u=u?{type:"MemberExpression",object:u,property:l,computed:!!(a&&l.type==="Literal"),optional:!1}:l}r=u}else r=AK(t)&&!/^[a-z]/.test(t)?{type:"Identifier",name:t}:{type:"Literal",value:t};if(r.type==="Literal"){const i=r.value;return uB.call(e.components,i)?e.components[i]:i}if(e.evaluater)return e.evaluater.evaluateExpression(r);Yx(e)}function Yx(e,t){const n=new Os("Cannot handle MDX estrees without `createEvaluater`",{ancestors:e.ancestors,place:t,ruleId:"mdx-estree",source:"hast-util-to-jsx-runtime"});throw n.file=e.filePath||void 0,n.url=Kye+"#cannot-handle-mdx-estrees-without-createevaluater",n}function DHe(e){const t={};let n;for(n in e)uB.call(e,n)&&(t[$He(n)]=e[n]);return t}function $He(e){let t=e.replace(sHe,CHe);return t.slice(0,3)==="ms-"&&(t="-"+t),t}function CHe(e){return"-"+e.toLowerCase()}const d7={action:["form"],cite:["blockquote","del","ins","q"],data:["object"],formAction:["button","input"],href:["a","area","base","link"],icon:["menuitem"],itemId:null,manifest:["html"],ping:["a","area"],poster:["video"],src:["audio","embed","iframe","img","input","script","source","track","video"]},wHe={};function sB(e,t){const n=wHe,r=typeof n.includeImageAlt=="boolean"?n.includeImageAlt:!0,i=typeof n.includeHtml=="boolean"?n.includeHtml:!0;return t1e(e,r,i)}function t1e(e,t,n){if(RHe(e)){if("value"in e)return e.type==="html"&&!n?"":e.value;if(t&&"alt"in e&&e.alt)return e.alt;if("children"in e)return IK(e.children,t,n)}return Array.isArray(e)?IK(e,t,n):""}function IK(e,t,n){const r=[];let i=-1;for(;++i<e.length;)r[i]=t1e(e[i],t,n);return r.join("")}function RHe(e){return!!(e&&typeof e=="object")}const LK=document.createElement("i");function cB(e){const t="&"+e+";";LK.innerHTML=t;const n=LK.textContent;return n.charCodeAt(n.length-1)===59&&e!=="semi"||n===t?!1:n}function Zf(e,t,n,r){const i=e.length;let a=0,u;if(t<0?t=-t>i?0:i+t:t=t>i?i:t,n=n>0?n:0,r.length<1e4)u=Array.from(r),u.unshift(t,n),e.splice(...u);else for(n&&e.splice(t,n);a<r.length;)u=r.slice(a,a+1e4),u.unshift(t,0),e.splice(...u),a+=1e4,t+=1e4}function Ud(e,t){return e.length>0?(Zf(e,e.length,0,t),e):t}const BK={}.hasOwnProperty;function n1e(e){const t={};let n=-1;for(;++n<e.length;)AHe(t,e[n]);return t}function AHe(e,t){let n;for(n in t){const i=(BK.call(e,n)?e[n]:void 0)||(e[n]={}),a=t[n];let u;if(a)for(u in a){BK.call(i,u)||(i[u]=[]);const l=a[u];THe(i[u],Array.isArray(l)?l:l?[l]:[])}}}function THe(e,t){let n=-1;const r=[];for(;++n<t.length;)(t[n].add==="after"?e:r).push(t[n]);Zf(e,0,0,r)}function r1e(e,t){const n=Number.parseInt(e,t);return n<9||n===11||n>13&&n<32||n>126&&n<160||n>55295&&n<57344||n>64975&&n<65008||(n&65535)===65535||(n&65535)===65534||n>1114111?"�":String.fromCodePoint(n)}function ap(e){return e.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()}const oc=Ey(/[A-Za-z]/),ms=Ey(/[\dA-Za-z]/),kHe=Ey(/[#-'*+\--9=?A-Z^-~]/);function nC(e){return e!==null&&(e<32||e===127)}const cF=Ey(/\d/),PHe=Ey(/[\dA-Fa-f]/),MHe=Ey(/[!-/:-@[-`{-~]/);function Mn(e){return e!==null&&e<-2}function la(e){return e!==null&&(e<0||e===32)}function zr(e){return e===-2||e===-1||e===32}const u5=Ey(new RegExp("\\p{P}|\\p{S}","u")),Ob=Ey(/\s/);function Ey(e){return t;function t(n){return n!==null&&n>-1&&e.test(String.fromCharCode(n))}}function h4(e){const t=[];let n=-1,r=0,i=0;for(;++n<e.length;){const a=e.charCodeAt(n);let u="";if(a===37&&ms(e.charCodeAt(n+1))&&ms(e.charCodeAt(n+2)))i=2;else if(a<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(a))||(u=String.fromCharCode(a));else if(a>55295&&a<57344){const l=e.charCodeAt(n+1);a<56320&&l>56319&&l<57344?(u=String.fromCharCode(a,l),i=1):u="�"}else u=String.fromCharCode(a);u&&(t.push(e.slice(r,n),encodeURIComponent(u)),r=n+i+1,u=""),i&&(n+=i,i=0)}return t.join("")+e.slice(r)}function si(e,t,n,r){const i=r?r-1:Number.POSITIVE_INFINITY;let a=0;return u;function u(o){return zr(o)?(e.enter(n),l(o)):t(o)}function l(o){return zr(o)&&a++<i?(e.consume(o),l):(e.exit(n),t(o))}}const FHe={tokenize:NHe};function NHe(e){const t=e.attempt(this.parser.constructs.contentInitial,r,i);let n;return t;function r(l){if(l===null){e.consume(l);return}return e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),si(e,t,"linePrefix")}function i(l){return e.enter("paragraph"),a(l)}function a(l){const o=e.enter("chunkText",{contentType:"text",previous:n});return n&&(n.next=o),n=o,u(l)}function u(l){if(l===null){e.exit("chunkText"),e.exit("paragraph"),e.consume(l);return}return Mn(l)?(e.consume(l),e.exit("chunkText"),a):(e.consume(l),u)}}const IHe={tokenize:LHe},QK={tokenize:BHe};function LHe(e){const t=this,n=[];let r=0,i,a,u;return l;function l(C){if(r<n.length){const T=n[r];return t.containerState=T[1],e.attempt(T[0].continuation,o,s)(C)}return s(C)}function o(C){if(r++,t.containerState._closeFlow){t.containerState._closeFlow=void 0,i&&E();const T=t.events.length;let R=T,$;for(;R--;)if(t.events[R][0]==="exit"&&t.events[R][1].type==="chunkFlow"){$=t.events[R][1].end;break}S(r);let k=T;for(;k<t.events.length;)t.events[k][1].end={...$},k++;return Zf(t.events,R+1,0,t.events.slice(T)),t.events.length=k,s(C)}return l(C)}function s(C){if(r===n.length){if(!i)return h(C);if(i.currentConstruct&&i.currentConstruct.concrete)return y(C);t.interrupt=!!(i.currentConstruct&&!i._gfmTableDynamicInterruptHack)}return t.containerState={},e.check(QK,c,d)(C)}function c(C){return i&&E(),S(r),h(C)}function d(C){return t.parser.lazy[t.now().line]=r!==n.length,u=t.now().offset,y(C)}function h(C){return t.containerState={},e.attempt(QK,m,y)(C)}function m(C){return r++,n.push([t.currentConstruct,t.containerState]),h(C)}function y(C){if(C===null){i&&E(),S(0),e.consume(C);return}return i=i||t.parser.flow(t.now()),e.enter("chunkFlow",{_tokenizer:i,contentType:"flow",previous:a}),v(C)}function v(C){if(C===null){_(e.exit("chunkFlow"),!0),S(0),e.consume(C);return}return Mn(C)?(e.consume(C),_(e.exit("chunkFlow")),r=0,t.interrupt=void 0,l):(e.consume(C),v)}function _(C,T){const R=t.sliceStream(C);if(T&&R.push(null),C.previous=a,a&&(a.next=C),a=C,i.defineSkip(C.start),i.write(R),t.parser.lazy[C.start.line]){let $=i.events.length;for(;$--;)if(i.events[$][1].start.offset<u&&(!i.events[$][1].end||i.events[$][1].end.offset>u))return;const k=t.events.length;let F=k,L,j;for(;F--;)if(t.events[F][0]==="exit"&&t.events[F][1].type==="chunkFlow"){if(L){j=t.events[F][1].end;break}L=!0}for(S(r),$=k;$<t.events.length;)t.events[$][1].end={...j},$++;Zf(t.events,F+1,0,t.events.slice(k)),t.events.length=$}}function S(C){let T=n.length;for(;T-- >C;){const R=n[T];t.containerState=R[1],R[0].exit.call(t,e)}n.length=C}function E(){i.write([null]),a=void 0,i=void 0,t.containerState._closeFlow=void 0}}function BHe(e,t,n){return si(e,e.attempt(this.parser.constructs.document,t,n),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}function z3(e){if(e===null||la(e)||Ob(e))return 1;if(u5(e))return 2}function l5(e,t,n){const r=[];let i=-1;for(;++i<e.length;){const a=e[i].resolveAll;a&&!r.includes(a)&&(t=a(t,n),r.push(a))}return t}const fF={name:"attention",resolveAll:QHe,tokenize:zHe};function QHe(e,t){let n=-1,r,i,a,u,l,o,s,c;for(;++n<e.length;)if(e[n][0]==="enter"&&e[n][1].type==="attentionSequence"&&e[n][1]._close){for(r=n;r--;)if(e[r][0]==="exit"&&e[r][1].type==="attentionSequence"&&e[r][1]._open&&t.sliceSerialize(e[r][1]).charCodeAt(0)===t.sliceSerialize(e[n][1]).charCodeAt(0)){if((e[r][1]._close||e[n][1]._open)&&(e[n][1].end.offset-e[n][1].start.offset)%3&&!((e[r][1].end.offset-e[r][1].start.offset+e[n][1].end.offset-e[n][1].start.offset)%3))continue;o=e[r][1].end.offset-e[r][1].start.offset>1&&e[n][1].end.offset-e[n][1].start.offset>1?2:1;const d={...e[r][1].end},h={...e[n][1].start};zK(d,-o),zK(h,o),u={type:o>1?"strongSequence":"emphasisSequence",start:d,end:{...e[r][1].end}},l={type:o>1?"strongSequence":"emphasisSequence",start:{...e[n][1].start},end:h},a={type:o>1?"strongText":"emphasisText",start:{...e[r][1].end},end:{...e[n][1].start}},i={type:o>1?"strong":"emphasis",start:{...u.start},end:{...l.end}},e[r][1].end={...u.start},e[n][1].start={...l.end},s=[],e[r][1].end.offset-e[r][1].start.offset&&(s=Ud(s,[["enter",e[r][1],t],["exit",e[r][1],t]])),s=Ud(s,[["enter",i,t],["enter",u,t],["exit",u,t],["enter",a,t]]),s=Ud(s,l5(t.parser.constructs.insideSpan.null,e.slice(r+1,n),t)),s=Ud(s,[["exit",a,t],["enter",l,t],["exit",l,t],["exit",i,t]]),e[n][1].end.offset-e[n][1].start.offset?(c=2,s=Ud(s,[["enter",e[n][1],t],["exit",e[n][1],t]])):c=0,Zf(e,r-1,n-r+3,s),n=r+s.length-c-2;break}}for(n=-1;++n<e.length;)e[n][1].type==="attentionSequence"&&(e[n][1].type="data");return e}function zHe(e,t){const n=this.parser.constructs.attentionMarkers.null,r=this.previous,i=z3(r);let a;return u;function u(o){return a=o,e.enter("attentionSequence"),l(o)}function l(o){if(o===a)return e.consume(o),l;const s=e.exit("attentionSequence"),c=z3(o),d=!c||c===2&&i||n.includes(o),h=!i||i===2&&c||n.includes(r);return s._open=!!(a===42?d:d&&(i||!h)),s._close=!!(a===42?h:h&&(c||!d)),t(o)}}function zK(e,t){e.column+=t,e.offset+=t,e._bufferIndex+=t}const qHe={name:"autolink",tokenize:VHe};function VHe(e,t,n){let r=0;return i;function i(m){return e.enter("autolink"),e.enter("autolinkMarker"),e.consume(m),e.exit("autolinkMarker"),e.enter("autolinkProtocol"),a}function a(m){return oc(m)?(e.consume(m),u):m===64?n(m):s(m)}function u(m){return m===43||m===45||m===46||ms(m)?(r=1,l(m)):s(m)}function l(m){return m===58?(e.consume(m),r=0,o):(m===43||m===45||m===46||ms(m))&&r++<32?(e.consume(m),l):(r=0,s(m))}function o(m){return m===62?(e.exit("autolinkProtocol"),e.enter("autolinkMarker"),e.consume(m),e.exit("autolinkMarker"),e.exit("autolink"),t):m===null||m===32||m===60||nC(m)?n(m):(e.consume(m),o)}function s(m){return m===64?(e.consume(m),c):kHe(m)?(e.consume(m),s):n(m)}function c(m){return ms(m)?d(m):n(m)}function d(m){return m===46?(e.consume(m),r=0,c):m===62?(e.exit("autolinkProtocol").type="autolinkEmail",e.enter("autolinkMarker"),e.consume(m),e.exit("autolinkMarker"),e.exit("autolink"),t):h(m)}function h(m){if((m===45||ms(m))&&r++<63){const y=m===45?h:d;return e.consume(m),y}return n(m)}}const FS={partial:!0,tokenize:UHe};function UHe(e,t,n){return r;function r(a){return zr(a)?si(e,i,"linePrefix")(a):i(a)}function i(a){return a===null||Mn(a)?t(a):n(a)}}const i1e={continuation:{tokenize:ZHe},exit:HHe,name:"blockQuote",tokenize:jHe};function jHe(e,t,n){const r=this;return i;function i(u){if(u===62){const l=r.containerState;return l.open||(e.enter("blockQuote",{_container:!0}),l.open=!0),e.enter("blockQuotePrefix"),e.enter("blockQuoteMarker"),e.consume(u),e.exit("blockQuoteMarker"),a}return n(u)}function a(u){return zr(u)?(e.enter("blockQuotePrefixWhitespace"),e.consume(u),e.exit("blockQuotePrefixWhitespace"),e.exit("blockQuotePrefix"),t):(e.exit("blockQuotePrefix"),t(u))}}function ZHe(e,t,n){const r=this;return i;function i(u){return zr(u)?si(e,a,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(u):a(u)}function a(u){return e.attempt(i1e,t,n)(u)}}function HHe(e){e.exit("blockQuote")}const a1e={name:"characterEscape",tokenize:XHe};function XHe(e,t,n){return r;function r(a){return e.enter("characterEscape"),e.enter("escapeMarker"),e.consume(a),e.exit("escapeMarker"),i}function i(a){return MHe(a)?(e.enter("characterEscapeValue"),e.consume(a),e.exit("characterEscapeValue"),e.exit("characterEscape"),t):n(a)}}const u1e={name:"characterReference",tokenize:YHe};function YHe(e,t,n){const r=this;let i=0,a,u;return l;function l(d){return e.enter("characterReference"),e.enter("characterReferenceMarker"),e.consume(d),e.exit("characterReferenceMarker"),o}function o(d){return d===35?(e.enter("characterReferenceMarkerNumeric"),e.consume(d),e.exit("characterReferenceMarkerNumeric"),s):(e.enter("characterReferenceValue"),a=31,u=ms,c(d))}function s(d){return d===88||d===120?(e.enter("characterReferenceMarkerHexadecimal"),e.consume(d),e.exit("characterReferenceMarkerHexadecimal"),e.enter("characterReferenceValue"),a=6,u=PHe,c):(e.enter("characterReferenceValue"),a=7,u=cF,c(d))}function c(d){if(d===59&&i){const h=e.exit("characterReferenceValue");return u===ms&&!cB(r.sliceSerialize(h))?n(d):(e.enter("characterReferenceMarker"),e.consume(d),e.exit("characterReferenceMarker"),e.exit("characterReference"),t)}return u(d)&&i++<a?(e.consume(d),c):n(d)}}const qK={partial:!0,tokenize:KHe},VK={concrete:!0,name:"codeFenced",tokenize:GHe};function GHe(e,t,n){const r=this,i={partial:!0,tokenize:R};let a=0,u=0,l;return o;function o($){return s($)}function s($){const k=r.events[r.events.length-1];return a=k&&k[1].type==="linePrefix"?k[2].sliceSerialize(k[1],!0).length:0,l=$,e.enter("codeFenced"),e.enter("codeFencedFence"),e.enter("codeFencedFenceSequence"),c($)}function c($){return $===l?(u++,e.consume($),c):u<3?n($):(e.exit("codeFencedFenceSequence"),zr($)?si(e,d,"whitespace")($):d($))}function d($){return $===null||Mn($)?(e.exit("codeFencedFence"),r.interrupt?t($):e.check(qK,v,T)($)):(e.enter("codeFencedFenceInfo"),e.enter("chunkString",{contentType:"string"}),h($))}function h($){return $===null||Mn($)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),d($)):zr($)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),si(e,m,"whitespace")($)):$===96&&$===l?n($):(e.consume($),h)}function m($){return $===null||Mn($)?d($):(e.enter("codeFencedFenceMeta"),e.enter("chunkString",{contentType:"string"}),y($))}function y($){return $===null||Mn($)?(e.exit("chunkString"),e.exit("codeFencedFenceMeta"),d($)):$===96&&$===l?n($):(e.consume($),y)}function v($){return e.attempt(i,T,_)($)}function _($){return e.enter("lineEnding"),e.consume($),e.exit("lineEnding"),S}function S($){return a>0&&zr($)?si(e,E,"linePrefix",a+1)($):E($)}function E($){return $===null||Mn($)?e.check(qK,v,T)($):(e.enter("codeFlowValue"),C($))}function C($){return $===null||Mn($)?(e.exit("codeFlowValue"),E($)):(e.consume($),C)}function T($){return e.exit("codeFenced"),t($)}function R($,k,F){let L=0;return j;function j(W){return $.enter("lineEnding"),$.consume(W),$.exit("lineEnding"),V}function V(W){return $.enter("codeFencedFence"),zr(W)?si($,q,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(W):q(W)}function q(W){return W===l?($.enter("codeFencedFenceSequence"),N(W)):F(W)}function N(W){return W===l?(L++,$.consume(W),N):L>=u?($.exit("codeFencedFenceSequence"),zr(W)?si($,U,"whitespace")(W):U(W)):F(W)}function U(W){return W===null||Mn(W)?($.exit("codeFencedFence"),k(W)):F(W)}}}function KHe(e,t,n){const r=this;return i;function i(u){return u===null?n(u):(e.enter("lineEnding"),e.consume(u),e.exit("lineEnding"),a)}function a(u){return r.parser.lazy[r.now().line]?n(u):t(u)}}const h7={name:"codeIndented",tokenize:JHe},WHe={partial:!0,tokenize:eXe};function JHe(e,t,n){const r=this;return i;function i(s){return e.enter("codeIndented"),si(e,a,"linePrefix",5)(s)}function a(s){const c=r.events[r.events.length-1];return c&&c[1].type==="linePrefix"&&c[2].sliceSerialize(c[1],!0).length>=4?u(s):n(s)}function u(s){return s===null?o(s):Mn(s)?e.attempt(WHe,u,o)(s):(e.enter("codeFlowValue"),l(s))}function l(s){return s===null||Mn(s)?(e.exit("codeFlowValue"),u(s)):(e.consume(s),l)}function o(s){return e.exit("codeIndented"),t(s)}}function eXe(e,t,n){const r=this;return i;function i(u){return r.parser.lazy[r.now().line]?n(u):Mn(u)?(e.enter("lineEnding"),e.consume(u),e.exit("lineEnding"),i):si(e,a,"linePrefix",5)(u)}function a(u){const l=r.events[r.events.length-1];return l&&l[1].type==="linePrefix"&&l[2].sliceSerialize(l[1],!0).length>=4?t(u):Mn(u)?i(u):n(u)}}const tXe={name:"codeText",previous:rXe,resolve:nXe,tokenize:iXe};function nXe(e){let t=e.length-4,n=3,r,i;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(r=n;++r<t;)if(e[r][1].type==="codeTextData"){e[n][1].type="codeTextPadding",e[t][1].type="codeTextPadding",n+=2,t-=2;break}}for(r=n-1,t++;++r<=t;)i===void 0?r!==t&&e[r][1].type!=="lineEnding"&&(i=r):(r===t||e[r][1].type==="lineEnding")&&(e[i][1].type="codeTextData",r!==i+2&&(e[i][1].end=e[r-1][1].end,e.splice(i+2,r-i-2),t-=r-i-2,r=i+2),i=void 0);return e}function rXe(e){return e!==96||this.events[this.events.length-1][1].type==="characterEscape"}function iXe(e,t,n){let r=0,i,a;return u;function u(d){return e.enter("codeText"),e.enter("codeTextSequence"),l(d)}function l(d){return d===96?(e.consume(d),r++,l):(e.exit("codeTextSequence"),o(d))}function o(d){return d===null?n(d):d===32?(e.enter("space"),e.consume(d),e.exit("space"),o):d===96?(a=e.enter("codeTextSequence"),i=0,c(d)):Mn(d)?(e.enter("lineEnding"),e.consume(d),e.exit("lineEnding"),o):(e.enter("codeTextData"),s(d))}function s(d){return d===null||d===32||d===96||Mn(d)?(e.exit("codeTextData"),o(d)):(e.consume(d),s)}function c(d){return d===96?(e.consume(d),i++,c):i===r?(e.exit("codeTextSequence"),e.exit("codeText"),t(d)):(a.type="codeTextData",s(d))}}class aXe{constructor(t){this.left=t?[...t]:[],this.right=[]}get(t){if(t<0||t>=this.left.length+this.right.length)throw new RangeError("Cannot access index `"+t+"` in a splice buffer of size `"+(this.left.length+this.right.length)+"`");return t<this.left.length?this.left[t]:this.right[this.right.length-t+this.left.length-1]}get length(){return this.left.length+this.right.length}shift(){return this.setCursor(0),this.right.pop()}slice(t,n){const r=n??Number.POSITIVE_INFINITY;return r<this.left.length?this.left.slice(t,r):t>this.left.length?this.right.slice(this.right.length-r+this.left.length,this.right.length-t+this.left.length).reverse():this.left.slice(t).concat(this.right.slice(this.right.length-r+this.left.length).reverse())}splice(t,n,r){const i=n||0;this.setCursor(Math.trunc(t));const a=this.right.splice(this.right.length-i,Number.POSITIVE_INFINITY);return r&&D2(this.left,r),a.reverse()}pop(){return this.setCursor(Number.POSITIVE_INFINITY),this.left.pop()}push(t){this.setCursor(Number.POSITIVE_INFINITY),this.left.push(t)}pushMany(t){this.setCursor(Number.POSITIVE_INFINITY),D2(this.left,t)}unshift(t){this.setCursor(0),this.right.push(t)}unshiftMany(t){this.setCursor(0),D2(this.right,t.reverse())}setCursor(t){if(!(t===this.left.length||t>this.left.length&&this.right.length===0||t<0&&this.left.length===0))if(t<this.left.length){const n=this.left.splice(t,Number.POSITIVE_INFINITY);D2(this.right,n.reverse())}else{const n=this.right.splice(this.left.length+this.right.length-t,Number.POSITIVE_INFINITY);D2(this.left,n.reverse())}}}function D2(e,t){let n=0;if(t.length<1e4)e.push(...t);else for(;n<t.length;)e.push(...t.slice(n,n+1e4)),n+=1e4}function l1e(e){const t={};let n=-1,r,i,a,u,l,o,s;const c=new aXe(e);for(;++n<c.length;){for(;n in t;)n=t[n];if(r=c.get(n),n&&r[1].type==="chunkFlow"&&c.get(n-1)[1].type==="listItemPrefix"&&(o=r[1]._tokenizer.events,a=0,a<o.length&&o[a][1].type==="lineEndingBlank"&&(a+=2),a<o.length&&o[a][1].type==="content"))for(;++a<o.length&&o[a][1].type!=="content";)o[a][1].type==="chunkText"&&(o[a][1]._isInFirstContentOfListItem=!0,a++);if(r[0]==="enter")r[1].contentType&&(Object.assign(t,uXe(c,n)),n=t[n],s=!0);else if(r[1]._container){for(a=n,i=void 0;a--;)if(u=c.get(a),u[1].type==="lineEnding"||u[1].type==="lineEndingBlank")u[0]==="enter"&&(i&&(c.get(i)[1].type="lineEndingBlank"),u[1].type="lineEnding",i=a);else if(!(u[1].type==="linePrefix"||u[1].type==="listItemIndent"))break;i&&(r[1].end={...c.get(i)[1].start},l=c.slice(i,n),l.unshift(r),c.splice(i,n-i+1,l))}}return Zf(e,0,Number.POSITIVE_INFINITY,c.slice(0)),!s}function uXe(e,t){const n=e.get(t)[1],r=e.get(t)[2];let i=t-1;const a=[];let u=n._tokenizer;u||(u=r.parser[n.contentType](n.start),n._contentTypeTextTrailing&&(u._contentTypeTextTrailing=!0));const l=u.events,o=[],s={};let c,d,h=-1,m=n,y=0,v=0;const _=[v];for(;m;){for(;e.get(++i)[1]!==m;);a.push(i),m._tokenizer||(c=r.sliceStream(m),m.next||c.push(null),d&&u.defineSkip(m.start),m._isInFirstContentOfListItem&&(u._gfmTasklistFirstContentOfListItem=!0),u.write(c),m._isInFirstContentOfListItem&&(u._gfmTasklistFirstContentOfListItem=void 0)),d=m,m=m.next}for(m=n;++h<l.length;)l[h][0]==="exit"&&l[h-1][0]==="enter"&&l[h][1].type===l[h-1][1].type&&l[h][1].start.line!==l[h][1].end.line&&(v=h+1,_.push(v),m._tokenizer=void 0,m.previous=void 0,m=m.next);for(u.events=[],m?(m._tokenizer=void 0,m.previous=void 0):_.pop(),h=_.length;h--;){const S=l.slice(_[h],_[h+1]),E=a.pop();o.push([E,E+S.length-1]),e.splice(E,2,S)}for(o.reverse(),h=-1;++h<o.length;)s[y+o[h][0]]=y+o[h][1],y+=o[h][1]-o[h][0]-1;return s}const lXe={resolve:sXe,tokenize:cXe},oXe={partial:!0,tokenize:fXe};function sXe(e){return l1e(e),e}function cXe(e,t){let n;return r;function r(l){return e.enter("content"),n=e.enter("chunkContent",{contentType:"content"}),i(l)}function i(l){return l===null?a(l):Mn(l)?e.check(oXe,u,a)(l):(e.consume(l),i)}function a(l){return e.exit("chunkContent"),e.exit("content"),t(l)}function u(l){return e.consume(l),e.exit("chunkContent"),n.next=e.enter("chunkContent",{contentType:"content",previous:n}),n=n.next,i}}function fXe(e,t,n){const r=this;return i;function i(u){return e.exit("chunkContent"),e.enter("lineEnding"),e.consume(u),e.exit("lineEnding"),si(e,a,"linePrefix")}function a(u){if(u===null||Mn(u))return n(u);const l=r.events[r.events.length-1];return!r.parser.constructs.disable.null.includes("codeIndented")&&l&&l[1].type==="linePrefix"&&l[2].sliceSerialize(l[1],!0).length>=4?t(u):e.interrupt(r.parser.constructs.flow,n,t)(u)}}function o1e(e,t,n,r,i,a,u,l,o){const s=o||Number.POSITIVE_INFINITY;let c=0;return d;function d(S){return S===60?(e.enter(r),e.enter(i),e.enter(a),e.consume(S),e.exit(a),h):S===null||S===32||S===41||nC(S)?n(S):(e.enter(r),e.enter(u),e.enter(l),e.enter("chunkString",{contentType:"string"}),v(S))}function h(S){return S===62?(e.enter(a),e.consume(S),e.exit(a),e.exit(i),e.exit(r),t):(e.enter(l),e.enter("chunkString",{contentType:"string"}),m(S))}function m(S){return S===62?(e.exit("chunkString"),e.exit(l),h(S)):S===null||S===60||Mn(S)?n(S):(e.consume(S),S===92?y:m)}function y(S){return S===60||S===62||S===92?(e.consume(S),m):m(S)}function v(S){return!c&&(S===null||S===41||la(S))?(e.exit("chunkString"),e.exit(l),e.exit(u),e.exit(r),t(S)):c<s&&S===40?(e.consume(S),c++,v):S===41?(e.consume(S),c--,v):S===null||S===32||S===40||nC(S)?n(S):(e.consume(S),S===92?_:v)}function _(S){return S===40||S===41||S===92?(e.consume(S),v):v(S)}}function s1e(e,t,n,r,i,a){const u=this;let l=0,o;return s;function s(m){return e.enter(r),e.enter(i),e.consume(m),e.exit(i),e.enter(a),c}function c(m){return l>999||m===null||m===91||m===93&&!o||m===94&&!l&&"_hiddenFootnoteSupport"in u.parser.constructs?n(m):m===93?(e.exit(a),e.enter(i),e.consume(m),e.exit(i),e.exit(r),t):Mn(m)?(e.enter("lineEnding"),e.consume(m),e.exit("lineEnding"),c):(e.enter("chunkString",{contentType:"string"}),d(m))}function d(m){return m===null||m===91||m===93||Mn(m)||l++>999?(e.exit("chunkString"),c(m)):(e.consume(m),o||(o=!zr(m)),m===92?h:d)}function h(m){return m===91||m===92||m===93?(e.consume(m),l++,d):d(m)}}function c1e(e,t,n,r,i,a){let u;return l;function l(h){return h===34||h===39||h===40?(e.enter(r),e.enter(i),e.consume(h),e.exit(i),u=h===40?41:h,o):n(h)}function o(h){return h===u?(e.enter(i),e.consume(h),e.exit(i),e.exit(r),t):(e.enter(a),s(h))}function s(h){return h===u?(e.exit(a),o(u)):h===null?n(h):Mn(h)?(e.enter("lineEnding"),e.consume(h),e.exit("lineEnding"),si(e,s,"linePrefix")):(e.enter("chunkString",{contentType:"string"}),c(h))}function c(h){return h===u||h===null||Mn(h)?(e.exit("chunkString"),s(h)):(e.consume(h),h===92?d:c)}function d(h){return h===u||h===92?(e.consume(h),c):c(h)}}function K2(e,t){let n;return r;function r(i){return Mn(i)?(e.enter("lineEnding"),e.consume(i),e.exit("lineEnding"),n=!0,r):zr(i)?si(e,r,n?"linePrefix":"lineSuffix")(i):t(i)}}const dXe={name:"definition",tokenize:pXe},hXe={partial:!0,tokenize:mXe};function pXe(e,t,n){const r=this;let i;return a;function a(m){return e.enter("definition"),u(m)}function u(m){return s1e.call(r,e,l,n,"definitionLabel","definitionLabelMarker","definitionLabelString")(m)}function l(m){return i=ap(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)),m===58?(e.enter("definitionMarker"),e.consume(m),e.exit("definitionMarker"),o):n(m)}function o(m){return la(m)?K2(e,s)(m):s(m)}function s(m){return o1e(e,c,n,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(m)}function c(m){return e.attempt(hXe,d,d)(m)}function d(m){return zr(m)?si(e,h,"whitespace")(m):h(m)}function h(m){return m===null||Mn(m)?(e.exit("definition"),r.parser.defined.push(i),t(m)):n(m)}}function mXe(e,t,n){return r;function r(l){return la(l)?K2(e,i)(l):n(l)}function i(l){return c1e(e,a,n,"definitionTitle","definitionTitleMarker","definitionTitleString")(l)}function a(l){return zr(l)?si(e,u,"whitespace")(l):u(l)}function u(l){return l===null||Mn(l)?t(l):n(l)}}const gXe={name:"hardBreakEscape",tokenize:vXe};function vXe(e,t,n){return r;function r(a){return e.enter("hardBreakEscape"),e.consume(a),i}function i(a){return Mn(a)?(e.exit("hardBreakEscape"),t(a)):n(a)}}const yXe={name:"headingAtx",resolve:bXe,tokenize:OXe};function bXe(e,t){let n=e.length-2,r=3,i,a;return e[r][1].type==="whitespace"&&(r+=2),n-2>r&&e[n][1].type==="whitespace"&&(n-=2),e[n][1].type==="atxHeadingSequence"&&(r===n-1||n-4>r&&e[n-2][1].type==="whitespace")&&(n-=r+1===n?2:4),n>r&&(i={type:"atxHeadingText",start:e[r][1].start,end:e[n][1].end},a={type:"chunkText",start:e[r][1].start,end:e[n][1].end,contentType:"text"},Zf(e,r,n-r+1,[["enter",i,t],["enter",a,t],["exit",a,t],["exit",i,t]])),e}function OXe(e,t,n){let r=0;return i;function i(c){return e.enter("atxHeading"),a(c)}function a(c){return e.enter("atxHeadingSequence"),u(c)}function u(c){return c===35&&r++<6?(e.consume(c),u):c===null||la(c)?(e.exit("atxHeadingSequence"),l(c)):n(c)}function l(c){return c===35?(e.enter("atxHeadingSequence"),o(c)):c===null||Mn(c)?(e.exit("atxHeading"),t(c)):zr(c)?si(e,l,"whitespace")(c):(e.enter("atxHeadingText"),s(c))}function o(c){return c===35?(e.consume(c),o):(e.exit("atxHeadingSequence"),l(c))}function s(c){return c===null||c===35||la(c)?(e.exit("atxHeadingText"),l(c)):(e.consume(c),s)}}const xXe=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],UK=["pre","script","style","textarea"],SXe={concrete:!0,name:"htmlFlow",resolveTo:DXe,tokenize:$Xe},_Xe={partial:!0,tokenize:wXe},EXe={partial:!0,tokenize:CXe};function DXe(e){let t=e.length;for(;t--&&!(e[t][0]==="enter"&&e[t][1].type==="htmlFlow"););return t>1&&e[t-2][1].type==="linePrefix"&&(e[t][1].start=e[t-2][1].start,e[t+1][1].start=e[t-2][1].start,e.splice(t-2,2)),e}function $Xe(e,t,n){const r=this;let i,a,u,l,o;return s;function s(B){return c(B)}function c(B){return e.enter("htmlFlow"),e.enter("htmlFlowData"),e.consume(B),d}function d(B){return B===33?(e.consume(B),h):B===47?(e.consume(B),a=!0,v):B===63?(e.consume(B),i=3,r.interrupt?t:M):oc(B)?(e.consume(B),u=String.fromCharCode(B),_):n(B)}function h(B){return B===45?(e.consume(B),i=2,m):B===91?(e.consume(B),i=5,l=0,y):oc(B)?(e.consume(B),i=4,r.interrupt?t:M):n(B)}function m(B){return B===45?(e.consume(B),r.interrupt?t:M):n(B)}function y(B){const ne="CDATA[";return B===ne.charCodeAt(l++)?(e.consume(B),l===ne.length?r.interrupt?t:q:y):n(B)}function v(B){return oc(B)?(e.consume(B),u=String.fromCharCode(B),_):n(B)}function _(B){if(B===null||B===47||B===62||la(B)){const ne=B===47,oe=u.toLowerCase();return!ne&&!a&&UK.includes(oe)?(i=1,r.interrupt?t(B):q(B)):xXe.includes(u.toLowerCase())?(i=6,ne?(e.consume(B),S):r.interrupt?t(B):q(B)):(i=7,r.interrupt&&!r.parser.lazy[r.now().line]?n(B):a?E(B):C(B))}return B===45||ms(B)?(e.consume(B),u+=String.fromCharCode(B),_):n(B)}function S(B){return B===62?(e.consume(B),r.interrupt?t:q):n(B)}function E(B){return zr(B)?(e.consume(B),E):j(B)}function C(B){return B===47?(e.consume(B),j):B===58||B===95||oc(B)?(e.consume(B),T):zr(B)?(e.consume(B),C):j(B)}function T(B){return B===45||B===46||B===58||B===95||ms(B)?(e.consume(B),T):R(B)}function R(B){return B===61?(e.consume(B),$):zr(B)?(e.consume(B),R):C(B)}function $(B){return B===null||B===60||B===61||B===62||B===96?n(B):B===34||B===39?(e.consume(B),o=B,k):zr(B)?(e.consume(B),$):F(B)}function k(B){return B===o?(e.consume(B),o=null,L):B===null||Mn(B)?n(B):(e.consume(B),k)}function F(B){return B===null||B===34||B===39||B===47||B===60||B===61||B===62||B===96||la(B)?R(B):(e.consume(B),F)}function L(B){return B===47||B===62||zr(B)?C(B):n(B)}function j(B){return B===62?(e.consume(B),V):n(B)}function V(B){return B===null||Mn(B)?q(B):zr(B)?(e.consume(B),V):n(B)}function q(B){return B===45&&i===2?(e.consume(B),G):B===60&&i===1?(e.consume(B),J):B===62&&i===4?(e.consume(B),K):B===63&&i===3?(e.consume(B),M):B===93&&i===5?(e.consume(B),H):Mn(B)&&(i===6||i===7)?(e.exit("htmlFlowData"),e.check(_Xe,X,N)(B)):B===null||Mn(B)?(e.exit("htmlFlowData"),N(B)):(e.consume(B),q)}function N(B){return e.check(EXe,U,X)(B)}function U(B){return e.enter("lineEnding"),e.consume(B),e.exit("lineEnding"),W}function W(B){return B===null||Mn(B)?N(B):(e.enter("htmlFlowData"),q(B))}function G(B){return B===45?(e.consume(B),M):q(B)}function J(B){return B===47?(e.consume(B),u="",te):q(B)}function te(B){if(B===62){const ne=u.toLowerCase();return UK.includes(ne)?(e.consume(B),K):q(B)}return oc(B)&&u.length<8?(e.consume(B),u+=String.fromCharCode(B),te):q(B)}function H(B){return B===93?(e.consume(B),M):q(B)}function M(B){return B===62?(e.consume(B),K):B===45&&i===2?(e.consume(B),M):q(B)}function K(B){return B===null||Mn(B)?(e.exit("htmlFlowData"),X(B)):(e.consume(B),K)}function X(B){return e.exit("htmlFlow"),t(B)}}function CXe(e,t,n){const r=this;return i;function i(u){return Mn(u)?(e.enter("lineEnding"),e.consume(u),e.exit("lineEnding"),a):n(u)}function a(u){return r.parser.lazy[r.now().line]?n(u):t(u)}}function wXe(e,t,n){return r;function r(i){return e.enter("lineEnding"),e.consume(i),e.exit("lineEnding"),e.attempt(FS,t,n)}}const RXe={name:"htmlText",tokenize:AXe};function AXe(e,t,n){const r=this;let i,a,u;return l;function l(M){return e.enter("htmlText"),e.enter("htmlTextData"),e.consume(M),o}function o(M){return M===33?(e.consume(M),s):M===47?(e.consume(M),R):M===63?(e.consume(M),C):oc(M)?(e.consume(M),F):n(M)}function s(M){return M===45?(e.consume(M),c):M===91?(e.consume(M),a=0,y):oc(M)?(e.consume(M),E):n(M)}function c(M){return M===45?(e.consume(M),m):n(M)}function d(M){return M===null?n(M):M===45?(e.consume(M),h):Mn(M)?(u=d,J(M)):(e.consume(M),d)}function h(M){return M===45?(e.consume(M),m):d(M)}function m(M){return M===62?G(M):M===45?h(M):d(M)}function y(M){const K="CDATA[";return M===K.charCodeAt(a++)?(e.consume(M),a===K.length?v:y):n(M)}function v(M){return M===null?n(M):M===93?(e.consume(M),_):Mn(M)?(u=v,J(M)):(e.consume(M),v)}function _(M){return M===93?(e.consume(M),S):v(M)}function S(M){return M===62?G(M):M===93?(e.consume(M),S):v(M)}function E(M){return M===null||M===62?G(M):Mn(M)?(u=E,J(M)):(e.consume(M),E)}function C(M){return M===null?n(M):M===63?(e.consume(M),T):Mn(M)?(u=C,J(M)):(e.consume(M),C)}function T(M){return M===62?G(M):C(M)}function R(M){return oc(M)?(e.consume(M),$):n(M)}function $(M){return M===45||ms(M)?(e.consume(M),$):k(M)}function k(M){return Mn(M)?(u=k,J(M)):zr(M)?(e.consume(M),k):G(M)}function F(M){return M===45||ms(M)?(e.consume(M),F):M===47||M===62||la(M)?L(M):n(M)}function L(M){return M===47?(e.consume(M),G):M===58||M===95||oc(M)?(e.consume(M),j):Mn(M)?(u=L,J(M)):zr(M)?(e.consume(M),L):G(M)}function j(M){return M===45||M===46||M===58||M===95||ms(M)?(e.consume(M),j):V(M)}function V(M){return M===61?(e.consume(M),q):Mn(M)?(u=V,J(M)):zr(M)?(e.consume(M),V):L(M)}function q(M){return M===null||M===60||M===61||M===62||M===96?n(M):M===34||M===39?(e.consume(M),i=M,N):Mn(M)?(u=q,J(M)):zr(M)?(e.consume(M),q):(e.consume(M),U)}function N(M){return M===i?(e.consume(M),i=void 0,W):M===null?n(M):Mn(M)?(u=N,J(M)):(e.consume(M),N)}function U(M){return M===null||M===34||M===39||M===60||M===61||M===96?n(M):M===47||M===62||la(M)?L(M):(e.consume(M),U)}function W(M){return M===47||M===62||la(M)?L(M):n(M)}function G(M){return M===62?(e.consume(M),e.exit("htmlTextData"),e.exit("htmlText"),t):n(M)}function J(M){return e.exit("htmlTextData"),e.enter("lineEnding"),e.consume(M),e.exit("lineEnding"),te}function te(M){return zr(M)?si(e,H,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(M):H(M)}function H(M){return e.enter("htmlTextData"),u(M)}}const fB={name:"labelEnd",resolveAll:MXe,resolveTo:FXe,tokenize:NXe},TXe={tokenize:IXe},kXe={tokenize:LXe},PXe={tokenize:BXe};function MXe(e){let t=-1;const n=[];for(;++t<e.length;){const r=e[t][1];if(n.push(e[t]),r.type==="labelImage"||r.type==="labelLink"||r.type==="labelEnd"){const i=r.type==="labelImage"?4:2;r.type="data",t+=i}}return e.length!==n.length&&Zf(e,0,e.length,n),e}function FXe(e,t){let n=e.length,r=0,i,a,u,l;for(;n--;)if(i=e[n][1],a){if(i.type==="link"||i.type==="labelLink"&&i._inactive)break;e[n][0]==="enter"&&i.type==="labelLink"&&(i._inactive=!0)}else if(u){if(e[n][0]==="enter"&&(i.type==="labelImage"||i.type==="labelLink")&&!i._balanced&&(a=n,i.type!=="labelLink")){r=2;break}}else i.type==="labelEnd"&&(u=n);const o={type:e[a][1].type==="labelLink"?"link":"image",start:{...e[a][1].start},end:{...e[e.length-1][1].end}},s={type:"label",start:{...e[a][1].start},end:{...e[u][1].end}},c={type:"labelText",start:{...e[a+r+2][1].end},end:{...e[u-2][1].start}};return l=[["enter",o,t],["enter",s,t]],l=Ud(l,e.slice(a+1,a+r+3)),l=Ud(l,[["enter",c,t]]),l=Ud(l,l5(t.parser.constructs.insideSpan.null,e.slice(a+r+4,u-3),t)),l=Ud(l,[["exit",c,t],e[u-2],e[u-1],["exit",s,t]]),l=Ud(l,e.slice(u+1)),l=Ud(l,[["exit",o,t]]),Zf(e,a,e.length,l),e}function NXe(e,t,n){const r=this;let i=r.events.length,a,u;for(;i--;)if((r.events[i][1].type==="labelImage"||r.events[i][1].type==="labelLink")&&!r.events[i][1]._balanced){a=r.events[i][1];break}return l;function l(h){return a?a._inactive?d(h):(u=r.parser.defined.includes(ap(r.sliceSerialize({start:a.end,end:r.now()}))),e.enter("labelEnd"),e.enter("labelMarker"),e.consume(h),e.exit("labelMarker"),e.exit("labelEnd"),o):n(h)}function o(h){return h===40?e.attempt(TXe,c,u?c:d)(h):h===91?e.attempt(kXe,c,u?s:d)(h):u?c(h):d(h)}function s(h){return e.attempt(PXe,c,d)(h)}function c(h){return t(h)}function d(h){return a._balanced=!0,n(h)}}function IXe(e,t,n){return r;function r(d){return e.enter("resource"),e.enter("resourceMarker"),e.consume(d),e.exit("resourceMarker"),i}function i(d){return la(d)?K2(e,a)(d):a(d)}function a(d){return d===41?c(d):o1e(e,u,l,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(d)}function u(d){return la(d)?K2(e,o)(d):c(d)}function l(d){return n(d)}function o(d){return d===34||d===39||d===40?c1e(e,s,n,"resourceTitle","resourceTitleMarker","resourceTitleString")(d):c(d)}function s(d){return la(d)?K2(e,c)(d):c(d)}function c(d){return d===41?(e.enter("resourceMarker"),e.consume(d),e.exit("resourceMarker"),e.exit("resource"),t):n(d)}}function LXe(e,t,n){const r=this;return i;function i(l){return s1e.call(r,e,a,u,"reference","referenceMarker","referenceString")(l)}function a(l){return r.parser.defined.includes(ap(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)))?t(l):n(l)}function u(l){return n(l)}}function BXe(e,t,n){return r;function r(a){return e.enter("reference"),e.enter("referenceMarker"),e.consume(a),e.exit("referenceMarker"),i}function i(a){return a===93?(e.enter("referenceMarker"),e.consume(a),e.exit("referenceMarker"),e.exit("reference"),t):n(a)}}const QXe={name:"labelStartImage",resolveAll:fB.resolveAll,tokenize:zXe};function zXe(e,t,n){const r=this;return i;function i(l){return e.enter("labelImage"),e.enter("labelImageMarker"),e.consume(l),e.exit("labelImageMarker"),a}function a(l){return l===91?(e.enter("labelMarker"),e.consume(l),e.exit("labelMarker"),e.exit("labelImage"),u):n(l)}function u(l){return l===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(l):t(l)}}const qXe={name:"labelStartLink",resolveAll:fB.resolveAll,tokenize:VXe};function VXe(e,t,n){const r=this;return i;function i(u){return e.enter("labelLink"),e.enter("labelMarker"),e.consume(u),e.exit("labelMarker"),e.exit("labelLink"),a}function a(u){return u===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(u):t(u)}}const p7={name:"lineEnding",tokenize:UXe};function UXe(e,t){return n;function n(r){return e.enter("lineEnding"),e.consume(r),e.exit("lineEnding"),si(e,t,"linePrefix")}}const vD={name:"thematicBreak",tokenize:jXe};function jXe(e,t,n){let r=0,i;return a;function a(s){return e.enter("thematicBreak"),u(s)}function u(s){return i=s,l(s)}function l(s){return s===i?(e.enter("thematicBreakSequence"),o(s)):r>=3&&(s===null||Mn(s))?(e.exit("thematicBreak"),t(s)):n(s)}function o(s){return s===i?(e.consume(s),r++,o):(e.exit("thematicBreakSequence"),zr(s)?si(e,l,"whitespace")(s):l(s))}}const Xc={continuation:{tokenize:YXe},exit:KXe,name:"list",tokenize:XXe},ZXe={partial:!0,tokenize:WXe},HXe={partial:!0,tokenize:GXe};function XXe(e,t,n){const r=this,i=r.events[r.events.length-1];let a=i&&i[1].type==="linePrefix"?i[2].sliceSerialize(i[1],!0).length:0,u=0;return l;function l(m){const y=r.containerState.type||(m===42||m===43||m===45?"listUnordered":"listOrdered");if(y==="listUnordered"?!r.containerState.marker||m===r.containerState.marker:cF(m)){if(r.containerState.type||(r.containerState.type=y,e.enter(y,{_container:!0})),y==="listUnordered")return e.enter("listItemPrefix"),m===42||m===45?e.check(vD,n,s)(m):s(m);if(!r.interrupt||m===49)return e.enter("listItemPrefix"),e.enter("listItemValue"),o(m)}return n(m)}function o(m){return cF(m)&&++u<10?(e.consume(m),o):(!r.interrupt||u<2)&&(r.containerState.marker?m===r.containerState.marker:m===41||m===46)?(e.exit("listItemValue"),s(m)):n(m)}function s(m){return e.enter("listItemMarker"),e.consume(m),e.exit("listItemMarker"),r.containerState.marker=r.containerState.marker||m,e.check(FS,r.interrupt?n:c,e.attempt(ZXe,h,d))}function c(m){return r.containerState.initialBlankLine=!0,a++,h(m)}function d(m){return zr(m)?(e.enter("listItemPrefixWhitespace"),e.consume(m),e.exit("listItemPrefixWhitespace"),h):n(m)}function h(m){return r.containerState.size=a+r.sliceSerialize(e.exit("listItemPrefix"),!0).length,t(m)}}function YXe(e,t,n){const r=this;return r.containerState._closeFlow=void 0,e.check(FS,i,a);function i(l){return r.containerState.furtherBlankLines=r.containerState.furtherBlankLines||r.containerState.initialBlankLine,si(e,t,"listItemIndent",r.containerState.size+1)(l)}function a(l){return r.containerState.furtherBlankLines||!zr(l)?(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,u(l)):(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,e.attempt(HXe,t,u)(l))}function u(l){return r.containerState._closeFlow=!0,r.interrupt=void 0,si(e,e.attempt(Xc,t,n),"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(l)}}function GXe(e,t,n){const r=this;return si(e,i,"listItemIndent",r.containerState.size+1);function i(a){const u=r.events[r.events.length-1];return u&&u[1].type==="listItemIndent"&&u[2].sliceSerialize(u[1],!0).length===r.containerState.size?t(a):n(a)}}function KXe(e){e.exit(this.containerState.type)}function WXe(e,t,n){const r=this;return si(e,i,"listItemPrefixWhitespace",r.parser.constructs.disable.null.includes("codeIndented")?void 0:5);function i(a){const u=r.events[r.events.length-1];return!zr(a)&&u&&u[1].type==="listItemPrefixWhitespace"?t(a):n(a)}}const jK={name:"setextUnderline",resolveTo:JXe,tokenize:eYe};function JXe(e,t){let n=e.length,r,i,a;for(;n--;)if(e[n][0]==="enter"){if(e[n][1].type==="content"){r=n;break}e[n][1].type==="paragraph"&&(i=n)}else e[n][1].type==="content"&&e.splice(n,1),!a&&e[n][1].type==="definition"&&(a=n);const u={type:"setextHeading",start:{...e[r][1].start},end:{...e[e.length-1][1].end}};return e[i][1].type="setextHeadingText",a?(e.splice(i,0,["enter",u,t]),e.splice(a+1,0,["exit",e[r][1],t]),e[r][1].end={...e[a][1].end}):e[r][1]=u,e.push(["exit",u,t]),e}function eYe(e,t,n){const r=this;let i;return a;function a(s){let c=r.events.length,d;for(;c--;)if(r.events[c][1].type!=="lineEnding"&&r.events[c][1].type!=="linePrefix"&&r.events[c][1].type!=="content"){d=r.events[c][1].type==="paragraph";break}return!r.parser.lazy[r.now().line]&&(r.interrupt||d)?(e.enter("setextHeadingLine"),i=s,u(s)):n(s)}function u(s){return e.enter("setextHeadingLineSequence"),l(s)}function l(s){return s===i?(e.consume(s),l):(e.exit("setextHeadingLineSequence"),zr(s)?si(e,o,"lineSuffix")(s):o(s))}function o(s){return s===null||Mn(s)?(e.exit("setextHeadingLine"),t(s)):n(s)}}const tYe={tokenize:nYe};function nYe(e){const t=this,n=e.attempt(FS,r,e.attempt(this.parser.constructs.flowInitial,i,si(e,e.attempt(this.parser.constructs.flow,i,e.attempt(lXe,i)),"linePrefix")));return n;function r(a){if(a===null){e.consume(a);return}return e.enter("lineEndingBlank"),e.consume(a),e.exit("lineEndingBlank"),t.currentConstruct=void 0,n}function i(a){if(a===null){e.consume(a);return}return e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),t.currentConstruct=void 0,n}}const rYe={resolveAll:d1e()},iYe=f1e("string"),aYe=f1e("text");function f1e(e){return{resolveAll:d1e(e==="text"?uYe:void 0),tokenize:t};function t(n){const r=this,i=this.parser.constructs[e],a=n.attempt(i,u,l);return u;function u(c){return s(c)?a(c):l(c)}function l(c){if(c===null){n.consume(c);return}return n.enter("data"),n.consume(c),o}function o(c){return s(c)?(n.exit("data"),a(c)):(n.consume(c),o)}function s(c){if(c===null)return!0;const d=i[c];let h=-1;if(d)for(;++h<d.length;){const m=d[h];if(!m.previous||m.previous.call(r,r.previous))return!0}return!1}}}function d1e(e){return t;function t(n,r){let i=-1,a;for(;++i<=n.length;)a===void 0?n[i]&&n[i][1].type==="data"&&(a=i,i++):(!n[i]||n[i][1].type!=="data")&&(i!==a+2&&(n[a][1].end=n[i-1][1].end,n.splice(a+2,i-a-2),i=a+2),a=void 0);return e?e(n,r):n}}function uYe(e,t){let n=0;for(;++n<=e.length;)if((n===e.length||e[n][1].type==="lineEnding")&&e[n-1][1].type==="data"){const r=e[n-1][1],i=t.sliceStream(r);let a=i.length,u=-1,l=0,o;for(;a--;){const s=i[a];if(typeof s=="string"){for(u=s.length;s.charCodeAt(u-1)===32;)l++,u--;if(u)break;u=-1}else if(s===-2)o=!0,l++;else if(s!==-1){a++;break}}if(t._contentTypeTextTrailing&&n===e.length&&(l=0),l){const s={type:n===e.length||o||l<2?"lineSuffix":"hardBreakTrailing",start:{_bufferIndex:a?u:r.start._bufferIndex+u,_index:r.start._index+a,line:r.end.line,column:r.end.column-l,offset:r.end.offset-l},end:{...r.end}};r.end={...s.start},r.start.offset===r.end.offset?Object.assign(r,s):(e.splice(n,0,["enter",s,t],["exit",s,t]),n+=2)}n++}return e}const lYe={42:Xc,43:Xc,45:Xc,48:Xc,49:Xc,50:Xc,51:Xc,52:Xc,53:Xc,54:Xc,55:Xc,56:Xc,57:Xc,62:i1e},oYe={91:dXe},sYe={[-2]:h7,[-1]:h7,32:h7},cYe={35:yXe,42:vD,45:[jK,vD],60:SXe,61:jK,95:vD,96:VK,126:VK},fYe={38:u1e,92:a1e},dYe={[-5]:p7,[-4]:p7,[-3]:p7,33:QXe,38:u1e,42:fF,60:[qHe,RXe],91:qXe,92:[gXe,a1e],93:fB,95:fF,96:tXe},hYe={null:[fF,rYe]},pYe={null:[42,95]},mYe={null:[]},gYe=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:pYe,contentInitial:oYe,disable:mYe,document:lYe,flow:cYe,flowInitial:sYe,insideSpan:hYe,string:fYe,text:dYe},Symbol.toStringTag,{value:"Module"}));function vYe(e,t,n){let r={_bufferIndex:-1,_index:0,line:n&&n.line||1,column:n&&n.column||1,offset:n&&n.offset||0};const i={},a=[];let u=[],l=[];const o={attempt:k(R),check:k($),consume:E,enter:C,exit:T,interrupt:k($,{interrupt:!0})},s={code:null,containerState:{},defineSkip:v,events:[],now:y,parser:e,previous:null,sliceSerialize:h,sliceStream:m,write:d};let c=t.tokenize.call(s,o);return t.resolveAll&&a.push(t),s;function d(V){return u=Ud(u,V),_(),u[u.length-1]!==null?[]:(F(t,0),s.events=l5(a,s.events,s),s.events)}function h(V,q){return bYe(m(V),q)}function m(V){return yYe(u,V)}function y(){const{_bufferIndex:V,_index:q,line:N,column:U,offset:W}=r;return{_bufferIndex:V,_index:q,line:N,column:U,offset:W}}function v(V){i[V.line]=V.column,j()}function _(){let V;for(;r._index<u.length;){const q=u[r._index];if(typeof q=="string")for(V=r._index,r._bufferIndex<0&&(r._bufferIndex=0);r._index===V&&r._bufferIndex<q.length;)S(q.charCodeAt(r._bufferIndex));else S(q)}}function S(V){c=c(V)}function E(V){Mn(V)?(r.line++,r.column=1,r.offset+=V===-3?2:1,j()):V!==-1&&(r.column++,r.offset++),r._bufferIndex<0?r._index++:(r._bufferIndex++,r._bufferIndex===u[r._index].length&&(r._bufferIndex=-1,r._index++)),s.previous=V}function C(V,q){const N=q||{};return N.type=V,N.start=y(),s.events.push(["enter",N,s]),l.push(N),N}function T(V){const q=l.pop();return q.end=y(),s.events.push(["exit",q,s]),q}function R(V,q){F(V,q.from)}function $(V,q){q.restore()}function k(V,q){return N;function N(U,W,G){let J,te,H,M;return Array.isArray(U)?X(U):"tokenize"in U?X([U]):K(U);function K(ie){return de;function de(be){const ve=be!==null&&ie[be],pe=be!==null&&ie.null,_e=[...Array.isArray(ve)?ve:ve?[ve]:[],...Array.isArray(pe)?pe:pe?[pe]:[]];return X(_e)(be)}}function X(ie){return J=ie,te=0,ie.length===0?G:B(ie[te])}function B(ie){return de;function de(be){return M=L(),H=ie,ie.partial||(s.currentConstruct=ie),ie.name&&s.parser.constructs.disable.null.includes(ie.name)?oe():ie.tokenize.call(q?Object.assign(Object.create(s),q):s,o,ne,oe)(be)}}function ne(ie){return V(H,M),W}function oe(ie){return M.restore(),++te<J.length?B(J[te]):G}}}function F(V,q){V.resolveAll&&!a.includes(V)&&a.push(V),V.resolve&&Zf(s.events,q,s.events.length-q,V.resolve(s.events.slice(q),s)),V.resolveTo&&(s.events=V.resolveTo(s.events,s))}function L(){const V=y(),q=s.previous,N=s.currentConstruct,U=s.events.length,W=Array.from(l);return{from:U,restore:G};function G(){r=V,s.previous=q,s.currentConstruct=N,s.events.length=U,l=W,j()}}function j(){r.line in i&&r.column<2&&(r.column=i[r.line],r.offset+=i[r.line]-1)}}function yYe(e,t){const n=t.start._index,r=t.start._bufferIndex,i=t.end._index,a=t.end._bufferIndex;let u;if(n===i)u=[e[n].slice(r,a)];else{if(u=e.slice(n,i),r>-1){const l=u[0];typeof l=="string"?u[0]=l.slice(r):u.shift()}a>0&&u.push(e[i].slice(0,a))}return u}function bYe(e,t){let n=-1;const r=[];let i;for(;++n<e.length;){const a=e[n];let u;if(typeof a=="string")u=a;else switch(a){case-5:{u="\r";break}case-4:{u=`
`;break}case-3:{u=`\r
`;break}case-2:{u=t?" ":"	";break}case-1:{if(!t&&i)continue;u=" ";break}default:u=String.fromCharCode(a)}i=a===-2,r.push(u)}return r.join("")}function OYe(e){const r={constructs:n1e([gYe,...(e||{}).extensions||[]]),content:i(FHe),defined:[],document:i(IHe),flow:i(tYe),lazy:{},string:i(iYe),text:i(aYe)};return r;function i(a){return u;function u(l){return vYe(r,a,l)}}}function xYe(e){for(;!l1e(e););return e}const ZK=/[\0\t\n\r]/g;function SYe(){let e=1,t="",n=!0,r;return i;function i(a,u,l){const o=[];let s,c,d,h,m;for(a=t+(typeof a=="string"?a.toString():new TextDecoder(u||void 0).decode(a)),d=0,t="",n&&(a.charCodeAt(0)===65279&&d++,n=void 0);d<a.length;){if(ZK.lastIndex=d,s=ZK.exec(a),h=s&&s.index!==void 0?s.index:a.length,m=a.charCodeAt(h),!s){t=a.slice(d);break}if(m===10&&d===h&&r)o.push(-3),r=void 0;else switch(r&&(o.push(-5),r=void 0),d<h&&(o.push(a.slice(d,h)),e+=h-d),m){case 0:{o.push(65533),e++;break}case 9:{for(c=Math.ceil(e/4)*4,o.push(-2);e++<c;)o.push(-1);break}case 10:{o.push(-4),e=1;break}default:r=!0,e=1}d=h+1}return l&&(r&&o.push(-5),t&&o.push(t),o.push(null)),o}}const _Ye=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi;function EYe(e){return e.replace(_Ye,DYe)}function DYe(e,t,n){if(t)return t;if(n.charCodeAt(0)===35){const i=n.charCodeAt(1),a=i===120||i===88;return r1e(n.slice(a?2:1),a?16:10)}return cB(n)||e}const h1e={}.hasOwnProperty;function $Ye(e,t,n){return typeof t!="string"&&(n=t,t=void 0),CYe(n)(xYe(OYe(n).document().write(SYe()(e,t,!0))))}function CYe(e){const t={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:a(tt),autolinkProtocol:L,autolinkEmail:L,atxHeading:a(we),blockQuote:a(pe),characterEscape:L,characterReference:L,codeFenced:a(_e),codeFencedFenceInfo:u,codeFencedFenceMeta:u,codeIndented:a(_e,u),codeText:a(se,u),codeTextData:L,data:L,codeFlowValue:L,definition:a(me),definitionDestinationString:u,definitionLabelString:u,definitionTitleString:u,emphasis:a(ge),hardBreakEscape:a(Ne),hardBreakTrailing:a(Ne),htmlFlow:a(Re,u),htmlFlowData:L,htmlText:a(Re,u),htmlTextData:L,image:a(et),label:u,link:a(tt),listItem:a($e),listItemValue:h,listOrdered:a(Oe,d),listUnordered:a(Oe),paragraph:a(Ae),reference:B,referenceString:u,resourceDestinationString:u,resourceTitleString:u,setextHeading:a(we),strong:a(Ue),thematicBreak:a(Ye)},exit:{atxHeading:o(),atxHeadingSequence:R,autolink:o(),autolinkEmail:ve,autolinkProtocol:be,blockQuote:o(),characterEscapeValue:j,characterReferenceMarkerHexadecimal:oe,characterReferenceMarkerNumeric:oe,characterReferenceValue:ie,characterReference:de,codeFenced:o(_),codeFencedFence:v,codeFencedFenceInfo:m,codeFencedFenceMeta:y,codeFlowValue:j,codeIndented:o(S),codeText:o(W),codeTextData:j,data:j,definition:o(),definitionDestinationString:T,definitionLabelString:E,definitionTitleString:C,emphasis:o(),hardBreakEscape:o(q),hardBreakTrailing:o(q),htmlFlow:o(N),htmlFlowData:j,htmlText:o(U),htmlTextData:j,image:o(J),label:H,labelText:te,lineEnding:V,link:o(G),listItem:o(),listOrdered:o(),listUnordered:o(),paragraph:o(),referenceString:ne,resourceDestinationString:M,resourceTitleString:K,resource:X,setextHeading:o(F),setextHeadingLineSequence:k,setextHeadingText:$,strong:o(),thematicBreak:o()}};p1e(t,(e||{}).mdastExtensions||[]);const n={};return r;function r(Me){let ze={type:"root",children:[]};const st={stack:[ze],tokenStack:[],config:t,enter:l,exit:s,buffer:u,resume:c,data:n},Ot=[];let Nt=-1;for(;++Nt<Me.length;)if(Me[Nt][1].type==="listOrdered"||Me[Nt][1].type==="listUnordered")if(Me[Nt][0]==="enter")Ot.push(Nt);else{const gt=Ot.pop();Nt=i(Me,gt,Nt)}for(Nt=-1;++Nt<Me.length;){const gt=t[Me[Nt][0]];h1e.call(gt,Me[Nt][1].type)&&gt[Me[Nt][1].type].call(Object.assign({sliceSerialize:Me[Nt][2].sliceSerialize},st),Me[Nt][1])}if(st.tokenStack.length>0){const gt=st.tokenStack[st.tokenStack.length-1];(gt[1]||HK).call(st,void 0,gt[0])}for(ze.position={start:pv(Me.length>0?Me[0][1].start:{line:1,column:1,offset:0}),end:pv(Me.length>0?Me[Me.length-2][1].end:{line:1,column:1,offset:0})},Nt=-1;++Nt<t.transforms.length;)ze=t.transforms[Nt](ze)||ze;return ze}function i(Me,ze,st){let Ot=ze-1,Nt=-1,gt=!1,qt,zt,an,rn;for(;++Ot<=st;){const Fe=Me[Ot];switch(Fe[1].type){case"listUnordered":case"listOrdered":case"blockQuote":{Fe[0]==="enter"?Nt++:Nt--,rn=void 0;break}case"lineEndingBlank":{Fe[0]==="enter"&&(qt&&!rn&&!Nt&&!an&&(an=Ot),rn=void 0);break}case"linePrefix":case"listItemValue":case"listItemMarker":case"listItemPrefix":case"listItemPrefixWhitespace":break;default:rn=void 0}if(!Nt&&Fe[0]==="enter"&&Fe[1].type==="listItemPrefix"||Nt===-1&&Fe[0]==="exit"&&(Fe[1].type==="listUnordered"||Fe[1].type==="listOrdered")){if(qt){let ht=Ot;for(zt=void 0;ht--;){const Tt=Me[ht];if(Tt[1].type==="lineEnding"||Tt[1].type==="lineEndingBlank"){if(Tt[0]==="exit")continue;zt&&(Me[zt][1].type="lineEndingBlank",gt=!0),Tt[1].type="lineEnding",zt=ht}else if(!(Tt[1].type==="linePrefix"||Tt[1].type==="blockQuotePrefix"||Tt[1].type==="blockQuotePrefixWhitespace"||Tt[1].type==="blockQuoteMarker"||Tt[1].type==="listItemIndent"))break}an&&(!zt||an<zt)&&(qt._spread=!0),qt.end=Object.assign({},zt?Me[zt][1].start:Fe[1].end),Me.splice(zt||Ot,0,["exit",qt,Fe[2]]),Ot++,st++}if(Fe[1].type==="listItemPrefix"){const ht={type:"listItem",_spread:!1,start:Object.assign({},Fe[1].start),end:void 0};qt=ht,Me.splice(Ot,0,["enter",ht,Fe[2]]),Ot++,st++,an=void 0,rn=!0}}}return Me[ze][1]._spread=gt,st}function a(Me,ze){return st;function st(Ot){l.call(this,Me(Ot),Ot),ze&&ze.call(this,Ot)}}function u(){this.stack.push({type:"fragment",children:[]})}function l(Me,ze,st){this.stack[this.stack.length-1].children.push(Me),this.stack.push(Me),this.tokenStack.push([ze,st||void 0]),Me.position={start:pv(ze.start),end:void 0}}function o(Me){return ze;function ze(st){Me&&Me.call(this,st),s.call(this,st)}}function s(Me,ze){const st=this.stack.pop(),Ot=this.tokenStack.pop();if(Ot)Ot[0].type!==Me.type&&(ze?ze.call(this,Me,Ot[0]):(Ot[1]||HK).call(this,Me,Ot[0]));else throw new Error("Cannot close `"+Me.type+"` ("+G2({start:Me.start,end:Me.end})+"): it’s not open");st.position.end=pv(Me.end)}function c(){return sB(this.stack.pop())}function d(){this.data.expectingFirstListItemValue=!0}function h(Me){if(this.data.expectingFirstListItemValue){const ze=this.stack[this.stack.length-2];ze.start=Number.parseInt(this.sliceSerialize(Me),10),this.data.expectingFirstListItemValue=void 0}}function m(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.lang=Me}function y(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.meta=Me}function v(){this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}function _(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.value=Me.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),this.data.flowCodeInside=void 0}function S(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.value=Me.replace(/(\r?\n|\r)$/g,"")}function E(Me){const ze=this.resume(),st=this.stack[this.stack.length-1];st.label=ze,st.identifier=ap(this.sliceSerialize(Me)).toLowerCase()}function C(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.title=Me}function T(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.url=Me}function R(Me){const ze=this.stack[this.stack.length-1];if(!ze.depth){const st=this.sliceSerialize(Me).length;ze.depth=st}}function $(){this.data.setextHeadingSlurpLineEnding=!0}function k(Me){const ze=this.stack[this.stack.length-1];ze.depth=this.sliceSerialize(Me).codePointAt(0)===61?1:2}function F(){this.data.setextHeadingSlurpLineEnding=void 0}function L(Me){const st=this.stack[this.stack.length-1].children;let Ot=st[st.length-1];(!Ot||Ot.type!=="text")&&(Ot=Ze(),Ot.position={start:pv(Me.start),end:void 0},st.push(Ot)),this.stack.push(Ot)}function j(Me){const ze=this.stack.pop();ze.value+=this.sliceSerialize(Me),ze.position.end=pv(Me.end)}function V(Me){const ze=this.stack[this.stack.length-1];if(this.data.atHardBreak){const st=ze.children[ze.children.length-1];st.position.end=pv(Me.end),this.data.atHardBreak=void 0;return}!this.data.setextHeadingSlurpLineEnding&&t.canContainEols.includes(ze.type)&&(L.call(this,Me),j.call(this,Me))}function q(){this.data.atHardBreak=!0}function N(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.value=Me}function U(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.value=Me}function W(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.value=Me}function G(){const Me=this.stack[this.stack.length-1];if(this.data.inReference){const ze=this.data.referenceType||"shortcut";Me.type+="Reference",Me.referenceType=ze,delete Me.url,delete Me.title}else delete Me.identifier,delete Me.label;this.data.referenceType=void 0}function J(){const Me=this.stack[this.stack.length-1];if(this.data.inReference){const ze=this.data.referenceType||"shortcut";Me.type+="Reference",Me.referenceType=ze,delete Me.url,delete Me.title}else delete Me.identifier,delete Me.label;this.data.referenceType=void 0}function te(Me){const ze=this.sliceSerialize(Me),st=this.stack[this.stack.length-2];st.label=EYe(ze),st.identifier=ap(ze).toLowerCase()}function H(){const Me=this.stack[this.stack.length-1],ze=this.resume(),st=this.stack[this.stack.length-1];if(this.data.inReference=!0,st.type==="link"){const Ot=Me.children;st.children=Ot}else st.alt=ze}function M(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.url=Me}function K(){const Me=this.resume(),ze=this.stack[this.stack.length-1];ze.title=Me}function X(){this.data.inReference=void 0}function B(){this.data.referenceType="collapsed"}function ne(Me){const ze=this.resume(),st=this.stack[this.stack.length-1];st.label=ze,st.identifier=ap(this.sliceSerialize(Me)).toLowerCase(),this.data.referenceType="full"}function oe(Me){this.data.characterReferenceType=Me.type}function ie(Me){const ze=this.sliceSerialize(Me),st=this.data.characterReferenceType;let Ot;st?(Ot=r1e(ze,st==="characterReferenceMarkerNumeric"?10:16),this.data.characterReferenceType=void 0):Ot=cB(ze);const Nt=this.stack[this.stack.length-1];Nt.value+=Ot}function de(Me){const ze=this.stack.pop();ze.position.end=pv(Me.end)}function be(Me){j.call(this,Me);const ze=this.stack[this.stack.length-1];ze.url=this.sliceSerialize(Me)}function ve(Me){j.call(this,Me);const ze=this.stack[this.stack.length-1];ze.url="mailto:"+this.sliceSerialize(Me)}function pe(){return{type:"blockquote",children:[]}}function _e(){return{type:"code",lang:null,meta:null,value:""}}function se(){return{type:"inlineCode",value:""}}function me(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function ge(){return{type:"emphasis",children:[]}}function we(){return{type:"heading",depth:0,children:[]}}function Ne(){return{type:"break"}}function Re(){return{type:"html",value:""}}function et(){return{type:"image",title:null,url:"",alt:null}}function tt(){return{type:"link",title:null,url:"",children:[]}}function Oe(Me){return{type:"list",ordered:Me.type==="listOrdered",start:null,spread:Me._spread,children:[]}}function $e(Me){return{type:"listItem",spread:Me._spread,checked:null,children:[]}}function Ae(){return{type:"paragraph",children:[]}}function Ue(){return{type:"strong",children:[]}}function Ze(){return{type:"text",value:""}}function Ye(){return{type:"thematicBreak"}}}function pv(e){return{line:e.line,column:e.column,offset:e.offset}}function p1e(e,t){let n=-1;for(;++n<t.length;){const r=t[n];Array.isArray(r)?p1e(e,r):wYe(e,r)}}function wYe(e,t){let n;for(n in t)if(h1e.call(t,n))switch(n){case"canContainEols":{const r=t[n];r&&e[n].push(...r);break}case"transforms":{const r=t[n];r&&e[n].push(...r);break}case"enter":case"exit":{const r=t[n];r&&Object.assign(e[n],r);break}}}function HK(e,t){throw e?new Error("Cannot close `"+e.type+"` ("+G2({start:e.start,end:e.end})+"): a different token (`"+t.type+"`, "+G2({start:t.start,end:t.end})+") is open"):new Error("Cannot close document, a token (`"+t.type+"`, "+G2({start:t.start,end:t.end})+") is still open")}function RYe(e){const t=this;t.parser=n;function n(r){return $Ye(r,{...t.data("settings"),...e,extensions:t.data("micromarkExtensions")||[],mdastExtensions:t.data("fromMarkdownExtensions")||[]})}}function AYe(e,t){const n={type:"element",tagName:"blockquote",properties:{},children:e.wrap(e.all(t),!0)};return e.patch(t,n),e.applyData(t,n)}function TYe(e,t){const n={type:"element",tagName:"br",properties:{},children:[]};return e.patch(t,n),[e.applyData(t,n),{type:"text",value:`
`}]}function kYe(e,t){const n=t.value?t.value+`
`:"",r={};t.lang&&(r.className=["language-"+t.lang]);let i={type:"element",tagName:"code",properties:r,children:[{type:"text",value:n}]};return t.meta&&(i.data={meta:t.meta}),e.patch(t,i),i=e.applyData(t,i),i={type:"element",tagName:"pre",properties:{},children:[i]},e.patch(t,i),i}function PYe(e,t){const n={type:"element",tagName:"del",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function MYe(e,t){const n={type:"element",tagName:"em",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function FYe(e,t){const n=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",r=String(t.identifier).toUpperCase(),i=h4(r.toLowerCase()),a=e.footnoteOrder.indexOf(r);let u,l=e.footnoteCounts.get(r);l===void 0?(l=0,e.footnoteOrder.push(r),u=e.footnoteOrder.length):u=a+1,l+=1,e.footnoteCounts.set(r,l);const o={type:"element",tagName:"a",properties:{href:"#"+n+"fn-"+i,id:n+"fnref-"+i+(l>1?"-"+l:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(u)}]};e.patch(t,o);const s={type:"element",tagName:"sup",properties:{},children:[o]};return e.patch(t,s),e.applyData(t,s)}function NYe(e,t){const n={type:"element",tagName:"h"+t.depth,properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function IYe(e,t){if(e.options.allowDangerousHtml){const n={type:"raw",value:t.value};return e.patch(t,n),e.applyData(t,n)}}function m1e(e,t){const n=t.referenceType;let r="]";if(n==="collapsed"?r+="[]":n==="full"&&(r+="["+(t.label||t.identifier)+"]"),t.type==="imageReference")return[{type:"text",value:"!["+t.alt+r}];const i=e.all(t),a=i[0];a&&a.type==="text"?a.value="["+a.value:i.unshift({type:"text",value:"["});const u=i[i.length-1];return u&&u.type==="text"?u.value+=r:i.push({type:"text",value:r}),i}function LYe(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return m1e(e,t);const i={src:h4(r.url||""),alt:t.alt};r.title!==null&&r.title!==void 0&&(i.title=r.title);const a={type:"element",tagName:"img",properties:i,children:[]};return e.patch(t,a),e.applyData(t,a)}function BYe(e,t){const n={src:h4(t.url)};t.alt!==null&&t.alt!==void 0&&(n.alt=t.alt),t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"img",properties:n,children:[]};return e.patch(t,r),e.applyData(t,r)}function QYe(e,t){const n={type:"text",value:t.value.replace(/\r?\n|\r/g," ")};e.patch(t,n);const r={type:"element",tagName:"code",properties:{},children:[n]};return e.patch(t,r),e.applyData(t,r)}function zYe(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return m1e(e,t);const i={href:h4(r.url||"")};r.title!==null&&r.title!==void 0&&(i.title=r.title);const a={type:"element",tagName:"a",properties:i,children:e.all(t)};return e.patch(t,a),e.applyData(t,a)}function qYe(e,t){const n={href:h4(t.url)};t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"a",properties:n,children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function VYe(e,t,n){const r=e.all(t),i=n?UYe(n):g1e(t),a={},u=[];if(typeof t.checked=="boolean"){const c=r[0];let d;c&&c.type==="element"&&c.tagName==="p"?d=c:(d={type:"element",tagName:"p",properties:{},children:[]},r.unshift(d)),d.children.length>0&&d.children.unshift({type:"text",value:" "}),d.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:t.checked,disabled:!0},children:[]}),a.className=["task-list-item"]}let l=-1;for(;++l<r.length;){const c=r[l];(i||l!==0||c.type!=="element"||c.tagName!=="p")&&u.push({type:"text",value:`
`}),c.type==="element"&&c.tagName==="p"&&!i?u.push(...c.children):u.push(c)}const o=r[r.length-1];o&&(i||o.type!=="element"||o.tagName!=="p")&&u.push({type:"text",value:`
`});const s={type:"element",tagName:"li",properties:a,children:u};return e.patch(t,s),e.applyData(t,s)}function UYe(e){let t=!1;if(e.type==="list"){t=e.spread||!1;const n=e.children;let r=-1;for(;!t&&++r<n.length;)t=g1e(n[r])}return t}function g1e(e){const t=e.spread;return t??e.children.length>1}function jYe(e,t){const n={},r=e.all(t);let i=-1;for(typeof t.start=="number"&&t.start!==1&&(n.start=t.start);++i<r.length;){const u=r[i];if(u.type==="element"&&u.tagName==="li"&&u.properties&&Array.isArray(u.properties.className)&&u.properties.className.includes("task-list-item")){n.className=["contains-task-list"];break}}const a={type:"element",tagName:t.ordered?"ol":"ul",properties:n,children:e.wrap(r,!0)};return e.patch(t,a),e.applyData(t,a)}function ZYe(e,t){const n={type:"element",tagName:"p",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function HYe(e,t){const n={type:"root",children:e.wrap(e.all(t))};return e.patch(t,n),e.applyData(t,n)}function XYe(e,t){const n={type:"element",tagName:"strong",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function YYe(e,t){const n=e.all(t),r=n.shift(),i=[];if(r){const u={type:"element",tagName:"thead",properties:{},children:e.wrap([r],!0)};e.patch(t.children[0],u),i.push(u)}if(n.length>0){const u={type:"element",tagName:"tbody",properties:{},children:e.wrap(n,!0)},l=aB(t.children[1]),o=Yye(t.children[t.children.length-1]);l&&o&&(u.position={start:l,end:o}),i.push(u)}const a={type:"element",tagName:"table",properties:{},children:e.wrap(i,!0)};return e.patch(t,a),e.applyData(t,a)}function GYe(e,t,n){const r=n?n.children:void 0,a=(r?r.indexOf(t):1)===0?"th":"td",u=n&&n.type==="table"?n.align:void 0,l=u?u.length:t.children.length;let o=-1;const s=[];for(;++o<l;){const d=t.children[o],h={},m=u?u[o]:void 0;m&&(h.align=m);let y={type:"element",tagName:a,properties:h,children:[]};d&&(y.children=e.all(d),e.patch(d,y),y=e.applyData(d,y)),s.push(y)}const c={type:"element",tagName:"tr",properties:{},children:e.wrap(s,!0)};return e.patch(t,c),e.applyData(t,c)}function KYe(e,t){const n={type:"element",tagName:"td",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}const XK=9,YK=32;function WYe(e){const t=String(e),n=/\r?\n|\r/g;let r=n.exec(t),i=0;const a=[];for(;r;)a.push(GK(t.slice(i,r.index),i>0,!0),r[0]),i=r.index+r[0].length,r=n.exec(t);return a.push(GK(t.slice(i),i>0,!1)),a.join("")}function GK(e,t,n){let r=0,i=e.length;if(t){let a=e.codePointAt(r);for(;a===XK||a===YK;)r++,a=e.codePointAt(r)}if(n){let a=e.codePointAt(i-1);for(;a===XK||a===YK;)i--,a=e.codePointAt(i-1)}return i>r?e.slice(r,i):""}function JYe(e,t){const n={type:"text",value:WYe(String(t.value))};return e.patch(t,n),e.applyData(t,n)}function eGe(e,t){const n={type:"element",tagName:"hr",properties:{},children:[]};return e.patch(t,n),e.applyData(t,n)}const tGe={blockquote:AYe,break:TYe,code:kYe,delete:PYe,emphasis:MYe,footnoteReference:FYe,heading:NYe,html:IYe,imageReference:LYe,image:BYe,inlineCode:QYe,linkReference:zYe,link:qYe,listItem:VYe,list:jYe,paragraph:ZYe,root:HYe,strong:XYe,table:YYe,tableCell:KYe,tableRow:GYe,text:JYe,thematicBreak:eGe,toml:CE,yaml:CE,definition:CE,footnoteDefinition:CE};function CE(){}const v1e=-1,o5=0,W2=1,rC=2,dB=3,hB=4,pB=5,mB=6,y1e=7,b1e=8,KK=typeof self=="object"?self:globalThis,nGe=(e,t)=>{const n=(i,a)=>(e.set(a,i),i),r=i=>{if(e.has(i))return e.get(i);const[a,u]=t[i];switch(a){case o5:case v1e:return n(u,i);case W2:{const l=n([],i);for(const o of u)l.push(r(o));return l}case rC:{const l=n({},i);for(const[o,s]of u)l[r(o)]=r(s);return l}case dB:return n(new Date(u),i);case hB:{const{source:l,flags:o}=u;return n(new RegExp(l,o),i)}case pB:{const l=n(new Map,i);for(const[o,s]of u)l.set(r(o),r(s));return l}case mB:{const l=n(new Set,i);for(const o of u)l.add(r(o));return l}case y1e:{const{name:l,message:o}=u;return n(new KK[l](o),i)}case b1e:return n(BigInt(u),i);case"BigInt":return n(Object(BigInt(u)),i);case"ArrayBuffer":return n(new Uint8Array(u).buffer,u);case"DataView":{const{buffer:l}=new Uint8Array(u);return n(new DataView(l),u)}}return n(new KK[a](u),i)};return r},WK=e=>nGe(new Map,e)(0),TO="",{toString:rGe}={},{keys:iGe}=Object,$2=e=>{const t=typeof e;if(t!=="object"||!e)return[o5,t];const n=rGe.call(e).slice(8,-1);switch(n){case"Array":return[W2,TO];case"Object":return[rC,TO];case"Date":return[dB,TO];case"RegExp":return[hB,TO];case"Map":return[pB,TO];case"Set":return[mB,TO];case"DataView":return[W2,n]}return n.includes("Array")?[W2,n]:n.includes("Error")?[y1e,n]:[rC,n]},wE=([e,t])=>e===o5&&(t==="function"||t==="symbol"),aGe=(e,t,n,r)=>{const i=(u,l)=>{const o=r.push(u)-1;return n.set(l,o),o},a=u=>{if(n.has(u))return n.get(u);let[l,o]=$2(u);switch(l){case o5:{let c=u;switch(o){case"bigint":l=b1e,c=u.toString();break;case"function":case"symbol":if(e)throw new TypeError("unable to serialize "+o);c=null;break;case"undefined":return i([v1e],u)}return i([l,c],u)}case W2:{if(o){let h=u;return o==="DataView"?h=new Uint8Array(u.buffer):o==="ArrayBuffer"&&(h=new Uint8Array(u)),i([o,[...h]],u)}const c=[],d=i([l,c],u);for(const h of u)c.push(a(h));return d}case rC:{if(o)switch(o){case"BigInt":return i([o,u.toString()],u);case"Boolean":case"Number":case"String":return i([o,u.valueOf()],u)}if(t&&"toJSON"in u)return a(u.toJSON());const c=[],d=i([l,c],u);for(const h of iGe(u))(e||!wE($2(u[h])))&&c.push([a(h),a(u[h])]);return d}case dB:return i([l,u.toISOString()],u);case hB:{const{source:c,flags:d}=u;return i([l,{source:c,flags:d}],u)}case pB:{const c=[],d=i([l,c],u);for(const[h,m]of u)(e||!(wE($2(h))||wE($2(m))))&&c.push([a(h),a(m)]);return d}case mB:{const c=[],d=i([l,c],u);for(const h of u)(e||!wE($2(h)))&&c.push(a(h));return d}}const{message:s}=u;return i([l,{name:o,message:s}],u)};return a},JK=(e,{json:t,lossy:n}={})=>{const r=[];return aGe(!(t||n),!!t,new Map,r)(e),r},iC=typeof structuredClone=="function"?(e,t)=>t&&("json"in t||"lossy"in t)?WK(JK(e,t)):structuredClone(e):(e,t)=>WK(JK(e,t));function uGe(e,t){const n=[{type:"text",value:"↩"}];return t>1&&n.push({type:"element",tagName:"sup",properties:{},children:[{type:"text",value:String(t)}]}),n}function lGe(e,t){return"Back to reference "+(e+1)+(t>1?"-"+t:"")}function oGe(e){const t=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",n=e.options.footnoteBackContent||uGe,r=e.options.footnoteBackLabel||lGe,i=e.options.footnoteLabel||"Footnotes",a=e.options.footnoteLabelTagName||"h2",u=e.options.footnoteLabelProperties||{className:["sr-only"]},l=[];let o=-1;for(;++o<e.footnoteOrder.length;){const s=e.footnoteById.get(e.footnoteOrder[o]);if(!s)continue;const c=e.all(s),d=String(s.identifier).toUpperCase(),h=h4(d.toLowerCase());let m=0;const y=[],v=e.footnoteCounts.get(d);for(;v!==void 0&&++m<=v;){y.length>0&&y.push({type:"text",value:" "});let E=typeof n=="string"?n:n(o,m);typeof E=="string"&&(E={type:"text",value:E}),y.push({type:"element",tagName:"a",properties:{href:"#"+t+"fnref-"+h+(m>1?"-"+m:""),dataFootnoteBackref:"",ariaLabel:typeof r=="string"?r:r(o,m),className:["data-footnote-backref"]},children:Array.isArray(E)?E:[E]})}const _=c[c.length-1];if(_&&_.type==="element"&&_.tagName==="p"){const E=_.children[_.children.length-1];E&&E.type==="text"?E.value+=" ":_.children.push({type:"text",value:" "}),_.children.push(...y)}else c.push(...y);const S={type:"element",tagName:"li",properties:{id:t+"fn-"+h},children:e.wrap(c,!0)};e.patch(s,S),l.push(S)}if(l.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:a,properties:{...iC(u),id:"footnote-label"},children:[{type:"text",value:i}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:e.wrap(l,!0)},{type:"text",value:`
`}]}}const s5=(function(e){if(e==null)return dGe;if(typeof e=="function")return c5(e);if(typeof e=="object")return Array.isArray(e)?sGe(e):cGe(e);if(typeof e=="string")return fGe(e);throw new Error("Expected function, string, or object as test")});function sGe(e){const t=[];let n=-1;for(;++n<e.length;)t[n]=s5(e[n]);return c5(r);function r(...i){let a=-1;for(;++a<t.length;)if(t[a].apply(this,i))return!0;return!1}}function cGe(e){const t=e;return c5(n);function n(r){const i=r;let a;for(a in e)if(i[a]!==t[a])return!1;return!0}}function fGe(e){return c5(t);function t(n){return n&&n.type===e}}function c5(e){return t;function t(n,r,i){return!!(hGe(n)&&e.call(this,n,typeof r=="number"?r:void 0,i||void 0))}}function dGe(){return!0}function hGe(e){return e!==null&&typeof e=="object"&&"type"in e}const O1e=[],pGe=!0,dF=!1,mGe="skip";function x1e(e,t,n,r){let i;typeof t=="function"&&typeof n!="function"?(r=n,n=t):i=t;const a=s5(i),u=r?-1:1;l(e,void 0,[])();function l(o,s,c){const d=o&&typeof o=="object"?o:{};if(typeof d.type=="string"){const m=typeof d.tagName=="string"?d.tagName:typeof d.name=="string"?d.name:void 0;Object.defineProperty(h,"name",{value:"node ("+(o.type+(m?"<"+m+">":""))+")"})}return h;function h(){let m=O1e,y,v,_;if((!t||a(o,s,c[c.length-1]||void 0))&&(m=gGe(n(o,c)),m[0]===dF))return m;if("children"in o&&o.children){const S=o;if(S.children&&m[0]!==mGe)for(v=(r?S.children.length:-1)+u,_=c.concat(S);v>-1&&v<S.children.length;){const E=S.children[v];if(y=l(E,v,_)(),y[0]===dF)return y;v=typeof y[1]=="number"?y[1]:v+u}}return m}}}function gGe(e){return Array.isArray(e)?e:typeof e=="number"?[pGe,e]:e==null?O1e:[e]}function gB(e,t,n,r){let i,a,u;typeof t=="function"&&typeof n!="function"?(a=void 0,u=t,i=n):(a=t,u=n,i=r),x1e(e,a,l,i);function l(o,s){const c=s[s.length-1],d=c?c.children.indexOf(o):void 0;return u(o,d,c)}}const hF={}.hasOwnProperty,vGe={};function yGe(e,t){const n=t||vGe,r=new Map,i=new Map,a=new Map,u={...tGe,...n.handlers},l={all:s,applyData:OGe,definitionById:r,footnoteById:i,footnoteCounts:a,footnoteOrder:[],handlers:u,one:o,options:n,patch:bGe,wrap:SGe};return gB(e,function(c){if(c.type==="definition"||c.type==="footnoteDefinition"){const d=c.type==="definition"?r:i,h=String(c.identifier).toUpperCase();d.has(h)||d.set(h,c)}}),l;function o(c,d){const h=c.type,m=l.handlers[h];if(hF.call(l.handlers,h)&&m)return m(l,c,d);if(l.options.passThrough&&l.options.passThrough.includes(h)){if("children"in c){const{children:v,..._}=c,S=iC(_);return S.children=l.all(c),S}return iC(c)}return(l.options.unknownHandler||xGe)(l,c,d)}function s(c){const d=[];if("children"in c){const h=c.children;let m=-1;for(;++m<h.length;){const y=l.one(h[m],c);if(y){if(m&&h[m-1].type==="break"&&(!Array.isArray(y)&&y.type==="text"&&(y.value=eW(y.value)),!Array.isArray(y)&&y.type==="element")){const v=y.children[0];v&&v.type==="text"&&(v.value=eW(v.value))}Array.isArray(y)?d.push(...y):d.push(y)}}}return d}}function bGe(e,t){e.position&&(t.position=lHe(e))}function OGe(e,t){let n=t;if(e&&e.data){const r=e.data.hName,i=e.data.hChildren,a=e.data.hProperties;if(typeof r=="string")if(n.type==="element")n.tagName=r;else{const u="children"in n?n.children:[n];n={type:"element",tagName:r,properties:{},children:u}}n.type==="element"&&a&&Object.assign(n.properties,iC(a)),"children"in n&&n.children&&i!==null&&i!==void 0&&(n.children=i)}return n}function xGe(e,t){const n=t.data||{},r="value"in t&&!(hF.call(n,"hProperties")||hF.call(n,"hChildren"))?{type:"text",value:t.value}:{type:"element",tagName:"div",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function SGe(e,t){const n=[];let r=-1;for(t&&n.push({type:"text",value:`
`});++r<e.length;)r&&n.push({type:"text",value:`
`}),n.push(e[r]);return t&&e.length>0&&n.push({type:"text",value:`
`}),n}function eW(e){let t=0,n=e.charCodeAt(t);for(;n===9||n===32;)t++,n=e.charCodeAt(t);return e.slice(t)}function tW(e,t){const n=yGe(e,t),r=n.one(e,void 0),i=oGe(n),a=Array.isArray(r)?{type:"root",children:r}:r||{type:"root",children:[]};return i&&a.children.push({type:"text",value:`
`},i),a}function _Ge(e,t){return e&&"run"in e?async function(n,r){const i=tW(n,{file:r,...t});await e.run(i,r)}:function(n,r){return tW(n,{file:r,...e||t})}}function nW(e){if(e)throw e}var m7,rW;function EGe(){if(rW)return m7;rW=1;var e=Object.prototype.hasOwnProperty,t=Object.prototype.toString,n=Object.defineProperty,r=Object.getOwnPropertyDescriptor,i=function(s){return typeof Array.isArray=="function"?Array.isArray(s):t.call(s)==="[object Array]"},a=function(s){if(!s||t.call(s)!=="[object Object]")return!1;var c=e.call(s,"constructor"),d=s.constructor&&s.constructor.prototype&&e.call(s.constructor.prototype,"isPrototypeOf");if(s.constructor&&!c&&!d)return!1;var h;for(h in s);return typeof h>"u"||e.call(s,h)},u=function(s,c){n&&c.name==="__proto__"?n(s,c.name,{enumerable:!0,configurable:!0,value:c.newValue,writable:!0}):s[c.name]=c.newValue},l=function(s,c){if(c==="__proto__")if(e.call(s,c)){if(r)return r(s,c).value}else return;return s[c]};return m7=function o(){var s,c,d,h,m,y,v=arguments[0],_=1,S=arguments.length,E=!1;for(typeof v=="boolean"&&(E=v,v=arguments[1]||{},_=2),(v==null||typeof v!="object"&&typeof v!="function")&&(v={});_<S;++_)if(s=arguments[_],s!=null)for(c in s)d=l(v,c),h=l(s,c),v!==h&&(E&&h&&(a(h)||(m=i(h)))?(m?(m=!1,y=d&&i(d)?d:[]):y=d&&a(d)?d:{},u(v,{name:c,newValue:o(E,y,h)})):typeof h<"u"&&u(v,{name:c,newValue:h}));return v},m7}var DGe=EGe();const g7=sa(DGe);function pF(e){if(typeof e!="object"||e===null)return!1;const t=Object.getPrototypeOf(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)}function $Ge(){const e=[],t={run:n,use:r};return t;function n(...i){let a=-1;const u=i.pop();if(typeof u!="function")throw new TypeError("Expected function as last argument, not "+u);l(null,...i);function l(o,...s){const c=e[++a];let d=-1;if(o){u(o);return}for(;++d<i.length;)(s[d]===null||s[d]===void 0)&&(s[d]=i[d]);i=s,c?CGe(c,l)(...s):u(null,...s)}}function r(i){if(typeof i!="function")throw new TypeError("Expected `middelware` to be a function, not "+i);return e.push(i),t}}function CGe(e,t){let n;return r;function r(...u){const l=e.length>u.length;let o;l&&u.push(i);try{o=e.apply(this,u)}catch(s){const c=s;if(l&&n)throw c;return i(c)}l||(o&&o.then&&typeof o.then=="function"?o.then(a,i):o instanceof Error?i(o):a(o))}function i(u,...l){n||(n=!0,t(u,...l))}function a(u){i(null,u)}}const h0={basename:wGe,dirname:RGe,extname:AGe,join:TGe,sep:"/"};function wGe(e,t){if(t!==void 0&&typeof t!="string")throw new TypeError('"ext" argument must be a string');NS(e);let n=0,r=-1,i=e.length,a;if(t===void 0||t.length===0||t.length>e.length){for(;i--;)if(e.codePointAt(i)===47){if(a){n=i+1;break}}else r<0&&(a=!0,r=i+1);return r<0?"":e.slice(n,r)}if(t===e)return"";let u=-1,l=t.length-1;for(;i--;)if(e.codePointAt(i)===47){if(a){n=i+1;break}}else u<0&&(a=!0,u=i+1),l>-1&&(e.codePointAt(i)===t.codePointAt(l--)?l<0&&(r=i):(l=-1,r=u));return n===r?r=u:r<0&&(r=e.length),e.slice(n,r)}function RGe(e){if(NS(e),e.length===0)return".";let t=-1,n=e.length,r;for(;--n;)if(e.codePointAt(n)===47){if(r){t=n;break}}else r||(r=!0);return t<0?e.codePointAt(0)===47?"/":".":t===1&&e.codePointAt(0)===47?"//":e.slice(0,t)}function AGe(e){NS(e);let t=e.length,n=-1,r=0,i=-1,a=0,u;for(;t--;){const l=e.codePointAt(t);if(l===47){if(u){r=t+1;break}continue}n<0&&(u=!0,n=t+1),l===46?i<0?i=t:a!==1&&(a=1):i>-1&&(a=-1)}return i<0||n<0||a===0||a===1&&i===n-1&&i===r+1?"":e.slice(i,n)}function TGe(...e){let t=-1,n;for(;++t<e.length;)NS(e[t]),e[t]&&(n=n===void 0?e[t]:n+"/"+e[t]);return n===void 0?".":kGe(n)}function kGe(e){NS(e);const t=e.codePointAt(0)===47;let n=PGe(e,!t);return n.length===0&&!t&&(n="."),n.length>0&&e.codePointAt(e.length-1)===47&&(n+="/"),t?"/"+n:n}function PGe(e,t){let n="",r=0,i=-1,a=0,u=-1,l,o;for(;++u<=e.length;){if(u<e.length)l=e.codePointAt(u);else{if(l===47)break;l=47}if(l===47){if(!(i===u-1||a===1))if(i!==u-1&&a===2){if(n.length<2||r!==2||n.codePointAt(n.length-1)!==46||n.codePointAt(n.length-2)!==46){if(n.length>2){if(o=n.lastIndexOf("/"),o!==n.length-1){o<0?(n="",r=0):(n=n.slice(0,o),r=n.length-1-n.lastIndexOf("/")),i=u,a=0;continue}}else if(n.length>0){n="",r=0,i=u,a=0;continue}}t&&(n=n.length>0?n+"/..":"..",r=2)}else n.length>0?n+="/"+e.slice(i+1,u):n=e.slice(i+1,u),r=u-i-1;i=u,a=0}else l===46&&a>-1?a++:a=-1}return n}function NS(e){if(typeof e!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(e))}const MGe={cwd:FGe};function FGe(){return"/"}function mF(e){return!!(e!==null&&typeof e=="object"&&"href"in e&&e.href&&"protocol"in e&&e.protocol&&e.auth===void 0)}function NGe(e){if(typeof e=="string")e=new URL(e);else if(!mF(e)){const t=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+e+"`");throw t.code="ERR_INVALID_ARG_TYPE",t}if(e.protocol!=="file:"){const t=new TypeError("The URL must be of scheme file");throw t.code="ERR_INVALID_URL_SCHEME",t}return IGe(e)}function IGe(e){if(e.hostname!==""){const r=new TypeError('File URL host must be "localhost" or empty on darwin');throw r.code="ERR_INVALID_FILE_URL_HOST",r}const t=e.pathname;let n=-1;for(;++n<t.length;)if(t.codePointAt(n)===37&&t.codePointAt(n+1)===50){const r=t.codePointAt(n+2);if(r===70||r===102){const i=new TypeError("File URL path must not include encoded / characters");throw i.code="ERR_INVALID_FILE_URL_PATH",i}}return decodeURIComponent(t)}const v7=["history","path","basename","stem","extname","dirname"];class S1e{constructor(t){let n;t?mF(t)?n={path:t}:typeof t=="string"||LGe(t)?n={value:t}:n=t:n={},this.cwd="cwd"in n?"":MGe.cwd(),this.data={},this.history=[],this.messages=[],this.value,this.map,this.result,this.stored;let r=-1;for(;++r<v7.length;){const a=v7[r];a in n&&n[a]!==void 0&&n[a]!==null&&(this[a]=a==="history"?[...n[a]]:n[a])}let i;for(i in n)v7.includes(i)||(this[i]=n[i])}get basename(){return typeof this.path=="string"?h0.basename(this.path):void 0}set basename(t){b7(t,"basename"),y7(t,"basename"),this.path=h0.join(this.dirname||"",t)}get dirname(){return typeof this.path=="string"?h0.dirname(this.path):void 0}set dirname(t){iW(this.basename,"dirname"),this.path=h0.join(t||"",this.basename)}get extname(){return typeof this.path=="string"?h0.extname(this.path):void 0}set extname(t){if(y7(t,"extname"),iW(this.dirname,"extname"),t){if(t.codePointAt(0)!==46)throw new Error("`extname` must start with `.`");if(t.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=h0.join(this.dirname,this.stem+(t||""))}get path(){return this.history[this.history.length-1]}set path(t){mF(t)&&(t=NGe(t)),b7(t,"path"),this.path!==t&&this.history.push(t)}get stem(){return typeof this.path=="string"?h0.basename(this.path,this.extname):void 0}set stem(t){b7(t,"stem"),y7(t,"stem"),this.path=h0.join(this.dirname||"",t+(this.extname||""))}fail(t,n,r){const i=this.message(t,n,r);throw i.fatal=!0,i}info(t,n,r){const i=this.message(t,n,r);return i.fatal=void 0,i}message(t,n,r){const i=new Os(t,n,r);return this.path&&(i.name=this.path+":"+i.name,i.file=this.path),i.fatal=!1,this.messages.push(i),i}toString(t){return this.value===void 0?"":typeof this.value=="string"?this.value:new TextDecoder(t||void 0).decode(this.value)}}function y7(e,t){if(e&&e.includes(h0.sep))throw new Error("`"+t+"` cannot be a path: did not expect `"+h0.sep+"`")}function b7(e,t){if(!e)throw new Error("`"+t+"` cannot be empty")}function iW(e,t){if(!e)throw new Error("Setting `"+t+"` requires `path` to be set too")}function LGe(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const BGe=(function(e){const r=this.constructor.prototype,i=r[e],a=function(){return i.apply(a,arguments)};return Object.setPrototypeOf(a,r),a}),QGe={}.hasOwnProperty;class vB extends BGe{constructor(){super("copy"),this.Compiler=void 0,this.Parser=void 0,this.attachers=[],this.compiler=void 0,this.freezeIndex=-1,this.frozen=void 0,this.namespace={},this.parser=void 0,this.transformers=$Ge()}copy(){const t=new vB;let n=-1;for(;++n<this.attachers.length;){const r=this.attachers[n];t.use(...r)}return t.data(g7(!0,{},this.namespace)),t}data(t,n){return typeof t=="string"?arguments.length===2?(S7("data",this.frozen),this.namespace[t]=n,this):QGe.call(this.namespace,t)&&this.namespace[t]||void 0:t?(S7("data",this.frozen),this.namespace=t,this):this.namespace}freeze(){if(this.frozen)return this;const t=this;for(;++this.freezeIndex<this.attachers.length;){const[n,...r]=this.attachers[this.freezeIndex];if(r[0]===!1)continue;r[0]===!0&&(r[0]=void 0);const i=n.call(t,...r);typeof i=="function"&&this.transformers.use(i)}return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(t){this.freeze();const n=RE(t),r=this.parser||this.Parser;return O7("parse",r),r(String(n),n)}process(t,n){const r=this;return this.freeze(),O7("process",this.parser||this.Parser),x7("process",this.compiler||this.Compiler),n?i(void 0,n):new Promise(i);function i(a,u){const l=RE(t),o=r.parse(l);r.run(o,l,function(c,d,h){if(c||!d||!h)return s(c);const m=d,y=r.stringify(m,h);VGe(y)?h.value=y:h.result=y,s(c,h)});function s(c,d){c||!d?u(c):a?a(d):n(void 0,d)}}}processSync(t){let n=!1,r;return this.freeze(),O7("processSync",this.parser||this.Parser),x7("processSync",this.compiler||this.Compiler),this.process(t,i),uW("processSync","process",n),r;function i(a,u){n=!0,nW(a),r=u}}run(t,n,r){aW(t),this.freeze();const i=this.transformers;return!r&&typeof n=="function"&&(r=n,n=void 0),r?a(void 0,r):new Promise(a);function a(u,l){const o=RE(n);i.run(t,o,s);function s(c,d,h){const m=d||t;c?l(c):u?u(m):r(void 0,m,h)}}}runSync(t,n){let r=!1,i;return this.run(t,n,a),uW("runSync","run",r),i;function a(u,l){nW(u),i=l,r=!0}}stringify(t,n){this.freeze();const r=RE(n),i=this.compiler||this.Compiler;return x7("stringify",i),aW(t),i(t,r)}use(t,...n){const r=this.attachers,i=this.namespace;if(S7("use",this.frozen),t!=null)if(typeof t=="function")o(t,n);else if(typeof t=="object")Array.isArray(t)?l(t):u(t);else throw new TypeError("Expected usable value, not `"+t+"`");return this;function a(s){if(typeof s=="function")o(s,[]);else if(typeof s=="object")if(Array.isArray(s)){const[c,...d]=s;o(c,d)}else u(s);else throw new TypeError("Expected usable value, not `"+s+"`")}function u(s){if(!("plugins"in s)&&!("settings"in s))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither");l(s.plugins),s.settings&&(i.settings=g7(!0,i.settings,s.settings))}function l(s){let c=-1;if(s!=null)if(Array.isArray(s))for(;++c<s.length;){const d=s[c];a(d)}else throw new TypeError("Expected a list of plugins, not `"+s+"`")}function o(s,c){let d=-1,h=-1;for(;++d<r.length;)if(r[d][0]===s){h=d;break}if(h===-1)r.push([s,...c]);else if(c.length>0){let[m,...y]=c;const v=r[h][1];pF(v)&&pF(m)&&(m=g7(!0,v,m)),r[h]=[s,m,...y]}}}}const zGe=new vB().freeze();function O7(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `parser`")}function x7(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `compiler`")}function S7(e,t){if(t)throw new Error("Cannot call `"+e+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function aW(e){if(!pF(e)||typeof e.type!="string")throw new TypeError("Expected node, got `"+e+"`")}function uW(e,t,n){if(!n)throw new Error("`"+e+"` finished async. Use `"+t+"` instead")}function RE(e){return qGe(e)?e:new S1e(e)}function qGe(e){return!!(e&&typeof e=="object"&&"message"in e&&"messages"in e)}function VGe(e){return typeof e=="string"||UGe(e)}function UGe(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const jGe="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",lW=[],oW={allowDangerousHtml:!0},ZGe=/^(https?|ircs?|mailto|xmpp)$/i,HGe=[{from:"astPlugins",id:"remove-buggy-html-in-markdown-parser"},{from:"allowDangerousHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"allowNode",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowElement"},{from:"allowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowedElements"},{from:"disallowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"disallowedElements"},{from:"escapeHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"includeElementIndex",id:"#remove-includeelementindex"},{from:"includeNodeIndex",id:"change-includenodeindex-to-includeelementindex"},{from:"linkTarget",id:"remove-linktarget"},{from:"plugins",id:"change-plugins-to-remarkplugins",to:"remarkPlugins"},{from:"rawSourcePos",id:"#remove-rawsourcepos"},{from:"renderers",id:"change-renderers-to-components",to:"components"},{from:"source",id:"change-source-to-children",to:"children"},{from:"sourcePos",id:"#remove-sourcepos"},{from:"transformImageUri",id:"#add-urltransform",to:"urlTransform"},{from:"transformLinkUri",id:"#add-urltransform",to:"urlTransform"}];function elt(e){const t=XGe(e),n=YGe(e);return GGe(t.runSync(t.parse(n),n),e)}function XGe(e){const t=e.rehypePlugins||lW,n=e.remarkPlugins||lW,r=e.remarkRehypeOptions?{...e.remarkRehypeOptions,...oW}:oW;return zGe().use(RYe).use(n).use(_Ge,r).use(t)}function YGe(e){const t=e.children||"",n=new S1e;return typeof t=="string"&&(n.value=t),n}function GGe(e,t){const n=t.allowedElements,r=t.allowElement,i=t.components,a=t.disallowedElements,u=t.skipHtml,l=t.unwrapDisallowed,o=t.urlTransform||KGe;for(const c of HGe)Object.hasOwn(t,c.from)&&(""+c.from+(c.to?"use `"+c.to+"` instead":"remove it")+jGe+c.id,void 0);return t.className&&(e={type:"element",tagName:"div",properties:{className:t.className},children:e.type==="root"?e.children:[e]}),gB(e,s),dHe(e,{Fragment:Mr.Fragment,components:i,ignoreInvalidStyle:!0,jsx:Mr.jsx,jsxs:Mr.jsxs,passKeys:!0,passNode:!0});function s(c,d,h){if(c.type==="raw"&&h&&typeof d=="number")return u?h.children.splice(d,1):h.children[d]={type:"text",value:c.value},d;if(c.type==="element"){let m;for(m in d7)if(Object.hasOwn(d7,m)&&Object.hasOwn(c.properties,m)){const y=c.properties[m],v=d7[m];(v===null||v.includes(c.tagName))&&(c.properties[m]=o(String(y||""),m,c))}}if(c.type==="element"){let m=n?!n.includes(c.tagName):a?a.includes(c.tagName):!1;if(!m&&r&&typeof d=="number"&&(m=!r(c,d,h)),m&&h&&typeof d=="number")return l&&c.children?h.children.splice(d,1,...c.children):h.children.splice(d,1),d}}}function KGe(e){const t=e.indexOf(":"),n=e.indexOf("?"),r=e.indexOf("#"),i=e.indexOf("/");return t===-1||i!==-1&&t>i||n!==-1&&t>n||r!==-1&&t>r||ZGe.test(e.slice(0,t))?e:""}function WGe(e){if(typeof e!="string")throw new TypeError("Expected a string");return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}function JGe(e,t,n){const i=s5((n||{}).ignore||[]),a=eKe(t);let u=-1;for(;++u<a.length;)x1e(e,"text",l);function l(s,c){let d=-1,h;for(;++d<c.length;){const m=c[d],y=h?h.children:void 0;if(i(m,y?y.indexOf(m):void 0,h))return;h=m}if(h)return o(s,c)}function o(s,c){const d=c[c.length-1],h=a[u][0],m=a[u][1];let y=0;const _=d.children.indexOf(s);let S=!1,E=[];h.lastIndex=0;let C=h.exec(s.value);for(;C;){const T=C.index,R={index:C.index,input:C.input,stack:[...c,s]};let $=m(...C,R);if(typeof $=="string"&&($=$.length>0?{type:"text",value:$}:void 0),$===!1?h.lastIndex=T+1:(y!==T&&E.push({type:"text",value:s.value.slice(y,T)}),Array.isArray($)?E.push(...$):$&&E.push($),y=T+C[0].length,S=!0),!h.global)break;C=h.exec(s.value)}return S?(y<s.value.length&&E.push({type:"text",value:s.value.slice(y)}),d.children.splice(_,1,...E)):E=[s],_+E.length}}function eKe(e){const t=[];if(!Array.isArray(e))throw new TypeError("Expected find and replace tuple or list of tuples");const n=!e[0]||Array.isArray(e[0])?e:[e];let r=-1;for(;++r<n.length;){const i=n[r];t.push([tKe(i[0]),nKe(i[1])])}return t}function tKe(e){return typeof e=="string"?new RegExp(WGe(e),"g"):e}function nKe(e){return typeof e=="function"?e:function(){return e}}const _7="phrasing",E7=["autolink","link","image","label"];function rKe(){return{transforms:[cKe],enter:{literalAutolink:aKe,literalAutolinkEmail:D7,literalAutolinkHttp:D7,literalAutolinkWww:D7},exit:{literalAutolink:sKe,literalAutolinkEmail:oKe,literalAutolinkHttp:uKe,literalAutolinkWww:lKe}}}function iKe(){return{unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",inConstruct:_7,notInConstruct:E7},{character:".",before:"[Ww]",after:"[\\-.\\w]",inConstruct:_7,notInConstruct:E7},{character:":",before:"[ps]",after:"\\/",inConstruct:_7,notInConstruct:E7}]}}function aKe(e){this.enter({type:"link",title:null,url:"",children:[]},e)}function D7(e){this.config.enter.autolinkProtocol.call(this,e)}function uKe(e){this.config.exit.autolinkProtocol.call(this,e)}function lKe(e){this.config.exit.data.call(this,e);const t=this.stack[this.stack.length-1];t.type,t.url="http://"+this.sliceSerialize(e)}function oKe(e){this.config.exit.autolinkEmail.call(this,e)}function sKe(e){this.exit(e)}function cKe(e){JGe(e,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,fKe],[new RegExp("(?<=^|\\s|\\p{P}|\\p{S})([-.\\w+]+)@([-\\w]+(?:\\.[-\\w]+)+)","gu"),dKe]],{ignore:["link","linkReference"]})}function fKe(e,t,n,r,i){let a="";if(!_1e(i)||(/^w/i.test(t)&&(n=t+n,t="",a="http://"),!hKe(n)))return!1;const u=pKe(n+r);if(!u[0])return!1;const l={type:"link",title:null,url:a+t+u[0],children:[{type:"text",value:t+u[0]}]};return u[1]?[l,{type:"text",value:u[1]}]:l}function dKe(e,t,n,r){return!_1e(r,!0)||/[-\d_]$/.test(n)?!1:{type:"link",title:null,url:"mailto:"+t+"@"+n,children:[{type:"text",value:t+"@"+n}]}}function hKe(e){const t=e.split(".");return!(t.length<2||t[t.length-1]&&(/_/.test(t[t.length-1])||!/[a-zA-Z\d]/.test(t[t.length-1]))||t[t.length-2]&&(/_/.test(t[t.length-2])||!/[a-zA-Z\d]/.test(t[t.length-2])))}function pKe(e){const t=/[!"&'),.:;<>?\]}]+$/.exec(e);if(!t)return[e,void 0];e=e.slice(0,t.index);let n=t[0],r=n.indexOf(")");const i=R$(e,"(");let a=R$(e,")");for(;r!==-1&&i>a;)e+=n.slice(0,r+1),n=n.slice(r+1),r=n.indexOf(")"),a++;return[e,n]}function _1e(e,t){const n=e.input.charCodeAt(e.index-1);return(e.index===0||Ob(n)||u5(n))&&(!t||n!==47)}E1e.peek=_Ke;function mKe(){this.buffer()}function gKe(e){this.enter({type:"footnoteReference",identifier:"",label:""},e)}function vKe(){this.buffer()}function yKe(e){this.enter({type:"footnoteDefinition",identifier:"",label:"",children:[]},e)}function bKe(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=ap(this.sliceSerialize(e)).toLowerCase(),n.label=t}function OKe(e){this.exit(e)}function xKe(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=ap(this.sliceSerialize(e)).toLowerCase(),n.label=t}function SKe(e){this.exit(e)}function _Ke(){return"["}function E1e(e,t,n,r){const i=n.createTracker(r);let a=i.move("[^");const u=n.enter("footnoteReference"),l=n.enter("reference");return a+=i.move(n.safe(n.associationId(e),{after:"]",before:a})),l(),u(),a+=i.move("]"),a}function EKe(){return{enter:{gfmFootnoteCallString:mKe,gfmFootnoteCall:gKe,gfmFootnoteDefinitionLabelString:vKe,gfmFootnoteDefinition:yKe},exit:{gfmFootnoteCallString:bKe,gfmFootnoteCall:OKe,gfmFootnoteDefinitionLabelString:xKe,gfmFootnoteDefinition:SKe}}}function DKe(e){let t=!1;return e&&e.firstLineBlank&&(t=!0),{handlers:{footnoteDefinition:n,footnoteReference:E1e},unsafe:[{character:"[",inConstruct:["label","phrasing","reference"]}]};function n(r,i,a,u){const l=a.createTracker(u);let o=l.move("[^");const s=a.enter("footnoteDefinition"),c=a.enter("label");return o+=l.move(a.safe(a.associationId(r),{before:o,after:"]"})),c(),o+=l.move("]:"),r.children&&r.children.length>0&&(l.shift(4),o+=l.move((t?`
`:" ")+a.indentLines(a.containerFlow(r,l.current()),t?D1e:$Ke))),s(),o}}function $Ke(e,t,n){return t===0?e:D1e(e,t,n)}function D1e(e,t,n){return(n?"":"    ")+e}const CKe=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];$1e.peek=kKe;function wKe(){return{canContainEols:["delete"],enter:{strikethrough:AKe},exit:{strikethrough:TKe}}}function RKe(){return{unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:CKe}],handlers:{delete:$1e}}}function AKe(e){this.enter({type:"delete",children:[]},e)}function TKe(e){this.exit(e)}function $1e(e,t,n,r){const i=n.createTracker(r),a=n.enter("strikethrough");let u=i.move("~~");return u+=n.containerPhrasing(e,{...i.current(),before:u,after:"~"}),u+=i.move("~~"),a(),u}function kKe(){return"~"}function PKe(e){return e.length}function MKe(e,t){const n=t||{},r=(n.align||[]).concat(),i=n.stringLength||PKe,a=[],u=[],l=[],o=[];let s=0,c=-1;for(;++c<e.length;){const v=[],_=[];let S=-1;for(e[c].length>s&&(s=e[c].length);++S<e[c].length;){const E=FKe(e[c][S]);if(n.alignDelimiters!==!1){const C=i(E);_[S]=C,(o[S]===void 0||C>o[S])&&(o[S]=C)}v.push(E)}u[c]=v,l[c]=_}let d=-1;if(typeof r=="object"&&"length"in r)for(;++d<s;)a[d]=sW(r[d]);else{const v=sW(r);for(;++d<s;)a[d]=v}d=-1;const h=[],m=[];for(;++d<s;){const v=a[d];let _="",S="";v===99?(_=":",S=":"):v===108?_=":":v===114&&(S=":");let E=n.alignDelimiters===!1?1:Math.max(1,o[d]-_.length-S.length);const C=_+"-".repeat(E)+S;n.alignDelimiters!==!1&&(E=_.length+E+S.length,E>o[d]&&(o[d]=E),m[d]=E),h[d]=C}u.splice(1,0,h),l.splice(1,0,m),c=-1;const y=[];for(;++c<u.length;){const v=u[c],_=l[c];d=-1;const S=[];for(;++d<s;){const E=v[d]||"";let C="",T="";if(n.alignDelimiters!==!1){const R=o[d]-(_[d]||0),$=a[d];$===114?C=" ".repeat(R):$===99?R%2?(C=" ".repeat(R/2+.5),T=" ".repeat(R/2-.5)):(C=" ".repeat(R/2),T=C):T=" ".repeat(R)}n.delimiterStart!==!1&&!d&&S.push("|"),n.padding!==!1&&!(n.alignDelimiters===!1&&E==="")&&(n.delimiterStart!==!1||d)&&S.push(" "),n.alignDelimiters!==!1&&S.push(C),S.push(E),n.alignDelimiters!==!1&&S.push(T),n.padding!==!1&&S.push(" "),(n.delimiterEnd!==!1||d!==s-1)&&S.push("|")}y.push(n.delimiterEnd===!1?S.join("").replace(/ +$/,""):S.join(""))}return y.join(`
`)}function FKe(e){return e==null?"":String(e)}function sW(e){const t=typeof e=="string"?e.codePointAt(0):0;return t===67||t===99?99:t===76||t===108?108:t===82||t===114?114:0}function NKe(e,t,n,r){const i=n.enter("blockquote"),a=n.createTracker(r);a.move("> "),a.shift(2);const u=n.indentLines(n.containerFlow(e,a.current()),IKe);return i(),u}function IKe(e,t,n){return">"+(n?"":" ")+e}function LKe(e,t){return cW(e,t.inConstruct,!0)&&!cW(e,t.notInConstruct,!1)}function cW(e,t,n){if(typeof t=="string"&&(t=[t]),!t||t.length===0)return n;let r=-1;for(;++r<t.length;)if(e.includes(t[r]))return!0;return!1}function fW(e,t,n,r){let i=-1;for(;++i<n.unsafe.length;)if(n.unsafe[i].character===`
`&&LKe(n.stack,n.unsafe[i]))return/[ \t]/.test(r.before)?"":" ";return`\\
`}function BKe(e,t){const n=String(e);let r=n.indexOf(t),i=r,a=0,u=0;if(typeof t!="string")throw new TypeError("Expected substring");for(;r!==-1;)r===i?++a>u&&(u=a):a=1,i=r+t.length,r=n.indexOf(t,i);return u}function QKe(e,t){return!!(t.options.fences===!1&&e.value&&!e.lang&&/[^ \r\n]/.test(e.value)&&!/^[\t ]*(?:[\r\n]|$)|(?:^|[\r\n])[\t ]*$/.test(e.value))}function zKe(e){const t=e.options.fence||"`";if(t!=="`"&&t!=="~")throw new Error("Cannot serialize code with `"+t+"` for `options.fence`, expected `` ` `` or `~`");return t}function qKe(e,t,n,r){const i=zKe(n),a=e.value||"",u=i==="`"?"GraveAccent":"Tilde";if(QKe(e,n)){const d=n.enter("codeIndented"),h=n.indentLines(a,VKe);return d(),h}const l=n.createTracker(r),o=i.repeat(Math.max(BKe(a,i)+1,3)),s=n.enter("codeFenced");let c=l.move(o);if(e.lang){const d=n.enter(`codeFencedLang${u}`);c+=l.move(n.safe(e.lang,{before:c,after:" ",encode:["`"],...l.current()})),d()}if(e.lang&&e.meta){const d=n.enter(`codeFencedMeta${u}`);c+=l.move(" "),c+=l.move(n.safe(e.meta,{before:c,after:`
`,encode:["`"],...l.current()})),d()}return c+=l.move(`
`),a&&(c+=l.move(a+`
`)),c+=l.move(o),s(),c}function VKe(e,t,n){return(n?"":"    ")+e}function yB(e){const t=e.options.quote||'"';if(t!=='"'&&t!=="'")throw new Error("Cannot serialize title with `"+t+"` for `options.quote`, expected `\"`, or `'`");return t}function UKe(e,t,n,r){const i=yB(n),a=i==='"'?"Quote":"Apostrophe",u=n.enter("definition");let l=n.enter("label");const o=n.createTracker(r);let s=o.move("[");return s+=o.move(n.safe(n.associationId(e),{before:s,after:"]",...o.current()})),s+=o.move("]: "),l(),!e.url||/[\0- \u007F]/.test(e.url)?(l=n.enter("destinationLiteral"),s+=o.move("<"),s+=o.move(n.safe(e.url,{before:s,after:">",...o.current()})),s+=o.move(">")):(l=n.enter("destinationRaw"),s+=o.move(n.safe(e.url,{before:s,after:e.title?" ":`
`,...o.current()}))),l(),e.title&&(l=n.enter(`title${a}`),s+=o.move(" "+i),s+=o.move(n.safe(e.title,{before:s,after:i,...o.current()})),s+=o.move(i),l()),u(),s}function jKe(e){const t=e.options.emphasis||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize emphasis with `"+t+"` for `options.emphasis`, expected `*`, or `_`");return t}function Gx(e){return"&#x"+e.toString(16).toUpperCase()+";"}function aC(e,t,n){const r=z3(e),i=z3(t);return r===void 0?i===void 0?n==="_"?{inside:!0,outside:!0}:{inside:!1,outside:!1}:i===1?{inside:!0,outside:!0}:{inside:!1,outside:!0}:r===1?i===void 0?{inside:!1,outside:!1}:i===1?{inside:!0,outside:!0}:{inside:!1,outside:!1}:i===void 0?{inside:!1,outside:!1}:i===1?{inside:!0,outside:!1}:{inside:!1,outside:!1}}C1e.peek=ZKe;function C1e(e,t,n,r){const i=jKe(n),a=n.enter("emphasis"),u=n.createTracker(r),l=u.move(i);let o=u.move(n.containerPhrasing(e,{after:i,before:l,...u.current()}));const s=o.charCodeAt(0),c=aC(r.before.charCodeAt(r.before.length-1),s,i);c.inside&&(o=Gx(s)+o.slice(1));const d=o.charCodeAt(o.length-1),h=aC(r.after.charCodeAt(0),d,i);h.inside&&(o=o.slice(0,-1)+Gx(d));const m=u.move(i);return a(),n.attentionEncodeSurroundingInfo={after:h.outside,before:c.outside},l+o+m}function ZKe(e,t,n){return n.options.emphasis||"*"}function HKe(e,t){let n=!1;return gB(e,function(r){if("value"in r&&/\r?\n|\r/.test(r.value)||r.type==="break")return n=!0,dF}),!!((!e.depth||e.depth<3)&&sB(e)&&(t.options.setext||n))}function XKe(e,t,n,r){const i=Math.max(Math.min(6,e.depth||1),1),a=n.createTracker(r);if(HKe(e,n)){const c=n.enter("headingSetext"),d=n.enter("phrasing"),h=n.containerPhrasing(e,{...a.current(),before:`
`,after:`
`});return d(),c(),h+`
`+(i===1?"=":"-").repeat(h.length-(Math.max(h.lastIndexOf("\r"),h.lastIndexOf(`
`))+1))}const u="#".repeat(i),l=n.enter("headingAtx"),o=n.enter("phrasing");a.move(u+" ");let s=n.containerPhrasing(e,{before:"# ",after:`
`,...a.current()});return/^[\t ]/.test(s)&&(s=Gx(s.charCodeAt(0))+s.slice(1)),s=s?u+" "+s:u,n.options.closeAtx&&(s+=" "+u),o(),l(),s}w1e.peek=YKe;function w1e(e){return e.value||""}function YKe(){return"<"}R1e.peek=GKe;function R1e(e,t,n,r){const i=yB(n),a=i==='"'?"Quote":"Apostrophe",u=n.enter("image");let l=n.enter("label");const o=n.createTracker(r);let s=o.move("![");return s+=o.move(n.safe(e.alt,{before:s,after:"]",...o.current()})),s+=o.move("]("),l(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(l=n.enter("destinationLiteral"),s+=o.move("<"),s+=o.move(n.safe(e.url,{before:s,after:">",...o.current()})),s+=o.move(">")):(l=n.enter("destinationRaw"),s+=o.move(n.safe(e.url,{before:s,after:e.title?" ":")",...o.current()}))),l(),e.title&&(l=n.enter(`title${a}`),s+=o.move(" "+i),s+=o.move(n.safe(e.title,{before:s,after:i,...o.current()})),s+=o.move(i),l()),s+=o.move(")"),u(),s}function GKe(){return"!"}A1e.peek=KKe;function A1e(e,t,n,r){const i=e.referenceType,a=n.enter("imageReference");let u=n.enter("label");const l=n.createTracker(r);let o=l.move("![");const s=n.safe(e.alt,{before:o,after:"]",...l.current()});o+=l.move(s+"]["),u();const c=n.stack;n.stack=[],u=n.enter("reference");const d=n.safe(n.associationId(e),{before:o,after:"]",...l.current()});return u(),n.stack=c,a(),i==="full"||!s||s!==d?o+=l.move(d+"]"):i==="shortcut"?o=o.slice(0,-1):o+=l.move("]"),o}function KKe(){return"!"}T1e.peek=WKe;function T1e(e,t,n){let r=e.value||"",i="`",a=-1;for(;new RegExp("(^|[^`])"+i+"([^`]|$)").test(r);)i+="`";for(/[^ \r\n]/.test(r)&&(/^[ \r\n]/.test(r)&&/[ \r\n]$/.test(r)||/^`|`$/.test(r))&&(r=" "+r+" ");++a<n.unsafe.length;){const u=n.unsafe[a],l=n.compilePattern(u);let o;if(u.atBreak)for(;o=l.exec(r);){let s=o.index;r.charCodeAt(s)===10&&r.charCodeAt(s-1)===13&&s--,r=r.slice(0,s)+" "+r.slice(o.index+1)}}return i+r+i}function WKe(){return"`"}function k1e(e,t){const n=sB(e);return!!(!t.options.resourceLink&&e.url&&!e.title&&e.children&&e.children.length===1&&e.children[0].type==="text"&&(n===e.url||"mailto:"+n===e.url)&&/^[a-z][a-z+.-]+:/i.test(e.url)&&!/[\0- <>\u007F]/.test(e.url))}P1e.peek=JKe;function P1e(e,t,n,r){const i=yB(n),a=i==='"'?"Quote":"Apostrophe",u=n.createTracker(r);let l,o;if(k1e(e,n)){const c=n.stack;n.stack=[],l=n.enter("autolink");let d=u.move("<");return d+=u.move(n.containerPhrasing(e,{before:d,after:">",...u.current()})),d+=u.move(">"),l(),n.stack=c,d}l=n.enter("link"),o=n.enter("label");let s=u.move("[");return s+=u.move(n.containerPhrasing(e,{before:s,after:"](",...u.current()})),s+=u.move("]("),o(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(o=n.enter("destinationLiteral"),s+=u.move("<"),s+=u.move(n.safe(e.url,{before:s,after:">",...u.current()})),s+=u.move(">")):(o=n.enter("destinationRaw"),s+=u.move(n.safe(e.url,{before:s,after:e.title?" ":")",...u.current()}))),o(),e.title&&(o=n.enter(`title${a}`),s+=u.move(" "+i),s+=u.move(n.safe(e.title,{before:s,after:i,...u.current()})),s+=u.move(i),o()),s+=u.move(")"),l(),s}function JKe(e,t,n){return k1e(e,n)?"<":"["}M1e.peek=eWe;function M1e(e,t,n,r){const i=e.referenceType,a=n.enter("linkReference");let u=n.enter("label");const l=n.createTracker(r);let o=l.move("[");const s=n.containerPhrasing(e,{before:o,after:"]",...l.current()});o+=l.move(s+"]["),u();const c=n.stack;n.stack=[],u=n.enter("reference");const d=n.safe(n.associationId(e),{before:o,after:"]",...l.current()});return u(),n.stack=c,a(),i==="full"||!s||s!==d?o+=l.move(d+"]"):i==="shortcut"?o=o.slice(0,-1):o+=l.move("]"),o}function eWe(){return"["}function bB(e){const t=e.options.bullet||"*";if(t!=="*"&&t!=="+"&&t!=="-")throw new Error("Cannot serialize items with `"+t+"` for `options.bullet`, expected `*`, `+`, or `-`");return t}function tWe(e){const t=bB(e),n=e.options.bulletOther;if(!n)return t==="*"?"-":"*";if(n!=="*"&&n!=="+"&&n!=="-")throw new Error("Cannot serialize items with `"+n+"` for `options.bulletOther`, expected `*`, `+`, or `-`");if(n===t)throw new Error("Expected `bullet` (`"+t+"`) and `bulletOther` (`"+n+"`) to be different");return n}function nWe(e){const t=e.options.bulletOrdered||".";if(t!=="."&&t!==")")throw new Error("Cannot serialize items with `"+t+"` for `options.bulletOrdered`, expected `.` or `)`");return t}function F1e(e){const t=e.options.rule||"*";if(t!=="*"&&t!=="-"&&t!=="_")throw new Error("Cannot serialize rules with `"+t+"` for `options.rule`, expected `*`, `-`, or `_`");return t}function rWe(e,t,n,r){const i=n.enter("list"),a=n.bulletCurrent;let u=e.ordered?nWe(n):bB(n);const l=e.ordered?u==="."?")":".":tWe(n);let o=t&&n.bulletLastUsed?u===n.bulletLastUsed:!1;if(!e.ordered){const c=e.children?e.children[0]:void 0;if((u==="*"||u==="-")&&c&&(!c.children||!c.children[0])&&n.stack[n.stack.length-1]==="list"&&n.stack[n.stack.length-2]==="listItem"&&n.stack[n.stack.length-3]==="list"&&n.stack[n.stack.length-4]==="listItem"&&n.indexStack[n.indexStack.length-1]===0&&n.indexStack[n.indexStack.length-2]===0&&n.indexStack[n.indexStack.length-3]===0&&(o=!0),F1e(n)===u&&c){let d=-1;for(;++d<e.children.length;){const h=e.children[d];if(h&&h.type==="listItem"&&h.children&&h.children[0]&&h.children[0].type==="thematicBreak"){o=!0;break}}}}o&&(u=l),n.bulletCurrent=u;const s=n.containerFlow(e,r);return n.bulletLastUsed=u,n.bulletCurrent=a,i(),s}function iWe(e){const t=e.options.listItemIndent||"one";if(t!=="tab"&&t!=="one"&&t!=="mixed")throw new Error("Cannot serialize items with `"+t+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`");return t}function aWe(e,t,n,r){const i=iWe(n);let a=n.bulletCurrent||bB(n);t&&t.type==="list"&&t.ordered&&(a=(typeof t.start=="number"&&t.start>-1?t.start:1)+(n.options.incrementListMarker===!1?0:t.children.indexOf(e))+a);let u=a.length+1;(i==="tab"||i==="mixed"&&(t&&t.type==="list"&&t.spread||e.spread))&&(u=Math.ceil(u/4)*4);const l=n.createTracker(r);l.move(a+" ".repeat(u-a.length)),l.shift(u);const o=n.enter("listItem"),s=n.indentLines(n.containerFlow(e,l.current()),c);return o(),s;function c(d,h,m){return h?(m?"":" ".repeat(u))+d:(m?a:a+" ".repeat(u-a.length))+d}}function uWe(e,t,n,r){const i=n.enter("paragraph"),a=n.enter("phrasing"),u=n.containerPhrasing(e,r);return a(),i(),u}const lWe=s5(["break","delete","emphasis","footnote","footnoteReference","image","imageReference","inlineCode","inlineMath","link","linkReference","mdxJsxTextElement","mdxTextExpression","strong","text","textDirective"]);function oWe(e,t,n,r){return(e.children.some(function(u){return lWe(u)})?n.containerPhrasing:n.containerFlow).call(n,e,r)}function sWe(e){const t=e.options.strong||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize strong with `"+t+"` for `options.strong`, expected `*`, or `_`");return t}N1e.peek=cWe;function N1e(e,t,n,r){const i=sWe(n),a=n.enter("strong"),u=n.createTracker(r),l=u.move(i+i);let o=u.move(n.containerPhrasing(e,{after:i,before:l,...u.current()}));const s=o.charCodeAt(0),c=aC(r.before.charCodeAt(r.before.length-1),s,i);c.inside&&(o=Gx(s)+o.slice(1));const d=o.charCodeAt(o.length-1),h=aC(r.after.charCodeAt(0),d,i);h.inside&&(o=o.slice(0,-1)+Gx(d));const m=u.move(i+i);return a(),n.attentionEncodeSurroundingInfo={after:h.outside,before:c.outside},l+o+m}function cWe(e,t,n){return n.options.strong||"*"}function fWe(e,t,n,r){return n.safe(e.value,r)}function dWe(e){const t=e.options.ruleRepetition||3;if(t<3)throw new Error("Cannot serialize rules with repetition `"+t+"` for `options.ruleRepetition`, expected `3` or more");return t}function hWe(e,t,n){const r=(F1e(n)+(n.options.ruleSpaces?" ":"")).repeat(dWe(n));return n.options.ruleSpaces?r.slice(0,-1):r}const I1e={blockquote:NKe,break:fW,code:qKe,definition:UKe,emphasis:C1e,hardBreak:fW,heading:XKe,html:w1e,image:R1e,imageReference:A1e,inlineCode:T1e,link:P1e,linkReference:M1e,list:rWe,listItem:aWe,paragraph:uWe,root:oWe,strong:N1e,text:fWe,thematicBreak:hWe};function pWe(){return{enter:{table:mWe,tableData:dW,tableHeader:dW,tableRow:vWe},exit:{codeText:yWe,table:gWe,tableData:$7,tableHeader:$7,tableRow:$7}}}function mWe(e){const t=e._align;this.enter({type:"table",align:t.map(function(n){return n==="none"?null:n}),children:[]},e),this.data.inTable=!0}function gWe(e){this.exit(e),this.data.inTable=void 0}function vWe(e){this.enter({type:"tableRow",children:[]},e)}function $7(e){this.exit(e)}function dW(e){this.enter({type:"tableCell",children:[]},e)}function yWe(e){let t=this.resume();this.data.inTable&&(t=t.replace(/\\([\\|])/g,bWe));const n=this.stack[this.stack.length-1];n.type,n.value=t,this.exit(e)}function bWe(e,t){return t==="|"?t:e}function OWe(e){const t=e||{},n=t.tableCellPadding,r=t.tablePipeAlign,i=t.stringLength,a=n?" ":"|";return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:`
`,inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[	 :-]"},{character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{inlineCode:h,table:u,tableCell:o,tableRow:l}};function u(m,y,v,_){return s(c(m,v,_),m.align)}function l(m,y,v,_){const S=d(m,v,_),E=s([S]);return E.slice(0,E.indexOf(`
`))}function o(m,y,v,_){const S=v.enter("tableCell"),E=v.enter("phrasing"),C=v.containerPhrasing(m,{..._,before:a,after:a});return E(),S(),C}function s(m,y){return MKe(m,{align:y,alignDelimiters:r,padding:n,stringLength:i})}function c(m,y,v){const _=m.children;let S=-1;const E=[],C=y.enter("table");for(;++S<_.length;)E[S]=d(_[S],y,v);return C(),E}function d(m,y,v){const _=m.children;let S=-1;const E=[],C=y.enter("tableRow");for(;++S<_.length;)E[S]=o(_[S],m,y,v);return C(),E}function h(m,y,v){let _=I1e.inlineCode(m,y,v);return v.stack.includes("tableCell")&&(_=_.replace(/\|/g,"\\$&")),_}}function xWe(){return{exit:{taskListCheckValueChecked:hW,taskListCheckValueUnchecked:hW,paragraph:_We}}}function SWe(){return{unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:EWe}}}function hW(e){const t=this.stack[this.stack.length-2];t.type,t.checked=e.type==="taskListCheckValueChecked"}function _We(e){const t=this.stack[this.stack.length-2];if(t&&t.type==="listItem"&&typeof t.checked=="boolean"){const n=this.stack[this.stack.length-1];n.type;const r=n.children[0];if(r&&r.type==="text"){const i=t.children;let a=-1,u;for(;++a<i.length;){const l=i[a];if(l.type==="paragraph"){u=l;break}}u===n&&(r.value=r.value.slice(1),r.value.length===0?n.children.shift():n.position&&r.position&&typeof r.position.start.offset=="number"&&(r.position.start.column++,r.position.start.offset++,n.position.start=Object.assign({},r.position.start)))}}this.exit(e)}function EWe(e,t,n,r){const i=e.children[0],a=typeof e.checked=="boolean"&&i&&i.type==="paragraph",u="["+(e.checked?"x":" ")+"] ",l=n.createTracker(r);a&&l.move(u);let o=I1e.listItem(e,t,n,{...r,...l.current()});return a&&(o=o.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,s)),o;function s(c){return c+u}}function DWe(){return[rKe(),EKe(),wKe(),pWe(),xWe()]}function $We(e){return{extensions:[iKe(),DKe(e),RKe(),OWe(e),SWe()]}}const CWe={tokenize:PWe,partial:!0},L1e={tokenize:MWe,partial:!0},B1e={tokenize:FWe,partial:!0},Q1e={tokenize:NWe,partial:!0},wWe={tokenize:IWe,partial:!0},z1e={name:"wwwAutolink",tokenize:TWe,previous:V1e},q1e={name:"protocolAutolink",tokenize:kWe,previous:U1e},Sg={name:"emailAutolink",tokenize:AWe,previous:j1e},j0={};function RWe(){return{text:j0}}let E1=48;for(;E1<123;)j0[E1]=Sg,E1++,E1===58?E1=65:E1===91&&(E1=97);j0[43]=Sg;j0[45]=Sg;j0[46]=Sg;j0[95]=Sg;j0[72]=[Sg,q1e];j0[104]=[Sg,q1e];j0[87]=[Sg,z1e];j0[119]=[Sg,z1e];function AWe(e,t,n){const r=this;let i,a;return u;function u(d){return!gF(d)||!j1e.call(r,r.previous)||OB(r.events)?n(d):(e.enter("literalAutolink"),e.enter("literalAutolinkEmail"),l(d))}function l(d){return gF(d)?(e.consume(d),l):d===64?(e.consume(d),o):n(d)}function o(d){return d===46?e.check(wWe,c,s)(d):d===45||d===95||ms(d)?(a=!0,e.consume(d),o):c(d)}function s(d){return e.consume(d),i=!0,o}function c(d){return a&&i&&oc(r.previous)?(e.exit("literalAutolinkEmail"),e.exit("literalAutolink"),t(d)):n(d)}}function TWe(e,t,n){const r=this;return i;function i(u){return u!==87&&u!==119||!V1e.call(r,r.previous)||OB(r.events)?n(u):(e.enter("literalAutolink"),e.enter("literalAutolinkWww"),e.check(CWe,e.attempt(L1e,e.attempt(B1e,a),n),n)(u))}function a(u){return e.exit("literalAutolinkWww"),e.exit("literalAutolink"),t(u)}}function kWe(e,t,n){const r=this;let i="",a=!1;return u;function u(d){return(d===72||d===104)&&U1e.call(r,r.previous)&&!OB(r.events)?(e.enter("literalAutolink"),e.enter("literalAutolinkHttp"),i+=String.fromCodePoint(d),e.consume(d),l):n(d)}function l(d){if(oc(d)&&i.length<5)return i+=String.fromCodePoint(d),e.consume(d),l;if(d===58){const h=i.toLowerCase();if(h==="http"||h==="https")return e.consume(d),o}return n(d)}function o(d){return d===47?(e.consume(d),a?s:(a=!0,o)):n(d)}function s(d){return d===null||nC(d)||la(d)||Ob(d)||u5(d)?n(d):e.attempt(L1e,e.attempt(B1e,c),n)(d)}function c(d){return e.exit("literalAutolinkHttp"),e.exit("literalAutolink"),t(d)}}function PWe(e,t,n){let r=0;return i;function i(u){return(u===87||u===119)&&r<3?(r++,e.consume(u),i):u===46&&r===3?(e.consume(u),a):n(u)}function a(u){return u===null?n(u):t(u)}}function MWe(e,t,n){let r,i,a;return u;function u(s){return s===46||s===95?e.check(Q1e,o,l)(s):s===null||la(s)||Ob(s)||s!==45&&u5(s)?o(s):(a=!0,e.consume(s),u)}function l(s){return s===95?r=!0:(i=r,r=void 0),e.consume(s),u}function o(s){return i||r||!a?n(s):t(s)}}function FWe(e,t){let n=0,r=0;return i;function i(u){return u===40?(n++,e.consume(u),i):u===41&&r<n?a(u):u===33||u===34||u===38||u===39||u===41||u===42||u===44||u===46||u===58||u===59||u===60||u===63||u===93||u===95||u===126?e.check(Q1e,t,a)(u):u===null||la(u)||Ob(u)?t(u):(e.consume(u),i)}function a(u){return u===41&&r++,e.consume(u),i}}function NWe(e,t,n){return r;function r(l){return l===33||l===34||l===39||l===41||l===42||l===44||l===46||l===58||l===59||l===63||l===95||l===126?(e.consume(l),r):l===38?(e.consume(l),a):l===93?(e.consume(l),i):l===60||l===null||la(l)||Ob(l)?t(l):n(l)}function i(l){return l===null||l===40||l===91||la(l)||Ob(l)?t(l):r(l)}function a(l){return oc(l)?u(l):n(l)}function u(l){return l===59?(e.consume(l),r):oc(l)?(e.consume(l),u):n(l)}}function IWe(e,t,n){return r;function r(a){return e.consume(a),i}function i(a){return ms(a)?n(a):t(a)}}function V1e(e){return e===null||e===40||e===42||e===95||e===91||e===93||e===126||la(e)}function U1e(e){return!oc(e)}function j1e(e){return!(e===47||gF(e))}function gF(e){return e===43||e===45||e===46||e===95||ms(e)}function OB(e){let t=e.length,n=!1;for(;t--;){const r=e[t][1];if((r.type==="labelLink"||r.type==="labelImage")&&!r._balanced){n=!0;break}if(r._gfmAutolinkLiteralWalkedInto){n=!1;break}}return e.length>0&&!n&&(e[e.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),n}const LWe={tokenize:ZWe,partial:!0};function BWe(){return{document:{91:{name:"gfmFootnoteDefinition",tokenize:VWe,continuation:{tokenize:UWe},exit:jWe}},text:{91:{name:"gfmFootnoteCall",tokenize:qWe},93:{name:"gfmPotentialFootnoteCall",add:"after",tokenize:QWe,resolveTo:zWe}}}}function QWe(e,t,n){const r=this;let i=r.events.length;const a=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let u;for(;i--;){const o=r.events[i][1];if(o.type==="labelImage"){u=o;break}if(o.type==="gfmFootnoteCall"||o.type==="labelLink"||o.type==="label"||o.type==="image"||o.type==="link")break}return l;function l(o){if(!u||!u._balanced)return n(o);const s=ap(r.sliceSerialize({start:u.end,end:r.now()}));return s.codePointAt(0)!==94||!a.includes(s.slice(1))?n(o):(e.enter("gfmFootnoteCallLabelMarker"),e.consume(o),e.exit("gfmFootnoteCallLabelMarker"),t(o))}}function zWe(e,t){let n=e.length;for(;n--;)if(e[n][1].type==="labelImage"&&e[n][0]==="enter"){e[n][1];break}e[n+1][1].type="data",e[n+3][1].type="gfmFootnoteCallLabelMarker";const r={type:"gfmFootnoteCall",start:Object.assign({},e[n+3][1].start),end:Object.assign({},e[e.length-1][1].end)},i={type:"gfmFootnoteCallMarker",start:Object.assign({},e[n+3][1].end),end:Object.assign({},e[n+3][1].end)};i.end.column++,i.end.offset++,i.end._bufferIndex++;const a={type:"gfmFootnoteCallString",start:Object.assign({},i.end),end:Object.assign({},e[e.length-1][1].start)},u={type:"chunkString",contentType:"string",start:Object.assign({},a.start),end:Object.assign({},a.end)},l=[e[n+1],e[n+2],["enter",r,t],e[n+3],e[n+4],["enter",i,t],["exit",i,t],["enter",a,t],["enter",u,t],["exit",u,t],["exit",a,t],e[e.length-2],e[e.length-1],["exit",r,t]];return e.splice(n,e.length-n+1,...l),e}function qWe(e,t,n){const r=this,i=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let a=0,u;return l;function l(d){return e.enter("gfmFootnoteCall"),e.enter("gfmFootnoteCallLabelMarker"),e.consume(d),e.exit("gfmFootnoteCallLabelMarker"),o}function o(d){return d!==94?n(d):(e.enter("gfmFootnoteCallMarker"),e.consume(d),e.exit("gfmFootnoteCallMarker"),e.enter("gfmFootnoteCallString"),e.enter("chunkString").contentType="string",s)}function s(d){if(a>999||d===93&&!u||d===null||d===91||la(d))return n(d);if(d===93){e.exit("chunkString");const h=e.exit("gfmFootnoteCallString");return i.includes(ap(r.sliceSerialize(h)))?(e.enter("gfmFootnoteCallLabelMarker"),e.consume(d),e.exit("gfmFootnoteCallLabelMarker"),e.exit("gfmFootnoteCall"),t):n(d)}return la(d)||(u=!0),a++,e.consume(d),d===92?c:s}function c(d){return d===91||d===92||d===93?(e.consume(d),a++,s):s(d)}}function VWe(e,t,n){const r=this,i=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let a,u=0,l;return o;function o(y){return e.enter("gfmFootnoteDefinition")._container=!0,e.enter("gfmFootnoteDefinitionLabel"),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(y),e.exit("gfmFootnoteDefinitionLabelMarker"),s}function s(y){return y===94?(e.enter("gfmFootnoteDefinitionMarker"),e.consume(y),e.exit("gfmFootnoteDefinitionMarker"),e.enter("gfmFootnoteDefinitionLabelString"),e.enter("chunkString").contentType="string",c):n(y)}function c(y){if(u>999||y===93&&!l||y===null||y===91||la(y))return n(y);if(y===93){e.exit("chunkString");const v=e.exit("gfmFootnoteDefinitionLabelString");return a=ap(r.sliceSerialize(v)),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(y),e.exit("gfmFootnoteDefinitionLabelMarker"),e.exit("gfmFootnoteDefinitionLabel"),h}return la(y)||(l=!0),u++,e.consume(y),y===92?d:c}function d(y){return y===91||y===92||y===93?(e.consume(y),u++,c):c(y)}function h(y){return y===58?(e.enter("definitionMarker"),e.consume(y),e.exit("definitionMarker"),i.includes(a)||i.push(a),si(e,m,"gfmFootnoteDefinitionWhitespace")):n(y)}function m(y){return t(y)}}function UWe(e,t,n){return e.check(FS,t,e.attempt(LWe,t,n))}function jWe(e){e.exit("gfmFootnoteDefinition")}function ZWe(e,t,n){const r=this;return si(e,i,"gfmFootnoteDefinitionIndent",5);function i(a){const u=r.events[r.events.length-1];return u&&u[1].type==="gfmFootnoteDefinitionIndent"&&u[2].sliceSerialize(u[1],!0).length===4?t(a):n(a)}}function HWe(e){let n=(e||{}).singleTilde;const r={name:"strikethrough",tokenize:a,resolveAll:i};return n==null&&(n=!0),{text:{126:r},insideSpan:{null:[r]},attentionMarkers:{null:[126]}};function i(u,l){let o=-1;for(;++o<u.length;)if(u[o][0]==="enter"&&u[o][1].type==="strikethroughSequenceTemporary"&&u[o][1]._close){let s=o;for(;s--;)if(u[s][0]==="exit"&&u[s][1].type==="strikethroughSequenceTemporary"&&u[s][1]._open&&u[o][1].end.offset-u[o][1].start.offset===u[s][1].end.offset-u[s][1].start.offset){u[o][1].type="strikethroughSequence",u[s][1].type="strikethroughSequence";const c={type:"strikethrough",start:Object.assign({},u[s][1].start),end:Object.assign({},u[o][1].end)},d={type:"strikethroughText",start:Object.assign({},u[s][1].end),end:Object.assign({},u[o][1].start)},h=[["enter",c,l],["enter",u[s][1],l],["exit",u[s][1],l],["enter",d,l]],m=l.parser.constructs.insideSpan.null;m&&Zf(h,h.length,0,l5(m,u.slice(s+1,o),l)),Zf(h,h.length,0,[["exit",d,l],["enter",u[o][1],l],["exit",u[o][1],l],["exit",c,l]]),Zf(u,s-1,o-s+3,h),o=s+h.length-2;break}}for(o=-1;++o<u.length;)u[o][1].type==="strikethroughSequenceTemporary"&&(u[o][1].type="data");return u}function a(u,l,o){const s=this.previous,c=this.events;let d=0;return h;function h(y){return s===126&&c[c.length-1][1].type!=="characterEscape"?o(y):(u.enter("strikethroughSequenceTemporary"),m(y))}function m(y){const v=z3(s);if(y===126)return d>1?o(y):(u.consume(y),d++,m);if(d<2&&!n)return o(y);const _=u.exit("strikethroughSequenceTemporary"),S=z3(y);return _._open=!S||S===2&&!!v,_._close=!v||v===2&&!!S,l(y)}}}class XWe{constructor(){this.map=[]}add(t,n,r){YWe(this,t,n,r)}consume(t){if(this.map.sort(function(a,u){return a[0]-u[0]}),this.map.length===0)return;let n=this.map.length;const r=[];for(;n>0;)n-=1,r.push(t.slice(this.map[n][0]+this.map[n][1]),this.map[n][2]),t.length=this.map[n][0];r.push(t.slice()),t.length=0;let i=r.pop();for(;i;){for(const a of i)t.push(a);i=r.pop()}this.map.length=0}}function YWe(e,t,n,r){let i=0;if(!(n===0&&r.length===0)){for(;i<e.map.length;){if(e.map[i][0]===t){e.map[i][1]+=n,e.map[i][2].push(...r);return}i+=1}e.map.push([t,n,r])}}function GWe(e,t){let n=!1;const r=[];for(;t<e.length;){const i=e[t];if(n){if(i[0]==="enter")i[1].type==="tableContent"&&r.push(e[t+1][1].type==="tableDelimiterMarker"?"left":"none");else if(i[1].type==="tableContent"){if(e[t-1][1].type==="tableDelimiterMarker"){const a=r.length-1;r[a]=r[a]==="left"?"center":"right"}}else if(i[1].type==="tableDelimiterRow")break}else i[0]==="enter"&&i[1].type==="tableDelimiterRow"&&(n=!0);t+=1}return r}function KWe(){return{flow:{null:{name:"table",tokenize:WWe,resolveAll:JWe}}}}function WWe(e,t,n){const r=this;let i=0,a=0,u;return l;function l(j){let V=r.events.length-1;for(;V>-1;){const U=r.events[V][1].type;if(U==="lineEnding"||U==="linePrefix")V--;else break}const q=V>-1?r.events[V][1].type:null,N=q==="tableHead"||q==="tableRow"?$:o;return N===$&&r.parser.lazy[r.now().line]?n(j):N(j)}function o(j){return e.enter("tableHead"),e.enter("tableRow"),s(j)}function s(j){return j===124||(u=!0,a+=1),c(j)}function c(j){return j===null?n(j):Mn(j)?a>1?(a=0,r.interrupt=!0,e.exit("tableRow"),e.enter("lineEnding"),e.consume(j),e.exit("lineEnding"),m):n(j):zr(j)?si(e,c,"whitespace")(j):(a+=1,u&&(u=!1,i+=1),j===124?(e.enter("tableCellDivider"),e.consume(j),e.exit("tableCellDivider"),u=!0,c):(e.enter("data"),d(j)))}function d(j){return j===null||j===124||la(j)?(e.exit("data"),c(j)):(e.consume(j),j===92?h:d)}function h(j){return j===92||j===124?(e.consume(j),d):d(j)}function m(j){return r.interrupt=!1,r.parser.lazy[r.now().line]?n(j):(e.enter("tableDelimiterRow"),u=!1,zr(j)?si(e,y,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(j):y(j))}function y(j){return j===45||j===58?_(j):j===124?(u=!0,e.enter("tableCellDivider"),e.consume(j),e.exit("tableCellDivider"),v):R(j)}function v(j){return zr(j)?si(e,_,"whitespace")(j):_(j)}function _(j){return j===58?(a+=1,u=!0,e.enter("tableDelimiterMarker"),e.consume(j),e.exit("tableDelimiterMarker"),S):j===45?(a+=1,S(j)):j===null||Mn(j)?T(j):R(j)}function S(j){return j===45?(e.enter("tableDelimiterFiller"),E(j)):R(j)}function E(j){return j===45?(e.consume(j),E):j===58?(u=!0,e.exit("tableDelimiterFiller"),e.enter("tableDelimiterMarker"),e.consume(j),e.exit("tableDelimiterMarker"),C):(e.exit("tableDelimiterFiller"),C(j))}function C(j){return zr(j)?si(e,T,"whitespace")(j):T(j)}function T(j){return j===124?y(j):j===null||Mn(j)?!u||i!==a?R(j):(e.exit("tableDelimiterRow"),e.exit("tableHead"),t(j)):R(j)}function R(j){return n(j)}function $(j){return e.enter("tableRow"),k(j)}function k(j){return j===124?(e.enter("tableCellDivider"),e.consume(j),e.exit("tableCellDivider"),k):j===null||Mn(j)?(e.exit("tableRow"),t(j)):zr(j)?si(e,k,"whitespace")(j):(e.enter("data"),F(j))}function F(j){return j===null||j===124||la(j)?(e.exit("data"),k(j)):(e.consume(j),j===92?L:F)}function L(j){return j===92||j===124?(e.consume(j),F):F(j)}}function JWe(e,t){let n=-1,r=!0,i=0,a=[0,0,0,0],u=[0,0,0,0],l=!1,o=0,s,c,d;const h=new XWe;for(;++n<e.length;){const m=e[n],y=m[1];m[0]==="enter"?y.type==="tableHead"?(l=!1,o!==0&&(pW(h,t,o,s,c),c=void 0,o=0),s={type:"table",start:Object.assign({},y.start),end:Object.assign({},y.end)},h.add(n,0,[["enter",s,t]])):y.type==="tableRow"||y.type==="tableDelimiterRow"?(r=!0,d=void 0,a=[0,0,0,0],u=[0,n+1,0,0],l&&(l=!1,c={type:"tableBody",start:Object.assign({},y.start),end:Object.assign({},y.end)},h.add(n,0,[["enter",c,t]])),i=y.type==="tableDelimiterRow"?2:c?3:1):i&&(y.type==="data"||y.type==="tableDelimiterMarker"||y.type==="tableDelimiterFiller")?(r=!1,u[2]===0&&(a[1]!==0&&(u[0]=u[1],d=AE(h,t,a,i,void 0,d),a=[0,0,0,0]),u[2]=n)):y.type==="tableCellDivider"&&(r?r=!1:(a[1]!==0&&(u[0]=u[1],d=AE(h,t,a,i,void 0,d)),a=u,u=[a[1],n,0,0])):y.type==="tableHead"?(l=!0,o=n):y.type==="tableRow"||y.type==="tableDelimiterRow"?(o=n,a[1]!==0?(u[0]=u[1],d=AE(h,t,a,i,n,d)):u[1]!==0&&(d=AE(h,t,u,i,n,d)),i=0):i&&(y.type==="data"||y.type==="tableDelimiterMarker"||y.type==="tableDelimiterFiller")&&(u[3]=n)}for(o!==0&&pW(h,t,o,s,c),h.consume(t.events),n=-1;++n<t.events.length;){const m=t.events[n];m[0]==="enter"&&m[1].type==="table"&&(m[1]._align=GWe(t.events,n))}return e}function AE(e,t,n,r,i,a){const u=r===1?"tableHeader":r===2?"tableDelimiter":"tableData",l="tableContent";n[0]!==0&&(a.end=Object.assign({},zO(t.events,n[0])),e.add(n[0],0,[["exit",a,t]]));const o=zO(t.events,n[1]);if(a={type:u,start:Object.assign({},o),end:Object.assign({},o)},e.add(n[1],0,[["enter",a,t]]),n[2]!==0){const s=zO(t.events,n[2]),c=zO(t.events,n[3]),d={type:l,start:Object.assign({},s),end:Object.assign({},c)};if(e.add(n[2],0,[["enter",d,t]]),r!==2){const h=t.events[n[2]],m=t.events[n[3]];if(h[1].end=Object.assign({},m[1].end),h[1].type="chunkText",h[1].contentType="text",n[3]>n[2]+1){const y=n[2]+1,v=n[3]-n[2]-1;e.add(y,v,[])}}e.add(n[3]+1,0,[["exit",d,t]])}return i!==void 0&&(a.end=Object.assign({},zO(t.events,i)),e.add(i,0,[["exit",a,t]]),a=void 0),a}function pW(e,t,n,r,i){const a=[],u=zO(t.events,n);i&&(i.end=Object.assign({},u),a.push(["exit",i,t])),r.end=Object.assign({},u),a.push(["exit",r,t]),e.add(n+1,0,a)}function zO(e,t){const n=e[t],r=n[0]==="enter"?"start":"end";return n[1][r]}const eJe={name:"tasklistCheck",tokenize:nJe};function tJe(){return{text:{91:eJe}}}function nJe(e,t,n){const r=this;return i;function i(o){return r.previous!==null||!r._gfmTasklistFirstContentOfListItem?n(o):(e.enter("taskListCheck"),e.enter("taskListCheckMarker"),e.consume(o),e.exit("taskListCheckMarker"),a)}function a(o){return la(o)?(e.enter("taskListCheckValueUnchecked"),e.consume(o),e.exit("taskListCheckValueUnchecked"),u):o===88||o===120?(e.enter("taskListCheckValueChecked"),e.consume(o),e.exit("taskListCheckValueChecked"),u):n(o)}function u(o){return o===93?(e.enter("taskListCheckMarker"),e.consume(o),e.exit("taskListCheckMarker"),e.exit("taskListCheck"),l):n(o)}function l(o){return Mn(o)?t(o):zr(o)?e.check({tokenize:rJe},t,n)(o):n(o)}}function rJe(e,t,n){return si(e,r,"whitespace");function r(i){return i===null?n(i):t(i)}}function iJe(e){return n1e([RWe(),BWe(),HWe(e),KWe(),tJe()])}const aJe={};function tlt(e){const t=this,n=e||aJe,r=t.data(),i=r.micromarkExtensions||(r.micromarkExtensions=[]),a=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),u=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);i.push(iJe(n)),a.push(DWe()),u.push($We(n))}function uJe(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return P.useMemo(()=>r=>{t.forEach(i=>i(r))},t)}const f5=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";function p4(e){const t=Object.prototype.toString.call(e);return t==="[object Window]"||t==="[object global]"}function xB(e){return"nodeType"in e}function pf(e){var t,n;return e?p4(e)?e:xB(e)&&(t=(n=e.ownerDocument)==null?void 0:n.defaultView)!=null?t:window:window}function SB(e){const{Document:t}=pf(e);return e instanceof t}function IS(e){return p4(e)?!1:e instanceof pf(e).HTMLElement}function Z1e(e){return e instanceof pf(e).SVGElement}function m4(e){return e?p4(e)?e.document:xB(e)?SB(e)?e:IS(e)||Z1e(e)?e.ownerDocument:document:document:document}const N0=f5?P.useLayoutEffect:P.useEffect;function _B(e){const t=P.useRef(e);return N0(()=>{t.current=e}),P.useCallback(function(){for(var n=arguments.length,r=new Array(n),i=0;i<n;i++)r[i]=arguments[i];return t.current==null?void 0:t.current(...r)},[])}function lJe(){const e=P.useRef(null),t=P.useCallback((r,i)=>{e.current=setInterval(r,i)},[]),n=P.useCallback(()=>{e.current!==null&&(clearInterval(e.current),e.current=null)},[]);return[t,n]}function Kx(e,t){t===void 0&&(t=[e]);const n=P.useRef(e);return N0(()=>{n.current!==e&&(n.current=e)},t),n}function LS(e,t){const n=P.useRef();return P.useMemo(()=>{const r=e(n.current);return n.current=r,r},[...t])}function uC(e){const t=_B(e),n=P.useRef(null),r=P.useCallback(i=>{i!==n.current&&(t==null||t(i,n.current)),n.current=i},[]);return[n,r]}function vF(e){const t=P.useRef();return P.useEffect(()=>{t.current=e},[e]),t.current}let C7={};function BS(e,t){return P.useMemo(()=>{if(t)return t;const n=C7[e]==null?0:C7[e]+1;return C7[e]=n,e+"-"+n},[e,t])}function H1e(e){return function(t){for(var n=arguments.length,r=new Array(n>1?n-1:0),i=1;i<n;i++)r[i-1]=arguments[i];return r.reduce((a,u)=>{const l=Object.entries(u);for(const[o,s]of l){const c=a[o];c!=null&&(a[o]=c+e*s)}return a},{...t})}}const x3=H1e(1),Wx=H1e(-1);function oJe(e){return"clientX"in e&&"clientY"in e}function EB(e){if(!e)return!1;const{KeyboardEvent:t}=pf(e.target);return t&&e instanceof t}function sJe(e){if(!e)return!1;const{TouchEvent:t}=pf(e.target);return t&&e instanceof t}function yF(e){if(sJe(e)){if(e.touches&&e.touches.length){const{clientX:t,clientY:n}=e.touches[0];return{x:t,y:n}}else if(e.changedTouches&&e.changedTouches.length){const{clientX:t,clientY:n}=e.changedTouches[0];return{x:t,y:n}}}return oJe(e)?{x:e.clientX,y:e.clientY}:null}const lC=Object.freeze({Translate:{toString(e){if(!e)return;const{x:t,y:n}=e;return"translate3d("+(t?Math.round(t):0)+"px, "+(n?Math.round(n):0)+"px, 0)"}},Scale:{toString(e){if(!e)return;const{scaleX:t,scaleY:n}=e;return"scaleX("+t+") scaleY("+n+")"}},Transform:{toString(e){if(e)return[lC.Translate.toString(e),lC.Scale.toString(e)].join(" ")}},Transition:{toString(e){let{property:t,duration:n,easing:r}=e;return t+" "+n+"ms "+r}}}),mW="a,frame,iframe,input:not([type=hidden]):not(:disabled),select:not(:disabled),textarea:not(:disabled),button:not(:disabled),*[tabindex]";function cJe(e){return e.matches(mW)?e:e.querySelector(mW)}const fJe={display:"none"};function dJe(e){let{id:t,value:n}=e;return ye.createElement("div",{id:t,style:fJe},n)}function hJe(e){let{id:t,announcement:n,ariaLiveType:r="assertive"}=e;const i={position:"fixed",top:0,left:0,width:1,height:1,margin:-1,border:0,padding:0,overflow:"hidden",clip:"rect(0 0 0 0)",clipPath:"inset(100%)",whiteSpace:"nowrap"};return ye.createElement("div",{id:t,style:i,role:"status","aria-live":r,"aria-atomic":!0},n)}function pJe(){const[e,t]=P.useState("");return{announce:P.useCallback(r=>{r!=null&&t(r)},[]),announcement:e}}const X1e=P.createContext(null);function mJe(e){const t=P.useContext(X1e);P.useEffect(()=>{if(!t)throw new Error("useDndMonitor must be used within a children of <DndContext>");return t(e)},[e,t])}function gJe(){const[e]=P.useState(()=>new Set),t=P.useCallback(r=>(e.add(r),()=>e.delete(r)),[e]);return[P.useCallback(r=>{let{type:i,event:a}=r;e.forEach(u=>{var l;return(l=u[i])==null?void 0:l.call(u,a)})},[e]),t]}const vJe={draggable:`
    To pick up a draggable item, press the space bar.
    While dragging, use the arrow keys to move the item.
    Press space again to drop the item in its new position, or press escape to cancel.
  `},yJe={onDragStart(e){let{active:t}=e;return"Picked up draggable item "+t.id+"."},onDragOver(e){let{active:t,over:n}=e;return n?"Draggable item "+t.id+" was moved over droppable area "+n.id+".":"Draggable item "+t.id+" is no longer over a droppable area."},onDragEnd(e){let{active:t,over:n}=e;return n?"Draggable item "+t.id+" was dropped over droppable area "+n.id:"Draggable item "+t.id+" was dropped."},onDragCancel(e){let{active:t}=e;return"Dragging was cancelled. Draggable item "+t.id+" was dropped."}};function bJe(e){let{announcements:t=yJe,container:n,hiddenTextDescribedById:r,screenReaderInstructions:i=vJe}=e;const{announce:a,announcement:u}=pJe(),l=BS("DndLiveRegion"),[o,s]=P.useState(!1);if(P.useEffect(()=>{s(!0)},[]),mJe(P.useMemo(()=>({onDragStart(d){let{active:h}=d;a(t.onDragStart({active:h}))},onDragMove(d){let{active:h,over:m}=d;t.onDragMove&&a(t.onDragMove({active:h,over:m}))},onDragOver(d){let{active:h,over:m}=d;a(t.onDragOver({active:h,over:m}))},onDragEnd(d){let{active:h,over:m}=d;a(t.onDragEnd({active:h,over:m}))},onDragCancel(d){let{active:h,over:m}=d;a(t.onDragCancel({active:h,over:m}))}}),[a,t])),!o)return null;const c=ye.createElement(ye.Fragment,null,ye.createElement(dJe,{id:r,value:i.draggable}),ye.createElement(hJe,{id:l,announcement:u}));return n?Vf.createPortal(c,n):c}var $l;(function(e){e.DragStart="dragStart",e.DragMove="dragMove",e.DragEnd="dragEnd",e.DragCancel="dragCancel",e.DragOver="dragOver",e.RegisterDroppable="registerDroppable",e.SetDroppableDisabled="setDroppableDisabled",e.UnregisterDroppable="unregisterDroppable"})($l||($l={}));function oC(){}function nlt(e,t){return P.useMemo(()=>({sensor:e,options:t??{}}),[e,t])}function rlt(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return P.useMemo(()=>[...t].filter(r=>r!=null),[...t])}const cp=Object.freeze({x:0,y:0});function OJe(e,t){return Math.sqrt(Math.pow(e.x-t.x,2)+Math.pow(e.y-t.y,2))}function xJe(e,t){let{data:{value:n}}=e,{data:{value:r}}=t;return n-r}function SJe(e,t){let{data:{value:n}}=e,{data:{value:r}}=t;return r-n}function gW(e){let{left:t,top:n,height:r,width:i}=e;return[{x:t,y:n},{x:t+i,y:n},{x:t,y:n+r},{x:t+i,y:n+r}]}function Y1e(e,t){if(!e||e.length===0)return null;const[n]=e;return n[t]}const _Je=e=>{let{collisionRect:t,droppableRects:n,droppableContainers:r}=e;const i=gW(t),a=[];for(const u of r){const{id:l}=u,o=n.get(l);if(o){const s=gW(o),c=i.reduce((h,m,y)=>h+OJe(s[y],m),0),d=Number((c/4).toFixed(4));a.push({id:l,data:{droppableContainer:u,value:d}})}}return a.sort(xJe)};function EJe(e,t){const n=Math.max(t.top,e.top),r=Math.max(t.left,e.left),i=Math.min(t.left+t.width,e.left+e.width),a=Math.min(t.top+t.height,e.top+e.height),u=i-r,l=a-n;if(r<i&&n<a){const o=t.width*t.height,s=e.width*e.height,c=u*l,d=c/(o+s-c);return Number(d.toFixed(4))}return 0}const DJe=e=>{let{collisionRect:t,droppableRects:n,droppableContainers:r}=e;const i=[];for(const a of r){const{id:u}=a,l=n.get(u);if(l){const o=EJe(l,t);o>0&&i.push({id:u,data:{droppableContainer:a,value:o}})}}return i.sort(SJe)};function $Je(e,t,n){return{...e,scaleX:t&&n?t.width/n.width:1,scaleY:t&&n?t.height/n.height:1}}function G1e(e,t){return e&&t?{x:e.left-t.left,y:e.top-t.top}:cp}function CJe(e){return function(n){for(var r=arguments.length,i=new Array(r>1?r-1:0),a=1;a<r;a++)i[a-1]=arguments[a];return i.reduce((u,l)=>({...u,top:u.top+e*l.y,bottom:u.bottom+e*l.y,left:u.left+e*l.x,right:u.right+e*l.x}),{...n})}}const wJe=CJe(1);function RJe(e){if(e.startsWith("matrix3d(")){const t=e.slice(9,-1).split(/, /);return{x:+t[12],y:+t[13],scaleX:+t[0],scaleY:+t[5]}}else if(e.startsWith("matrix(")){const t=e.slice(7,-1).split(/, /);return{x:+t[4],y:+t[5],scaleX:+t[0],scaleY:+t[3]}}return null}function AJe(e,t,n){const r=RJe(t);if(!r)return e;const{scaleX:i,scaleY:a,x:u,y:l}=r,o=e.left-u-(1-i)*parseFloat(n),s=e.top-l-(1-a)*parseFloat(n.slice(n.indexOf(" ")+1)),c=i?e.width/i:e.width,d=a?e.height/a:e.height;return{width:c,height:d,top:s,right:o+c,bottom:s+d,left:o}}const TJe={ignoreTransform:!1};function g4(e,t){t===void 0&&(t=TJe);let n=e.getBoundingClientRect();if(t.ignoreTransform){const{transform:s,transformOrigin:c}=pf(e).getComputedStyle(e);s&&(n=AJe(n,s,c))}const{top:r,left:i,width:a,height:u,bottom:l,right:o}=n;return{top:r,left:i,width:a,height:u,bottom:l,right:o}}function vW(e){return g4(e,{ignoreTransform:!0})}function kJe(e){const t=e.innerWidth,n=e.innerHeight;return{top:0,left:0,right:t,bottom:n,width:t,height:n}}function PJe(e,t){return t===void 0&&(t=pf(e).getComputedStyle(e)),t.position==="fixed"}function MJe(e,t){t===void 0&&(t=pf(e).getComputedStyle(e));const n=/(auto|scroll|overlay)/;return["overflow","overflowX","overflowY"].some(i=>{const a=t[i];return typeof a=="string"?n.test(a):!1})}function d5(e,t){const n=[];function r(i){if(t!=null&&n.length>=t||!i)return n;if(SB(i)&&i.scrollingElement!=null&&!n.includes(i.scrollingElement))return n.push(i.scrollingElement),n;if(!IS(i)||Z1e(i)||n.includes(i))return n;const a=pf(e).getComputedStyle(i);return i!==e&&MJe(i,a)&&n.push(i),PJe(i,a)?n:r(i.parentNode)}return e?r(e):n}function K1e(e){const[t]=d5(e,1);return t??null}function w7(e){return!f5||!e?null:p4(e)?e:xB(e)?SB(e)||e===m4(e).scrollingElement?window:IS(e)?e:null:null}function W1e(e){return p4(e)?e.scrollX:e.scrollLeft}function J1e(e){return p4(e)?e.scrollY:e.scrollTop}function bF(e){return{x:W1e(e),y:J1e(e)}}var to;(function(e){e[e.Forward=1]="Forward",e[e.Backward=-1]="Backward"})(to||(to={}));function ebe(e){return!f5||!e?!1:e===document.scrollingElement}function tbe(e){const t={x:0,y:0},n=ebe(e)?{height:window.innerHeight,width:window.innerWidth}:{height:e.clientHeight,width:e.clientWidth},r={x:e.scrollWidth-n.width,y:e.scrollHeight-n.height},i=e.scrollTop<=t.y,a=e.scrollLeft<=t.x,u=e.scrollTop>=r.y,l=e.scrollLeft>=r.x;return{isTop:i,isLeft:a,isBottom:u,isRight:l,maxScroll:r,minScroll:t}}const FJe={x:.2,y:.2};function NJe(e,t,n,r,i){let{top:a,left:u,right:l,bottom:o}=n;r===void 0&&(r=10),i===void 0&&(i=FJe);const{isTop:s,isBottom:c,isLeft:d,isRight:h}=tbe(e),m={x:0,y:0},y={x:0,y:0},v={height:t.height*i.y,width:t.width*i.x};return!s&&a<=t.top+v.height?(m.y=to.Backward,y.y=r*Math.abs((t.top+v.height-a)/v.height)):!c&&o>=t.bottom-v.height&&(m.y=to.Forward,y.y=r*Math.abs((t.bottom-v.height-o)/v.height)),!h&&l>=t.right-v.width?(m.x=to.Forward,y.x=r*Math.abs((t.right-v.width-l)/v.width)):!d&&u<=t.left+v.width&&(m.x=to.Backward,y.x=r*Math.abs((t.left+v.width-u)/v.width)),{direction:m,speed:y}}function IJe(e){if(e===document.scrollingElement){const{innerWidth:a,innerHeight:u}=window;return{top:0,left:0,right:a,bottom:u,width:a,height:u}}const{top:t,left:n,right:r,bottom:i}=e.getBoundingClientRect();return{top:t,left:n,right:r,bottom:i,width:e.clientWidth,height:e.clientHeight}}function nbe(e){return e.reduce((t,n)=>x3(t,bF(n)),cp)}function LJe(e){return e.reduce((t,n)=>t+W1e(n),0)}function BJe(e){return e.reduce((t,n)=>t+J1e(n),0)}function QJe(e,t){if(t===void 0&&(t=g4),!e)return;const{top:n,left:r,bottom:i,right:a}=t(e);K1e(e)&&(i<=0||a<=0||n>=window.innerHeight||r>=window.innerWidth)&&e.scrollIntoView({block:"center",inline:"center"})}const zJe=[["x",["left","right"],LJe],["y",["top","bottom"],BJe]];class DB{constructor(t,n){this.rect=void 0,this.width=void 0,this.height=void 0,this.top=void 0,this.bottom=void 0,this.right=void 0,this.left=void 0;const r=d5(n),i=nbe(r);this.rect={...t},this.width=t.width,this.height=t.height;for(const[a,u,l]of zJe)for(const o of u)Object.defineProperty(this,o,{get:()=>{const s=l(r),c=i[a]-s;return this.rect[o]+c},enumerable:!0});Object.defineProperty(this,"rect",{enumerable:!1})}}class J2{constructor(t){this.target=void 0,this.listeners=[],this.removeAll=()=>{this.listeners.forEach(n=>{var r;return(r=this.target)==null?void 0:r.removeEventListener(...n)})},this.target=t}add(t,n,r){var i;(i=this.target)==null||i.addEventListener(t,n,r),this.listeners.push([t,n,r])}}function qJe(e){const{EventTarget:t}=pf(e);return e instanceof t?e:m4(e)}function R7(e,t){const n=Math.abs(e.x),r=Math.abs(e.y);return typeof t=="number"?Math.sqrt(n**2+r**2)>t:"x"in t&&"y"in t?n>t.x&&r>t.y:"x"in t?n>t.x:"y"in t?r>t.y:!1}var qd;(function(e){e.Click="click",e.DragStart="dragstart",e.Keydown="keydown",e.ContextMenu="contextmenu",e.Resize="resize",e.SelectionChange="selectionchange",e.VisibilityChange="visibilitychange"})(qd||(qd={}));function yW(e){e.preventDefault()}function VJe(e){e.stopPropagation()}var Jr;(function(e){e.Space="Space",e.Down="ArrowDown",e.Right="ArrowRight",e.Left="ArrowLeft",e.Up="ArrowUp",e.Esc="Escape",e.Enter="Enter",e.Tab="Tab"})(Jr||(Jr={}));const rbe={start:[Jr.Space,Jr.Enter],cancel:[Jr.Esc],end:[Jr.Space,Jr.Enter,Jr.Tab]},UJe=(e,t)=>{let{currentCoordinates:n}=t;switch(e.code){case Jr.Right:return{...n,x:n.x+25};case Jr.Left:return{...n,x:n.x-25};case Jr.Down:return{...n,y:n.y+25};case Jr.Up:return{...n,y:n.y-25}}};class ibe{constructor(t){this.props=void 0,this.autoScrollEnabled=!1,this.referenceCoordinates=void 0,this.listeners=void 0,this.windowListeners=void 0,this.props=t;const{event:{target:n}}=t;this.props=t,this.listeners=new J2(m4(n)),this.windowListeners=new J2(pf(n)),this.handleKeyDown=this.handleKeyDown.bind(this),this.handleCancel=this.handleCancel.bind(this),this.attach()}attach(){this.handleStart(),this.windowListeners.add(qd.Resize,this.handleCancel),this.windowListeners.add(qd.VisibilityChange,this.handleCancel),setTimeout(()=>this.listeners.add(qd.Keydown,this.handleKeyDown))}handleStart(){const{activeNode:t,onStart:n}=this.props,r=t.node.current;r&&QJe(r),n(cp)}handleKeyDown(t){if(EB(t)){const{active:n,context:r,options:i}=this.props,{keyboardCodes:a=rbe,coordinateGetter:u=UJe,scrollBehavior:l="smooth"}=i,{code:o}=t;if(a.end.includes(o)){this.handleEnd(t);return}if(a.cancel.includes(o)){this.handleCancel(t);return}const{collisionRect:s}=r.current,c=s?{x:s.left,y:s.top}:cp;this.referenceCoordinates||(this.referenceCoordinates=c);const d=u(t,{active:n,context:r.current,currentCoordinates:c});if(d){const h=Wx(d,c),m={x:0,y:0},{scrollableAncestors:y}=r.current;for(const v of y){const _=t.code,{isTop:S,isRight:E,isLeft:C,isBottom:T,maxScroll:R,minScroll:$}=tbe(v),k=IJe(v),F={x:Math.min(_===Jr.Right?k.right-k.width/2:k.right,Math.max(_===Jr.Right?k.left:k.left+k.width/2,d.x)),y:Math.min(_===Jr.Down?k.bottom-k.height/2:k.bottom,Math.max(_===Jr.Down?k.top:k.top+k.height/2,d.y))},L=_===Jr.Right&&!E||_===Jr.Left&&!C,j=_===Jr.Down&&!T||_===Jr.Up&&!S;if(L&&F.x!==d.x){const V=v.scrollLeft+h.x,q=_===Jr.Right&&V<=R.x||_===Jr.Left&&V>=$.x;if(q&&!h.y){v.scrollTo({left:V,behavior:l});return}q?m.x=v.scrollLeft-V:m.x=_===Jr.Right?v.scrollLeft-R.x:v.scrollLeft-$.x,m.x&&v.scrollBy({left:-m.x,behavior:l});break}else if(j&&F.y!==d.y){const V=v.scrollTop+h.y,q=_===Jr.Down&&V<=R.y||_===Jr.Up&&V>=$.y;if(q&&!h.x){v.scrollTo({top:V,behavior:l});return}q?m.y=v.scrollTop-V:m.y=_===Jr.Down?v.scrollTop-R.y:v.scrollTop-$.y,m.y&&v.scrollBy({top:-m.y,behavior:l});break}}this.handleMove(t,x3(Wx(d,this.referenceCoordinates),m))}}}handleMove(t,n){const{onMove:r}=this.props;t.preventDefault(),r(n)}handleEnd(t){const{onEnd:n}=this.props;t.preventDefault(),this.detach(),n()}handleCancel(t){const{onCancel:n}=this.props;t.preventDefault(),this.detach(),n()}detach(){this.listeners.removeAll(),this.windowListeners.removeAll()}}ibe.activators=[{eventName:"onKeyDown",handler:(e,t,n)=>{let{keyboardCodes:r=rbe,onActivation:i}=t,{active:a}=n;const{code:u}=e.nativeEvent;if(r.start.includes(u)){const l=a.activatorNode.current;return l&&e.target!==l?!1:(e.preventDefault(),i==null||i({event:e.nativeEvent}),!0)}return!1}}];function bW(e){return!!(e&&"distance"in e)}function OW(e){return!!(e&&"delay"in e)}class $B{constructor(t,n,r){var i;r===void 0&&(r=qJe(t.event.target)),this.props=void 0,this.events=void 0,this.autoScrollEnabled=!0,this.document=void 0,this.activated=!1,this.initialCoordinates=void 0,this.timeoutId=null,this.listeners=void 0,this.documentListeners=void 0,this.windowListeners=void 0,this.props=t,this.events=n;const{event:a}=t,{target:u}=a;this.props=t,this.events=n,this.document=m4(u),this.documentListeners=new J2(this.document),this.listeners=new J2(r),this.windowListeners=new J2(pf(u)),this.initialCoordinates=(i=yF(a))!=null?i:cp,this.handleStart=this.handleStart.bind(this),this.handleMove=this.handleMove.bind(this),this.handleEnd=this.handleEnd.bind(this),this.handleCancel=this.handleCancel.bind(this),this.handleKeydown=this.handleKeydown.bind(this),this.removeTextSelection=this.removeTextSelection.bind(this),this.attach()}attach(){const{events:t,props:{options:{activationConstraint:n,bypassActivationConstraint:r}}}=this;if(this.listeners.add(t.move.name,this.handleMove,{passive:!1}),this.listeners.add(t.end.name,this.handleEnd),t.cancel&&this.listeners.add(t.cancel.name,this.handleCancel),this.windowListeners.add(qd.Resize,this.handleCancel),this.windowListeners.add(qd.DragStart,yW),this.windowListeners.add(qd.VisibilityChange,this.handleCancel),this.windowListeners.add(qd.ContextMenu,yW),this.documentListeners.add(qd.Keydown,this.handleKeydown),n){if(r!=null&&r({event:this.props.event,activeNode:this.props.activeNode,options:this.props.options}))return this.handleStart();if(OW(n)){this.timeoutId=setTimeout(this.handleStart,n.delay),this.handlePending(n);return}if(bW(n)){this.handlePending(n);return}}this.handleStart()}detach(){this.listeners.removeAll(),this.windowListeners.removeAll(),setTimeout(this.documentListeners.removeAll,50),this.timeoutId!==null&&(clearTimeout(this.timeoutId),this.timeoutId=null)}handlePending(t,n){const{active:r,onPending:i}=this.props;i(r,t,this.initialCoordinates,n)}handleStart(){const{initialCoordinates:t}=this,{onStart:n}=this.props;t&&(this.activated=!0,this.documentListeners.add(qd.Click,VJe,{capture:!0}),this.removeTextSelection(),this.documentListeners.add(qd.SelectionChange,this.removeTextSelection),n(t))}handleMove(t){var n;const{activated:r,initialCoordinates:i,props:a}=this,{onMove:u,options:{activationConstraint:l}}=a;if(!i)return;const o=(n=yF(t))!=null?n:cp,s=Wx(i,o);if(!r&&l){if(bW(l)){if(l.tolerance!=null&&R7(s,l.tolerance))return this.handleCancel();if(R7(s,l.distance))return this.handleStart()}if(OW(l)&&R7(s,l.tolerance))return this.handleCancel();this.handlePending(l,s);return}t.cancelable&&t.preventDefault(),u(o)}handleEnd(){const{onAbort:t,onEnd:n}=this.props;this.detach(),this.activated||t(this.props.active),n()}handleCancel(){const{onAbort:t,onCancel:n}=this.props;this.detach(),this.activated||t(this.props.active),n()}handleKeydown(t){t.code===Jr.Esc&&this.handleCancel()}removeTextSelection(){var t;(t=this.document.getSelection())==null||t.removeAllRanges()}}const jJe={cancel:{name:"pointercancel"},move:{name:"pointermove"},end:{name:"pointerup"}};class abe extends $B{constructor(t){const{event:n}=t,r=m4(n.target);super(t,jJe,r)}}abe.activators=[{eventName:"onPointerDown",handler:(e,t)=>{let{nativeEvent:n}=e,{onActivation:r}=t;return!n.isPrimary||n.button!==0?!1:(r==null||r({event:n}),!0)}}];const ZJe={move:{name:"mousemove"},end:{name:"mouseup"}};var OF;(function(e){e[e.RightClick=2]="RightClick"})(OF||(OF={}));class HJe extends $B{constructor(t){super(t,ZJe,m4(t.event.target))}}HJe.activators=[{eventName:"onMouseDown",handler:(e,t)=>{let{nativeEvent:n}=e,{onActivation:r}=t;return n.button===OF.RightClick?!1:(r==null||r({event:n}),!0)}}];const A7={cancel:{name:"touchcancel"},move:{name:"touchmove"},end:{name:"touchend"}};class XJe extends $B{constructor(t){super(t,A7)}static setup(){return window.addEventListener(A7.move.name,t,{capture:!1,passive:!1}),function(){window.removeEventListener(A7.move.name,t)};function t(){}}}XJe.activators=[{eventName:"onTouchStart",handler:(e,t)=>{let{nativeEvent:n}=e,{onActivation:r}=t;const{touches:i}=n;return i.length>1?!1:(r==null||r({event:n}),!0)}}];var ex;(function(e){e[e.Pointer=0]="Pointer",e[e.DraggableRect=1]="DraggableRect"})(ex||(ex={}));var sC;(function(e){e[e.TreeOrder=0]="TreeOrder",e[e.ReversedTreeOrder=1]="ReversedTreeOrder"})(sC||(sC={}));function YJe(e){let{acceleration:t,activator:n=ex.Pointer,canScroll:r,draggingRect:i,enabled:a,interval:u=5,order:l=sC.TreeOrder,pointerCoordinates:o,scrollableAncestors:s,scrollableAncestorRects:c,delta:d,threshold:h}=e;const m=KJe({delta:d,disabled:!a}),[y,v]=lJe(),_=P.useRef({x:0,y:0}),S=P.useRef({x:0,y:0}),E=P.useMemo(()=>{switch(n){case ex.Pointer:return o?{top:o.y,bottom:o.y,left:o.x,right:o.x}:null;case ex.DraggableRect:return i}},[n,i,o]),C=P.useRef(null),T=P.useCallback(()=>{const $=C.current;if(!$)return;const k=_.current.x*S.current.x,F=_.current.y*S.current.y;$.scrollBy(k,F)},[]),R=P.useMemo(()=>l===sC.TreeOrder?[...s].reverse():s,[l,s]);P.useEffect(()=>{if(!a||!s.length||!E){v();return}for(const $ of R){if((r==null?void 0:r($))===!1)continue;const k=s.indexOf($),F=c[k];if(!F)continue;const{direction:L,speed:j}=NJe($,F,E,t,h);for(const V of["x","y"])m[V][L[V]]||(j[V]=0,L[V]=0);if(j.x>0||j.y>0){v(),C.current=$,y(T,u),_.current=j,S.current=L;return}}_.current={x:0,y:0},S.current={x:0,y:0},v()},[t,T,r,v,a,u,JSON.stringify(E),JSON.stringify(m),y,s,R,c,JSON.stringify(h)])}const GJe={x:{[to.Backward]:!1,[to.Forward]:!1},y:{[to.Backward]:!1,[to.Forward]:!1}};function KJe(e){let{delta:t,disabled:n}=e;const r=vF(t);return LS(i=>{if(n||!r||!i)return GJe;const a={x:Math.sign(t.x-r.x),y:Math.sign(t.y-r.y)};return{x:{[to.Backward]:i.x[to.Backward]||a.x===-1,[to.Forward]:i.x[to.Forward]||a.x===1},y:{[to.Backward]:i.y[to.Backward]||a.y===-1,[to.Forward]:i.y[to.Forward]||a.y===1}}},[n,t,r])}function WJe(e,t){const n=t!=null?e.get(t):void 0,r=n?n.node.current:null;return LS(i=>{var a;return t==null?null:(a=r??i)!=null?a:null},[r,t])}function JJe(e,t){return P.useMemo(()=>e.reduce((n,r)=>{const{sensor:i}=r,a=i.activators.map(u=>({eventName:u.eventName,handler:t(u.handler,r)}));return[...n,...a]},[]),[e,t])}var Jx;(function(e){e[e.Always=0]="Always",e[e.BeforeDragging=1]="BeforeDragging",e[e.WhileDragging=2]="WhileDragging"})(Jx||(Jx={}));var xF;(function(e){e.Optimized="optimized"})(xF||(xF={}));const xW=new Map;function eet(e,t){let{dragging:n,dependencies:r,config:i}=t;const[a,u]=P.useState(null),{frequency:l,measure:o,strategy:s}=i,c=P.useRef(e),d=_(),h=Kx(d),m=P.useCallback(function(S){S===void 0&&(S=[]),!h.current&&u(E=>E===null?S:E.concat(S.filter(C=>!E.includes(C))))},[h]),y=P.useRef(null),v=LS(S=>{if(d&&!n)return xW;if(!S||S===xW||c.current!==e||a!=null){const E=new Map;for(let C of e){if(!C)continue;if(a&&a.length>0&&!a.includes(C.id)&&C.rect.current){E.set(C.id,C.rect.current);continue}const T=C.node.current,R=T?new DB(o(T),T):null;C.rect.current=R,R&&E.set(C.id,R)}return E}return S},[e,a,n,d,o]);return P.useEffect(()=>{c.current=e},[e]),P.useEffect(()=>{d||m()},[n,d]),P.useEffect(()=>{a&&a.length>0&&u(null)},[JSON.stringify(a)]),P.useEffect(()=>{d||typeof l!="number"||y.current!==null||(y.current=setTimeout(()=>{m(),y.current=null},l))},[l,d,m,...r]),{droppableRects:v,measureDroppableContainers:m,measuringScheduled:a!=null};function _(){switch(s){case Jx.Always:return!1;case Jx.BeforeDragging:return n;default:return!n}}}function ube(e,t){return LS(n=>e?n||(typeof t=="function"?t(e):e):null,[t,e])}function tet(e,t){return ube(e,t)}function net(e){let{callback:t,disabled:n}=e;const r=_B(t),i=P.useMemo(()=>{if(n||typeof window>"u"||typeof window.MutationObserver>"u")return;const{MutationObserver:a}=window;return new a(r)},[r,n]);return P.useEffect(()=>()=>i==null?void 0:i.disconnect(),[i]),i}function h5(e){let{callback:t,disabled:n}=e;const r=_B(t),i=P.useMemo(()=>{if(n||typeof window>"u"||typeof window.ResizeObserver>"u")return;const{ResizeObserver:a}=window;return new a(r)},[n]);return P.useEffect(()=>()=>i==null?void 0:i.disconnect(),[i]),i}function ret(e){return new DB(g4(e),e)}function SW(e,t,n){t===void 0&&(t=ret);const[r,i]=P.useState(null);function a(){i(o=>{if(!e)return null;if(e.isConnected===!1){var s;return(s=o??n)!=null?s:null}const c=t(e);return JSON.stringify(o)===JSON.stringify(c)?o:c})}const u=net({callback(o){if(e)for(const s of o){const{type:c,target:d}=s;if(c==="childList"&&d instanceof HTMLElement&&d.contains(e)){a();break}}}}),l=h5({callback:a});return N0(()=>{a(),e?(l==null||l.observe(e),u==null||u.observe(document.body,{childList:!0,subtree:!0})):(l==null||l.disconnect(),u==null||u.disconnect())},[e]),r}function iet(e){const t=ube(e);return G1e(e,t)}const _W=[];function aet(e){const t=P.useRef(e),n=LS(r=>e?r&&r!==_W&&e&&t.current&&e.parentNode===t.current.parentNode?r:d5(e):_W,[e]);return P.useEffect(()=>{t.current=e},[e]),n}function uet(e){const[t,n]=P.useState(null),r=P.useRef(e),i=P.useCallback(a=>{const u=w7(a.target);u&&n(l=>l?(l.set(u,bF(u)),new Map(l)):null)},[]);return P.useEffect(()=>{const a=r.current;if(e!==a){u(a);const l=e.map(o=>{const s=w7(o);return s?(s.addEventListener("scroll",i,{passive:!0}),[s,bF(s)]):null}).filter(o=>o!=null);n(l.length?new Map(l):null),r.current=e}return()=>{u(e),u(a)};function u(l){l.forEach(o=>{const s=w7(o);s==null||s.removeEventListener("scroll",i)})}},[i,e]),P.useMemo(()=>e.length?t?Array.from(t.values()).reduce((a,u)=>x3(a,u),cp):nbe(e):cp,[e,t])}function EW(e,t){t===void 0&&(t=[]);const n=P.useRef(null);return P.useEffect(()=>{n.current=null},t),P.useEffect(()=>{const r=e!==cp;r&&!n.current&&(n.current=e),!r&&n.current&&(n.current=null)},[e]),n.current?Wx(e,n.current):cp}function oet(e){P.useEffect(()=>{if(!f5)return;const t=e.map(n=>{let{sensor:r}=n;return r.setup==null?void 0:r.setup()});return()=>{for(const n of t)n==null||n()}},e.map(t=>{let{sensor:n}=t;return n}))}function set(e,t){return P.useMemo(()=>e.reduce((n,r)=>{let{eventName:i,handler:a}=r;return n[i]=u=>{a(u,t)},n},{}),[e,t])}function lbe(e){return P.useMemo(()=>e?kJe(e):null,[e])}const DW=[];function cet(e,t){t===void 0&&(t=g4);const[n]=e,r=lbe(n?pf(n):null),[i,a]=P.useState(DW);function u(){a(()=>e.length?e.map(o=>ebe(o)?r:new DB(t(o),o)):DW)}const l=h5({callback:u});return N0(()=>{l==null||l.disconnect(),u(),e.forEach(o=>l==null?void 0:l.observe(o))},[e]),i}function fet(e){if(!e)return null;if(e.children.length>1)return e;const t=e.children[0];return IS(t)?t:e}function det(e){let{measure:t}=e;const[n,r]=P.useState(null),i=P.useCallback(s=>{for(const{target:c}of s)if(IS(c)){r(d=>{const h=t(c);return d?{...d,width:h.width,height:h.height}:h});break}},[t]),a=h5({callback:i}),u=P.useCallback(s=>{const c=fet(s);a==null||a.disconnect(),c&&(a==null||a.observe(c)),r(c?t(c):null)},[t,a]),[l,o]=uC(u);return P.useMemo(()=>({nodeRef:l,rect:n,setRef:o}),[n,l,o])}const het=[{sensor:abe,options:{}},{sensor:ibe,options:{}}],pet={current:{}},yD={draggable:{measure:vW},droppable:{measure:vW,strategy:Jx.WhileDragging,frequency:xF.Optimized},dragOverlay:{measure:g4}};class tx extends Map{get(t){var n;return t!=null&&(n=super.get(t))!=null?n:void 0}toArray(){return Array.from(this.values())}getEnabled(){return this.toArray().filter(t=>{let{disabled:n}=t;return!n})}getNodeFor(t){var n,r;return(n=(r=this.get(t))==null?void 0:r.node.current)!=null?n:void 0}}const met={activatorEvent:null,active:null,activeNode:null,activeNodeRect:null,collisions:null,containerNodeRect:null,draggableNodes:new Map,droppableRects:new Map,droppableContainers:new tx,over:null,dragOverlay:{nodeRef:{current:null},rect:null,setRef:oC},scrollableAncestors:[],scrollableAncestorRects:[],measuringConfiguration:yD,measureDroppableContainers:oC,windowRect:null,measuringScheduled:!1},get={activatorEvent:null,activators:[],active:null,activeNodeRect:null,ariaDescribedById:{draggable:""},dispatch:oC,draggableNodes:new Map,over:null,measureDroppableContainers:oC},p5=P.createContext(get),obe=P.createContext(met);function vet(){return{draggable:{active:null,initialCoordinates:{x:0,y:0},nodes:new Map,translate:{x:0,y:0}},droppable:{containers:new tx}}}function yet(e,t){switch(t.type){case $l.DragStart:return{...e,draggable:{...e.draggable,initialCoordinates:t.initialCoordinates,active:t.active}};case $l.DragMove:return e.draggable.active==null?e:{...e,draggable:{...e.draggable,translate:{x:t.coordinates.x-e.draggable.initialCoordinates.x,y:t.coordinates.y-e.draggable.initialCoordinates.y}}};case $l.DragEnd:case $l.DragCancel:return{...e,draggable:{...e.draggable,active:null,initialCoordinates:{x:0,y:0},translate:{x:0,y:0}}};case $l.RegisterDroppable:{const{element:n}=t,{id:r}=n,i=new tx(e.droppable.containers);return i.set(r,n),{...e,droppable:{...e.droppable,containers:i}}}case $l.SetDroppableDisabled:{const{id:n,key:r,disabled:i}=t,a=e.droppable.containers.get(n);if(!a||r!==a.key)return e;const u=new tx(e.droppable.containers);return u.set(n,{...a,disabled:i}),{...e,droppable:{...e.droppable,containers:u}}}case $l.UnregisterDroppable:{const{id:n,key:r}=t,i=e.droppable.containers.get(n);if(!i||r!==i.key)return e;const a=new tx(e.droppable.containers);return a.delete(n),{...e,droppable:{...e.droppable,containers:a}}}default:return e}}function bet(e){let{disabled:t}=e;const{active:n,activatorEvent:r,draggableNodes:i}=P.useContext(p5),a=vF(r),u=vF(n==null?void 0:n.id);return P.useEffect(()=>{if(!t&&!r&&a&&u!=null){if(!EB(a)||document.activeElement===a.target)return;const l=i.get(u);if(!l)return;const{activatorNode:o,node:s}=l;if(!o.current&&!s.current)return;requestAnimationFrame(()=>{for(const c of[o.current,s.current]){if(!c)continue;const d=cJe(c);if(d){d.focus();break}}})}},[r,t,i,u,a]),null}function Oet(e,t){let{transform:n,...r}=t;return e!=null&&e.length?e.reduce((i,a)=>a({transform:i,...r}),n):n}function xet(e){return P.useMemo(()=>({draggable:{...yD.draggable,...e==null?void 0:e.draggable},droppable:{...yD.droppable,...e==null?void 0:e.droppable},dragOverlay:{...yD.dragOverlay,...e==null?void 0:e.dragOverlay}}),[e==null?void 0:e.draggable,e==null?void 0:e.droppable,e==null?void 0:e.dragOverlay])}function _et(e){let{activeNode:t,measure:n,initialRect:r,config:i=!0}=e;const a=P.useRef(!1),{x:u,y:l}=typeof i=="boolean"?{x:i,y:i}:i;N0(()=>{if(!u&&!l||!t){a.current=!1;return}if(a.current||!r)return;const s=t==null?void 0:t.node.current;if(!s||s.isConnected===!1)return;const c=n(s),d=G1e(c,r);if(u||(d.x=0),l||(d.y=0),a.current=!0,Math.abs(d.x)>0||Math.abs(d.y)>0){const h=K1e(s);h&&h.scrollBy({top:d.y,left:d.x})}},[t,u,l,r,n])}const sbe=P.createContext({...cp,scaleX:1,scaleY:1});var Cv;(function(e){e[e.Uninitialized=0]="Uninitialized",e[e.Initializing=1]="Initializing",e[e.Initialized=2]="Initialized"})(Cv||(Cv={}));const ilt=P.memo(function(t){var n,r,i,a;let{id:u,accessibility:l,autoScroll:o=!0,children:s,sensors:c=het,collisionDetection:d=DJe,measuring:h,modifiers:m,...y}=t;const v=P.useReducer(yet,void 0,vet),[_,S]=v,[E,C]=gJe(),[T,R]=P.useState(Cv.Uninitialized),$=T===Cv.Initialized,{draggable:{active:k,nodes:F,translate:L},droppable:{containers:j}}=_,V=k!=null?F.get(k):null,q=P.useRef({initial:null,translated:null}),N=P.useMemo(()=>{var ln;return k!=null?{id:k,data:(ln=V==null?void 0:V.data)!=null?ln:pet,rect:q}:null},[k,V]),U=P.useRef(null),[W,G]=P.useState(null),[J,te]=P.useState(null),H=Kx(y,Object.values(y)),M=BS("DndDescribedBy",u),K=P.useMemo(()=>j.getEnabled(),[j]),X=xet(h),{droppableRects:B,measureDroppableContainers:ne,measuringScheduled:oe}=eet(K,{dragging:$,dependencies:[L.x,L.y],config:X.droppable}),ie=WJe(F,k),de=P.useMemo(()=>J?yF(J):null,[J]),be=Ln(),ve=tet(ie,X.draggable.measure);_et({activeNode:k!=null?F.get(k):null,config:be.layoutShiftCompensation,initialRect:ve,measure:X.draggable.measure});const pe=SW(ie,X.draggable.measure,ve),_e=SW(ie?ie.parentElement:null),se=P.useRef({activatorEvent:null,active:null,activeNode:ie,collisionRect:null,collisions:null,droppableRects:B,draggableNodes:F,draggingNode:null,draggingNodeRect:null,droppableContainers:j,over:null,scrollableAncestors:[],scrollAdjustedTranslate:null}),me=j.getNodeFor((n=se.current.over)==null?void 0:n.id),ge=det({measure:X.dragOverlay.measure}),we=(r=ge.nodeRef.current)!=null?r:ie,Ne=$?(i=ge.rect)!=null?i:pe:null,Re=!!(ge.nodeRef.current&&ge.rect),et=iet(Re?null:pe),tt=lbe(we?pf(we):null),Oe=aet($?me??ie:null),$e=cet(Oe),Ae=Oet(m,{transform:{x:L.x-et.x,y:L.y-et.y,scaleX:1,scaleY:1},activatorEvent:J,active:N,activeNodeRect:pe,containerNodeRect:_e,draggingNodeRect:Ne,over:se.current.over,overlayNodeRect:ge.rect,scrollableAncestors:Oe,scrollableAncestorRects:$e,windowRect:tt}),Ue=de?x3(de,L):null,Ze=uet(Oe),Ye=EW(Ze),Me=EW(Ze,[pe]),ze=x3(Ae,Ye),st=Ne?wJe(Ne,Ae):null,Ot=N&&st?d({active:N,collisionRect:st,droppableRects:B,droppableContainers:K,pointerCoordinates:Ue}):null,Nt=Y1e(Ot,"id"),[gt,qt]=P.useState(null),zt=Re?Ae:x3(Ae,Me),an=$Je(zt,(a=gt==null?void 0:gt.rect)!=null?a:null,pe),rn=P.useRef(null),Fe=P.useCallback((ln,Zn)=>{let{sensor:cr,options:ur}=Zn;if(U.current==null)return;const Cr=F.get(U.current);if(!Cr)return;const Vr=ln.nativeEvent,ke=new cr({active:U.current,activeNode:Cr,event:Vr,options:ur,context:se,onAbort(nt){if(!F.get(nt))return;const{onDragAbort:$t}=H.current,Ut={id:nt};$t==null||$t(Ut),E({type:"onDragAbort",event:Ut})},onPending(nt,dt,$t,Ut){if(!F.get(nt))return;const{onDragPending:Lt}=H.current,Vt={id:nt,constraint:dt,initialCoordinates:$t,offset:Ut};Lt==null||Lt(Vt),E({type:"onDragPending",event:Vt})},onStart(nt){const dt=U.current;if(dt==null)return;const $t=F.get(dt);if(!$t)return;const{onDragStart:Ut}=H.current,Zt={activatorEvent:Vr,active:{id:dt,data:$t.data,rect:q}};Vf.unstable_batchedUpdates(()=>{Ut==null||Ut(Zt),R(Cv.Initializing),S({type:$l.DragStart,initialCoordinates:nt,active:dt}),E({type:"onDragStart",event:Zt}),G(rn.current),te(Vr)})},onMove(nt){S({type:$l.DragMove,coordinates:nt})},onEnd:He($l.DragEnd),onCancel:He($l.DragCancel)});rn.current=ke;function He(nt){return async function(){const{active:$t,collisions:Ut,over:Zt,scrollAdjustedTranslate:Lt}=se.current;let Vt=null;if($t&&Lt){const{cancelDrop:tn}=H.current;Vt={activatorEvent:Vr,active:$t,collisions:Ut,delta:Lt,over:Zt},nt===$l.DragEnd&&typeof tn=="function"&&await Promise.resolve(tn(Vt))&&(nt=$l.DragCancel)}U.current=null,Vf.unstable_batchedUpdates(()=>{S({type:nt}),R(Cv.Uninitialized),qt(null),G(null),te(null),rn.current=null;const tn=nt===$l.DragEnd?"onDragEnd":"onDragCancel";if(Vt){const nn=H.current[tn];nn==null||nn(Vt),E({type:tn,event:Vt})}})}}},[F]),ht=P.useCallback((ln,Zn)=>(cr,ur)=>{const Cr=cr.nativeEvent,Vr=F.get(ur);if(U.current!==null||!Vr||Cr.dndKit||Cr.defaultPrevented)return;const ke={active:Vr};ln(cr,Zn.options,ke)===!0&&(Cr.dndKit={capturedBy:Zn.sensor},U.current=ur,Fe(cr,Zn))},[F,Fe]),Tt=JJe(c,ht);oet(c),N0(()=>{pe&&T===Cv.Initializing&&R(Cv.Initialized)},[pe,T]),P.useEffect(()=>{const{onDragMove:ln}=H.current,{active:Zn,activatorEvent:cr,collisions:ur,over:Cr}=se.current;if(!Zn||!cr)return;const Vr={active:Zn,activatorEvent:cr,collisions:ur,delta:{x:ze.x,y:ze.y},over:Cr};Vf.unstable_batchedUpdates(()=>{ln==null||ln(Vr),E({type:"onDragMove",event:Vr})})},[ze.x,ze.y]),P.useEffect(()=>{const{active:ln,activatorEvent:Zn,collisions:cr,droppableContainers:ur,scrollAdjustedTranslate:Cr}=se.current;if(!ln||U.current==null||!Zn||!Cr)return;const{onDragOver:Vr}=H.current,ke=ur.get(Nt),He=ke&&ke.rect.current?{id:ke.id,rect:ke.rect.current,data:ke.data,disabled:ke.disabled}:null,nt={active:ln,activatorEvent:Zn,collisions:cr,delta:{x:Cr.x,y:Cr.y},over:He};Vf.unstable_batchedUpdates(()=>{qt(He),Vr==null||Vr(nt),E({type:"onDragOver",event:nt})})},[Nt]),N0(()=>{se.current={activatorEvent:J,active:N,activeNode:ie,collisionRect:st,collisions:Ot,droppableRects:B,draggableNodes:F,draggingNode:we,draggingNodeRect:Ne,droppableContainers:j,over:gt,scrollableAncestors:Oe,scrollAdjustedTranslate:ze},q.current={initial:Ne,translated:st}},[N,ie,Ot,st,F,we,Ne,B,j,gt,Oe,ze]),YJe({...be,delta:L,draggingRect:st,pointerCoordinates:Ue,scrollableAncestors:Oe,scrollableAncestorRects:$e});const Qt=P.useMemo(()=>({active:N,activeNode:ie,activeNodeRect:pe,activatorEvent:J,collisions:Ot,containerNodeRect:_e,dragOverlay:ge,draggableNodes:F,droppableContainers:j,droppableRects:B,over:gt,measureDroppableContainers:ne,scrollableAncestors:Oe,scrollableAncestorRects:$e,measuringConfiguration:X,measuringScheduled:oe,windowRect:tt}),[N,ie,pe,J,Ot,_e,ge,F,j,B,gt,ne,Oe,$e,X,oe,tt]),un=P.useMemo(()=>({activatorEvent:J,activators:Tt,active:N,activeNodeRect:pe,ariaDescribedById:{draggable:M},dispatch:S,draggableNodes:F,over:gt,measureDroppableContainers:ne}),[J,Tt,N,pe,S,M,F,gt,ne]);return ye.createElement(X1e.Provider,{value:C},ye.createElement(p5.Provider,{value:un},ye.createElement(obe.Provider,{value:Qt},ye.createElement(sbe.Provider,{value:an},s)),ye.createElement(bet,{disabled:(l==null?void 0:l.restoreFocus)===!1})),ye.createElement(bJe,{...l,hiddenTextDescribedById:M}));function Ln(){const ln=(W==null?void 0:W.autoScrollEnabled)===!1,Zn=typeof o=="object"?o.enabled===!1:o===!1,cr=$&&!ln&&!Zn;return typeof o=="object"?{...o,enabled:cr}:{enabled:cr}}}),Eet=P.createContext(null),$W="button",Det="Draggable";function $et(e){let{id:t,data:n,disabled:r=!1,attributes:i}=e;const a=BS(Det),{activators:u,activatorEvent:l,active:o,activeNodeRect:s,ariaDescribedById:c,draggableNodes:d,over:h}=P.useContext(p5),{role:m=$W,roleDescription:y="draggable",tabIndex:v=0}=i??{},_=(o==null?void 0:o.id)===t,S=P.useContext(_?sbe:Eet),[E,C]=uC(),[T,R]=uC(),$=set(u,t),k=Kx(n);N0(()=>(d.set(t,{id:t,key:a,node:E,activatorNode:T,data:k}),()=>{const L=d.get(t);L&&L.key===a&&d.delete(t)}),[d,t]);const F=P.useMemo(()=>({role:m,tabIndex:v,"aria-disabled":r,"aria-pressed":_&&m===$W?!0:void 0,"aria-roledescription":y,"aria-describedby":c.draggable}),[r,m,v,_,y,c.draggable]);return{active:o,activatorEvent:l,activeNodeRect:s,attributes:F,isDragging:_,listeners:r?void 0:$,node:E,over:h,setNodeRef:C,setActivatorNodeRef:R,transform:S}}function Cet(){return P.useContext(obe)}const wet="Droppable",Ret={timeout:25};function Aet(e){let{data:t,disabled:n=!1,id:r,resizeObserverConfig:i}=e;const a=BS(wet),{active:u,dispatch:l,over:o,measureDroppableContainers:s}=P.useContext(p5),c=P.useRef({disabled:n}),d=P.useRef(!1),h=P.useRef(null),m=P.useRef(null),{disabled:y,updateMeasurementsFor:v,timeout:_}={...Ret,...i},S=Kx(v??r),E=P.useCallback(()=>{if(!d.current){d.current=!0;return}m.current!=null&&clearTimeout(m.current),m.current=setTimeout(()=>{s(Array.isArray(S.current)?S.current:[S.current]),m.current=null},_)},[_]),C=h5({callback:E,disabled:y||!u}),T=P.useCallback((F,L)=>{C&&(L&&(C.unobserve(L),d.current=!1),F&&C.observe(F))},[C]),[R,$]=uC(T),k=Kx(t);return P.useEffect(()=>{!C||!R.current||(C.disconnect(),d.current=!1,C.observe(R.current))},[R,C]),P.useEffect(()=>(l({type:$l.RegisterDroppable,element:{id:r,key:a,disabled:n,node:R,rect:h,data:k}}),()=>l({type:$l.UnregisterDroppable,key:a,id:r})),[r]),P.useEffect(()=>{n!==c.current.disabled&&(l({type:$l.SetDroppableDisabled,id:r,key:a,disabled:n}),c.current.disabled=n)},[r,a,n,l]),{active:u,rect:h,isOver:(o==null?void 0:o.id)===r,node:R,over:o,setNodeRef:$}}function cbe(e,t,n){const r=e.slice();return r.splice(n<0?r.length+n:n,0,r.splice(t,1)[0]),r}function Tet(e,t){return e.reduce((n,r,i)=>{const a=t.get(r);return a&&(n[i]=a),n},Array(e.length))}function TE(e){return e!==null&&e>=0}function ket(e,t){if(e===t)return!0;if(e.length!==t.length)return!1;for(let n=0;n<e.length;n++)if(e[n]!==t[n])return!1;return!0}function Pet(e){return typeof e=="boolean"?{draggable:e,droppable:e}:e}const fbe=e=>{let{rects:t,activeIndex:n,overIndex:r,index:i}=e;const a=cbe(t,r,n),u=t[i],l=a[i];return!l||!u?null:{x:l.left-u.left,y:l.top-u.top,scaleX:l.width/u.width,scaleY:l.height/u.height}},dbe="Sortable",hbe=ye.createContext({activeIndex:-1,containerId:dbe,disableTransforms:!1,items:[],overIndex:-1,useDragOverlay:!1,sortedRects:[],strategy:fbe,disabled:{draggable:!1,droppable:!1}});function alt(e){let{children:t,id:n,items:r,strategy:i=fbe,disabled:a=!1}=e;const{active:u,dragOverlay:l,droppableRects:o,over:s,measureDroppableContainers:c}=Cet(),d=BS(dbe,n),h=l.rect!==null,m=P.useMemo(()=>r.map($=>typeof $=="object"&&"id"in $?$.id:$),[r]),y=u!=null,v=u?m.indexOf(u.id):-1,_=s?m.indexOf(s.id):-1,S=P.useRef(m),E=!ket(m,S.current),C=_!==-1&&v===-1||E,T=Pet(a);N0(()=>{E&&y&&c(m)},[E,m,y,c]),P.useEffect(()=>{S.current=m},[m]);const R=P.useMemo(()=>({activeIndex:v,containerId:d,disabled:T,disableTransforms:C,items:m,overIndex:_,useDragOverlay:h,sortedRects:Tet(m,o),strategy:i}),[v,d,T.draggable,T.droppable,C,m,_,o,h,i]);return ye.createElement(hbe.Provider,{value:R},t)}const Met=e=>{let{id:t,items:n,activeIndex:r,overIndex:i}=e;return cbe(n,r,i).indexOf(t)},Fet=e=>{let{containerId:t,isSorting:n,wasDragging:r,index:i,items:a,newIndex:u,previousItems:l,previousContainerId:o,transition:s}=e;return!s||!r||l!==a&&i===u?!1:n?!0:u!==i&&t===o},Net={duration:200,easing:"ease"},pbe="transform",Iet=lC.Transition.toString({property:pbe,duration:0,easing:"linear"}),Let={roleDescription:"sortable"};function Bet(e){let{disabled:t,index:n,node:r,rect:i}=e;const[a,u]=P.useState(null),l=P.useRef(n);return N0(()=>{if(!t&&n!==l.current&&r.current){const o=i.current;if(o){const s=g4(r.current,{ignoreTransform:!0}),c={x:o.left-s.left,y:o.top-s.top,scaleX:o.width/s.width,scaleY:o.height/s.height};(c.x||c.y)&&u(c)}}n!==l.current&&(l.current=n)},[t,n,r,i]),P.useEffect(()=>{a&&u(null)},[a]),a}function ult(e){let{animateLayoutChanges:t=Fet,attributes:n,disabled:r,data:i,getNewIndex:a=Met,id:u,strategy:l,resizeObserverConfig:o,transition:s=Net}=e;const{items:c,containerId:d,activeIndex:h,disabled:m,disableTransforms:y,sortedRects:v,overIndex:_,useDragOverlay:S,strategy:E}=P.useContext(hbe),C=Qet(r,m),T=c.indexOf(u),R=P.useMemo(()=>({sortable:{containerId:d,index:T,items:c},...i}),[d,i,T,c]),$=P.useMemo(()=>c.slice(c.indexOf(u)),[c,u]),{rect:k,node:F,isOver:L,setNodeRef:j}=Aet({id:u,data:R,disabled:C.droppable,resizeObserverConfig:{updateMeasurementsFor:$,...o}}),{active:V,activatorEvent:q,activeNodeRect:N,attributes:U,setNodeRef:W,listeners:G,isDragging:J,over:te,setActivatorNodeRef:H,transform:M}=$et({id:u,data:R,attributes:{...Let,...n},disabled:C.draggable}),K=uJe(j,W),X=!!V,B=X&&!y&&TE(h)&&TE(_),ne=!S&&J,oe=ne&&B?M:null,de=B?oe??(l??E)({rects:v,activeNodeRect:N,activeIndex:h,overIndex:_,index:T}):null,be=TE(h)&&TE(_)?a({id:u,items:c,activeIndex:h,overIndex:_}):T,ve=V==null?void 0:V.id,pe=P.useRef({activeId:ve,items:c,newIndex:be,containerId:d}),_e=c!==pe.current.items,se=t({active:V,containerId:d,isDragging:J,isSorting:X,id:u,index:T,items:c,newIndex:pe.current.newIndex,previousItems:pe.current.items,previousContainerId:pe.current.containerId,transition:s,wasDragging:pe.current.activeId!=null}),me=Bet({disabled:!se,index:T,node:F,rect:k});return P.useEffect(()=>{X&&pe.current.newIndex!==be&&(pe.current.newIndex=be),d!==pe.current.containerId&&(pe.current.containerId=d),c!==pe.current.items&&(pe.current.items=c)},[X,be,d,c]),P.useEffect(()=>{if(ve===pe.current.activeId)return;if(ve&&!pe.current.activeId){pe.current.activeId=ve;return}const we=setTimeout(()=>{pe.current.activeId=ve},50);return()=>clearTimeout(we)},[ve]),{active:V,activeIndex:h,attributes:U,data:R,rect:k,index:T,newIndex:be,items:c,isOver:L,isSorting:X,isDragging:J,listeners:G,node:F,overIndex:_,over:te,setNodeRef:K,setActivatorNodeRef:H,setDroppableNodeRef:j,setDraggableNodeRef:W,transform:me??de,transition:ge()};function ge(){if(me||_e&&pe.current.newIndex===T)return Iet;if(!(ne&&!EB(q)||!s)&&(X||se))return lC.Transition.toString({...s,property:pbe})}}function Qet(e,t){var n,r;return typeof e=="boolean"?{draggable:e,droppable:!1}:{draggable:(n=e==null?void 0:e.draggable)!=null?n:t.draggable,droppable:(r=e==null?void 0:e.droppable)!=null?r:t.droppable}}function cC(e){if(!e)return!1;const t=e.data.current;return!!(t&&"sortable"in t&&typeof t.sortable=="object"&&"containerId"in t.sortable&&"items"in t.sortable&&"index"in t.sortable)}const zet=[Jr.Down,Jr.Right,Jr.Up,Jr.Left],llt=(e,t)=>{let{context:{active:n,collisionRect:r,droppableRects:i,droppableContainers:a,over:u,scrollableAncestors:l}}=t;if(zet.includes(e.code)){if(e.preventDefault(),!n||!r)return;const o=[];a.getEnabled().forEach(d=>{if(!d||d!=null&&d.disabled)return;const h=i.get(d.id);if(h)switch(e.code){case Jr.Down:r.top<h.top&&o.push(d);break;case Jr.Up:r.top>h.top&&o.push(d);break;case Jr.Left:r.left>h.left&&o.push(d);break;case Jr.Right:r.left<h.left&&o.push(d);break}});const s=_Je({collisionRect:r,droppableRects:i,droppableContainers:o});let c=Y1e(s,"id");if(c===(u==null?void 0:u.id)&&s.length>1&&(c=s[1].id),c!=null){const d=a.get(n.id),h=a.get(c),m=h?i.get(h.id):null,y=h==null?void 0:h.node.current;if(y&&m&&d&&h){const _=d5(y).some(($,k)=>l[k]!==$),S=mbe(d,h),E=qet(d,h),C=_||!S?{x:0,y:0}:{x:E?r.width-m.width:0,y:E?r.height-m.height:0},T={x:m.left,y:m.top};return C.x&&C.y?T:Wx(T,C)}}}};function mbe(e,t){return!cC(e)||!cC(t)?!1:e.data.current.sortable.containerId===t.data.current.sortable.containerId}function qet(e,t){return!cC(e)||!cC(t)||!mbe(e,t)?!1:e.data.current.sortable.index<t.data.current.sortable.index}var CW=Object.prototype.hasOwnProperty;function wW(e,t,n){for(n of e.keys())if(nx(n,t))return n}function nx(e,t){var n,r,i;if(e===t)return!0;if(e&&t&&(n=e.constructor)===t.constructor){if(n===Date)return e.getTime()===t.getTime();if(n===RegExp)return e.toString()===t.toString();if(n===Array){if((r=e.length)===t.length)for(;r--&&nx(e[r],t[r]););return r===-1}if(n===Set){if(e.size!==t.size)return!1;for(r of e)if(i=r,i&&typeof i=="object"&&(i=wW(t,i),!i)||!t.has(i))return!1;return!0}if(n===Map){if(e.size!==t.size)return!1;for(r of e)if(i=r[0],i&&typeof i=="object"&&(i=wW(t,i),!i)||!nx(r[1],t.get(i)))return!1;return!0}if(n===ArrayBuffer)e=new Uint8Array(e),t=new Uint8Array(t);else if(n===DataView){if((r=e.byteLength)===t.byteLength)for(;r--&&e.getInt8(r)===t.getInt8(r););return r===-1}if(ArrayBuffer.isView(e)){if((r=e.byteLength)===t.byteLength)for(;r--&&e[r]===t[r];);return r===-1}if(!n||typeof e=="object"){r=0;for(n in e)if(CW.call(e,n)&&++r&&!CW.call(t,n)||!(n in t)||!nx(e[n],t[n]))return!1;return Object.keys(t).length===r}}return e!==e&&t!==t}function Vet(e){var t=P.useRef(e),n=P.useRef(0);return nx(e,t.current)||(t.current=e,n.current+=1),P.useMemo(function(){return t.current},[n.current])}function olt(e,t){return P.useEffect(e,Vet(t))}var T7={exports:{}},km={};/**
 * @license React
 * react-reconciler-constants.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var RW;function Uet(){return RW||(RW=1,km.ConcurrentRoot=1,km.ContinuousEventPriority=8,km.DefaultEventPriority=32,km.DiscreteEventPriority=2,km.IdleEventPriority=268435456,km.LegacyRoot=0,km.NoEventPriority=0),km}var AW;function jet(){return AW||(AW=1,T7.exports=Uet()),T7.exports}var bD=jet();const TW=e=>{let t;const n=new Set,r=(s,c)=>{const d=typeof s=="function"?s(t):s;if(!Object.is(d,t)){const h=t;t=c??(typeof d!="object"||d===null)?d:Object.assign({},t,d),n.forEach(m=>m(t,h))}},i=()=>t,l={setState:r,getState:i,getInitialState:()=>o,subscribe:s=>(n.add(s),()=>n.delete(s))},o=t=e(r,i,l);return l},Zet=e=>e?TW(e):TW,{useSyncExternalStoreWithSelector:Het}=dee,Xet=e=>e;function Yet(e,t=Xet,n){const r=Het(e.subscribe,e.getState,e.getInitialState,t,n);return ye.useDebugValue(r),r}const kW=(e,t)=>{const n=Zet(e),r=(i,a=t)=>Yet(n,i,a);return Object.assign(r,n),r},Get=(e,t)=>e?kW(e,t):kW;var k7={exports:{}},P7={exports:{}},M7={exports:{}},F7={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var PW;function Ket(){return PW||(PW=1,(function(e){function t(G,J){var te=G.length;G.push(J);e:for(;0<te;){var H=te-1>>>1,M=G[H];if(0<i(M,J))G[H]=J,G[te]=M,te=H;else break e}}function n(G){return G.length===0?null:G[0]}function r(G){if(G.length===0)return null;var J=G[0],te=G.pop();if(te!==J){G[0]=te;e:for(var H=0,M=G.length,K=M>>>1;H<K;){var X=2*(H+1)-1,B=G[X],ne=X+1,oe=G[ne];if(0>i(B,te))ne<M&&0>i(oe,B)?(G[H]=oe,G[ne]=te,H=ne):(G[H]=B,G[X]=te,H=X);else if(ne<M&&0>i(oe,te))G[H]=oe,G[ne]=te,H=ne;else break e}}return J}function i(G,J){var te=G.sortIndex-J.sortIndex;return te!==0?te:G.id-J.id}if(e.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var a=performance;e.unstable_now=function(){return a.now()}}else{var u=Date,l=u.now();e.unstable_now=function(){return u.now()-l}}var o=[],s=[],c=1,d=null,h=3,m=!1,y=!1,v=!1,_=typeof setTimeout=="function"?setTimeout:null,S=typeof clearTimeout=="function"?clearTimeout:null,E=typeof setImmediate<"u"?setImmediate:null;function C(G){for(var J=n(s);J!==null;){if(J.callback===null)r(s);else if(J.startTime<=G)r(s),J.sortIndex=J.expirationTime,t(o,J);else break;J=n(s)}}function T(G){if(v=!1,C(G),!y)if(n(o)!==null)y=!0,U();else{var J=n(s);J!==null&&W(T,J.startTime-G)}}var R=!1,$=-1,k=5,F=-1;function L(){return!(e.unstable_now()-F<k)}function j(){if(R){var G=e.unstable_now();F=G;var J=!0;try{e:{y=!1,v&&(v=!1,S($),$=-1),m=!0;var te=h;try{t:{for(C(G),d=n(o);d!==null&&!(d.expirationTime>G&&L());){var H=d.callback;if(typeof H=="function"){d.callback=null,h=d.priorityLevel;var M=H(d.expirationTime<=G);if(G=e.unstable_now(),typeof M=="function"){d.callback=M,C(G),J=!0;break t}d===n(o)&&r(o),C(G)}else r(o);d=n(o)}if(d!==null)J=!0;else{var K=n(s);K!==null&&W(T,K.startTime-G),J=!1}}break e}finally{d=null,h=te,m=!1}J=void 0}}finally{J?V():R=!1}}}var V;if(typeof E=="function")V=function(){E(j)};else if(typeof MessageChannel<"u"){var q=new MessageChannel,N=q.port2;q.port1.onmessage=j,V=function(){N.postMessage(null)}}else V=function(){_(j,0)};function U(){R||(R=!0,V())}function W(G,J){$=_(function(){G(e.unstable_now())},J)}e.unstable_IdlePriority=5,e.unstable_ImmediatePriority=1,e.unstable_LowPriority=4,e.unstable_NormalPriority=3,e.unstable_Profiling=null,e.unstable_UserBlockingPriority=2,e.unstable_cancelCallback=function(G){G.callback=null},e.unstable_continueExecution=function(){y||m||(y=!0,U())},e.unstable_forceFrameRate=function(G){0>G||125<G?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):k=0<G?Math.floor(1e3/G):5},e.unstable_getCurrentPriorityLevel=function(){return h},e.unstable_getFirstCallbackNode=function(){return n(o)},e.unstable_next=function(G){switch(h){case 1:case 2:case 3:var J=3;break;default:J=h}var te=h;h=J;try{return G()}finally{h=te}},e.unstable_pauseExecution=function(){},e.unstable_requestPaint=function(){},e.unstable_runWithPriority=function(G,J){switch(G){case 1:case 2:case 3:case 4:case 5:break;default:G=3}var te=h;h=G;try{return J()}finally{h=te}},e.unstable_scheduleCallback=function(G,J,te){var H=e.unstable_now();switch(typeof te=="object"&&te!==null?(te=te.delay,te=typeof te=="number"&&0<te?H+te:H):te=H,G){case 1:var M=-1;break;case 2:M=250;break;case 5:M=1073741823;break;case 4:M=1e4;break;default:M=5e3}return M=te+M,G={id:c++,callback:J,priorityLevel:G,startTime:te,expirationTime:M,sortIndex:-1},te>H?(G.sortIndex=te,t(s,G),n(o)===null&&G===n(s)&&(v?(S($),$=-1):v=!0,W(T,te-H))):(G.sortIndex=M,t(o,G),y||m||(y=!0,U())),G},e.unstable_shouldYield=L,e.unstable_wrapCallback=function(G){var J=h;return function(){var te=h;h=J;try{return G.apply(this,arguments)}finally{h=te}}}})(F7)),F7}var MW;function gbe(){return MW||(MW=1,M7.exports=Ket()),M7.exports}/**
 * @license React
 * react-reconciler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var FW;function Wet(){return FW||(FW=1,(function(e){e.exports=function(t){function n(g,b,A,z){return new Mu(g,b,A,z)}function r(){}function i(g){var b="https://react.dev/errors/"+g;if(1<arguments.length){b+="?args[]="+encodeURIComponent(arguments[1]);for(var A=2;A<arguments.length;A++)b+="&args[]="+encodeURIComponent(arguments[A])}return"Minified React error #"+g+"; visit "+b+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function a(g){return g===null||typeof g!="object"?null:(g=am&&g[am]||g["@@iterator"],typeof g=="function"?g:null)}function u(g){if(g==null)return null;if(typeof g=="function")return g.$$typeof===Bs?null:g.displayName||g.name||null;if(typeof g=="string")return g;switch(g){case Xo:return"Fragment";case Ls:return"Portal";case Ay:return"Profiler";case Ry:return"StrictMode";case Dg:return"Suspense";case vd:return"SuspenseList"}if(typeof g=="object")switch(g.$$typeof){case Ac:return(g.displayName||"Context")+".Provider";case gd:return(g._context.displayName||"Context")+".Consumer";case Fp:var b=g.render;return g=g.displayName,g||(g=b.displayName||b.name||"",g=g!==""?"ForwardRef("+g+")":"ForwardRef"),g;case Np:return b=g.displayName||null,b!==null?b:u(g.type)||"Memo";case Go:b=g._payload,g=g._init;try{return u(g(b))}catch{}}return null}function l(g){if($g===void 0)try{throw Error()}catch(A){var b=A.stack.trim().match(/\n( *(at )?)/);$g=b&&b[1]||"",Cg=-1<A.stack.indexOf(`
    at`)?" (<anonymous>)":-1<A.stack.indexOf("@")?"@unknown:0:0":""}return`
`+$g+g+Cg}function o(g,b){if(!g||yd)return"";yd=!0;var A=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var z={DetermineComponentFrameRoot:function(){try{if(b){var Ht=function(){throw Error()};if(Object.defineProperty(Ht.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(Ht,[])}catch(Hn){var Wt=Hn}Reflect.construct(g,[],Ht)}else{try{Ht.call()}catch(Hn){Wt=Hn}g.call(Ht.prototype)}}else{try{throw Error()}catch(Hn){Wt=Hn}(Ht=g())&&typeof Ht.catch=="function"&&Ht.catch(function(){})}}catch(Hn){if(Hn&&Wt&&typeof Hn.stack=="string")return[Hn.stack,Wt.stack]}return[null,null]}};z.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var ee=Object.getOwnPropertyDescriptor(z.DetermineComponentFrameRoot,"name");ee&&ee.configurable&&Object.defineProperty(z.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var le=z.DetermineComponentFrameRoot(),De=le[0],Ie=le[1];if(De&&Ie){var We=De.split(`
`),vt=Ie.split(`
`);for(ee=z=0;z<We.length&&!We[z].includes("DetermineComponentFrameRoot");)z++;for(;ee<vt.length&&!vt[ee].includes("DetermineComponentFrameRoot");)ee++;if(z===We.length||ee===vt.length)for(z=We.length-1,ee=vt.length-1;1<=z&&0<=ee&&We[z]!==vt[ee];)ee--;for(;1<=z&&0<=ee;z--,ee--)if(We[z]!==vt[ee]){if(z!==1||ee!==1)do if(z--,ee--,0>ee||We[z]!==vt[ee]){var kt=`
`+We[z].replace(" at new "," at ");return g.displayName&&kt.includes("<anonymous>")&&(kt=kt.replace("<anonymous>",g.displayName)),kt}while(1<=z&&0<=ee);break}}}finally{yd=!1,Error.prepareStackTrace=A}return(A=g?g.displayName||g.name:"")?l(A):""}function s(g){switch(g.tag){case 26:case 27:case 5:return l(g.type);case 16:return l("Lazy");case 13:return l("Suspense");case 19:return l("SuspenseList");case 0:case 15:return g=o(g.type,!1),g;case 11:return g=o(g.type.render,!1),g;case 1:return g=o(g.type,!0),g;default:return""}}function c(g){try{var b="";do b+=s(g),g=g.return;while(g);return b}catch(A){return`
Error generating stack: `+A.message+`
`+A.stack}}function d(g){var b=g,A=g;if(g.alternate)for(;b.return;)b=b.return;else{g=b;do b=g,(b.flags&4098)!==0&&(A=b.return),g=b.return;while(g)}return b.tag===3?A:null}function h(g){if(d(g)!==g)throw Error(i(188))}function m(g){var b=g.alternate;if(!b){if(b=d(g),b===null)throw Error(i(188));return b!==g?null:g}for(var A=g,z=b;;){var ee=A.return;if(ee===null)break;var le=ee.alternate;if(le===null){if(z=ee.return,z!==null){A=z;continue}break}if(ee.child===le.child){for(le=ee.child;le;){if(le===A)return h(ee),g;if(le===z)return h(ee),b;le=le.sibling}throw Error(i(188))}if(A.return!==z.return)A=ee,z=le;else{for(var De=!1,Ie=ee.child;Ie;){if(Ie===A){De=!0,A=ee,z=le;break}if(Ie===z){De=!0,z=ee,A=le;break}Ie=Ie.sibling}if(!De){for(Ie=le.child;Ie;){if(Ie===A){De=!0,A=le,z=ee;break}if(Ie===z){De=!0,z=le,A=ee;break}Ie=Ie.sibling}if(!De)throw Error(i(189))}}if(A.alternate!==z)throw Error(i(190))}if(A.tag!==3)throw Error(i(188));return A.stateNode.current===A?g:b}function y(g){var b=g.tag;if(b===5||b===26||b===27||b===6)return g;for(g=g.child;g!==null;){if(b=y(g),b!==null)return b;g=g.sibling}return null}function v(g){var b=g.tag;if(b===5||b===26||b===27||b===6)return g;for(g=g.child;g!==null;){if(g.tag!==4&&(b=v(g),b!==null))return b;g=g.sibling}return null}function _(g){return{current:g}}function S(g){0>Fc||(g.current=$d[Fc],$d[Fc]=null,Fc--)}function E(g,b){Fc++,$d[Fc]=g.current,g.current=b}function C(g){return g>>>=0,g===0?32:31-(Cd(g)/jb|0)|0}function T(g){var b=g&42;if(b!==0)return b;switch(g&-g){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return g&4194176;case 4194304:case 8388608:case 16777216:case 33554432:return g&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return g}}function R(g,b){var A=g.pendingLanes;if(A===0)return 0;var z=0,ee=g.suspendedLanes,le=g.pingedLanes,De=g.warmLanes;g=g.finishedLanes!==0;var Ie=A&134217727;return Ie!==0?(A=Ie&~ee,A!==0?z=T(A):(le&=Ie,le!==0?z=T(le):g||(De=Ie&~De,De!==0&&(z=T(De))))):(Ie=A&~ee,Ie!==0?z=T(Ie):le!==0?z=T(le):g||(De=A&~De,De!==0&&(z=T(De)))),z===0?0:b!==0&&b!==z&&(b&ee)===0&&(ee=z&-z,De=b&-b,ee>=De||ee===32&&(De&4194176)!==0)?b:z}function $(g,b){return(g.pendingLanes&~(g.suspendedLanes&~g.pingedLanes)&b)===0}function k(g,b){switch(g){case 1:case 2:case 4:case 8:return b+250;case 16:case 32:case 64:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return b+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function F(){var g=wh;return wh<<=1,(wh&4194176)===0&&(wh=128),g}function L(){var g=wd;return wd<<=1,(wd&62914560)===0&&(wd=4194304),g}function j(g){for(var b=[],A=0;31>A;A++)b.push(g);return b}function V(g,b){g.pendingLanes|=b,b!==268435456&&(g.suspendedLanes=0,g.pingedLanes=0,g.warmLanes=0)}function q(g,b,A,z,ee,le){var De=g.pendingLanes;g.pendingLanes=A,g.suspendedLanes=0,g.pingedLanes=0,g.warmLanes=0,g.expiredLanes&=A,g.entangledLanes&=A,g.errorRecoveryDisabledLanes&=A,g.shellSuspendCounter=0;var Ie=g.entanglements,We=g.expirationTimes,vt=g.hiddenUpdates;for(A=De&~A;0<A;){var kt=31-il(A),Ht=1<<kt;Ie[kt]=0,We[kt]=-1;var Wt=vt[kt];if(Wt!==null)for(vt[kt]=null,kt=0;kt<Wt.length;kt++){var Hn=Wt[kt];Hn!==null&&(Hn.lane&=-536870913)}A&=~Ht}z!==0&&N(g,z,0),le!==0&&ee===0&&g.tag!==0&&(g.suspendedLanes|=le&~(De&~b))}function N(g,b,A){g.pendingLanes|=b,g.suspendedLanes&=~b;var z=31-il(b);g.entangledLanes|=b,g.entanglements[z]=g.entanglements[z]|1073741824|A&4194218}function U(g,b){var A=g.entangledLanes|=b;for(g=g.entanglements;A;){var z=31-il(A),ee=1<<z;ee&b|g[z]&b&&(g[z]|=b),A&=~ee}}function W(g){return g&=-g,2<g?8<g?(g&134217727)!==0?32:268435456:8:2}function G(g){if(al&&typeof al.onCommitFiberRoot=="function")try{al.onCommitFiberRoot(Ul,g,void 0,(g.current.flags&128)===128)}catch{}}function J(g){if(typeof Hb=="function"&&Wy(g),al&&typeof al.setStrictMode=="function")try{al.setStrictMode(Ul,g)}catch{}}function te(g,b){return g===b&&(g!==0||1/g===1/b)||g!==g&&b!==b}function H(g,b){if(typeof g=="object"&&g!==null){var A=Vp.get(g);return A!==void 0?A:(b={value:g,source:b,stack:c(b)},Vp.set(g,b),b)}return{value:g,source:b,stack:c(b)}}function M(g,b){bi[$i++]=Rd,bi[$i++]=Sn,Sn=g,Rd=b}function K(g,b,A){xl[nu++]=ns,xl[nu++]=yo,xl[nu++]=Vs,Vs=g;var z=ns;g=yo;var ee=32-il(z)-1;z&=~(1<<ee),A+=1;var le=32-il(b)+ee;if(30<le){var De=ee-ee%5;le=(z&(1<<De)-1).toString(32),z>>=De,ee-=De,ns=1<<32-il(b)+ee|A<<ee|z,yo=le+g}else ns=1<<le|A<<ee|z,yo=g}function X(g){g.return!==null&&(M(g,1),K(g,1,0))}function B(g){for(;g===Sn;)Sn=bi[--$i],bi[$i]=null,Rd=bi[--$i],bi[$i]=null;for(;g===Vs;)Vs=xl[--nu],xl[nu]=null,yo=xl[--nu],xl[nu]=null,ns=xl[--nu],xl[nu]=null}function ne(g,b){E(Us,b),E(gm,g),E(Ir,null),g=bd(b),S(Ir),E(Ir,g)}function oe(){S(Ir),S(gm),S(Us)}function ie(g){g.memoizedState!==null&&E(Th,g);var b=Ir.current,A=Ty(b,g.type);b!==A&&(E(gm,g),E(Ir,A))}function de(g){gm.current===g&&(S(Ir),S(gm)),Th.current===g&&(S(Th),Ja?Tn._currentValue=bu:Tn._currentValue2=bu)}function be(g){var b=Error(i(418,""));throw me(H(b,g)),Oo}function ve(g,b){if(!wa)throw Error(i(175));Vy(g.stateNode,g.type,g.memoizedProps,b,g)||be(g)}function pe(g){for(ul=g.return;ul;)switch(ul.tag){case 3:case 27:rs=!0;return;case 5:case 13:rs=!1;return;default:ul=ul.return}}function _e(g){if(!wa||g!==ul)return!1;if(!Lr)return pe(g),Lr=!0,!1;var b=!1;if(Ou?g.tag!==3&&g.tag!==27&&(g.tag!==5||qb(g.type)&&!Od(g.type,g.memoizedProps))&&(b=!0):g.tag!==3&&(g.tag!==5||qb(g.type)&&!Od(g.type,g.memoizedProps))&&(b=!0),b&&xu&&be(g),pe(g),g.tag===13){if(!wa)throw Error(i(316));if(g=g.memoizedState,g=g!==null?g.dehydrated:null,!g)throw Error(i(317));xu=zb(g)}else xu=ul?Mc(g.stateNode):null;return!0}function se(){wa&&(xu=ul=null,Lr=!1)}function me(g){bo===null?bo=[g]:bo.push(g)}function ge(){for(var g=Ic,b=Up=Ic=0;b<g;){var A=Ci[b];Ci[b++]=null;var z=Ci[b];Ci[b++]=null;var ee=Ci[b];Ci[b++]=null;var le=Ci[b];if(Ci[b++]=null,z!==null&&ee!==null){var De=z.pending;De===null?ee.next=ee:(ee.next=De.next,De.next=ee),z.pending=ee}le!==0&&et(A,ee,le)}}function we(g,b,A,z){Ci[Ic++]=g,Ci[Ic++]=b,Ci[Ic++]=A,Ci[Ic++]=z,Up|=z,g.lanes|=z,g=g.alternate,g!==null&&(g.lanes|=z)}function Ne(g,b,A,z){return we(g,b,A,z),tt(g)}function Re(g,b){return we(g,null,null,b),tt(g)}function et(g,b,A){g.lanes|=A;var z=g.alternate;z!==null&&(z.lanes|=A);for(var ee=!1,le=g.return;le!==null;)le.childLanes|=A,z=le.alternate,z!==null&&(z.childLanes|=A),le.tag===22&&(g=le.stateNode,g===null||g._visibility&1||(ee=!0)),g=le,le=le.return;ee&&b!==null&&g.tag===3&&(le=g.stateNode,ee=31-il(A),le=le.hiddenUpdates,g=le[ee],g===null?le[ee]=[b]:g.push(b),b.lane=A|536870912)}function tt(g){if(50<Bh)throw Bh=0,_l=null,Error(i(185));for(var b=g.return;b!==null;)g=b,b=g.return;return g.tag===3?g.stateNode:null}function Oe(g){g!==kh&&g.next===null&&(kh===null?Ad=kh=g:kh=kh.next=g),Df=!0,vm||(vm=!0,Me(Ae))}function $e(g,b){if(!is&&Df){is=!0;do for(var A=!1,z=Ad;z!==null;){if(g!==0){var ee=z.pendingLanes;if(ee===0)var le=0;else{var De=z.suspendedLanes,Ie=z.pingedLanes;le=(1<<31-il(42|g)+1)-1,le&=ee&~(De&~Ie),le=le&201326677?le&201326677|1:le?le|2:0}le!==0&&(A=!0,Ye(z,le))}else le=lr,le=R(z,z===dr?le:0),(le&3)===0||$(z,le)||(A=!0,Ye(z,le));z=z.next}while(A);is=!1}}function Ae(){Df=vm=!1;var g=0;$f!==0&&(Sd()&&(g=$f),$f=0);for(var b=qi(),A=null,z=Ad;z!==null;){var ee=z.next,le=Ue(z,b);le===0?(z.next=null,A===null?Ad=ee:A.next=ee,ee===null&&(kh=A)):(A=z,(g!==0||(le&3)!==0)&&(Df=!0)),z=ee}$e(g)}function Ue(g,b){for(var A=g.suspendedLanes,z=g.pingedLanes,ee=g.expirationTimes,le=g.pendingLanes&-62914561;0<le;){var De=31-il(le),Ie=1<<De,We=ee[De];We===-1?((Ie&A)===0||(Ie&z)!==0)&&(ee[De]=k(Ie,b)):We<=b&&(g.expiredLanes|=Ie),le&=~Ie}if(b=dr,A=lr,A=R(g,g===b?A:0),z=g.callbackNode,A===0||g===b&&Oi===2||g.cancelPendingCommit!==null)return z!==null&&z!==null&&Ah(z),g.callbackNode=null,g.callbackPriority=0;if((A&3)===0||$(g,A)){if(b=A&-A,b===g.callbackPriority)return b;switch(z!==null&&Ah(z),W(A)){case 2:case 8:A=Ky;break;case 32:A=Hg;break;case 268435456:A=mm;break;default:A=Hg}return z=Ze.bind(null,g),A=Rh(A,z),g.callbackPriority=b,g.callbackNode=A,b}return z!==null&&z!==null&&Ah(z),g.callbackPriority=2,g.callbackNode=null,2}function Ze(g,b){var A=g.callbackNode;if(Kt()&&g.callbackNode!==A)return null;var z=lr;return z=R(g,g===dr?z:0),z===0?null:(bh(g,z,b),Ue(g,qi()),g.callbackNode!=null&&g.callbackNode===A?Ze.bind(null,g):null)}function Ye(g,b){if(Kt())return null;bh(g,b,!0)}function Me(g){pa?om(function(){(bn&6)!==0?Rh(Zg,g):g()}):Rh(Zg,g)}function ze(){return $f===0&&($f=F()),$f}function st(g,b){if(ym===null){var A=ym=[];Xg=0,jl=ze(),Td={status:"pending",value:void 0,then:function(z){A.push(z)}}}return Xg++,b.then(Ot,Ot),b}function Ot(){if(--Xg===0&&ym!==null){Td!==null&&(Td.status="fulfilled");var g=ym;ym=null,jl=0,Td=null;for(var b=0;b<g.length;b++)(0,g[b])()}}function Nt(g,b){var A=[],z={status:"pending",value:null,reason:null,then:function(ee){A.push(ee)}};return g.then(function(){z.status="fulfilled",z.value=b;for(var ee=0;ee<A.length;ee++)(0,A[ee])(b)},function(ee){for(z.status="rejected",z.reason=ee,ee=0;ee<A.length;ee++)(0,A[ee])(void 0)}),z}function gt(g){g.updateQueue={baseState:g.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function qt(g,b){g=g.updateQueue,b.updateQueue===g&&(b.updateQueue={baseState:g.baseState,firstBaseUpdate:g.firstBaseUpdate,lastBaseUpdate:g.lastBaseUpdate,shared:g.shared,callbacks:null})}function zt(g){return{lane:g,tag:0,payload:null,callback:null,next:null}}function an(g,b,A){var z=g.updateQueue;if(z===null)return null;if(z=z.shared,(bn&2)!==0){var ee=z.pending;return ee===null?b.next=b:(b.next=ee.next,ee.next=b),z.pending=b,b=tt(g),et(g,null,A),b}return we(g,z,b,A),tt(g)}function rn(g,b,A){if(b=b.updateQueue,b!==null&&(b=b.shared,(A&4194176)!==0)){var z=b.lanes;z&=g.pendingLanes,A|=z,b.lanes=A,U(g,A)}}function Fe(g,b){var A=g.updateQueue,z=g.alternate;if(z!==null&&(z=z.updateQueue,A===z)){var ee=null,le=null;if(A=A.firstBaseUpdate,A!==null){do{var De={lane:A.lane,tag:A.tag,payload:A.payload,callback:null,next:null};le===null?ee=le=De:le=le.next=De,A=A.next}while(A!==null);le===null?ee=le=b:le=le.next=b}else ee=le=b;A={baseState:z.baseState,firstBaseUpdate:ee,lastBaseUpdate:le,shared:z.shared,callbacks:z.callbacks},g.updateQueue=A;return}g=A.lastBaseUpdate,g===null?A.firstBaseUpdate=b:g.next=b,A.lastBaseUpdate=b}function ht(){if(Ph){var g=Td;if(g!==null)throw g}}function Tt(g,b,A,z){Ph=!1;var ee=g.updateQueue;Lc=!1;var le=ee.firstBaseUpdate,De=ee.lastBaseUpdate,Ie=ee.shared.pending;if(Ie!==null){ee.shared.pending=null;var We=Ie,vt=We.next;We.next=null,De===null?le=vt:De.next=vt,De=We;var kt=g.alternate;kt!==null&&(kt=kt.updateQueue,Ie=kt.lastBaseUpdate,Ie!==De&&(Ie===null?kt.firstBaseUpdate=vt:Ie.next=vt,kt.lastBaseUpdate=We))}if(le!==null){var Ht=ee.baseState;De=0,kt=vt=We=null,Ie=le;do{var Wt=Ie.lane&-536870913,Hn=Wt!==Ie.lane;if(Hn?(lr&Wt)===Wt:(z&Wt)===Wt){Wt!==0&&Wt===jl&&(Ph=!0),kt!==null&&(kt=kt.next={lane:0,tag:Ie.tag,payload:Ie.payload,callback:null,next:null});e:{var Yl=g,Em=Ie;Wt=b;var Qh=A;switch(Em.tag){case 1:if(Yl=Em.payload,typeof Yl=="function"){Ht=Yl.call(Qh,Ht,Wt);break e}Ht=Yl;break e;case 3:Yl.flags=Yl.flags&-65537|128;case 0:if(Yl=Em.payload,Wt=typeof Yl=="function"?Yl.call(Qh,Ht,Wt):Yl,Wt==null)break e;Ht=Sh({},Ht,Wt);break e;case 2:Lc=!0}}Wt=Ie.callback,Wt!==null&&(g.flags|=64,Hn&&(g.flags|=8192),Hn=ee.callbacks,Hn===null?ee.callbacks=[Wt]:Hn.push(Wt))}else Hn={lane:Wt,tag:Ie.tag,payload:Ie.payload,callback:Ie.callback,next:null},kt===null?(vt=kt=Hn,We=Ht):kt=kt.next=Hn,De|=Wt;if(Ie=Ie.next,Ie===null){if(Ie=ee.shared.pending,Ie===null)break;Hn=Ie,Ie=Hn.next,Hn.next=null,ee.lastBaseUpdate=Hn,ee.shared.pending=null}}while(!0);kt===null&&(We=Ht),ee.baseState=We,ee.firstBaseUpdate=vt,ee.lastBaseUpdate=kt,le===null&&(ee.shared.lanes=0),Do|=De,g.lanes=De,g.memoizedState=Ht}}function Qt(g,b){if(typeof g!="function")throw Error(i(191,g));g.call(b)}function un(g,b){var A=g.callbacks;if(A!==null)for(g.callbacks=null,g=0;g<A.length;g++)Qt(A[g],b)}function Ln(g,b){if(Ol(g,b))return!0;if(typeof g!="object"||g===null||typeof b!="object"||b===null)return!1;var A=Object.keys(g),z=Object.keys(b);if(A.length!==z.length)return!1;for(z=0;z<A.length;z++){var ee=A[z];if(!bm.call(b,ee)||!Ol(g[ee],b[ee]))return!1}return!0}function ln(g){return g=g.status,g==="fulfilled"||g==="rejected"}function Zn(){}function cr(g,b,A){switch(A=g[A],A===void 0?g.push(b):A!==b&&(b.then(Zn,Zn),b=A),b.status){case"fulfilled":return b.value;case"rejected":throw g=b.reason,g===Xr?Error(i(483)):g;default:if(typeof b.status=="string")b.then(Zn,Zn);else{if(g=dr,g!==null&&100<g.shellSuspendCounter)throw Error(i(482));g=b,g.status="pending",g.then(function(z){if(b.status==="pending"){var ee=b;ee.status="fulfilled",ee.value=z}},function(z){if(b.status==="pending"){var ee=b;ee.status="rejected",ee.reason=z}})}switch(b.status){case"fulfilled":return b.value;case"rejected":throw g=b.reason,g===Xr?Error(i(483)):g}throw Cf=b,Xr}}function ur(){if(Cf===null)throw Error(i(459));var g=Cf;return Cf=null,g}function Cr(g){var b=xo;return xo+=1,js===null&&(js=[]),cr(js,g,b)}function Vr(g,b){b=b.props.ref,g.ref=b!==void 0?b:null}function ke(g,b){throw b.$$typeof===wy?Error(i(525)):(g=Object.prototype.toString.call(b),Error(i(31,g==="[object Object]"?"object with keys {"+Object.keys(b).join(", ")+"}":g)))}function He(g){var b=g._init;return b(g._payload)}function nt(g){function b(ut,Ge){if(g){var ct=ut.deletions;ct===null?(ut.deletions=[Ge],ut.flags|=16):ct.push(Ge)}}function A(ut,Ge){if(!g)return null;for(;Ge!==null;)b(ut,Ge),Ge=Ge.sibling;return null}function z(ut){for(var Ge=new Map;ut!==null;)ut.key!==null?Ge.set(ut.key,ut):Ge.set(ut.index,ut),ut=ut.sibling;return Ge}function ee(ut,Ge){return ut=Ka(ut,Ge),ut.index=0,ut.sibling=null,ut}function le(ut,Ge,ct){return ut.index=ct,g?(ct=ut.alternate,ct!==null?(ct=ct.index,ct<Ge?(ut.flags|=33554434,Ge):ct):(ut.flags|=33554434,Ge)):(ut.flags|=1048576,Ge)}function De(ut){return g&&ut.alternate===null&&(ut.flags|=33554434),ut}function Ie(ut,Ge,ct,At){return Ge===null||Ge.tag!==6?(Ge=Bl(ct,ut.mode,At),Ge.return=ut,Ge):(Ge=ee(Ge,ct),Ge.return=ut,Ge)}function We(ut,Ge,ct,At){var gn=ct.type;return gn===Xo?kt(ut,Ge,ct.props.children,At,ct.key):Ge!==null&&(Ge.elementType===gn||typeof gn=="object"&&gn!==null&&gn.$$typeof===Go&&He(gn)===Ge.type)?(Ge=ee(Ge,ct.props),Vr(Ge,ct),Ge.return=ut,Ge):(Ge=Ll(ct.type,ct.key,ct.props,null,ut.mode,At),Vr(Ge,ct),Ge.return=ut,Ge)}function vt(ut,Ge,ct,At){return Ge===null||Ge.tag!==4||Ge.stateNode.containerInfo!==ct.containerInfo||Ge.stateNode.implementation!==ct.implementation?(Ge=md(ct,ut.mode,At),Ge.return=ut,Ge):(Ge=ee(Ge,ct.children||[]),Ge.return=ut,Ge)}function kt(ut,Ge,ct,At,gn){return Ge===null||Ge.tag!==7?(Ge=Fu(ct,ut.mode,At,gn),Ge.return=ut,Ge):(Ge=ee(Ge,ct),Ge.return=ut,Ge)}function Ht(ut,Ge,ct){if(typeof Ge=="string"&&Ge!==""||typeof Ge=="number"||typeof Ge=="bigint")return Ge=Bl(""+Ge,ut.mode,ct),Ge.return=ut,Ge;if(typeof Ge=="object"&&Ge!==null){switch(Ge.$$typeof){case Ef:return ct=Ll(Ge.type,Ge.key,Ge.props,null,ut.mode,ct),Vr(ct,Ge),ct.return=ut,ct;case Ls:return Ge=md(Ge,ut.mode,ct),Ge.return=ut,Ge;case Go:var At=Ge._init;return Ge=At(Ge._payload),Ht(ut,Ge,ct)}if(Ju(Ge)||a(Ge))return Ge=Fu(Ge,ut.mode,ct,null),Ge.return=ut,Ge;if(typeof Ge.then=="function")return Ht(ut,Cr(Ge),ct);if(Ge.$$typeof===Ac)return Ht(ut,mh(ut,Ge),ct);ke(ut,Ge)}return null}function Wt(ut,Ge,ct,At){var gn=Ge!==null?Ge.key:null;if(typeof ct=="string"&&ct!==""||typeof ct=="number"||typeof ct=="bigint")return gn!==null?null:Ie(ut,Ge,""+ct,At);if(typeof ct=="object"&&ct!==null){switch(ct.$$typeof){case Ef:return ct.key===gn?We(ut,Ge,ct,At):null;case Ls:return ct.key===gn?vt(ut,Ge,ct,At):null;case Go:return gn=ct._init,ct=gn(ct._payload),Wt(ut,Ge,ct,At)}if(Ju(ct)||a(ct))return gn!==null?null:kt(ut,Ge,ct,At,null);if(typeof ct.then=="function")return Wt(ut,Ge,Cr(ct),At);if(ct.$$typeof===Ac)return Wt(ut,Ge,mh(ut,ct),At);ke(ut,ct)}return null}function Hn(ut,Ge,ct,At,gn){if(typeof At=="string"&&At!==""||typeof At=="number"||typeof At=="bigint")return ut=ut.get(ct)||null,Ie(Ge,ut,""+At,gn);if(typeof At=="object"&&At!==null){switch(At.$$typeof){case Ef:return ut=ut.get(At.key===null?ct:At.key)||null,We(Ge,ut,At,gn);case Ls:return ut=ut.get(At.key===null?ct:At.key)||null,vt(Ge,ut,At,gn);case Go:var fi=At._init;return At=fi(At._payload),Hn(ut,Ge,ct,At,gn)}if(Ju(At)||a(At))return ut=ut.get(ct)||null,kt(Ge,ut,At,gn,null);if(typeof At.then=="function")return Hn(ut,Ge,ct,Cr(At),gn);if(At.$$typeof===Ac)return Hn(ut,Ge,ct,mh(Ge,At),gn);ke(Ge,At)}return null}function Yl(ut,Ge,ct,At){for(var gn=null,fi=null,kn=Ge,kr=Ge=0,Va=null;kn!==null&&kr<ct.length;kr++){kn.index>kr?(Va=kn,kn=null):Va=kn.sibling;var Er=Wt(ut,kn,ct[kr],At);if(Er===null){kn===null&&(kn=Va);break}g&&kn&&Er.alternate===null&&b(ut,kn),Ge=le(Er,Ge,kr),fi===null?gn=Er:fi.sibling=Er,fi=Er,kn=Va}if(kr===ct.length)return A(ut,kn),Lr&&M(ut,kr),gn;if(kn===null){for(;kr<ct.length;kr++)kn=Ht(ut,ct[kr],At),kn!==null&&(Ge=le(kn,Ge,kr),fi===null?gn=kn:fi.sibling=kn,fi=kn);return Lr&&M(ut,kr),gn}for(kn=z(kn);kr<ct.length;kr++)Va=Hn(kn,ut,kr,ct[kr],At),Va!==null&&(g&&Va.alternate!==null&&kn.delete(Va.key===null?kr:Va.key),Ge=le(Va,Ge,kr),fi===null?gn=Va:fi.sibling=Va,fi=Va);return g&&kn.forEach(function(Vc){return b(ut,Vc)}),Lr&&M(ut,kr),gn}function Em(ut,Ge,ct,At){if(ct==null)throw Error(i(151));for(var gn=null,fi=null,kn=Ge,kr=Ge=0,Va=null,Er=ct.next();kn!==null&&!Er.done;kr++,Er=ct.next()){kn.index>kr?(Va=kn,kn=null):Va=kn.sibling;var Vc=Wt(ut,kn,Er.value,At);if(Vc===null){kn===null&&(kn=Va);break}g&&kn&&Vc.alternate===null&&b(ut,kn),Ge=le(Vc,Ge,kr),fi===null?gn=Vc:fi.sibling=Vc,fi=Vc,kn=Va}if(Er.done)return A(ut,kn),Lr&&M(ut,kr),gn;if(kn===null){for(;!Er.done;kr++,Er=ct.next())Er=Ht(ut,Er.value,At),Er!==null&&(Ge=le(Er,Ge,kr),fi===null?gn=Er:fi.sibling=Er,fi=Er);return Lr&&M(ut,kr),gn}for(kn=z(kn);!Er.done;kr++,Er=ct.next())Er=Hn(kn,ut,kr,Er.value,At),Er!==null&&(g&&Er.alternate!==null&&kn.delete(Er.key===null?kr:Er.key),Ge=le(Er,Ge,kr),fi===null?gn=Er:fi.sibling=Er,fi=Er);return g&&kn.forEach(function(Dm){return b(ut,Dm)}),Lr&&M(ut,kr),gn}function Qh(ut,Ge,ct,At){if(typeof ct=="object"&&ct!==null&&ct.type===Xo&&ct.key===null&&(ct=ct.props.children),typeof ct=="object"&&ct!==null){switch(ct.$$typeof){case Ef:e:{for(var gn=ct.key;Ge!==null;){if(Ge.key===gn){if(gn=ct.type,gn===Xo){if(Ge.tag===7){A(ut,Ge.sibling),At=ee(Ge,ct.props.children),At.return=ut,ut=At;break e}}else if(Ge.elementType===gn||typeof gn=="object"&&gn!==null&&gn.$$typeof===Go&&He(gn)===Ge.type){A(ut,Ge.sibling),At=ee(Ge,ct.props),Vr(At,ct),At.return=ut,ut=At;break e}A(ut,Ge);break}else b(ut,Ge);Ge=Ge.sibling}ct.type===Xo?(At=Fu(ct.props.children,ut.mode,At,ct.key),At.return=ut,ut=At):(At=Ll(ct.type,ct.key,ct.props,null,ut.mode,At),Vr(At,ct),At.return=ut,ut=At)}return De(ut);case Ls:e:{for(gn=ct.key;Ge!==null;){if(Ge.key===gn)if(Ge.tag===4&&Ge.stateNode.containerInfo===ct.containerInfo&&Ge.stateNode.implementation===ct.implementation){A(ut,Ge.sibling),At=ee(Ge,ct.children||[]),At.return=ut,ut=At;break e}else{A(ut,Ge);break}else b(ut,Ge);Ge=Ge.sibling}At=md(ct,ut.mode,At),At.return=ut,ut=At}return De(ut);case Go:return gn=ct._init,ct=gn(ct._payload),Qh(ut,Ge,ct,At)}if(Ju(ct))return Yl(ut,Ge,ct,At);if(a(ct)){if(gn=a(ct),typeof gn!="function")throw Error(i(150));return ct=gn.call(ct),Em(ut,Ge,ct,At)}if(typeof ct.then=="function")return Qh(ut,Ge,Cr(ct),At);if(ct.$$typeof===Ac)return Qh(ut,Ge,mh(ut,ct),At);ke(ut,ct)}return typeof ct=="string"&&ct!==""||typeof ct=="number"||typeof ct=="bigint"?(ct=""+ct,Ge!==null&&Ge.tag===6?(A(ut,Ge.sibling),At=ee(Ge,ct),At.return=ut,ut=At):(A(ut,Ge),At=Bl(ct,ut.mode,At),At.return=ut,ut=At),De(ut)):A(ut,Ge)}return function(ut,Ge,ct,At){try{xo=0;var gn=Qh(ut,Ge,ct,At);return js=null,gn}catch(kn){if(kn===Xr)throw kn;var fi=n(29,kn,null,ut.mode);return fi.lanes=At,fi.return=ut,fi}finally{}}}function dt(g,b){g=Hs,E(iu,g),E(ru,b),Hs=g|b.baseLanes}function $t(){E(iu,Hs),E(ru,ru.current)}function Ut(){Hs=iu.current,S(ru),S(iu)}function Zt(g){var b=g.alternate;E(za,za.current&1),E(So,g),_o===null&&(b===null||ru.current!==null||b.memoizedState!==null)&&(_o=g)}function Lt(g){if(g.tag===22){if(E(za,za.current),E(So,g),_o===null){var b=g.alternate;b!==null&&b.memoizedState!==null&&(_o=g)}}else Vt()}function Vt(){E(za,za.current),E(So,So.current)}function tn(g){S(So),_o===g&&(_o=null),S(za)}function nn(g){for(var b=g;b!==null;){if(b.tag===13){var A=b.memoizedState;if(A!==null&&(A=A.dehydrated,A===null||Ig(A)||_d(A)))return b}else if(b.tag===19&&b.memoizedProps.revealOrder!==void 0){if((b.flags&128)!==0)return b}else if(b.child!==null){b.child.return=b,b=b.child;continue}if(b===g)break;for(;b.sibling===null;){if(b.return===null||b.return===g)return null;b=b.return}b.sibling.return=b.return,b=b.sibling}return null}function Rt(){throw Error(i(321))}function sn(g,b){if(b===null)return!1;for(var A=0;A<b.length&&A<g.length;A++)if(!Ol(g[A],b[A]))return!1;return!0}function gr(g,b,A,z,ee,le){return Bc=le,er=b,b.memoizedState=null,b.updateQueue=null,b.lanes=0,_n.H=g===null||g.memoizedState===null?qa:ll,wf=!1,le=A(z,ee),wf=!1,Vi&&(le=Da(b,A,z,ee)),Pi(g),le}function Pi(g){_n.H=Rr;var b=Yr!==null&&Yr.next!==null;if(Bc=0,Aa=Yr=er=null,as=!1,ma=0,jp=null,b)throw Error(i(300));g===null||Ta||(g=g.dependencies,g!==null&&Uo(g)&&(Ta=!0))}function Da(g,b,A,z){er=g;var ee=0;do{if(Vi&&(jp=null),ma=0,Vi=!1,25<=ee)throw Error(i(301));if(ee+=1,Aa=Yr=null,g.updateQueue!=null){var le=g.updateQueue;le.lastEffect=null,le.events=null,le.stores=null,le.memoCache!=null&&(le.memoCache.index=0)}_n.H=Pd,le=b(A,z)}while(Vi);return le}function mi(){var g=_n.H,b=g.useState()[0];return b=typeof b.then=="function"?ca(b):b,g=g.useState()[0],(Yr!==null?Yr.memoizedState:null)!==g&&(er.flags|=1024),b}function Ur(){var g=Om!==0;return Om=0,g}function wu(g,b,A){b.updateQueue=g.updateQueue,b.flags&=-2053,g.lanes&=~A}function Al(g){if(as){for(g=g.memoizedState;g!==null;){var b=g.queue;b!==null&&(b.pending=null),g=g.next}as=!1}Bc=0,Aa=Yr=er=null,Vi=!1,ma=Om=0,jp=null}function Hr(){var g={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Aa===null?er.memoizedState=Aa=g:Aa=Aa.next=g,Aa}function Pt(){if(Yr===null){var g=er.alternate;g=g!==null?g.memoizedState:null}else g=Yr.next;var b=Aa===null?er.memoizedState:Aa.next;if(b!==null)Aa=b,Yr=g;else{if(g===null)throw er.alternate===null?Error(i(467)):Error(i(310));Yr=g,g={memoizedState:Yr.memoizedState,baseState:Yr.baseState,baseQueue:Yr.baseQueue,queue:Yr.queue,next:null},Aa===null?er.memoizedState=Aa=g:Aa=Aa.next=g}return Aa}function ca(g){var b=ma;return ma+=1,jp===null&&(jp=[]),g=cr(jp,g,b),b=er,(Aa===null?b.memoizedState:Aa.next)===null&&(b=b.alternate,_n.H=b===null||b.memoizedState===null?qa:ll),g}function Wi(g){if(g!==null&&typeof g=="object"){if(typeof g.then=="function")return ca(g);if(g.$$typeof===Ac)return Ba(g)}throw Error(i(438,String(g)))}function ti(g){var b=null,A=er.updateQueue;if(A!==null&&(b=A.memoCache),b==null){var z=er.alternate;z!==null&&(z=z.updateQueue,z!==null&&(z=z.memoCache,z!=null&&(b={data:z.data.map(function(ee){return ee.slice()}),index:0})))}if(b==null&&(b={data:[],index:0}),A===null&&(A=xm(),er.updateQueue=A),A.memoCache=b,A=b.data[b.index],A===void 0)for(A=b.data[b.index]=Array(g),z=0;z<g;z++)A[z]=Lb;return b.index++,A}function Ru(g,b){return typeof b=="function"?b(g):b}function uo(g){var b=Pt();return Xn(b,Yr,g)}function Xn(g,b,A){var z=g.queue;if(z===null)throw Error(i(311));z.lastRenderedReducer=A;var ee=g.baseQueue,le=z.pending;if(le!==null){if(ee!==null){var De=ee.next;ee.next=le.next,le.next=De}b.baseQueue=ee=le,z.pending=null}if(le=g.baseState,ee===null)g.memoizedState=le;else{b=ee.next;var Ie=De=null,We=null,vt=b,kt=!1;do{var Ht=vt.lane&-536870913;if(Ht!==vt.lane?(lr&Ht)===Ht:(Bc&Ht)===Ht){var Wt=vt.revertLane;if(Wt===0)We!==null&&(We=We.next={lane:0,revertLane:0,action:vt.action,hasEagerState:vt.hasEagerState,eagerState:vt.eagerState,next:null}),Ht===jl&&(kt=!0);else if((Bc&Wt)===Wt){vt=vt.next,Wt===jl&&(kt=!0);continue}else Ht={lane:0,revertLane:vt.revertLane,action:vt.action,hasEagerState:vt.hasEagerState,eagerState:vt.eagerState,next:null},We===null?(Ie=We=Ht,De=le):We=We.next=Ht,er.lanes|=Wt,Do|=Wt;Ht=vt.action,wf&&A(le,Ht),le=vt.hasEagerState?vt.eagerState:A(le,Ht)}else Wt={lane:Ht,revertLane:vt.revertLane,action:vt.action,hasEagerState:vt.hasEagerState,eagerState:vt.eagerState,next:null},We===null?(Ie=We=Wt,De=le):We=We.next=Wt,er.lanes|=Ht,Do|=Ht;vt=vt.next}while(vt!==null&&vt!==b);if(We===null?De=le:We.next=Ie,!Ol(le,g.memoizedState)&&(Ta=!0,kt&&(A=Td,A!==null)))throw A;g.memoizedState=le,g.baseState=De,g.baseQueue=We,z.lastRenderedState=le}return ee===null&&(z.lanes=0),[g.memoizedState,z.dispatch]}function gi(g){var b=Pt(),A=b.queue;if(A===null)throw Error(i(311));A.lastRenderedReducer=g;var z=A.dispatch,ee=A.pending,le=b.memoizedState;if(ee!==null){A.pending=null;var De=ee=ee.next;do le=g(le,De.action),De=De.next;while(De!==ee);Ol(le,b.memoizedState)||(Ta=!0),b.memoizedState=le,b.baseQueue===null&&(b.baseState=le),A.lastRenderedState=le}return[le,z]}function xs(g,b,A){var z=er,ee=Pt(),le=Lr;if(le){if(A===void 0)throw Error(i(407));A=A()}else A=b();var De=!Ol((Yr||ee).memoizedState,A);if(De&&(ee.memoizedState=A,Ta=!0),ee=ee.queue,gf(_s.bind(null,z,ee,g),[g]),ee.getSnapshot!==b||De||Aa!==null&&Aa.memoizedState.tag&1){if(z.flags|=2048,Bo(9,ni.bind(null,z,ee,A,b),{destroy:void 0},null),dr===null)throw Error(i(349));le||(Bc&60)!==0||Ss(z,b,A)}return A}function Ss(g,b,A){g.flags|=16384,g={getSnapshot:b,value:A},b=er.updateQueue,b===null?(b=xm(),er.updateQueue=b,b.stores=[g]):(A=b.stores,A===null?b.stores=[g]:A.push(g))}function ni(g,b,A,z){b.value=A,b.getSnapshot=z,$a(b)&&pc(g)}function _s(g,b,A){return A(function(){$a(b)&&pc(g)})}function $a(g){var b=g.getSnapshot;g=g.value;try{var A=b();return!Ol(g,A)}catch{return!0}}function pc(g){var b=Re(g,2);b!==null&&mu(b,g,2)}function Fr(g){var b=Hr();if(typeof g=="function"){var A=g;if(g=A(),wf){J(!0);try{A()}finally{J(!1)}}}return b.memoizedState=b.baseState=g,b.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ru,lastRenderedState:g},b}function Ji(g,b,A,z){return g.baseState=A,Xn(g,Yr,typeof z=="function"?z:Ru)}function Io(g,b,A,z,ee){if(bc(g))throw Error(i(485));if(g=b.action,g!==null){var le={payload:ee,action:g,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(De){le.listeners.push(De)}};_n.T!==null?A(!0):le.isTransition=!1,z(le),A=b.pending,A===null?(le.next=b.pending=le,Op(b,le)):(le.next=A.next,b.pending=A.next=le)}}function Op(g,b){var A=b.action,z=b.payload,ee=g.state;if(b.isTransition){var le=_n.T,De={};_n.T=De;try{var Ie=A(ee,z),We=_n.S;We!==null&&We(De,Ie),mf(g,b,Ie)}catch(vt){Tl(g,b,vt)}finally{_n.T=le}}else try{le=A(ee,z),mf(g,b,le)}catch(vt){Tl(g,b,vt)}}function mf(g,b,A){A!==null&&typeof A=="object"&&typeof A.then=="function"?A.then(function(z){Lo(g,b,z)},function(z){return Tl(g,b,z)}):Lo(g,b,A)}function Lo(g,b,A){b.status="fulfilled",b.value=A,oh(b),g.state=A,b=g.pending,b!==null&&(A=b.next,A===b?g.pending=null:(A=A.next,b.next=A,Op(g,A)))}function Tl(g,b,A){var z=g.pending;if(g.pending=null,z!==null){z=z.next;do b.status="rejected",b.reason=A,oh(b),b=b.next;while(b!==z)}g.action=null}function oh(g){g=g.listeners;for(var b=0;b<g.length;b++)(0,g[b])()}function Ha(g,b){return b}function td(g,b){if(Lr){var A=dr.formState;if(A!==null){e:{var z=er;if(Lr){if(xu){var ee=By(xu,rs);if(ee){xu=Mc(ee),z=ql(ee);break e}}be(z)}z=!1}z&&(b=A[0])}}A=Hr(),A.memoizedState=A.baseState=b,z={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ha,lastRenderedState:b},A.queue=z,A=dh.bind(null,er,z),z.dispatch=A,z=Fr(!1);var le=Bn.bind(null,er,!1,z.queue);return z=Hr(),ee={state:b,dispatch:null,action:g,pending:null},z.queue=ee,A=Io.bind(null,er,ee,le,A),ee.dispatch=A,z.memoizedState=g,[b,A,!1]}function Es(g){var b=Pt();return nd(b,Yr,g)}function nd(g,b,A){b=Xn(g,b,Ha)[0],g=uo(Ru)[0],b=typeof b=="object"&&b!==null&&typeof b.then=="function"?ca(b):b;var z=Pt(),ee=z.queue,le=ee.dispatch;return A!==z.memoizedState&&(er.flags|=2048,Bo(9,mc.bind(null,ee,A),{destroy:void 0},null)),[b,le,g]}function mc(g,b){g.action=b}function gc(g){var b=Pt(),A=Yr;if(A!==null)return nd(b,A,g);Pt(),b=b.memoizedState,A=Pt();var z=A.queue.dispatch;return A.memoizedState=g,[b,z,!1]}function Bo(g,b,A,z){return g={tag:g,create:b,inst:A,deps:z,next:null},b=er.updateQueue,b===null&&(b=xm(),er.updateQueue=b),A=b.lastEffect,A===null?b.lastEffect=g.next=g:(z=A.next,A.next=g,g.next=z,b.lastEffect=g),g}function Au(){return Pt().memoizedState}function Ds(g,b,A,z){var ee=Hr();er.flags|=g,ee.memoizedState=Bo(1|b,A,{destroy:void 0},z===void 0?null:z)}function $s(g,b,A,z){var ee=Pt();z=z===void 0?null:z;var le=ee.memoizedState.inst;Yr!==null&&z!==null&&sn(z,Yr.memoizedState.deps)?ee.memoizedState=Bo(b,A,le,z):(er.flags|=g,ee.memoizedState=Bo(1|b,A,le,z))}function Z0(g,b){Ds(8390656,8,g,b)}function gf(g,b){$s(2048,8,g,b)}function H0(g,b){return $s(4,2,g,b)}function xp(g,b){return $s(4,4,g,b)}function vf(g,b){if(typeof b=="function"){g=g();var A=b(g);return function(){typeof A=="function"?A():b(null)}}if(b!=null)return g=g(),b.current=g,function(){b.current=null}}function lo(g,b,A){A=A!=null?A.concat([g]):null,$s(4,4,vf.bind(null,b,g),A)}function sh(){}function ch(g,b){var A=Pt();b=b===void 0?null:b;var z=A.memoizedState;return b!==null&&sn(b,z[1])?z[0]:(A.memoizedState=[g,b],g)}function Cs(g,b){var A=Pt();b=b===void 0?null:b;var z=A.memoizedState;if(b!==null&&sn(b,z[1]))return z[0];if(z=g(),wf){J(!0);try{g()}finally{J(!1)}}return A.memoizedState=[z,b],z}function vc(g,b,A){return A===void 0||(Bc&1073741824)!==0?g.memoizedState=b:(g.memoizedState=A,g=Wu(),er.lanes|=g,Do|=g,A)}function X0(g,b,A,z){return Ol(A,b)?A:ru.current!==null?(g=vc(g,A,z),Ol(g,b)||(Ta=!0),g):(Bc&42)===0?(Ta=!0,g.memoizedState=A):(g=Wu(),er.lanes|=g,Do|=g,b)}function Sp(g,b,A,z,ee){var le=tu();yu(le!==0&&8>le?le:8);var De=_n.T,Ie={};_n.T=Ie,Bn(g,!1,b,A);try{var We=ee(),vt=_n.S;if(vt!==null&&vt(Ie,We),We!==null&&typeof We=="object"&&typeof We.then=="function"){var kt=Nt(We,z);wr(g,b,kt,Xi(g))}else wr(g,b,z,Xi(g))}catch(Ht){wr(g,b,{then:function(){},status:"rejected",reason:Ht},Xi())}finally{yu(le),_n.T=De}}function _p(g){var b=g.memoizedState;if(b!==null)return b;b={memoizedState:bu,baseState:bu,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ru,lastRenderedState:bu},next:null};var A={};return b.next={memoizedState:A,baseState:A,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ru,lastRenderedState:A},next:null},g.memoizedState=b,g=g.alternate,g!==null&&(g.memoizedState=b),b}function ws(){return Ba(Tn)}function Qo(){return Pt().memoizedState}function Ep(){return Pt().memoizedState}function fh(g){for(var b=g.return;b!==null;){switch(b.tag){case 24:case 3:var A=Xi();g=zt(A);var z=an(b,g,A);z!==null&&(mu(z,b,A),rn(z,b,A)),b={cache:sd()},g.payload=b;return}b=b.return}}function yc(g,b,A){var z=Xi();A={lane:z,revertLane:0,action:A,hasEagerState:!1,eagerState:null,next:null},bc(g)?zo(b,A):(A=Ne(g,b,A,z),A!==null&&(mu(A,g,z),Oc(A,b,z)))}function dh(g,b,A){var z=Xi();wr(g,b,A,z)}function wr(g,b,A,z){var ee={lane:z,revertLane:0,action:A,hasEagerState:!1,eagerState:null,next:null};if(bc(g))zo(b,ee);else{var le=g.alternate;if(g.lanes===0&&(le===null||le.lanes===0)&&(le=b.lastRenderedReducer,le!==null))try{var De=b.lastRenderedState,Ie=le(De,A);if(ee.hasEagerState=!0,ee.eagerState=Ie,Ol(Ie,De))return we(g,b,ee,0),dr===null&&ge(),!1}catch{}finally{}if(A=Ne(g,b,ee,z),A!==null)return mu(A,g,z),Oc(A,b,z),!0}return!1}function Bn(g,b,A,z){if(z={lane:2,revertLane:ze(),action:z,hasEagerState:!1,eagerState:null,next:null},bc(g)){if(b)throw Error(i(479))}else b=Ne(g,A,z,2),b!==null&&mu(b,g,2)}function bc(g){var b=g.alternate;return g===er||b!==null&&b===er}function zo(g,b){Vi=as=!0;var A=g.pending;A===null?b.next=b:(b.next=A.next,A.next=b),g.pending=b}function Oc(g,b,A){if((A&4194176)!==0){var z=b.lanes;z&=g.pendingLanes,A|=z,b.lanes=A,U(g,A)}}function ea(g,b,A,z){b=g.memoizedState,A=A(z,b),A=A==null?b:Sh({},b,A),g.memoizedState=A,g.lanes===0&&(g.updateQueue.baseState=A)}function Rs(g,b,A,z,ee,le,De){return g=g.stateNode,typeof g.shouldComponentUpdate=="function"?g.shouldComponentUpdate(z,le,De):b.prototype&&b.prototype.isPureReactComponent?!Ln(A,z)||!Ln(ee,le):!0}function rd(g,b,A,z){g=b.state,typeof b.componentWillReceiveProps=="function"&&b.componentWillReceiveProps(A,z),typeof b.UNSAFE_componentWillReceiveProps=="function"&&b.UNSAFE_componentWillReceiveProps(A,z),b.state!==g&&Sm.enqueueReplaceState(b,b.state,null)}function kl(g,b){var A=b;if("ref"in b){A={};for(var z in b)z!=="ref"&&(A[z]=b[z])}if(g=g.defaultProps){A===b&&(A=Sh({},A));for(var ee in g)A[ee]===void 0&&(A[ee]=g[ee])}return A}function id(g,b){try{var A=g.onUncaughtError;A(b.value,{componentStack:b.stack})}catch(z){setTimeout(function(){throw z})}}function ta(g,b,A){try{var z=g.onCaughtError;z(A.value,{componentStack:A.stack,errorBoundary:b.tag===1?b.stateNode:null})}catch(ee){setTimeout(function(){throw ee})}}function As(g,b,A){return A=zt(A),A.tag=3,A.payload={element:null},A.callback=function(){id(g,b)},A}function Pl(g){return g=zt(g),g.tag=3,g}function ad(g,b,A,z){var ee=A.type.getDerivedStateFromError;if(typeof ee=="function"){var le=z.value;g.payload=function(){return ee(le)},g.callback=function(){ta(b,A,z)}}var De=A.stateNode;De!==null&&typeof De.componentDidCatch=="function"&&(g.callback=function(){ta(b,A,z),typeof ee!="function"&&($o===null?$o=new Set([this]):$o.add(this));var Ie=z.stack;this.componentDidCatch(z.value,{componentStack:Ie!==null?Ie:""})})}function Dp(g,b,A,z,ee){if(A.flags|=32768,z!==null&&typeof z=="object"&&typeof z.then=="function"){if(b=A.alternate,b!==null&&Sc(b,A,ee,!0),A=So.current,A!==null){switch(A.tag){case 13:return _o===null?pn():A.alternate===null&&Tr===0&&(Tr=3),A.flags&=-257,A.flags|=65536,A.lanes=ee,z===kd?A.flags|=16384:(b=A.updateQueue,b===null?A.updateQueue=new Set([z]):b.add(z),vn(g,z,ee)),!1;case 22:return A.flags|=65536,z===kd?A.flags|=16384:(b=A.updateQueue,b===null?(b={transitions:null,markerInstances:null,retryQueue:new Set([z])},A.updateQueue=b):(A=b.retryQueue,A===null?b.retryQueue=new Set([z]):A.add(z)),vn(g,z,ee)),!1}throw Error(i(435,A.tag))}return vn(g,z,ee),pn(),!1}if(Lr)return b=So.current,b!==null?((b.flags&65536)===0&&(b.flags|=256),b.flags|=65536,b.lanes=ee,z!==Oo&&(g=Error(i(422),{cause:z}),me(H(g,A)))):(z!==Oo&&(b=Error(i(423),{cause:z}),me(H(b,A))),g=g.current.alternate,g.flags|=65536,ee&=-ee,g.lanes|=ee,z=H(z,A),ee=As(g.stateNode,z,ee),Fe(g,ee),Tr!==4&&(Tr=2)),!1;var le=Error(i(520),{cause:z});if(le=H(le,A),Hp===null?Hp=[le]:Hp.push(le),Tr!==4&&(Tr=2),b===null)return!0;z=H(z,A),A=b;do{switch(A.tag){case 3:return A.flags|=65536,g=ee&-ee,A.lanes|=g,g=As(A.stateNode,z,g),Fe(A,g),!1;case 1:if(b=A.type,le=A.stateNode,(A.flags&128)===0&&(typeof b.getDerivedStateFromError=="function"||le!==null&&typeof le.componentDidCatch=="function"&&($o===null||!$o.has(le))))return A.flags|=65536,ee&=-ee,A.lanes|=ee,ee=Pl(ee),ad(ee,g,A,z),Fe(A,ee),!1}A=A.return}while(A!==null);return!1}function ri(g,b,A,z){b.child=g===null?Gg(b,null,A,z):Zs(b,g.child,A,z)}function Y0(g,b,A,z,ee){A=A.render;var le=b.ref;if("ref"in z){var De={};for(var Ie in z)Ie!=="ref"&&(De[Ie]=z[Ie])}else De=z;return Ps(b),z=gr(g,b,A,De,le,ee),Ie=Ur(),g!==null&&!Ta?(wu(g,b,ee),ks(g,b,ee)):(Lr&&Ie&&X(b),b.flags|=1,ri(g,b,z,ee),b.child)}function G0(g,b,A,z,ee){if(g===null){var le=A.type;return typeof le=="function"&&!zn(le)&&le.defaultProps===void 0&&A.compare===null?(b.tag=15,b.type=le,ud(g,b,le,z,ee)):(g=Ll(A.type,null,z,b,b.mode,ee),g.ref=b.ref,g.return=b,b.child=g)}if(le=g.child,!Ap(g,ee)){var De=le.memoizedProps;if(A=A.compare,A=A!==null?A:Ln,A(De,z)&&g.ref===b.ref)return ks(g,b,ee)}return b.flags|=1,g=Ka(le,z),g.ref=b.ref,g.return=b,b.child=g}function ud(g,b,A,z,ee){if(g!==null){var le=g.memoizedProps;if(Ln(le,z)&&g.ref===b.ref)if(Ta=!1,b.pendingProps=z=le,Ap(g,ee))(g.flags&131072)!==0&&(Ta=!0);else return b.lanes=g.lanes,ks(g,b,ee)}return fa(g,b,A,z,ee)}function K0(g,b,A){var z=b.pendingProps,ee=z.children,le=(b.stateNode._pendingVisibility&2)!==0,De=g!==null?g.memoizedState:null;if(ld(g,b),z.mode==="hidden"||le){if((b.flags&128)!==0){if(z=De!==null?De.baseLanes|A:A,g!==null){for(ee=b.child=g.child,le=0;ee!==null;)le=le|ee.lanes|ee.childLanes,ee=ee.sibling;b.childLanes=le&~z}else b.childLanes=0,b.child=null;return xc(g,b,z,A)}if((A&536870912)!==0)b.memoizedState={baseLanes:0,cachePool:null},g!==null&&fu(b,De!==null?De.cachePool:null),De!==null?dt(b,De):$t(),Lt(b);else return b.lanes=b.childLanes=536870912,xc(g,b,De!==null?De.baseLanes|A:A,A)}else De!==null?(fu(b,De.cachePool),dt(b,De),Vt(),b.memoizedState=null):(g!==null&&fu(b,null),$t(),Vt());return ri(g,b,ee,A),b.child}function xc(g,b,A,z){var ee=Ms();return ee=ee===null?null:{parent:Ja?Gr._currentValue:Gr._currentValue2,pool:ee},b.memoizedState={baseLanes:A,cachePool:ee},g!==null&&fu(b,null),$t(),Lt(b),g!==null&&Sc(g,b,z,!0),null}function ld(g,b){var A=b.ref;if(A===null)g!==null&&g.ref!==null&&(b.flags|=2097664);else{if(typeof A!="function"&&typeof A!="object")throw Error(i(284));(g===null||g.ref!==A)&&(b.flags|=2097664)}}function fa(g,b,A,z,ee){return Ps(b),A=gr(g,b,A,z,void 0,ee),z=Ur(),g!==null&&!Ta?(wu(g,b,ee),ks(g,b,ee)):(Lr&&z&&X(b),b.flags|=1,ri(g,b,A,ee),b.child)}function od(g,b,A,z,ee,le){return Ps(b),b.updateQueue=null,A=Da(b,z,A,ee),Pi(g),z=Ur(),g!==null&&!Ta?(wu(g,b,le),ks(g,b,le)):(Lr&&z&&X(b),b.flags|=1,ri(g,b,A,le),b.child)}function La(g,b,A,z,ee){if(Ps(b),b.stateNode===null){var le=Nc,De=A.contextType;typeof De=="object"&&De!==null&&(le=Ba(De)),le=new A(z,le),b.memoizedState=le.state!==null&&le.state!==void 0?le.state:null,le.updater=Sm,b.stateNode=le,le._reactInternals=b,le=b.stateNode,le.props=z,le.state=b.memoizedState,le.refs={},gt(b),De=A.contextType,le.context=typeof De=="object"&&De!==null?Ba(De):Nc,le.state=b.memoizedState,De=A.getDerivedStateFromProps,typeof De=="function"&&(ea(b,A,De,z),le.state=b.memoizedState),typeof A.getDerivedStateFromProps=="function"||typeof le.getSnapshotBeforeUpdate=="function"||typeof le.UNSAFE_componentWillMount!="function"&&typeof le.componentWillMount!="function"||(De=le.state,typeof le.componentWillMount=="function"&&le.componentWillMount(),typeof le.UNSAFE_componentWillMount=="function"&&le.UNSAFE_componentWillMount(),De!==le.state&&Sm.enqueueReplaceState(le,le.state,null),Tt(b,z,le,ee),ht(),le.state=b.memoizedState),typeof le.componentDidMount=="function"&&(b.flags|=4194308),z=!0}else if(g===null){le=b.stateNode;var Ie=b.memoizedProps,We=kl(A,Ie);le.props=We;var vt=le.context,kt=A.contextType;De=Nc,typeof kt=="object"&&kt!==null&&(De=Ba(kt));var Ht=A.getDerivedStateFromProps;kt=typeof Ht=="function"||typeof le.getSnapshotBeforeUpdate=="function",Ie=b.pendingProps!==Ie,kt||typeof le.UNSAFE_componentWillReceiveProps!="function"&&typeof le.componentWillReceiveProps!="function"||(Ie||vt!==De)&&rd(b,le,z,De),Lc=!1;var Wt=b.memoizedState;le.state=Wt,Tt(b,z,le,ee),ht(),vt=b.memoizedState,Ie||Wt!==vt||Lc?(typeof Ht=="function"&&(ea(b,A,Ht,z),vt=b.memoizedState),(We=Lc||Rs(b,A,We,z,Wt,vt,De))?(kt||typeof le.UNSAFE_componentWillMount!="function"&&typeof le.componentWillMount!="function"||(typeof le.componentWillMount=="function"&&le.componentWillMount(),typeof le.UNSAFE_componentWillMount=="function"&&le.UNSAFE_componentWillMount()),typeof le.componentDidMount=="function"&&(b.flags|=4194308)):(typeof le.componentDidMount=="function"&&(b.flags|=4194308),b.memoizedProps=z,b.memoizedState=vt),le.props=z,le.state=vt,le.context=De,z=We):(typeof le.componentDidMount=="function"&&(b.flags|=4194308),z=!1)}else{le=b.stateNode,qt(g,b),De=b.memoizedProps,kt=kl(A,De),le.props=kt,Ht=b.pendingProps,Wt=le.context,vt=A.contextType,We=Nc,typeof vt=="object"&&vt!==null&&(We=Ba(vt)),Ie=A.getDerivedStateFromProps,(vt=typeof Ie=="function"||typeof le.getSnapshotBeforeUpdate=="function")||typeof le.UNSAFE_componentWillReceiveProps!="function"&&typeof le.componentWillReceiveProps!="function"||(De!==Ht||Wt!==We)&&rd(b,le,z,We),Lc=!1,Wt=b.memoizedState,le.state=Wt,Tt(b,z,le,ee),ht();var Hn=b.memoizedState;De!==Ht||Wt!==Hn||Lc||g!==null&&g.dependencies!==null&&Uo(g.dependencies)?(typeof Ie=="function"&&(ea(b,A,Ie,z),Hn=b.memoizedState),(kt=Lc||Rs(b,A,kt,z,Wt,Hn,We)||g!==null&&g.dependencies!==null&&Uo(g.dependencies))?(vt||typeof le.UNSAFE_componentWillUpdate!="function"&&typeof le.componentWillUpdate!="function"||(typeof le.componentWillUpdate=="function"&&le.componentWillUpdate(z,Hn,We),typeof le.UNSAFE_componentWillUpdate=="function"&&le.UNSAFE_componentWillUpdate(z,Hn,We)),typeof le.componentDidUpdate=="function"&&(b.flags|=4),typeof le.getSnapshotBeforeUpdate=="function"&&(b.flags|=1024)):(typeof le.componentDidUpdate!="function"||De===g.memoizedProps&&Wt===g.memoizedState||(b.flags|=4),typeof le.getSnapshotBeforeUpdate!="function"||De===g.memoizedProps&&Wt===g.memoizedState||(b.flags|=1024),b.memoizedProps=z,b.memoizedState=Hn),le.props=z,le.state=Hn,le.context=We,z=kt):(typeof le.componentDidUpdate!="function"||De===g.memoizedProps&&Wt===g.memoizedState||(b.flags|=4),typeof le.getSnapshotBeforeUpdate!="function"||De===g.memoizedProps&&Wt===g.memoizedState||(b.flags|=1024),z=!1)}return le=z,ld(g,b),z=(b.flags&128)!==0,le||z?(le=b.stateNode,A=z&&typeof A.getDerivedStateFromError!="function"?null:le.render(),b.flags|=1,g!==null&&z?(b.child=Zs(b,g.child,null,ee),b.child=Zs(b,null,A,ee)):ri(g,b,A,ee),b.memoizedState=le.state,g=b.child):g=ks(g,b,ee),g}function _g(g,b,A,z){return se(),b.flags|=256,ri(g,b,A,z),b.child}function $p(g){return{baseLanes:g,cachePool:Tp()}}function qo(g,b,A){return g=g!==null?g.childLanes&~A:0,b&&(g|=Xl),g}function hh(g,b,A){var z=b.pendingProps,ee=!1,le=(b.flags&128)!==0,De;if((De=le)||(De=g!==null&&g.memoizedState===null?!1:(za.current&2)!==0),De&&(ee=!0,b.flags&=-129),De=(b.flags&32)!==0,b.flags&=-33,g===null){if(Lr){if(ee?Zt(b):Vt(),Lr){var Ie=xu,We;(We=Ie)&&(Ie=qy(Ie,rs),Ie!==null?(b.memoizedState={dehydrated:Ie,treeContext:Vs!==null?{id:ns,overflow:yo}:null,retryLane:536870912},We=n(18,null,null,0),We.stateNode=Ie,We.return=b,b.child=We,ul=b,xu=null,We=!0):We=!1),We||be(b)}if(Ie=b.memoizedState,Ie!==null&&(Ie=Ie.dehydrated,Ie!==null))return _d(Ie)?b.lanes=16:b.lanes=536870912,null;tn(b)}return Ie=z.children,z=z.fallback,ee?(Vt(),ee=b.mode,Ie=vi({mode:"hidden",children:Ie},ee),z=Fu(z,ee,A,null),Ie.return=b,z.return=b,Ie.sibling=z,b.child=Ie,ee=b.child,ee.memoizedState=$p(A),ee.childLanes=qo(g,De,A),b.memoizedState=ol,z):(Zt(b),Ts(b,Ie))}if(We=g.memoizedState,We!==null&&(Ie=We.dehydrated,Ie!==null)){if(le)b.flags&256?(Zt(b),b.flags&=-257,b=Vo(g,b,A)):b.memoizedState!==null?(Vt(),b.child=g.child,b.flags|=128,b=null):(Vt(),ee=z.fallback,Ie=b.mode,z=vi({mode:"visible",children:z.children},Ie),ee=Fu(ee,Ie,A,null),ee.flags|=2,z.return=b,ee.return=b,z.sibling=ee,b.child=z,Zs(b,g.child,null,A),z=b.child,z.memoizedState=$p(A),z.childLanes=qo(g,De,A),b.memoizedState=ol,b=ee);else if(Zt(b),_d(Ie))De=Lg(Ie).digest,z=Error(i(419)),z.stack="",z.digest=De,me({value:z,source:null,stack:null}),b=Vo(g,b,A);else if(Ta||Sc(g,b,A,!1),De=(A&g.childLanes)!==0,Ta||De){if(De=dr,De!==null){if(z=A&-A,(z&42)!==0)z=1;else switch(z){case 2:z=1;break;case 8:z=4;break;case 32:z=16;break;case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:z=64;break;case 268435456:z=134217728;break;default:z=0}if(z=(z&(De.suspendedLanes|A))!==0?0:z,z!==0&&z!==We.retryLane)throw We.retryLane=z,Re(g,z),mu(De,g,z),Xb}Ig(Ie)||pn(),b=Vo(g,b,A)}else Ig(Ie)?(b.flags|=128,b.child=g.child,b=Se.bind(null,g),Qb(Ie,b),b=null):(g=We.treeContext,wa&&(xu=cm(Ie),ul=b,Lr=!0,bo=null,rs=!1,g!==null&&(xl[nu++]=ns,xl[nu++]=yo,xl[nu++]=Vs,ns=g.id,yo=g.overflow,Vs=b)),b=Ts(b,z.children),b.flags|=4096);return b}return ee?(Vt(),ee=z.fallback,Ie=b.mode,We=g.child,le=We.sibling,z=Ka(We,{mode:"hidden",children:z.children}),z.subtreeFlags=We.subtreeFlags&31457280,le!==null?ee=Ka(le,ee):(ee=Fu(ee,Ie,A,null),ee.flags|=2),ee.return=b,z.return=b,z.sibling=ee,b.child=z,z=ee,ee=b.child,Ie=g.child.memoizedState,Ie===null?Ie=$p(A):(We=Ie.cachePool,We!==null?(le=Ja?Gr._currentValue:Gr._currentValue2,We=We.parent!==le?{parent:le,pool:le}:We):We=Tp(),Ie={baseLanes:Ie.baseLanes|A,cachePool:We}),ee.memoizedState=Ie,ee.childLanes=qo(g,De,A),b.memoizedState=ol,z):(Zt(b),A=g.child,g=A.sibling,A=Ka(A,{mode:"visible",children:z.children}),A.return=b,A.sibling=null,g!==null&&(De=b.deletions,De===null?(b.deletions=[g],b.flags|=16):De.push(g)),b.child=A,b.memoizedState=null,A)}function Ts(g,b){return b=vi({mode:"visible",children:b},g.mode),b.return=g,g.child=b}function vi(g,b){return Rc(g,b,0,null)}function Vo(g,b,A){return Zs(b,g.child,null,A),g=Ts(b,b.pendingProps.children),g.flags|=2,b.memoizedState=null,g}function Cp(g,b,A){g.lanes|=b;var z=g.alternate;z!==null&&(z.lanes|=b),J0(g.return,b,A)}function wp(g,b,A,z,ee){var le=g.memoizedState;le===null?g.memoizedState={isBackwards:b,rendering:null,renderingStartTime:0,last:z,tail:A,tailMode:ee}:(le.isBackwards=b,le.rendering=null,le.renderingStartTime=0,le.last=z,le.tail=A,le.tailMode=ee)}function Rp(g,b,A){var z=b.pendingProps,ee=z.revealOrder,le=z.tail;if(ri(g,b,z.children,A),z=za.current,(z&2)!==0)z=z&1|2,b.flags|=128;else{if(g!==null&&(g.flags&128)!==0)e:for(g=b.child;g!==null;){if(g.tag===13)g.memoizedState!==null&&Cp(g,A,b);else if(g.tag===19)Cp(g,A,b);else if(g.child!==null){g.child.return=g,g=g.child;continue}if(g===b)break e;for(;g.sibling===null;){if(g.return===null||g.return===b)break e;g=g.return}g.sibling.return=g.return,g=g.sibling}z&=1}switch(E(za,z),ee){case"forwards":for(A=b.child,ee=null;A!==null;)g=A.alternate,g!==null&&nn(g)===null&&(ee=A),A=A.sibling;A=ee,A===null?(ee=b.child,b.child=null):(ee=A.sibling,A.sibling=null),wp(b,!1,ee,A,le);break;case"backwards":for(A=null,ee=b.child,b.child=null;ee!==null;){if(g=ee.alternate,g!==null&&nn(g)===null){b.child=ee;break}g=ee.sibling,ee.sibling=A,A=ee,ee=g}wp(b,!0,A,null,le);break;case"together":wp(b,!1,null,null,void 0);break;default:b.memoizedState=null}return b.child}function ks(g,b,A){if(g!==null&&(b.dependencies=g.dependencies),Do|=b.lanes,(A&b.childLanes)===0)if(g!==null){if(Sc(g,b,A,!1),(A&b.childLanes)===0)return null}else return null;if(g!==null&&b.child!==g.child)throw Error(i(153));if(b.child!==null){for(g=b.child,A=Ka(g,g.pendingProps),b.child=A,A.return=b;g.sibling!==null;)g=g.sibling,A=A.sibling=Ka(g,g.pendingProps),A.return=b;A.sibling=null}return b.child}function Ap(g,b){return(g.lanes&b)!==0?!0:(g=g.dependencies,!!(g!==null&&Uo(g)))}function Dy(g,b,A){switch(b.tag){case 3:ne(b,b.stateNode.containerInfo),oo(b,Gr,g.memoizedState.cache),se();break;case 27:case 5:ie(b);break;case 4:ne(b,b.stateNode.containerInfo);break;case 10:oo(b,b.type,b.memoizedProps.value);break;case 13:var z=b.memoizedState;if(z!==null)return z.dehydrated!==null?(Zt(b),b.flags|=128,null):(A&b.child.childLanes)!==0?hh(g,b,A):(Zt(b),g=ks(g,b,A),g!==null?g.sibling:null);Zt(b);break;case 19:var ee=(g.flags&128)!==0;if(z=(A&b.childLanes)!==0,z||(Sc(g,b,A,!1),z=(A&b.childLanes)!==0),ee){if(z)return Rp(g,b,A);b.flags|=128}if(ee=b.memoizedState,ee!==null&&(ee.rendering=null,ee.tail=null,ee.lastEffect=null),E(za,za.current),z)break;return null;case 22:case 23:return b.lanes=0,K0(g,b,A);case 24:oo(b,Gr,g.memoizedState.cache)}return ks(g,b,A)}function W0(g,b,A){if(g!==null)if(g.memoizedProps!==b.pendingProps)Ta=!0;else{if(!Ap(g,A)&&(b.flags&128)===0)return Ta=!1,Dy(g,b,A);Ta=(g.flags&131072)!==0}else Ta=!1,Lr&&(b.flags&1048576)!==0&&K(b,Rd,b.index);switch(b.lanes=0,b.tag){case 16:e:{g=b.pendingProps;var z=b.elementType,ee=z._init;if(z=ee(z._payload),b.type=z,typeof z=="function")zn(z)?(g=kl(z,g),b.tag=1,b=La(null,b,z,g,A)):(b.tag=0,b=fa(null,b,z,g,A));else{if(z!=null){if(ee=z.$$typeof,ee===Fp){b.tag=11,b=Y0(null,b,z,g,A);break e}else if(ee===Np){b.tag=14,b=G0(null,b,z,g,A);break e}}throw b=u(z)||z,Error(i(306,b,""))}}return b;case 0:return fa(g,b,b.type,b.pendingProps,A);case 1:return z=b.type,ee=kl(z,b.pendingProps),La(g,b,z,ee,A);case 3:e:{if(ne(b,b.stateNode.containerInfo),g===null)throw Error(i(387));var le=b.pendingProps;ee=b.memoizedState,z=ee.element,qt(g,b),Tt(b,le,null,A);var De=b.memoizedState;if(le=De.cache,oo(b,Gr,le),le!==ee.cache&&ph(b,[Gr],A,!0),ht(),le=De.element,wa&&ee.isDehydrated)if(ee={element:le,isDehydrated:!1,cache:De.cache},b.updateQueue.baseState=ee,b.memoizedState=ee,b.flags&256){b=_g(g,b,le,A);break e}else if(le!==z){z=H(Error(i(424)),b),me(z),b=_g(g,b,le,A);break e}else for(wa&&(xu=Qy(b.stateNode.containerInfo),ul=b,Lr=!0,bo=null,rs=!0),A=Gg(b,null,le,A),b.child=A;A;)A.flags=A.flags&-3|4096,A=A.sibling;else{if(se(),le===z){b=ks(g,b,A);break e}ri(g,b,le,A)}b=b.child}return b;case 26:if(Vl)return ld(g,b),g===null?(A=hm(b.type,null,b.pendingProps,null))?b.memoizedState=A:Lr||(b.stateNode=Ug(b.type,b.pendingProps,Us.current,b)):b.memoizedState=hm(b.type,g.memoizedProps,b.pendingProps,g.memoizedState),null;case 27:if(Ou)return ie(b),g===null&&Ou&&Lr&&(z=b.stateNode=Dd(b.type,b.pendingProps,Us.current,Ir.current,!1),ul=b,rs=!0,xu=qp(z)),z=b.pendingProps.children,g!==null||Lr?ri(g,b,z,A):b.child=Zs(b,null,z,A),ld(g,b),b.child;case 5:return g===null&&Lr&&(Vb(b.type,b.pendingProps,Ir.current),(ee=z=xu)&&(z=zy(z,b.type,b.pendingProps,rs),z!==null?(b.stateNode=z,ul=b,xu=qp(z),rs=!1,ee=!0):ee=!1),ee||be(b)),ie(b),ee=b.type,le=b.pendingProps,De=g!==null?g.memoizedProps:null,z=le.children,Od(ee,le)?z=null:De!==null&&Od(ee,De)&&(b.flags|=32),b.memoizedState!==null&&(ee=gr(g,b,mi,null,null,A),Ja?Tn._currentValue=ee:Tn._currentValue2=ee),ld(g,b),ri(g,b,z,A),b.child;case 6:return g===null&&Lr&&(Ub(b.pendingProps,Ir.current),(g=A=xu)&&(A=Bg(A,b.pendingProps,rs),A!==null?(b.stateNode=A,ul=b,xu=null,g=!0):g=!1),g||be(b)),null;case 13:return hh(g,b,A);case 4:return ne(b,b.stateNode.containerInfo),z=b.pendingProps,g===null?b.child=Zs(b,null,z,A):ri(g,b,z,A),b.child;case 11:return Y0(g,b,b.type,b.pendingProps,A);case 7:return ri(g,b,b.pendingProps,A),b.child;case 8:return ri(g,b,b.pendingProps.children,A),b.child;case 12:return ri(g,b,b.pendingProps.children,A),b.child;case 10:return z=b.pendingProps,oo(b,b.type,z.value),ri(g,b,z.children,A),b.child;case 9:return ee=b.type._context,z=b.pendingProps.children,Ps(b),ee=Ba(ee),z=z(ee),b.flags|=1,ri(g,b,z,A),b.child;case 14:return G0(g,b,b.type,b.pendingProps,A);case 15:return ud(g,b,b.type,b.pendingProps,A);case 19:return Rp(g,b,A);case 22:return K0(g,b,A);case 24:return Ps(b),z=Ba(Gr),g===null?(ee=Ms(),ee===null&&(ee=dr,le=sd(),ee.pooledCache=le,le.refCount++,le!==null&&(ee.pooledCacheLanes|=A),ee=le),b.memoizedState={parent:z,cache:ee},gt(b),oo(b,Gr,ee)):((g.lanes&A)!==0&&(qt(g,b),Tt(b,null,null,A),ht()),ee=g.memoizedState,le=b.memoizedState,ee.parent!==z?(ee={parent:z,cache:z},b.memoizedState=ee,b.lanes===0&&(b.memoizedState=b.updateQueue.baseState=ee),oo(b,Gr,z)):(z=le.cache,oo(b,Gr,z),z!==ee.cache&&ph(b,[Gr],A,!0))),ri(g,b,b.pendingProps.children,A),b.child;case 29:throw b.pendingProps}throw Error(i(156,b.tag))}function oo(g,b,A){Ja?(E(Zl,b._currentValue),b._currentValue=A):(E(Zl,b._currentValue2),b._currentValue2=A)}function Xu(g){var b=Zl.current;Ja?g._currentValue=b:g._currentValue2=b,S(Zl)}function J0(g,b,A){for(;g!==null;){var z=g.alternate;if((g.childLanes&b)!==b?(g.childLanes|=b,z!==null&&(z.childLanes|=b)):z!==null&&(z.childLanes&b)!==b&&(z.childLanes|=b),g===A)break;g=g.return}}function ph(g,b,A,z){var ee=g.child;for(ee!==null&&(ee.return=g);ee!==null;){var le=ee.dependencies;if(le!==null){var De=ee.child;le=le.firstContext;e:for(;le!==null;){var Ie=le;le=ee;for(var We=0;We<b.length;We++)if(Ie.context===b[We]){le.lanes|=A,Ie=le.alternate,Ie!==null&&(Ie.lanes|=A),J0(le.return,A,g),z||(De=null);break e}le=Ie.next}}else if(ee.tag===18){if(De=ee.return,De===null)throw Error(i(341));De.lanes|=A,le=De.alternate,le!==null&&(le.lanes|=A),J0(De,A,g),De=null}else De=ee.child;if(De!==null)De.return=ee;else for(De=ee;De!==null;){if(De===g){De=null;break}if(ee=De.sibling,ee!==null){ee.return=De.return,De=ee;break}De=De.return}ee=De}}function Sc(g,b,A,z){g=null;for(var ee=b,le=!1;ee!==null;){if(!le){if((ee.flags&524288)!==0)le=!0;else if((ee.flags&262144)!==0)break}if(ee.tag===10){var De=ee.alternate;if(De===null)throw Error(i(387));if(De=De.memoizedProps,De!==null){var Ie=ee.type;Ol(ee.pendingProps.value,De.value)||(g!==null?g.push(Ie):g=[Ie])}}else if(ee===Th.current){if(De=ee.alternate,De===null)throw Error(i(387));De.memoizedState.memoizedState!==ee.memoizedState.memoizedState&&(g!==null?g.push(Tn):g=[Tn])}ee=ee.return}g!==null&&ph(b,g,A,z),b.flags|=262144}function Uo(g){for(g=g.firstContext;g!==null;){var b=g.context;if(!Ol(Ja?b._currentValue:b._currentValue2,g.memoizedValue))return!0;g=g.next}return!1}function Ps(g){Md=g,Br=null,g=g.dependencies,g!==null&&(g.firstContext=null)}function Ba(g){return gh(Md,g)}function mh(g,b){return Md===null&&Ps(g),gh(g,b)}function gh(g,b){var A=Ja?b._currentValue:b._currentValue2;if(b={context:b,memoizedValue:A,next:null},Br===null){if(g===null)throw Error(i(308));Br=b,g.dependencies={lanes:0,firstContext:b},g.flags|=524288}else Br=Br.next=b;return A}function sd(){return{controller:new Yb,data:new Map,refCount:0}}function cd(g){g.refCount--,g.refCount===0&&Rf(Mh,function(){g.controller.abort()})}function Ms(){var g=Af.current;return g!==null?g:dr.pooledCache}function fu(g,b){b===null?E(Af,Af.current):E(Af,b.pool)}function Tp(){var g=Ms();return g===null?null:{parent:Ja?Gr._currentValue:Gr._currentValue2,pool:g}}function Xa(g){g.flags|=4}function kp(g,b){if(g!==null&&g.child===b.child)return!1;if((b.flags&16)!==0)return!0;for(g=b.child;g!==null;){if((g.flags&13878)!==0||(g.subtreeFlags&13878)!==0)return!0;g=g.sibling}return!1}function fd(g,b,A,z){if(eu)for(A=b.child;A!==null;){if(A.tag===5||A.tag===6)kc(g,A.stateNode);else if(!(A.tag===4||Ou&&A.tag===27)&&A.child!==null){A.child.return=A,A=A.child;continue}if(A===b)break;for(;A.sibling===null;){if(A.return===null||A.return===b)return;A=A.return}A.sibling.return=A.return,A=A.sibling}else if(tl)for(var ee=b.child;ee!==null;){if(ee.tag===5){var le=ee.stateNode;A&&z&&(le=Ly(le,ee.type,ee.memoizedProps)),kc(g,le)}else if(ee.tag===6)le=ee.stateNode,A&&z&&(le=zl(le,ee.memoizedProps)),kc(g,le);else if(ee.tag!==4){if(ee.tag===22&&ee.memoizedState!==null)le=ee.child,le!==null&&(le.return=ee),fd(g,ee,!0,!0);else if(ee.child!==null){ee.child.return=ee,ee=ee.child;continue}}if(ee===b)break;for(;ee.sibling===null;){if(ee.return===null||ee.return===b)return;ee=ee.return}ee.sibling.return=ee.return,ee=ee.sibling}}function yf(g,b,A,z){if(tl)for(var ee=b.child;ee!==null;){if(ee.tag===5){var le=ee.stateNode;A&&z&&(le=Ly(le,ee.type,ee.memoizedProps)),$h(g,le)}else if(ee.tag===6)le=ee.stateNode,A&&z&&(le=zl(le,ee.memoizedProps)),$h(g,le);else if(ee.tag!==4){if(ee.tag===22&&ee.memoizedState!==null)le=ee.child,le!==null&&(le.return=ee),yf(g,ee,!(ee.memoizedProps!==null&&ee.memoizedProps.mode==="manual"),!0);else if(ee.child!==null){ee.child.return=ee,ee=ee.child;continue}}if(ee===b)break;for(;ee.sibling===null;){if(ee.return===null||ee.return===b)return;ee=ee.return}ee.sibling.return=ee.return,ee=ee.sibling}}function dd(g,b){if(tl&&kp(g,b)){g=b.stateNode;var A=g.containerInfo,z=Ng();yf(z,b,!1,!1),g.pendingChildren=z,Xa(b),Ny(A,z)}}function Yu(g,b,A,z){if(eu)g.memoizedProps!==z&&Xa(b);else if(tl){var ee=g.stateNode,le=g.memoizedProps;if((g=kp(g,b))||le!==z){var De=Ir.current;le=Fy(ee,A,le,z,!g,null),le===ee?b.stateNode=ee:(Wo(le,A,z,De)&&Xa(b),b.stateNode=le,g?fd(le,b,!1,!1):Xa(b))}else b.stateNode=ee}}function so(g,b,A){if(Bb(b,A)){if(g.flags|=16777216,!go(b,A))if(Ni())g.flags|=8192;else throw Cf=kd,Yg}else g.flags&=-16777217}function em(g,b){if(Hy(b)){if(g.flags|=16777216,!jg(b))if(Ni())g.flags|=8192;else throw Cf=kd,Yg}else g.flags&=-16777217}function du(g,b){b!==null&&(g.flags|=4),g.flags&16384&&(b=g.tag!==22?L():536870912,g.lanes|=b,zc|=b)}function bf(g,b){if(!Lr)switch(g.tailMode){case"hidden":b=g.tail;for(var A=null;b!==null;)b.alternate!==null&&(A=b),b=b.sibling;A===null?g.tail=null:A.sibling=null;break;case"collapsed":A=g.tail;for(var z=null;A!==null;)A.alternate!==null&&(z=A),A=A.sibling;z===null?b||g.tail===null?g.tail=null:g.tail.sibling=null:z.sibling=null}}function Sr(g){var b=g.alternate!==null&&g.alternate.child===g.child,A=0,z=0;if(b)for(var ee=g.child;ee!==null;)A|=ee.lanes|ee.childLanes,z|=ee.subtreeFlags&31457280,z|=ee.flags&31457280,ee.return=g,ee=ee.sibling;else for(ee=g.child;ee!==null;)A|=ee.lanes|ee.childLanes,z|=ee.subtreeFlags,z|=ee.flags,ee.return=g,ee=ee.sibling;return g.subtreeFlags|=z,g.childLanes=A,b}function vh(g,b,A){var z=b.pendingProps;switch(B(b),b.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Sr(b),null;case 1:return Sr(b),null;case 3:return A=b.stateNode,z=null,g!==null&&(z=g.memoizedState.cache),b.memoizedState.cache!==z&&(b.flags|=2048),Xu(Gr),oe(),A.pendingContext&&(A.context=A.pendingContext,A.pendingContext=null),(g===null||g.child===null)&&(_e(b)?Xa(b):g===null||g.memoizedState.isDehydrated&&(b.flags&256)===0||(b.flags|=1024,bo!==null&&(Fl(bo),bo=null))),dd(g,b),Sr(b),null;case 26:if(Vl){A=b.type;var ee=b.memoizedState;return g===null?(Xa(b),ee!==null?(Sr(b),em(b,ee)):(Sr(b),so(b,A,z))):ee?ee!==g.memoizedState?(Xa(b),Sr(b),em(b,ee)):(Sr(b),b.flags&=-16777217):(eu?g.memoizedProps!==z&&Xa(b):Yu(g,b,A,z),Sr(b),so(b,A,z)),null}case 27:if(Ou){if(de(b),A=Us.current,ee=b.type,g!==null&&b.stateNode!=null)eu?g.memoizedProps!==z&&Xa(b):Yu(g,b,ee,z);else{if(!z){if(b.stateNode===null)throw Error(i(166));return Sr(b),null}g=Ir.current,_e(b)?ve(b,g):(g=Dd(ee,z,A,g,!0),b.stateNode=g,Xa(b))}return Sr(b),null}case 5:if(de(b),A=b.type,g!==null&&b.stateNode!=null)Yu(g,b,A,z);else{if(!z){if(b.stateNode===null)throw Error(i(166));return Sr(b),null}g=Ir.current,_e(b)?ve(b,g):(ee=wg(A,z,Us.current,g,b),fd(ee,b,!1,!1),b.stateNode=ee,Wo(ee,A,z,g)&&Xa(b))}return Sr(b),so(b,b.type,b.pendingProps),null;case 6:if(g&&b.stateNode!=null)A=g.memoizedProps,eu?A!==z&&Xa(b):tl&&(A!==z?(b.stateNode=um(z,Us.current,Ir.current,b),Xa(b)):b.stateNode=g.stateNode);else{if(typeof z!="string"&&b.stateNode===null)throw Error(i(166));if(g=Us.current,A=Ir.current,_e(b)){if(!wa)throw Error(i(176));if(g=b.stateNode,A=b.memoizedProps,z=null,ee=ul,ee!==null)switch(ee.tag){case 27:case 5:z=ee.memoizedProps}Qg(g,A,b,z)||be(b)}else b.stateNode=um(z,g,A,b)}return Sr(b),null;case 13:if(z=b.memoizedState,g===null||g.memoizedState!==null&&g.memoizedState.dehydrated!==null){if(ee=_e(b),z!==null&&z.dehydrated!==null){if(g===null){if(!ee)throw Error(i(318));if(!wa)throw Error(i(344));if(ee=b.memoizedState,ee=ee!==null?ee.dehydrated:null,!ee)throw Error(i(317));vo(ee,b)}else se(),(b.flags&128)===0&&(b.memoizedState=null),b.flags|=4;Sr(b),ee=!1}else bo!==null&&(Fl(bo),bo=null),ee=!0;if(!ee)return b.flags&256?(tn(b),b):(tn(b),null)}if(tn(b),(b.flags&128)!==0)return b.lanes=A,b;if(A=z!==null,g=g!==null&&g.memoizedState!==null,A){z=b.child,ee=null,z.alternate!==null&&z.alternate.memoizedState!==null&&z.alternate.memoizedState.cachePool!==null&&(ee=z.alternate.memoizedState.cachePool.pool);var le=null;z.memoizedState!==null&&z.memoizedState.cachePool!==null&&(le=z.memoizedState.cachePool.pool),le!==ee&&(z.flags|=2048)}return A!==g&&A&&(b.child.flags|=8192),du(b,b.updateQueue),Sr(b),null;case 4:return oe(),dd(g,b),g===null&&Iu(b.stateNode.containerInfo),Sr(b),null;case 10:return Xu(b.type),Sr(b),null;case 19:if(S(za),ee=b.memoizedState,ee===null)return Sr(b),null;if(z=(b.flags&128)!==0,le=ee.rendering,le===null)if(z)bf(ee,!1);else{if(Tr!==0||g!==null&&(g.flags&128)!==0)for(g=b.child;g!==null;){if(le=nn(g),le!==null){for(b.flags|=128,bf(ee,!1),g=le.updateQueue,b.updateQueue=g,du(b,g),b.subtreeFlags=0,g=A,A=b.child;A!==null;)Ns(A,g),A=A.sibling;return E(za,za.current&1|2),b.child}g=g.sibling}ee.tail!==null&&qi()>aa&&(b.flags|=128,z=!0,bf(ee,!1),b.lanes=4194304)}else{if(!z)if(g=nn(le),g!==null){if(b.flags|=128,z=!0,g=g.updateQueue,b.updateQueue=g,du(b,g),bf(ee,!0),ee.tail===null&&ee.tailMode==="hidden"&&!le.alternate&&!Lr)return Sr(b),null}else 2*qi()-ee.renderingStartTime>aa&&A!==536870912&&(b.flags|=128,z=!0,bf(ee,!1),b.lanes=4194304);ee.isBackwards?(le.sibling=b.child,b.child=le):(g=ee.last,g!==null?g.sibling=le:b.child=le,ee.last=le)}return ee.tail!==null?(b=ee.tail,ee.rendering=b,ee.tail=b.sibling,ee.renderingStartTime=qi(),b.sibling=null,g=za.current,E(za,z?g&1|2:g&1),b):(Sr(b),null);case 22:case 23:return tn(b),Ut(),z=b.memoizedState!==null,g!==null?g.memoizedState!==null!==z&&(b.flags|=8192):z&&(b.flags|=8192),z?(A&536870912)!==0&&(b.flags&128)===0&&(Sr(b),b.subtreeFlags&6&&(b.flags|=8192)):Sr(b),A=b.updateQueue,A!==null&&du(b,A.retryQueue),A=null,g!==null&&g.memoizedState!==null&&g.memoizedState.cachePool!==null&&(A=g.memoizedState.cachePool.pool),z=null,b.memoizedState!==null&&b.memoizedState.cachePool!==null&&(z=b.memoizedState.cachePool.pool),z!==A&&(b.flags|=2048),g!==null&&S(Af),null;case 24:return A=null,g!==null&&(A=g.memoizedState.cache),b.memoizedState.cache!==A&&(b.flags|=2048),Xu(Gr),Sr(b),null;case 25:return null}throw Error(i(156,b.tag))}function Pp(g,b){switch(B(b),b.tag){case 1:return g=b.flags,g&65536?(b.flags=g&-65537|128,b):null;case 3:return Xu(Gr),oe(),g=b.flags,(g&65536)!==0&&(g&128)===0?(b.flags=g&-65537|128,b):null;case 26:case 27:case 5:return de(b),null;case 13:if(tn(b),g=b.memoizedState,g!==null&&g.dehydrated!==null){if(b.alternate===null)throw Error(i(340));se()}return g=b.flags,g&65536?(b.flags=g&-65537|128,b):null;case 19:return S(za),null;case 4:return oe(),null;case 10:return Xu(b.type),null;case 22:case 23:return tn(b),Ut(),g!==null&&S(Af),g=b.flags,g&65536?(b.flags=g&-65537|128,b):null;case 24:return Xu(Gr),null;case 25:return null;default:return null}}function co(g,b){switch(B(b),b.tag){case 3:Xu(Gr),oe();break;case 26:case 27:case 5:de(b);break;case 4:oe();break;case 13:tn(b);break;case 19:S(za);break;case 10:Xu(b.type);break;case 22:case 23:tn(b),Ut(),g!==null&&S(Af);break;case 24:Xu(Gr)}}function Kn(g,b){try{var A=b.updateQueue,z=A!==null?A.lastEffect:null;if(z!==null){var ee=z.next;A=ee;do{if((A.tag&g)===g){z=void 0;var le=A.create,De=A.inst;z=le(),De.destroy=z}A=A.next}while(A!==ee)}}catch(Ie){cn(b,b.return,Ie)}}function yl(g,b,A){try{var z=b.updateQueue,ee=z!==null?z.lastEffect:null;if(ee!==null){var le=ee.next;z=le;do{if((z.tag&g)===g){var De=z.inst,Ie=De.destroy;if(Ie!==void 0){De.destroy=void 0,ee=b;var We=A;try{Ie()}catch(vt){cn(ee,We,vt)}}}z=z.next}while(z!==le)}}catch(vt){cn(b,b.return,vt)}}function Eg(g){var b=g.updateQueue;if(b!==null){var A=g.stateNode;try{un(b,A)}catch(z){cn(g,g.return,z)}}}function Mi(g,b,A){A.props=kl(g.type,g.memoizedProps),A.state=g.memoizedState;try{A.componentWillUnmount()}catch(z){cn(g,b,z)}}function hu(g,b){try{var A=g.ref;if(A!==null){var z=g.stateNode;switch(g.tag){case 26:case 27:case 5:var ee=Lp(z);break;default:ee=z}typeof A=="function"?g.refCleanup=A(ee):A.current=ee}}catch(le){cn(g,b,le)}}function fr(g,b){var A=g.ref,z=g.refCleanup;if(A!==null)if(typeof z=="function")try{z()}catch(ee){cn(g,b,ee)}finally{g.refCleanup=null,g=g.alternate,g!=null&&(g.refCleanup=null)}else if(typeof A=="function")try{A(null)}catch(ee){cn(g,b,ee)}else A.current=null}function Of(g){var b=g.type,A=g.memoizedProps,z=g.stateNode;try{b4(z,b,A,g)}catch(ee){cn(g,g.return,ee)}}function tm(g,b,A){try{Mg(g.stateNode,g.type,A,b,g)}catch(z){cn(g,g.return,z)}}function nm(g){return g.tag===5||g.tag===3||(Vl?g.tag===26:!1)||(Ou?g.tag===27:!1)||g.tag===4}function vr(g){e:for(;;){for(;g.sibling===null;){if(g.return===null||nm(g.return))return null;g=g.return}for(g.sibling.return=g.return,g=g.sibling;g.tag!==5&&g.tag!==6&&(!Ou||g.tag!==27)&&g.tag!==18;){if(g.flags&2||g.child===null||g.tag===4)continue e;g.child.return=g,g=g.child}if(!(g.flags&2))return g.stateNode}}function rm(g,b,A){var z=g.tag;if(z===5||z===6)g=g.stateNode,b?Py(A,g,b):ky(A,g);else if(!(z===4||Ou&&z===27)&&(g=g.child,g!==null))for(rm(g,b,A),g=g.sibling;g!==null;)rm(g,b,A),g=g.sibling}function xf(g,b,A){var z=g.tag;if(z===5||z===6)g=g.stateNode,b?Fg(A,g,b):Pg(A,g);else if(!(z===4||Ou&&z===27)&&(g=g.child,g!==null))for(xf(g,b,A),g=g.sibling;g!==null;)xf(g,b,A),g=g.sibling}function _c(g,b,A){g=g.containerInfo;try{Iy(g,A)}catch(z){cn(b,b.return,z)}}function Xe(g,b){for(Ko(g.containerInfo),ga=b;ga!==null;)if(g=ga,b=g.child,(g.subtreeFlags&1028)!==0&&b!==null)b.return=g,ga=b;else for(;ga!==null;){g=ga;var A=g.alternate;switch(b=g.flags,g.tag){case 0:break;case 11:case 15:break;case 1:if((b&1024)!==0&&A!==null){b=void 0;var z=g,ee=A.memoizedProps;A=A.memoizedState;var le=z.stateNode;try{var De=kl(z.type,ee,z.elementType===z.type);b=le.getSnapshotBeforeUpdate(De,A),le.__reactInternalSnapshotBeforeUpdate=b}catch(Ie){cn(z,z.return,Ie)}}break;case 3:(b&1024)!==0&&eu&&Jn(g.stateNode.containerInfo);break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((b&1024)!==0)throw Error(i(163))}if(b=g.sibling,b!==null){b.return=g.return,ga=b;break}ga=g.return}return De=Fh,Fh=!1,De}function pt(g,b,A){var z=A.flags;switch(A.tag){case 0:case 11:case 15:Ml(g,A),z&4&&Kn(5,A);break;case 1:if(Ml(g,A),z&4)if(g=A.stateNode,b===null)try{g.componentDidMount()}catch(Ie){cn(A,A.return,Ie)}else{var ee=kl(A.type,b.memoizedProps);b=b.memoizedState;try{g.componentDidUpdate(ee,b,g.__reactInternalSnapshotBeforeUpdate)}catch(Ie){cn(A,A.return,Ie)}}z&64&&Eg(A),z&512&&hu(A,A.return);break;case 3:if(Ml(g,A),z&64&&(z=A.updateQueue,z!==null)){if(g=null,A.child!==null)switch(A.child.tag){case 27:case 5:g=Lp(A.child.stateNode);break;case 1:g=A.child.stateNode}try{un(z,g)}catch(Ie){cn(A,A.return,Ie)}}break;case 26:if(Vl){Ml(g,A),z&512&&hu(A,A.return);break}case 27:case 5:Ml(g,A),b===null&&z&4&&Of(A),z&512&&hu(A,A.return);break;case 12:Ml(g,A);break;case 13:Ml(g,A),z&4&&rr(g,A);break;case 22:if(ee=A.memoizedState!==null||au,!ee){b=b!==null&&b.memoizedState!==null||ra;var le=au,De=ra;au=ee,(ra=b)&&!De?ho(g,A,(A.subtreeFlags&8772)!==0):Ml(g,A),au=le,ra=De}z&512&&(A.memoizedProps.mode==="manual"?hu(A,A.return):fr(A,A.return));break;default:Ml(g,A)}}function rt(g){var b=g.alternate;b!==null&&(g.alternate=null,rt(b)),g.child=null,g.deletions=null,g.sibling=null,g.tag===5&&(b=g.stateNode,b!==null&&lm(b)),g.stateNode=null,g.return=null,g.dependencies=null,g.memoizedProps=null,g.memoizedState=null,g.pendingProps=null,g.stateNode=null,g.updateQueue=null}function Bt(g,b,A){for(A=A.child;A!==null;)Dn(g,b,A),A=A.sibling}function Dn(g,b,A){if(al&&typeof al.onCommitFiberUnmount=="function")try{al.onCommitFiberUnmount(Ul,A)}catch{}switch(A.tag){case 26:if(Vl){ra||fr(A,b),Bt(g,b,A),A.memoizedState?rl(A.memoizedState):A.stateNode&&Zy(A.stateNode);break}case 27:if(Ou){ra||fr(A,b);var z=ka,ee=Hl;ka=A.stateNode,Bt(g,b,A),Yy(A.stateNode),ka=z,Hl=ee;break}case 5:ra||fr(A,b);case 6:if(eu){if(z=ka,ee=Hl,ka=null,Bt(g,b,A),ka=z,Hl=ee,ka!==null)if(Hl)try{Ra(ka,A.stateNode)}catch(le){cn(A,b,le)}else try{nl(ka,A.stateNode)}catch(le){cn(A,b,le)}}else Bt(g,b,A);break;case 18:eu&&ka!==null&&(Hl?dm(ka,A.stateNode):Uy(ka,A.stateNode));break;case 4:eu?(z=ka,ee=Hl,ka=A.stateNode.containerInfo,Hl=!0,Bt(g,b,A),ka=z,Hl=ee):(tl&&_c(A.stateNode,A,Ng()),Bt(g,b,A));break;case 0:case 11:case 14:case 15:ra||yl(2,A,b),ra||yl(4,A,b),Bt(g,b,A);break;case 1:ra||(fr(A,b),z=A.stateNode,typeof z.componentWillUnmount=="function"&&Mi(A,b,z)),Bt(g,b,A);break;case 21:Bt(g,b,A);break;case 22:ra||fr(A,b),ra=(z=ra)||A.memoizedState!==null,Bt(g,b,A),ra=z;break;default:Bt(g,b,A)}}function rr(g,b){if(wa&&b.memoizedState===null&&(g=b.alternate,g!==null&&(g=g.memoizedState,g!==null&&(g=g.dehydrated,g!==null))))try{fm(g)}catch(A){cn(b,b.return,A)}}function Fi(g){switch(g.tag){case 13:case 19:var b=g.stateNode;return b===null&&(b=g.stateNode=new Zp),b;case 22:return g=g.stateNode,b=g._retryCache,b===null&&(b=g._retryCache=new Zp),b;default:throw Error(i(435,g.tag))}}function Nr(g,b){var A=Fi(g);b.forEach(function(z){var ee=bl.bind(null,g,z);A.has(z)||(A.add(z),z.then(ee,ee))})}function Ya(g,b){var A=b.deletions;if(A!==null)for(var z=0;z<A.length;z++){var ee=A[z],le=g,De=b;if(eu){var Ie=De;e:for(;Ie!==null;){switch(Ie.tag){case 27:case 5:ka=Ie.stateNode,Hl=!1;break e;case 3:ka=Ie.stateNode.containerInfo,Hl=!0;break e;case 4:ka=Ie.stateNode.containerInfo,Hl=!0;break e}Ie=Ie.return}if(ka===null)throw Error(i(160));Dn(le,De,ee),ka=null,Hl=!1}else Dn(le,De,ee);le=ee.alternate,le!==null&&(le.return=null),ee.return=null}if(b.subtreeFlags&13878)for(b=b.child;b!==null;)Ec(b,g),b=b.sibling}function Ec(g,b){var A=g.alternate,z=g.flags;switch(g.tag){case 0:case 11:case 14:case 15:Ya(b,g),_i(g),z&4&&(yl(3,g,g.return),Kn(3,g),yl(5,g,g.return));break;case 1:Ya(b,g),_i(g),z&512&&(ra||A===null||fr(A,A.return)),z&64&&au&&(g=g.updateQueue,g!==null&&(z=g.callbacks,z!==null&&(A=g.shared.hiddenCallbacks,g.shared.hiddenCallbacks=A===null?z:A.concat(z))));break;case 26:if(Vl){var ee=Sl;Ya(b,g),_i(g),z&512&&(ra||A===null||fr(A,A.return)),z&4&&(z=A!==null?A.memoizedState:null,b=g.memoizedState,A===null?b===null?g.stateNode===null?g.stateNode=ts(ee,g.type,g.memoizedProps,g):jy(ee,g.type,g.stateNode):g.stateNode=Vg(ee,b,g.memoizedProps):z!==b?(z===null?A.stateNode!==null&&Zy(A.stateNode):rl(z),b===null?jy(ee,g.type,g.stateNode):Vg(ee,b,g.memoizedProps)):b===null&&g.stateNode!==null&&tm(g,g.memoizedProps,A.memoizedProps));break}case 27:if(Ou&&z&4&&g.alternate===null){ee=g.stateNode;var le=g.memoizedProps;try{pm(ee),O4(g.type,le,ee,g)}catch(kt){cn(g,g.return,kt)}}case 5:if(Ya(b,g),_i(g),z&512&&(ra||A===null||fr(A,A.return)),eu){if(g.flags&32){b=g.stateNode;try{Dh(b)}catch(kt){cn(g,g.return,kt)}}z&4&&g.stateNode!=null&&(b=g.memoizedProps,tm(g,b,A!==null?A.memoizedProps:b)),z&1024&&(Qc=!0)}break;case 6:if(Ya(b,g),_i(g),z&4&&eu){if(g.stateNode===null)throw Error(i(162));z=g.memoizedProps,A=A!==null?A.memoizedProps:z,b=g.stateNode;try{sm(b,A,z)}catch(kt){cn(g,g.return,kt)}}break;case 3:if(Vl?(Ed(),ee=Sl,Sl=qg(b.containerInfo),Ya(b,g),Sl=ee):Ya(b,g),_i(g),z&4){if(eu&&wa&&A!==null&&A.memoizedState.isDehydrated)try{qs(b.containerInfo)}catch(kt){cn(g,g.return,kt)}if(tl){z=b.containerInfo,A=b.pendingChildren;try{Iy(z,A)}catch(kt){cn(g,g.return,kt)}}}Qc&&(Qc=!1,hd(g));break;case 4:Vl?(A=Sl,Sl=qg(g.stateNode.containerInfo),Ya(b,g),_i(g),Sl=A):(Ya(b,g),_i(g)),z&4&&tl&&_c(g.stateNode,g,g.stateNode.pendingChildren);break;case 12:Ya(b,g),_i(g);break;case 13:Ya(b,g),_i(g),g.child.flags&8192&&g.memoizedState!==null!=(A!==null&&A.memoizedState!==null)&&(qc=qi()),z&4&&(z=g.updateQueue,z!==null&&(g.updateQueue=null,Nr(g,z)));break;case 22:z&512&&(ra||A===null||fr(A,A.return)),ee=g.memoizedState!==null;var De=A!==null&&A.memoizedState!==null,Ie=au,We=ra;if(au=Ie||ee,ra=We||De,Ya(b,g),ra=We,au=Ie,_i(g),b=g.stateNode,b._current=g,b._visibility&=-3,b._visibility|=b._pendingVisibility&2,z&8192&&(b._visibility=ee?b._visibility&-2:b._visibility|1,ee&&(b=au||ra,A===null||De||b||fo(g)),eu&&(g.memoizedProps===null||g.memoizedProps.mode!=="manual"))){e:if(A=null,eu)for(b=g;;){if(b.tag===5||Vl&&b.tag===26||Ou&&b.tag===27){if(A===null){De=A=b;try{le=De.stateNode,ee?Qp(le):My(De.stateNode,De.memoizedProps)}catch(kt){cn(De,De.return,kt)}}}else if(b.tag===6){if(A===null){De=b;try{var vt=De.stateNode;ee?zp(vt):zs(vt,De.memoizedProps)}catch(kt){cn(De,De.return,kt)}}}else if((b.tag!==22&&b.tag!==23||b.memoizedState===null||b===g)&&b.child!==null){b.child.return=b,b=b.child;continue}if(b===g)break e;for(;b.sibling===null;){if(b.return===null||b.return===g)break e;A===b&&(A=null),b=b.return}A===b&&(A=null),b.sibling.return=b.return,b=b.sibling}}z&4&&(z=g.updateQueue,z!==null&&(A=z.retryQueue,A!==null&&(z.retryQueue=null,Nr(g,A))));break;case 19:Ya(b,g),_i(g),z&4&&(z=g.updateQueue,z!==null&&(g.updateQueue=null,Nr(g,z)));break;case 21:break;default:Ya(b,g),_i(g)}}function _i(g){var b=g.flags;if(b&2){try{if(eu&&(!Ou||g.tag!==27)){e:{for(var A=g.return;A!==null;){if(nm(A)){var z=A;break e}A=A.return}throw Error(i(160))}switch(z.tag){case 27:if(Ou){var ee=z.stateNode,le=vr(g);xf(g,le,ee);break}case 5:var De=z.stateNode;z.flags&32&&(Dh(De),z.flags&=-33);var Ie=vr(g);xf(g,Ie,De);break;case 3:case 4:var We=z.stateNode.containerInfo,vt=vr(g);rm(g,vt,We);break;default:throw Error(i(161))}}}catch(kt){cn(g,g.return,kt)}g.flags&=-3}b&4096&&(g.flags&=-4097)}function hd(g){if(g.subtreeFlags&1024)for(g=g.child;g!==null;){var b=g;hd(b),b.tag===5&&b.flags&1024&&yi(b.stateNode),g=g.sibling}}function Ml(g,b){if(b.subtreeFlags&8772)for(b=b.child;b!==null;)pt(g,b.alternate,b),b=b.sibling}function fo(g){for(g=g.child;g!==null;){var b=g;switch(b.tag){case 0:case 11:case 14:case 15:yl(4,b,b.return),fo(b);break;case 1:fr(b,b.return);var A=b.stateNode;typeof A.componentWillUnmount=="function"&&Mi(b,b.return,A),fo(b);break;case 26:case 27:case 5:fr(b,b.return),fo(b);break;case 22:fr(b,b.return),b.memoizedState===null&&fo(b);break;default:fo(b)}g=g.sibling}}function ho(g,b,A){for(A=A&&(b.subtreeFlags&8772)!==0,b=b.child;b!==null;){var z=b.alternate,ee=g,le=b,De=le.flags;switch(le.tag){case 0:case 11:case 15:ho(ee,le,A),Kn(4,le);break;case 1:if(ho(ee,le,A),z=le,ee=z.stateNode,typeof ee.componentDidMount=="function")try{ee.componentDidMount()}catch(vt){cn(z,z.return,vt)}if(z=le,ee=z.updateQueue,ee!==null){var Ie=z.stateNode;try{var We=ee.shared.hiddenCallbacks;if(We!==null)for(ee.shared.hiddenCallbacks=null,ee=0;ee<We.length;ee++)Qt(We[ee],Ie)}catch(vt){cn(z,z.return,vt)}}A&&De&64&&Eg(le),hu(le,le.return);break;case 26:case 27:case 5:ho(ee,le,A),A&&z===null&&De&4&&Of(le),hu(le,le.return);break;case 12:ho(ee,le,A);break;case 13:ho(ee,le,A),A&&De&4&&rr(ee,le);break;case 22:le.memoizedState===null&&ho(ee,le,A),hu(le,le.return);break;default:ho(ee,le,A)}b=b.sibling}}function Sf(g,b){var A=null;g!==null&&g.memoizedState!==null&&g.memoizedState.cachePool!==null&&(A=g.memoizedState.cachePool.pool),g=null,b.memoizedState!==null&&b.memoizedState.cachePool!==null&&(g=b.memoizedState.cachePool.pool),g!==A&&(g!=null&&g.refCount++,A!=null&&cd(A))}function _r(g,b){g=null,b.alternate!==null&&(g=b.alternate.memoizedState.cache),b=b.memoizedState.cache,b!==g&&(b.refCount++,g!=null&&cd(g))}function jo(g,b,A,z){if(b.subtreeFlags&10256)for(b=b.child;b!==null;)yh(g,b,A,z),b=b.sibling}function yh(g,b,A,z){var ee=b.flags;switch(b.tag){case 0:case 11:case 15:jo(g,b,A,z),ee&2048&&Kn(9,b);break;case 3:jo(g,b,A,z),ee&2048&&(g=null,b.alternate!==null&&(g=b.alternate.memoizedState.cache),b=b.memoizedState.cache,b!==g&&(b.refCount++,g!=null&&cd(g)));break;case 12:if(ee&2048){jo(g,b,A,z),g=b.stateNode;try{var le=b.memoizedProps,De=le.id,Ie=le.onPostCommit;typeof Ie=="function"&&Ie(De,b.alternate===null?"mount":"update",g.passiveEffectDuration,-0)}catch(We){cn(b,b.return,We)}}else jo(g,b,A,z);break;case 23:break;case 22:le=b.stateNode,b.memoizedState!==null?le._visibility&4?jo(g,b,A,z):Zo(g,b):le._visibility&4?jo(g,b,A,z):(le._visibility|=4,da(g,b,A,z,(b.subtreeFlags&10256)!==0)),ee&2048&&Sf(b.alternate,b);break;case 24:jo(g,b,A,z),ee&2048&&_r(b.alternate,b);break;default:jo(g,b,A,z)}}function da(g,b,A,z,ee){for(ee=ee&&(b.subtreeFlags&10256)!==0,b=b.child;b!==null;){var le=g,De=b,Ie=A,We=z,vt=De.flags;switch(De.tag){case 0:case 11:case 15:da(le,De,Ie,We,ee),Kn(8,De);break;case 23:break;case 22:var kt=De.stateNode;De.memoizedState!==null?kt._visibility&4?da(le,De,Ie,We,ee):Zo(le,De):(kt._visibility|=4,da(le,De,Ie,We,ee)),ee&&vt&2048&&Sf(De.alternate,De);break;case 24:da(le,De,Ie,We,ee),ee&&vt&2048&&_r(De.alternate,De);break;default:da(le,De,Ie,We,ee)}b=b.sibling}}function Zo(g,b){if(b.subtreeFlags&10256)for(b=b.child;b!==null;){var A=g,z=b,ee=z.flags;switch(z.tag){case 22:Zo(A,z),ee&2048&&Sf(z.alternate,z);break;case 24:Zo(A,z),ee&2048&&_r(z.alternate,z);break;default:Zo(A,z)}b=b.sibling}}function Ca(g){if(g.subtreeFlags&Nh)for(g=g.child;g!==null;)po(g),g=g.sibling}function po(g){switch(g.tag){case 26:Ca(g),g.flags&Nh&&(g.memoizedState!==null?Xy(Sl,g.memoizedState,g.memoizedProps):ha(g.type,g.memoizedProps));break;case 5:Ca(g),g.flags&Nh&&ha(g.type,g.memoizedProps);break;case 3:case 4:if(Vl){var b=Sl;Sl=qg(g.stateNode.containerInfo),Ca(g),Sl=b}else Ca(g);break;case 22:g.memoizedState===null&&(b=g.alternate,b!==null&&b.memoizedState!==null?(b=Nh,Nh=16777216,Ca(g),Nh=b):Ca(g));break;default:Ca(g)}}function Fs(g){var b=g.alternate;if(b!==null&&(g=b.child,g!==null)){b.child=null;do b=g.sibling,g.sibling=null,g=b;while(g!==null)}}function Ga(g){var b=g.deletions;if((g.flags&16)!==0){if(b!==null)for(var A=0;A<b.length;A++){var z=b[A];ga=z,Ku(z,g)}Fs(g)}if(g.subtreeFlags&10256)for(g=g.child;g!==null;)Gu(g),g=g.sibling}function Gu(g){switch(g.tag){case 0:case 11:case 15:Ga(g),g.flags&2048&&yl(9,g,g.return);break;case 3:Ga(g);break;case 12:Ga(g);break;case 22:var b=g.stateNode;g.memoizedState!==null&&b._visibility&4&&(g.return===null||g.return.tag!==13)?(b._visibility&=-5,Dc(g)):Ga(g);break;default:Ga(g)}}function Dc(g){var b=g.deletions;if((g.flags&16)!==0){if(b!==null)for(var A=0;A<b.length;A++){var z=b[A];ga=z,Ku(z,g)}Fs(g)}for(g=g.child;g!==null;){switch(b=g,b.tag){case 0:case 11:case 15:yl(8,b,b.return),Dc(b);break;case 22:A=b.stateNode,A._visibility&4&&(A._visibility&=-5,Dc(b));break;default:Dc(b)}g=g.sibling}}function Ku(g,b){for(;ga!==null;){var A=ga;switch(A.tag){case 0:case 11:case 15:yl(8,A,b);break;case 23:case 22:if(A.memoizedState!==null&&A.memoizedState.cachePool!==null){var z=A.memoizedState.cachePool.pool;z!=null&&z.refCount++}break;case 24:cd(A.memoizedState.cache)}if(z=A.child,z!==null)z.return=A,ga=z;else e:for(A=g;ga!==null;){z=ga;var ee=z.sibling,le=z.return;if(rt(z),z===A){ga=null;break e}if(ee!==null){ee.return=le,ga=ee;break e}ga=le}}}function $c(g){var b=Rg(g);if(b!=null){if(typeof b.memoizedProps["data-testname"]!="string")throw Error(i(364));return b}if(g=Eh(g),g===null)throw Error(i(362));return g.stateNode.current}function Cc(g,b){var A=g.tag;switch(b.$$typeof){case _m:if(g.type===b.value)return!0;break;case Jg:e:{for(b=b.value,g=[g,0],A=0;A<g.length;){var z=g[A++],ee=z.tag,le=g[A++],De=b[le];if(ee!==5&&ee!==26&&ee!==27||!es(z)){for(;De!=null&&Cc(z,De);)le++,De=b[le];if(le===b.length){b=!0;break e}else for(z=z.child;z!==null;)g.push(z,le),z=z.sibling}}b=!1}return b;case ev:if((A===5||A===26||A===27)&&y4(g.stateNode,b.value))return!0;break;case ii:if((A===5||A===6||A===26||A===27)&&(g=Bp(g),g!==null&&0<=g.indexOf(b.value)))return!0;break;case Ar:if((A===5||A===26||A===27)&&(g=g.memoizedProps["data-testname"],typeof g=="string"&&g.toLowerCase()===b.value.toLowerCase()))return!0;break;default:throw Error(i(365))}return!1}function pu(g){switch(g.$$typeof){case _m:return"<"+(u(g.value)||"Unknown")+">";case Jg:return":has("+(pu(g)||"")+")";case ev:return'[role="'+g.value+'"]';case ii:return'"'+g.value+'"';case Ar:return'[data-testname="'+g.value+'"]';default:throw Error(i(365))}}function pd(g,b){var A=[];g=[g,0];for(var z=0;z<g.length;){var ee=g[z++],le=ee.tag,De=g[z++],Ie=b[De];if(le!==5&&le!==26&&le!==27||!es(ee)){for(;Ie!=null&&Cc(ee,Ie);)De++,Ie=b[De];if(De===b.length)A.push(ee);else for(ee=ee.child;ee!==null;)g.push(ee,De),ee=ee.sibling}}return A}function na(g,b){if(!Pc)throw Error(i(363));g=$c(g),g=pd(g,b),b=[],g=Array.from(g);for(var A=0;A<g.length;){var z=g[A++],ee=z.tag;if(ee===5||ee===26||ee===27)es(z)||b.push(z.stateNode);else for(z=z.child;z!==null;)g.push(z),z=z.sibling}return b}function Xi(){if((bn&2)!==0&&lr!==0)return lr&-lr;if(_n.T!==null){var g=jl;return g!==0?g:ze()}return Jo()}function Wu(){Xl===0&&(Xl=(lr&536870912)===0||Lr?F():536870912);var g=So.current;return g!==null&&(g.flags|=32),Xl}function mu(g,b,A){(g===dr&&Oi===2||g.cancelPendingCommit!==null)&&(Nl(g,0),gu(g,lr,Xl,!1)),V(g,A),((bn&2)===0||g!==dr)&&(g===dr&&((bn&2)===0&&(Xs|=A),Tr===4&&gu(g,lr,Xl,!1)),Oe(g))}function bh(g,b,A){if((bn&6)!==0)throw Error(i(327));var z=!A&&(b&60)===0&&(b&g.expiredLanes)===0||$(g,b),ee=z?ue(g,b):Pu(g,b,!0),le=z;do{if(ee===0){Eo&&!z&&gu(g,b,0,!1);break}else if(ee===6)gu(g,b,0,!Kr);else{if(A=g.current.alternate,le&&!Oh(A)){ee=Pu(g,b,!1),le=!1;continue}if(ee===2){if(le=b,g.errorRecoveryDisabledLanes&le)var De=0;else De=g.pendingLanes&-536870913,De=De!==0?De:De&536870912?536870912:0;if(De!==0){b=De;e:{var Ie=g;ee=Hp;var We=wa&&Ie.current.memoizedState.isDehydrated;if(We&&(Nl(Ie,De).flags|=256),De=Pu(Ie,De,!1),De!==2){if(Tf&&!We){Ie.errorRecoveryDisabledLanes|=le,Xs|=le,ee=4;break e}le=cl,cl=ee,le!==null&&Fl(le)}ee=De}if(le=!1,ee!==2)continue}}if(ee===1){Nl(g,0),gu(g,b,0,!0);break}e:{switch(z=g,ee){case 0:case 1:throw Error(i(345));case 4:if((b&4194176)===b){gu(z,b,Xl,!Kr);break e}break;case 2:cl=null;break;case 3:case 5:break;default:throw Error(i(329))}if(z.finishedWork=A,z.finishedLanes=b,(b&62914560)===b&&(le=qc+300-qi(),10<le)){if(gu(z,b,Xl,!Kr),R(z,0)!==0)break e;z.timeoutHandle=Wa(_f.bind(null,z,A,cl,Ys,Xp,b,Xl,Xs,zc,Kr,2,-0,0),le);break e}_f(z,A,cl,Ys,Xp,b,Xl,Xs,zc,Kr,0,-0,0)}}break}while(!0);Oe(g)}function Fl(g){cl===null?cl=g:cl.push.apply(cl,g)}function _f(g,b,A,z,ee,le,De,Ie,We,vt,kt,Ht,Wt){var Hn=b.subtreeFlags;if((Hn&8192||(Hn&16785408)===16785408)&&(Ql(),po(b),b=Ag(),b!==null)){g.cancelPendingCommit=b(Be.bind(null,g,A,z,ee,De,Ie,We,1,Ht,Wt)),gu(g,le,De,!vt);return}Be(g,A,z,ee,De,Ie,We,kt,Ht,Wt)}function Oh(g){for(var b=g;;){var A=b.tag;if((A===0||A===11||A===15)&&b.flags&16384&&(A=b.updateQueue,A!==null&&(A=A.stores,A!==null)))for(var z=0;z<A.length;z++){var ee=A[z],le=ee.getSnapshot;ee=ee.value;try{if(!Ol(le(),ee))return!1}catch{return!1}}if(A=b.child,b.subtreeFlags&16384&&A!==null)A.return=b,b=A;else{if(b===g)break;for(;b.sibling===null;){if(b.return===null||b.return===g)return!0;b=b.return}b.sibling.return=b.return,b=b.sibling}}return!0}function gu(g,b,A,z){b&=~sl,b&=~Xs,g.suspendedLanes|=b,g.pingedLanes&=~b,z&&(g.warmLanes|=b),z=g.expirationTimes;for(var ee=b;0<ee;){var le=31-il(ee),De=1<<le;z[le]=-1,ee&=~De}A!==0&&N(g,A,b)}function Mp(){return(bn&6)===0?($e(0),!1):!0}function Tu(){if(Yn!==null){if(Oi===0)var g=Yn.return;else g=Yn,Br=Md=null,Al(g),js=null,xo=0,g=Yn;for(;g!==null;)co(g.alternate,g),g=g.return;Yn=null}}function Nl(g,b){g.finishedWork=null,g.finishedLanes=0;var A=g.timeoutHandle;A!==xd&&(g.timeoutHandle=xd,_h(A)),A=g.cancelPendingCommit,A!==null&&(g.cancelPendingCommit=null,A()),Tu(),dr=g,Yn=A=Ka(g.current,null),lr=b,Oi=0,ia=null,Kr=!1,Eo=$(g,b),Tf=!1,zc=Xl=sl=Xs=Do=Tr=0,cl=Hp=null,Xp=!1,(b&8)!==0&&(b|=b&32);var z=g.entangledLanes;if(z!==0)for(g=g.entanglements,z&=b;0<z;){var ee=31-il(z),le=1<<ee;b|=g[ee],z&=~le}return Hs=b,ge(),A}function wc(g,b){er=null,_n.H=Rr,b===Xr?(b=ur(),Oi=3):b===Yg?(b=ur(),Oi=4):Oi=b===Xb?8:b!==null&&typeof b=="object"&&typeof b.then=="function"?6:1,ia=b,Yn===null&&(Tr=1,id(g,H(b,g.current)))}function Ni(){var g=So.current;return g===null?!0:(lr&4194176)===lr?_o===null:(lr&62914560)===lr||(lr&536870912)!==0?g===_o:!1}function Ei(){var g=_n.H;return _n.H=Rr,g===null?Rr:g}function ku(){var g=_n.A;return _n.A=Wg,g}function pn(){Tr=4,Kr||(lr&4194176)!==lr&&So.current!==null||(Eo=!0),(Do&134217727)===0&&(Xs&134217727)===0||dr===null||gu(dr,lr,Xl,!1)}function Pu(g,b,A){var z=bn;bn|=2;var ee=Ei(),le=ku();(dr!==g||lr!==b)&&(Ys=null,Nl(g,b)),b=!1;var De=Tr;e:do try{if(Oi!==0&&Yn!==null){var Ie=Yn,We=ia;switch(Oi){case 8:Tu(),De=6;break e;case 3:case 2:case 6:So.current===null&&(b=!0);var vt=Oi;if(Oi=0,ia=null,xe(g,Ie,We,vt),A&&Eo){De=0;break e}break;default:vt=Oi,Oi=0,ia=null,xe(g,Ie,We,vt)}}Ho(),De=Tr;break}catch(kt){wc(g,kt)}while(!0);return b&&g.shellSuspendCounter++,Br=Md=null,bn=z,_n.H=ee,_n.A=le,Yn===null&&(dr=null,lr=0,ge()),De}function Ho(){for(;Yn!==null;)re(Yn)}function ue(g,b){var A=bn;bn|=2;var z=Ei(),ee=ku();dr!==g||lr!==b?(Ys=null,aa=qi()+500,Nl(g,b)):Eo=$(g,b);e:do try{if(Oi!==0&&Yn!==null){b=Yn;var le=ia;t:switch(Oi){case 1:Oi=0,ia=null,xe(g,b,le,1);break;case 2:if(ln(le)){Oi=0,ia=null,fe(b);break}b=function(){Oi===2&&dr===g&&(Oi=7),Oe(g)},le.then(b,b);break e;case 3:Oi=7;break e;case 4:Oi=5;break e;case 7:ln(le)?(Oi=0,ia=null,fe(b)):(Oi=0,ia=null,xe(g,b,le,7));break;case 5:var De=null;switch(Yn.tag){case 26:De=Yn.memoizedState;case 5:case 27:var Ie=Yn,We=Ie.type,vt=Ie.pendingProps;if(De?jg(De):go(We,vt)){Oi=0,ia=null;var kt=Ie.sibling;if(kt!==null)Yn=kt;else{var Ht=Ie.return;Ht!==null?(Yn=Ht,Te(Ht)):Yn=null}break t}}Oi=0,ia=null,xe(g,b,le,5);break;case 6:Oi=0,ia=null,xe(g,b,le,6);break;case 8:Tu(),Tr=6;break e;default:throw Error(i(462))}}I();break}catch(Wt){wc(g,Wt)}while(!0);return Br=Md=null,_n.H=z,_n.A=ee,bn=A,Yn!==null?0:(dr=null,lr=0,ge(),Tr)}function I(){for(;Yn!==null&&!Zb();)re(Yn)}function re(g){var b=W0(g.alternate,g,Hs);g.memoizedProps=g.pendingProps,b===null?Te(g):Yn=b}function fe(g){var b=g,A=b.alternate;switch(b.tag){case 15:case 0:b=od(A,b,b.pendingProps,b.type,void 0,lr);break;case 11:b=od(A,b,b.pendingProps,b.type.render,b.ref,lr);break;case 5:Al(b);default:co(A,b),b=Yn=Ns(b,Hs),b=W0(A,b,Hs)}g.memoizedProps=g.pendingProps,b===null?Te(g):Yn=b}function xe(g,b,A,z){Br=Md=null,Al(b),js=null,xo=0;var ee=b.return;try{if(Dp(g,ee,b,A,lr)){Tr=1,id(g,H(A,g.current)),Yn=null;return}}catch(le){if(ee!==null)throw Yn=ee,le;Tr=1,id(g,H(A,g.current)),Yn=null;return}b.flags&32768?(Lr||z===1?g=!0:Eo||(lr&536870912)!==0?g=!1:(Kr=g=!0,(z===2||z===3||z===6)&&(z=So.current,z!==null&&z.tag===13&&(z.flags|=16384))),Qe(b,g)):Te(b)}function Te(g){var b=g;do{if((b.flags&32768)!==0){Qe(b,Kr);return}g=b.return;var A=vh(b.alternate,b,Hs);if(A!==null){Yn=A;return}if(b=b.sibling,b!==null){Yn=b;return}Yn=b=g}while(b!==null);Tr===0&&(Tr=5)}function Qe(g,b){do{var A=Pp(g.alternate,g);if(A!==null){A.flags&=32767,Yn=A;return}if(A=g.return,A!==null&&(A.flags|=32768,A.subtreeFlags=0,A.deletions=null),!b&&(g=g.sibling,g!==null)){Yn=g;return}Yn=g=A}while(g!==null);Tr=6,Yn=null}function Be(g,b,A,z,ee,le,De,Ie,We,vt){var kt=_n.T,Ht=tu();try{yu(2),_n.T=null,je(g,b,A,z,Ht,ee,le,De,Ie,We,vt)}finally{_n.T=kt,yu(Ht)}}function je(g,b,A,z,ee,le,De,Ie){do Kt();while(kf!==null);if((bn&6)!==0)throw Error(i(327));var We=g.finishedWork;if(z=g.finishedLanes,We===null)return null;if(g.finishedWork=null,g.finishedLanes=0,We===g.current)throw Error(i(177));g.callbackNode=null,g.callbackPriority=0,g.cancelPendingCommit=null;var vt=We.lanes|We.childLanes;if(vt|=Up,q(g,z,vt,le,De,Ie),g===dr&&(Yn=dr=null,lr=0),(We.subtreeFlags&10256)===0&&(We.flags&10256)===0||us||(us=!0,tv=vt,Lh=A,Il(Hg,function(){return Kt(),null})),A=(We.flags&15990)!==0,(We.subtreeFlags&15990)!==0||A?(A=_n.T,_n.T=null,le=tu(),yu(2),De=bn,bn|=4,Xe(g,We),Ec(We,g),Tc(g.containerInfo),g.current=We,pt(g,We.alternate,We),Gy(),bn=De,yu(le),_n.T=A):g.current=We,us?(us=!1,kf=g,Ih=z):Ct(g,vt),vt=g.pendingLanes,vt===0&&($o=null),G(We.stateNode),Oe(g),b!==null)for(ee=g.onRecoverableError,We=0;We<b.length;We++)vt=b[We],ee(vt.value,{componentStack:vt.stack});return(Ih&3)!==0&&Kt(),vt=g.pendingLanes,(z&4194218)!==0&&(vt&42)!==0?g===_l?Bh++:(Bh=0,_l=g):Bh=0,$e(0),null}function Ct(g,b){(g.pooledCacheLanes&=b)===0&&(b=g.pooledCache,b!=null&&(g.pooledCache=null,cd(b)))}function Kt(){if(kf!==null){var g=kf,b=tv;tv=0;var A=W(Ih),z=32>A?32:A;A=_n.T;var ee=tu();try{if(yu(z),_n.T=null,kf===null)var le=!1;else{z=Lh,Lh=null;var De=kf,Ie=Ih;if(kf=null,Ih=0,(bn&6)!==0)throw Error(i(331));var We=bn;if(bn|=4,Gu(De.current),yh(De,De.current,Ie,z),bn=We,$e(0,!1),al&&typeof al.onPostCommitFiberRoot=="function")try{al.onPostCommitFiberRoot(Ul,De)}catch{}le=!0}return le}finally{yu(ee),_n.T=A,Ct(g,b)}}return!1}function Qn(g,b,A){b=H(A,b),b=As(g.stateNode,b,2),g=an(g,b,2),g!==null&&(V(g,2),Oe(g))}function cn(g,b,A){if(g.tag===3)Qn(g,g,A);else for(;b!==null;){if(b.tag===3){Qn(b,g,A);break}else if(b.tag===1){var z=b.stateNode;if(typeof b.type.getDerivedStateFromError=="function"||typeof z.componentDidCatch=="function"&&($o===null||!$o.has(z))){g=H(A,g),A=Pl(2),z=an(b,A,2),z!==null&&(ad(A,z,b,g),V(z,2),Oe(z));break}}b=b.return}}function vn(g,b,A){var z=g.pingCache;if(z===null){z=g.pingCache=new yr;var ee=new Set;z.set(b,ee)}else ee=z.get(b),ee===void 0&&(ee=new Set,z.set(b,ee));ee.has(A)||(Tf=!0,ee.add(A),g=Di.bind(null,g,b,A),b.then(g,g))}function Di(g,b,A){var z=g.pingCache;z!==null&&z.delete(b),g.pingedLanes|=g.suspendedLanes&A,g.warmLanes&=~A,dr===g&&(lr&A)===A&&(Tr===4||Tr===3&&(lr&62914560)===lr&&300>qi()-qc?(bn&2)===0&&Nl(g,0):sl|=A,zc===lr&&(zc=0)),Oe(g)}function Qa(g,b){b===0&&(b=L()),g=Re(g,b),g!==null&&(V(g,b),Oe(g))}function Se(g){var b=g.memoizedState,A=0;b!==null&&(A=b.retryLane),Qa(g,A)}function bl(g,b){var A=0;switch(g.tag){case 13:var z=g.stateNode,ee=g.memoizedState;ee!==null&&(A=ee.retryLane);break;case 19:z=g.stateNode;break;case 22:z=g.stateNode._retryCache;break;default:throw Error(i(314))}z!==null&&z.delete(b),Qa(g,A)}function Il(g,b){return Rh(g,b)}function Mu(g,b,A,z){this.tag=g,this.key=A,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=b,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=z,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function zn(g){return g=g.prototype,!(!g||!g.isReactComponent)}function Ka(g,b){var A=g.alternate;return A===null?(A=n(g.tag,b,g.key,g.mode),A.elementType=g.elementType,A.type=g.type,A.stateNode=g.stateNode,A.alternate=g,g.alternate=A):(A.pendingProps=b,A.type=g.type,A.flags=0,A.subtreeFlags=0,A.deletions=null),A.flags=g.flags&31457280,A.childLanes=g.childLanes,A.lanes=g.lanes,A.child=g.child,A.memoizedProps=g.memoizedProps,A.memoizedState=g.memoizedState,A.updateQueue=g.updateQueue,b=g.dependencies,A.dependencies=b===null?null:{lanes:b.lanes,firstContext:b.firstContext},A.sibling=g.sibling,A.index=g.index,A.ref=g.ref,A.refCleanup=g.refCleanup,A}function Ns(g,b){g.flags&=31457282;var A=g.alternate;return A===null?(g.childLanes=0,g.lanes=b,g.child=null,g.subtreeFlags=0,g.memoizedProps=null,g.memoizedState=null,g.updateQueue=null,g.dependencies=null,g.stateNode=null):(g.childLanes=A.childLanes,g.lanes=A.lanes,g.child=A.child,g.subtreeFlags=0,g.deletions=null,g.memoizedProps=A.memoizedProps,g.memoizedState=A.memoizedState,g.updateQueue=A.updateQueue,g.type=A.type,b=A.dependencies,g.dependencies=b===null?null:{lanes:b.lanes,firstContext:b.firstContext}),g}function Ll(g,b,A,z,ee,le){var De=0;if(z=g,typeof g=="function")zn(g)&&(De=1);else if(typeof g=="string")De=Vl&&Ou?zg(g,A,Ir.current)?26:Ch(g)?27:5:Vl?zg(g,A,Ir.current)?26:5:Ou&&Ch(g)?27:5;else e:switch(g){case Xo:return Fu(A.children,ee,le,b);case Ry:De=8,ee|=24;break;case Ay:return g=n(12,A,b,ee|2),g.elementType=Ay,g.lanes=le,g;case Dg:return g=n(13,A,b,ee),g.elementType=Dg,g.lanes=le,g;case vd:return g=n(19,A,b,ee),g.elementType=vd,g.lanes=le,g;case im:return Rc(A,ee,le,b);default:if(typeof g=="object"&&g!==null)switch(g.$$typeof){case Yo:case Ac:De=10;break e;case gd:De=9;break e;case Fp:De=11;break e;case Np:De=14;break e;case Go:De=16,z=null;break e}De=29,A=Error(i(130,g===null?"null":typeof g,"")),z=null}return b=n(De,A,b,ee),b.elementType=g,b.type=z,b.lanes=le,b}function Fu(g,b,A,z){return g=n(7,g,z,b),g.lanes=A,g}function Rc(g,b,A,z){g=n(22,g,z,b),g.elementType=im,g.lanes=A;var ee={_visibility:1,_pendingVisibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null,_current:null,detach:function(){var le=ee._current;if(le===null)throw Error(i(456));if((ee._pendingVisibility&2)===0){var De=Re(le,2);De!==null&&(ee._pendingVisibility|=2,mu(De,le,2))}},attach:function(){var le=ee._current;if(le===null)throw Error(i(456));if((ee._pendingVisibility&2)!==0){var De=Re(le,2);De!==null&&(ee._pendingVisibility&=-3,mu(De,le,2))}}};return g.stateNode=ee,g}function Bl(g,b,A){return g=n(6,g,null,b),g.lanes=A,g}function md(g,b,A){return b=n(4,g.children!==null?g.children:[],g.key,b),b.lanes=A,b.stateNode={containerInfo:g.containerInfo,pendingChildren:null,implementation:g.implementation},b}function xh(g,b,A,z,ee,le,De,Ie){this.tag=1,this.containerInfo=g,this.finishedWork=this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=xd,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=j(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.finishedLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=j(0),this.hiddenUpdates=j(null),this.identifierPrefix=z,this.onUncaughtError=ee,this.onCaughtError=le,this.onRecoverableError=De,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=Ie,this.incompleteTransitions=new Map}function vu(g,b,A,z,ee,le,De,Ie,We,vt,kt,Ht){return g=new xh(g,b,A,De,Ie,We,vt,Ht),b=1,le===!0&&(b|=24),le=n(3,null,null,b),g.current=le,le.stateNode=g,b=sd(),b.refCount++,g.pooledCache=b,b.refCount++,le.memoizedState={element:z,isDehydrated:A,cache:b},gt(le),g}function mo(g){return g?(g=Nc,g):Nc}function $y(g){var b=g._reactInternals;if(b===void 0)throw typeof g.render=="function"?Error(i(188)):(g=Object.keys(g).join(","),Error(i(268,g)));return g=m(b),g=g!==null?y(g):null,g===null?null:Lp(g.stateNode)}function Nb(g,b,A,z,ee,le){ee=mo(ee),z.context===null?z.context=ee:z.pendingContext=ee,z=zt(b),z.payload={element:A},le=le===void 0?null:le,le!==null&&(z.callback=le),A=an(g,z,b),A!==null&&(mu(A,g,b),rn(A,g,b))}function Ib(g,b){if(g=g.memoizedState,g!==null&&g.dehydrated!==null){var A=g.retryLane;g.retryLane=A!==0&&A<b?A:b}}function Cy(g,b){Ib(g,b),(g=g.alternate)&&Ib(g,b)}var yn={},Is=nr(),Nu=gbe(),Sh=Object.assign,wy=Symbol.for("react.element"),Ef=Symbol.for("react.transitional.element"),Ls=Symbol.for("react.portal"),Xo=Symbol.for("react.fragment"),Ry=Symbol.for("react.strict_mode"),Ay=Symbol.for("react.profiler"),Yo=Symbol.for("react.provider"),gd=Symbol.for("react.consumer"),Ac=Symbol.for("react.context"),Fp=Symbol.for("react.forward_ref"),Dg=Symbol.for("react.suspense"),vd=Symbol.for("react.suspense_list"),Np=Symbol.for("react.memo"),Go=Symbol.for("react.lazy"),im=Symbol.for("react.offscreen"),Lb=Symbol.for("react.memo_cache_sentinel"),am=Symbol.iterator,Bs=Symbol.for("react.client.reference"),_n=Is.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,$g,Cg,yd=!1,Ju=Array.isArray,Ip=t.rendererVersion,Qs=t.rendererPackageName,el=t.extraDevToolsConfig,Lp=t.getPublicInstance,bd=t.getRootHostContext,Ty=t.getChildHostContext,Ko=t.prepareForCommit,Tc=t.resetAfterCommit,wg=t.createInstance,kc=t.appendInitialChild,Wo=t.finalizeInitialChildren,Od=t.shouldSetTextContent,um=t.createTextInstance,Wa=t.scheduleTimeout,_h=t.cancelTimeout,xd=t.noTimeout,Ja=t.isPrimaryRenderer;t.warnsIfNotActing;var eu=t.supportsMutation,tl=t.supportsPersistence,wa=t.supportsHydration,Rg=t.getInstanceFromNode;t.beforeActiveInstanceBlur,t.afterActiveInstanceBlur;var Iu=t.preparePortalMount;t.prepareScopeUpdate,t.getInstanceFromScope;var yu=t.setCurrentUpdatePriority,tu=t.getCurrentUpdatePriority,Jo=t.resolveUpdatePriority;t.resolveEventType,t.resolveEventTimeStamp;var Sd=t.shouldAttemptEagerTransition,lm=t.detachDeletedInstance;t.requestPostPaintCallback;var Bb=t.maySuspendCommit,go=t.preloadInstance,Ql=t.startSuspendingCommit,ha=t.suspendInstance,Ag=t.waitForCommitToBeReady,bu=t.NotPendingTransition,Tn=t.HostTransitionContext,yi=t.resetFormInstance;t.bindToConsole;var pa=t.supportsMicrotasks,om=t.scheduleMicrotask,Pc=t.supportsTestSelectors,Eh=t.findFiberRoot,Tg=t.getBoundingRect,Bp=t.getTextContent,es=t.isHiddenSubtree,y4=t.matchAccessibilityRole,Yi=t.setFocusIfFocusable,kg=t.setupIntersectionObserver,Pg=t.appendChild,ky=t.appendChildToContainer,sm=t.commitTextUpdate,b4=t.commitMount,Mg=t.commitUpdate,Fg=t.insertBefore,Py=t.insertInContainerBefore,nl=t.removeChild,Ra=t.removeChildFromContainer,Dh=t.resetTextContent,Qp=t.hideInstance,zp=t.hideTextInstance,My=t.unhideInstance,zs=t.unhideTextInstance,Jn=t.clearContainer,Fy=t.cloneInstance,Ng=t.createContainerChildSet,$h=t.appendChildToContainerChildSet,Ny=t.finalizeContainerChildren,Iy=t.replaceContainerChildren,Ly=t.cloneHiddenInstance,zl=t.cloneHiddenTextInstance,Ig=t.isSuspenseInstancePending,_d=t.isSuspenseInstanceFallback,Lg=t.getSuspenseInstanceFallbackErrorDetails,Qb=t.registerSuspenseInstanceRetry,By=t.canHydrateFormStateMarker,ql=t.isFormStateMarkerMatching,Mc=t.getNextHydratableSibling,qp=t.getFirstHydratableChild,Qy=t.getFirstHydratableChildWithinContainer,cm=t.getFirstHydratableChildWithinSuspenseInstance,zy=t.canHydrateInstance,Bg=t.canHydrateTextInstance,qy=t.canHydrateSuspenseInstance,Vy=t.hydrateInstance,Qg=t.hydrateTextInstance,vo=t.hydrateSuspenseInstance,zb=t.getNextHydratableInstanceAfterSuspenseInstance,qs=t.commitHydratedContainer,fm=t.commitHydratedSuspenseInstance,Uy=t.clearSuspenseBoundary,dm=t.clearSuspenseBoundaryFromContainer,qb=t.shouldDeleteUnhydratedTailInstances;t.diffHydratedPropsForDevWarnings,t.diffHydratedTextForDevWarnings,t.describeHydratableInstanceForDevWarnings;var Vb=t.validateHydratableInstance,Ub=t.validateHydratableTextInstance,Vl=t.supportsResources,zg=t.isHostHoistableType,qg=t.getHoistableRoot,hm=t.getResource,Vg=t.acquireResource,rl=t.releaseResource,ts=t.hydrateHoistable,jy=t.mountHoistable,Zy=t.unmountHoistable,Ug=t.createHoistableInstance,Ed=t.prepareToCommitHoistables,Hy=t.mayResourceSuspendCommit,jg=t.preloadResource,Xy=t.suspendResource,Ou=t.supportsSingletons,Dd=t.resolveSingletonInstance,pm=t.clearSingleton,O4=t.acquireSingletonInstance,Yy=t.releaseSingletonInstance,Ch=t.isHostSingletonType,$d=[],Fc=-1,Nc={},il=Math.clz32?Math.clz32:C,Cd=Math.log,jb=Math.LN2,wh=128,wd=4194304,Rh=Nu.unstable_scheduleCallback,Ah=Nu.unstable_cancelCallback,Zb=Nu.unstable_shouldYield,Gy=Nu.unstable_requestPaint,qi=Nu.unstable_now,Zg=Nu.unstable_ImmediatePriority,Ky=Nu.unstable_UserBlockingPriority,Hg=Nu.unstable_NormalPriority,mm=Nu.unstable_IdlePriority,Hb=Nu.log,Wy=Nu.unstable_setDisableYieldValue,Ul=null,al=null,Ol=typeof Object.is=="function"?Object.is:te,Vp=new WeakMap,bi=[],$i=0,Sn=null,Rd=0,xl=[],nu=0,Vs=null,ns=1,yo="",Ir=_(null),gm=_(null),Us=_(null),Th=_(null),ul=null,xu=null,Lr=!1,bo=null,rs=!1,Oo=Error(i(519)),Ci=[],Ic=0,Up=0,Ad=null,kh=null,vm=!1,Df=!1,is=!1,$f=0,ym=null,Xg=0,jl=0,Td=null,Lc=!1,Ph=!1,bm=Object.prototype.hasOwnProperty,Xr=Error(i(460)),Yg=Error(i(474)),kd={then:function(){}},Cf=null,js=null,xo=0,Zs=nt(!0),Gg=nt(!1),ru=_(null),iu=_(0),So=_(null),_o=null,za=_(0),Bc=0,er=null,Yr=null,Aa=null,as=!1,Vi=!1,wf=!1,Om=0,ma=0,jp=null,Jy=0,xm=function(){return{lastEffect:null,events:null,stores:null,memoCache:null}},Rr={readContext:Ba,use:Wi,useCallback:Rt,useContext:Rt,useEffect:Rt,useImperativeHandle:Rt,useLayoutEffect:Rt,useInsertionEffect:Rt,useMemo:Rt,useReducer:Rt,useRef:Rt,useState:Rt,useDebugValue:Rt,useDeferredValue:Rt,useTransition:Rt,useSyncExternalStore:Rt,useId:Rt};Rr.useCacheRefresh=Rt,Rr.useMemoCache=Rt,Rr.useHostTransitionStatus=Rt,Rr.useFormState=Rt,Rr.useActionState=Rt,Rr.useOptimistic=Rt;var qa={readContext:Ba,use:Wi,useCallback:function(g,b){return Hr().memoizedState=[g,b===void 0?null:b],g},useContext:Ba,useEffect:Z0,useImperativeHandle:function(g,b,A){A=A!=null?A.concat([g]):null,Ds(4194308,4,vf.bind(null,b,g),A)},useLayoutEffect:function(g,b){return Ds(4194308,4,g,b)},useInsertionEffect:function(g,b){Ds(4,2,g,b)},useMemo:function(g,b){var A=Hr();b=b===void 0?null:b;var z=g();if(wf){J(!0);try{g()}finally{J(!1)}}return A.memoizedState=[z,b],z},useReducer:function(g,b,A){var z=Hr();if(A!==void 0){var ee=A(b);if(wf){J(!0);try{A(b)}finally{J(!1)}}}else ee=b;return z.memoizedState=z.baseState=ee,g={pending:null,lanes:0,dispatch:null,lastRenderedReducer:g,lastRenderedState:ee},z.queue=g,g=g.dispatch=yc.bind(null,er,g),[z.memoizedState,g]},useRef:function(g){var b=Hr();return g={current:g},b.memoizedState=g},useState:function(g){g=Fr(g);var b=g.queue,A=dh.bind(null,er,b);return b.dispatch=A,[g.memoizedState,A]},useDebugValue:sh,useDeferredValue:function(g,b){var A=Hr();return vc(A,g,b)},useTransition:function(){var g=Fr(!1);return g=Sp.bind(null,er,g.queue,!0,!1),Hr().memoizedState=g,[!1,g]},useSyncExternalStore:function(g,b,A){var z=er,ee=Hr();if(Lr){if(A===void 0)throw Error(i(407));A=A()}else{if(A=b(),dr===null)throw Error(i(349));(lr&60)!==0||Ss(z,b,A)}ee.memoizedState=A;var le={value:A,getSnapshot:b};return ee.queue=le,Z0(_s.bind(null,z,le,g),[g]),z.flags|=2048,Bo(9,ni.bind(null,z,le,A,b),{destroy:void 0},null),A},useId:function(){var g=Hr(),b=dr.identifierPrefix;if(Lr){var A=yo,z=ns;A=(z&~(1<<32-il(z)-1)).toString(32)+A,b=":"+b+"R"+A,A=Om++,0<A&&(b+="H"+A.toString(32)),b+=":"}else A=Jy++,b=":"+b+"r"+A.toString(32)+":";return g.memoizedState=b},useCacheRefresh:function(){return Hr().memoizedState=fh.bind(null,er)}};qa.useMemoCache=ti,qa.useHostTransitionStatus=ws,qa.useFormState=td,qa.useActionState=td,qa.useOptimistic=function(g){var b=Hr();b.memoizedState=b.baseState=g;var A={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return b.queue=A,b=Bn.bind(null,er,!0,A),A.dispatch=b,[g,b]};var ll={readContext:Ba,use:Wi,useCallback:ch,useContext:Ba,useEffect:gf,useImperativeHandle:lo,useInsertionEffect:H0,useLayoutEffect:xp,useMemo:Cs,useReducer:uo,useRef:Au,useState:function(){return uo(Ru)},useDebugValue:sh,useDeferredValue:function(g,b){var A=Pt();return X0(A,Yr.memoizedState,g,b)},useTransition:function(){var g=uo(Ru)[0],b=Pt().memoizedState;return[typeof g=="boolean"?g:ca(g),b]},useSyncExternalStore:xs,useId:Qo};ll.useCacheRefresh=Ep,ll.useMemoCache=ti,ll.useHostTransitionStatus=ws,ll.useFormState=Es,ll.useActionState=Es,ll.useOptimistic=function(g,b){var A=Pt();return Ji(A,Yr,g,b)};var Pd={readContext:Ba,use:Wi,useCallback:ch,useContext:Ba,useEffect:gf,useImperativeHandle:lo,useInsertionEffect:H0,useLayoutEffect:xp,useMemo:Cs,useReducer:gi,useRef:Au,useState:function(){return gi(Ru)},useDebugValue:sh,useDeferredValue:function(g,b){var A=Pt();return Yr===null?vc(A,g,b):X0(A,Yr.memoizedState,g,b)},useTransition:function(){var g=gi(Ru)[0],b=Pt().memoizedState;return[typeof g=="boolean"?g:ca(g),b]},useSyncExternalStore:xs,useId:Qo};Pd.useCacheRefresh=Ep,Pd.useMemoCache=ti,Pd.useHostTransitionStatus=ws,Pd.useFormState=gc,Pd.useActionState=gc,Pd.useOptimistic=function(g,b){var A=Pt();return Yr!==null?Ji(A,Yr,g,b):(A.baseState=g,[g,A.queue.dispatch])};var Sm={isMounted:function(g){return(g=g._reactInternals)?d(g)===g:!1},enqueueSetState:function(g,b,A){g=g._reactInternals;var z=Xi(),ee=zt(z);ee.payload=b,A!=null&&(ee.callback=A),b=an(g,ee,z),b!==null&&(mu(b,g,z),rn(b,g,z))},enqueueReplaceState:function(g,b,A){g=g._reactInternals;var z=Xi(),ee=zt(z);ee.tag=1,ee.payload=b,A!=null&&(ee.callback=A),b=an(g,ee,z),b!==null&&(mu(b,g,z),rn(b,g,z))},enqueueForceUpdate:function(g,b){g=g._reactInternals;var A=Xi(),z=zt(A);z.tag=2,b!=null&&(z.callback=b),b=an(g,z,A),b!==null&&(mu(b,g,A),rn(b,g,A))}},e1=typeof reportError=="function"?reportError:function(g){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var b=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof g=="object"&&g!==null&&typeof g.message=="string"?String(g.message):String(g),error:g});if(!window.dispatchEvent(b))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",g);return}console.error(g)},Xb=Error(i(461)),Ta=!1,ol={dehydrated:null,treeContext:null,retryLane:0},Zl=_(null),Md=null,Br=null,Yb=typeof AbortController<"u"?AbortController:function(){var g=[],b=this.signal={aborted:!1,addEventListener:function(A,z){g.push(z)}};this.abort=function(){b.aborted=!0,g.forEach(function(A){return A()})}},Rf=Nu.unstable_scheduleCallback,Mh=Nu.unstable_NormalPriority,Gr={$$typeof:Ac,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0},Kg=_n.S;_n.S=function(g,b){typeof b=="object"&&b!==null&&typeof b.then=="function"&&st(g,b),Kg!==null&&Kg(g,b)};var Af=_(null),au=!1,ra=!1,Qc=!1,Zp=typeof WeakSet=="function"?WeakSet:Set,ga=null,Fh=!1,ka=null,Hl=!1,Sl=null,Nh=8192,Wg={getCacheForType:function(g){var b=Ba(Gr),A=b.data.get(g);return A===void 0&&(A=g(),b.data.set(g,A)),A}},_m=0,Jg=1,ev=2,Ar=3,ii=4;if(typeof Symbol=="function"&&Symbol.for){var tr=Symbol.for;_m=tr("selector.component"),Jg=tr("selector.has_pseudo_class"),ev=tr("selector.role"),Ar=tr("selector.test_id"),ii=tr("selector.text")}var yr=typeof WeakMap=="function"?WeakMap:Map,bn=0,dr=null,Yn=null,lr=0,Oi=0,ia=null,Kr=!1,Eo=!1,Tf=!1,Hs=0,Tr=0,Do=0,Xs=0,sl=0,Xl=0,zc=0,Hp=null,cl=null,Xp=!1,qc=0,aa=1/0,Ys=null,$o=null,us=!1,kf=null,Ih=0,tv=0,Lh=null,Bh=0,_l=null;return yn.attemptContinuousHydration=function(g){if(g.tag===13){var b=Re(g,67108864);b!==null&&mu(b,g,67108864),Cy(g,67108864)}},yn.attemptHydrationAtCurrentPriority=function(g){if(g.tag===13){var b=Xi(),A=Re(g,b);A!==null&&mu(A,g,b),Cy(g,b)}},yn.attemptSynchronousHydration=function(g){switch(g.tag){case 3:if(g=g.stateNode,g.current.memoizedState.isDehydrated){var b=T(g.pendingLanes);if(b!==0){for(g.pendingLanes|=2,g.entangledLanes|=2;b;){var A=1<<31-il(b);g.entanglements[1]|=A,b&=~A}Oe(g),(bn&6)===0&&(aa=qi()+500,$e(0))}}break;case 13:b=Re(g,2),b!==null&&mu(b,g,2),Mp(),Cy(g,2)}},yn.batchedUpdates=function(g,b){return g(b)},yn.createComponentSelector=function(g){return{$$typeof:_m,value:g}},yn.createContainer=function(g,b,A,z,ee,le,De,Ie,We,vt){return vu(g,b,!1,null,A,z,le,De,Ie,We,vt,null)},yn.createHasPseudoClassSelector=function(g){return{$$typeof:Jg,value:g}},yn.createHydrationContainer=function(g,b,A,z,ee,le,De,Ie,We,vt,kt,Ht,Wt){return g=vu(A,z,!0,g,ee,le,Ie,We,vt,kt,Ht,Wt),g.context=mo(null),A=g.current,z=Xi(),ee=zt(z),ee.callback=b??null,an(A,ee,z),g.current.lanes=z,V(g,z),Oe(g),g},yn.createPortal=function(g,b,A){var z=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:Ls,key:z==null?null:""+z,children:g,containerInfo:b,implementation:A}},yn.createRoleSelector=function(g){return{$$typeof:ev,value:g}},yn.createTestNameSelector=function(g){return{$$typeof:Ar,value:g}},yn.createTextSelector=function(g){return{$$typeof:ii,value:g}},yn.defaultOnCaughtError=function(g){console.error(g)},yn.defaultOnRecoverableError=function(g){e1(g)},yn.defaultOnUncaughtError=function(g){e1(g)},yn.deferredUpdates=function(g){var b=_n.T,A=tu();try{return yu(32),_n.T=null,g()}finally{yu(A),_n.T=b}},yn.discreteUpdates=function(g,b,A,z,ee){var le=_n.T,De=tu();try{return yu(2),_n.T=null,g(b,A,z,ee)}finally{yu(De),_n.T=le,bn===0&&(aa=qi()+500)}},yn.findAllNodes=na,yn.findBoundingRects=function(g,b){if(!Pc)throw Error(i(363));b=na(g,b),g=[];for(var A=0;A<b.length;A++)g.push(Tg(b[A]));for(b=g.length-1;0<b;b--){A=g[b];for(var z=A.x,ee=z+A.width,le=A.y,De=le+A.height,Ie=b-1;0<=Ie;Ie--)if(b!==Ie){var We=g[Ie],vt=We.x,kt=vt+We.width,Ht=We.y,Wt=Ht+We.height;if(z>=vt&&le>=Ht&&ee<=kt&&De<=Wt){g.splice(b,1);break}else if(z!==vt||A.width!==We.width||Wt<le||Ht>De){if(!(le!==Ht||A.height!==We.height||kt<z||vt>ee)){vt>z&&(We.width+=vt-z,We.x=z),kt<ee&&(We.width=ee-vt),g.splice(b,1);break}}else{Ht>le&&(We.height+=Ht-le,We.y=le),Wt<De&&(We.height=De-Ht),g.splice(b,1);break}}}return g},yn.findHostInstance=$y,yn.findHostInstanceWithNoPortals=function(g){return g=m(g),g=g!==null?v(g):null,g===null?null:Lp(g.stateNode)},yn.findHostInstanceWithWarning=function(g){return $y(g)},yn.flushPassiveEffects=Kt,yn.flushSyncFromReconciler=function(g){var b=bn;bn|=1;var A=_n.T,z=tu();try{if(yu(2),_n.T=null,g)return g()}finally{yu(z),_n.T=A,bn=b,(bn&6)===0&&$e(0)}},yn.flushSyncWork=Mp,yn.focusWithin=function(g,b){if(!Pc)throw Error(i(363));for(g=$c(g),b=pd(g,b),b=Array.from(b),g=0;g<b.length;){var A=b[g++],z=A.tag;if(!es(A)){if((z===5||z===26||z===27)&&Yi(A.stateNode))return!0;for(A=A.child;A!==null;)b.push(A),A=A.sibling}}return!1},yn.getFindAllNodesFailureDescription=function(g,b){if(!Pc)throw Error(i(363));var A=0,z=[];g=[$c(g),0];for(var ee=0;ee<g.length;){var le=g[ee++],De=le.tag,Ie=g[ee++],We=b[Ie];if((De!==5&&De!==26&&De!==27||!es(le))&&(Cc(le,We)&&(z.push(pu(We)),Ie++,Ie>A&&(A=Ie)),Ie<b.length))for(le=le.child;le!==null;)g.push(le,Ie),le=le.sibling}if(A<b.length){for(g=[];A<b.length;A++)g.push(pu(b[A]));return`findAllNodes was able to match part of the selector:
  `+(z.join(" > ")+`

No matching component was found for:
  `)+g.join(" > ")}return null},yn.getPublicRootInstance=function(g){if(g=g.current,!g.child)return null;switch(g.child.tag){case 27:case 5:return Lp(g.child.stateNode);default:return g.child.stateNode}},yn.injectIntoDevTools=function(){var g={bundleType:0,version:Ip,rendererPackageName:Qs,currentDispatcherRef:_n,findFiberByHostInstance:Rg,reconcilerVersion:"19.0.0"};if(el!==null&&(g.rendererConfig=el),typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u")g=!1;else{var b=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(b.isDisabled||!b.supportsFiber)g=!0;else{try{Ul=b.inject(g),al=b}catch{}g=!!b.checkDCE}}return g},yn.isAlreadyRendering=function(){return!1},yn.observeVisibleRects=function(g,b,A,z){if(!Pc)throw Error(i(363));g=na(g,b);var ee=kg(g,A,z).disconnect;return{disconnect:function(){ee()}}},yn.shouldError=function(){return null},yn.shouldSuspend=function(){return!1},yn.startHostTransition=function(g,b,A,z){if(g.tag!==5)throw Error(i(476));var ee=_p(g).queue;Sp(g,ee,b,bu,A===null?r:function(){var le=_p(g).next.queue;return wr(g,le,{},Xi()),A(z)})},yn.updateContainer=function(g,b,A,z){var ee=b.current,le=Xi();return Nb(ee,le,g,b,A,z),le},yn.updateContainerSync=function(g,b,A,z){return b.tag===0&&Kt(),Nb(b.current,2,g,b,A,z),2},yn},e.exports.default=e.exports,Object.defineProperty(e.exports,"__esModule",{value:!0})})(P7)),P7.exports}var NW;function Jet(){return NW||(NW=1,k7.exports=Wet()),k7.exports}var ett=Jet();const ttt=sa(ett);var IW=gbe();function CB(e,t,n){if(!e)return;if(n(e)===!0)return e;let r=t?e.return:e.child;for(;r;){const i=CB(r,t,n);if(i)return i;r=t?null:r.sibling}}function vbe(e){try{return Object.defineProperties(e,{_currentRenderer:{get(){return null},set(){}},_currentRenderer2:{get(){return null},set(){}}})}catch{return e}}const wB=vbe(P.createContext(null));class ybe extends P.Component{render(){return P.createElement(wB.Provider,{value:this._reactInternals},this.props.children)}}function bbe(){const e=P.useContext(wB);if(e===null)throw new Error("its-fine: useFiber must be called within a <FiberProvider />!");const t=P.useId();return P.useMemo(()=>{for(const n of[e,e==null?void 0:e.alternate]){if(!n)continue;const r=CB(n,!1,i=>{let a=i.memoizedState;for(;a;){if(a.memoizedState===t)return!0;a=a.next}});if(r)return r}},[e,t])}const ntt=Symbol.for("react.context"),rtt=e=>e!==null&&typeof e=="object"&&"$$typeof"in e&&e.$$typeof===ntt;function itt(){const e=bbe(),[t]=P.useState(()=>new Map);t.clear();let n=e;for(;n;){const r=n.type;rtt(r)&&r!==wB&&!t.has(r)&&t.set(r,P.use(vbe(r))),n=n.return}return t}function att(){const e=itt();return P.useMemo(()=>Array.from(e.keys()).reduce((t,n)=>r=>P.createElement(t,null,P.createElement(n.Provider,{...r,value:e.get(n)})),t=>P.createElement(ybe,{...t})),[e])}function Obe(e){let t=e.root;for(;t.getState().previousRoot;)t=t.getState().previousRoot;return t}const xbe=e=>e&&e.isOrthographicCamera,utt=e=>e&&e.hasOwnProperty("current"),ltt=e=>e!=null&&(typeof e=="string"||typeof e=="number"||e.isColor),QS=((e,t)=>typeof window<"u"&&(((e=window.document)==null?void 0:e.createElement)||((t=window.navigator)==null?void 0:t.product)==="ReactNative"))()?P.useLayoutEffect:P.useEffect;function Sbe(e){const t=P.useRef(e);return QS(()=>void(t.current=e),[e]),t}function ott(){const e=bbe(),t=att();return P.useMemo(()=>({children:n})=>{const i=!!CB(e,!0,a=>a.type===P.StrictMode)?P.StrictMode:P.Fragment;return Mr.jsx(i,{children:Mr.jsx(t,{children:n})})},[e,t])}function stt({set:e}){return QS(()=>(e(new Promise(()=>null)),()=>e(!1)),[e]),null}const ctt=(e=>(e=class extends P.Component{constructor(...n){super(...n),this.state={error:!1}}componentDidCatch(n){this.props.set(n)}render(){return this.state.error?null:this.props.children}},e.getDerivedStateFromError=()=>({error:!0}),e))();function _be(e){var t;const n=typeof window<"u"?(t=window.devicePixelRatio)!=null?t:2:1;return Array.isArray(e)?Math.min(Math.max(e[0],n),e[1]):e}function kO(e){var t;return(t=e.__r3f)==null?void 0:t.root.getState()}const lu={obj:e=>e===Object(e)&&!lu.arr(e)&&typeof e!="function",fun:e=>typeof e=="function",str:e=>typeof e=="string",num:e=>typeof e=="number",boo:e=>typeof e=="boolean",und:e=>e===void 0,nul:e=>e===null,arr:e=>Array.isArray(e),equ(e,t,{arrays:n="shallow",objects:r="reference",strict:i=!0}={}){if(typeof e!=typeof t||!!e!=!!t)return!1;if(lu.str(e)||lu.num(e)||lu.boo(e))return e===t;const a=lu.obj(e);if(a&&r==="reference")return e===t;const u=lu.arr(e);if(u&&n==="reference")return e===t;if((u||a)&&e===t)return!0;let l;for(l in e)if(!(l in t))return!1;if(a&&n==="shallow"&&r==="shallow"){for(l in i?t:e)if(!lu.equ(e[l],t[l],{strict:i,objects:"reference"}))return!1}else for(l in i?t:e)if(e[l]!==t[l])return!1;if(lu.und(l)){if(u&&e.length===0&&t.length===0||a&&Object.keys(e).length===0&&Object.keys(t).length===0)return!0;if(e!==t)return!1}return!0}};function ftt(e){e.type!=="Scene"&&(e.dispose==null||e.dispose());for(const t in e){const n=e[t];(n==null?void 0:n.type)!=="Scene"&&(n==null||n.dispose==null||n.dispose())}}const Ebe=["children","key","ref"];function dtt(e){const t={};for(const n in e)Ebe.includes(n)||(t[n]=e[n]);return t}function fC(e,t,n,r){const i=e;let a=i==null?void 0:i.__r3f;return a||(a={root:t,type:n,parent:null,children:[],props:dtt(r),object:i,eventCount:0,handlers:{},isHidden:!1},i&&(i.__r3f=a)),a}function eS(e,t){let n=e[t];if(!t.includes("-"))return{root:e,key:t,target:n};n=e;for(const i of t.split("-")){var r;t=i,e=n,n=(r=n)==null?void 0:r[t]}return{root:e,key:t,target:n}}const LW=/-\d+$/;function dC(e,t){if(lu.str(t.props.attach)){if(LW.test(t.props.attach)){const i=t.props.attach.replace(LW,""),{root:a,key:u}=eS(e.object,i);Array.isArray(a[u])||(a[u]=[])}const{root:n,key:r}=eS(e.object,t.props.attach);t.previousAttach=n[r],n[r]=t.object}else lu.fun(t.props.attach)&&(t.previousAttach=t.props.attach(e.object,t.object))}function hC(e,t){if(lu.str(t.props.attach)){const{root:n,key:r}=eS(e.object,t.props.attach),i=t.previousAttach;i===void 0?delete n[r]:n[r]=i}else t.previousAttach==null||t.previousAttach(e.object,t.object);delete t.previousAttach}const SF=[...Ebe,"args","dispose","attach","object","onUpdate","dispose"],BW=new Map;function htt(e){let t=BW.get(e.constructor);try{t||(t=new e.constructor,BW.set(e.constructor,t))}catch{}return t}function ptt(e,t){const n={};for(const r in t)if(!SF.includes(r)&&!lu.equ(t[r],e.props[r])){n[r]=t[r];for(const i in t)i.startsWith(`${r}-`)&&(n[i]=t[i])}for(const r in e.props){if(SF.includes(r)||t.hasOwnProperty(r))continue;const{root:i,key:a}=eS(e.object,r);if(i.constructor&&i.constructor.length===0){const u=htt(i);lu.und(u)||(n[a]=u[a])}else n[a]=0}return n}const mtt=["map","emissiveMap","sheenColorMap","specularColorMap","envMap"],gtt=/^on(Pointer|Click|DoubleClick|ContextMenu|Wheel)/;function Pv(e,t){var n;const r=e.__r3f,i=r&&Obe(r).getState(),a=r==null?void 0:r.eventCount;for(const l in t){let o=t[l];if(SF.includes(l))continue;if(r&&gtt.test(l)){typeof o=="function"?r.handlers[l]=o:delete r.handlers[l],r.eventCount=Object.keys(r.handlers).length;continue}if(o===void 0)continue;let{root:s,key:c,target:d}=eS(e,l);if(d instanceof FB&&o instanceof FB)d.mask=o.mask;else if(d instanceof mC&&ltt(o))d.set(o);else if(d!==null&&typeof d=="object"&&typeof d.set=="function"&&typeof d.copy=="function"&&o!=null&&o.constructor&&d.constructor===o.constructor)d.copy(o);else if(d!==null&&typeof d=="object"&&typeof d.set=="function"&&Array.isArray(o))typeof d.fromArray=="function"?d.fromArray(o):d.set(...o);else if(d!==null&&typeof d=="object"&&typeof d.set=="function"&&typeof o=="number")typeof d.setScalar=="function"?d.setScalar(o):d.set(o);else{var u;s[c]=o,i&&!i.linear&&mtt.includes(c)&&(u=s[c])!=null&&u.isTexture&&s[c].format===iOe&&s[c].type===aOe&&(s[c].colorSpace=rJ)}}if(r!=null&&r.parent&&i!=null&&i.internal&&(n=r.object)!=null&&n.isObject3D&&a!==r.eventCount){const l=r.object,o=i.internal.interaction.indexOf(l);o>-1&&i.internal.interaction.splice(o,1),r.eventCount&&l.raycast!==null&&i.internal.interaction.push(l)}return r&&r.props.attach===void 0&&(r.object.isBufferGeometry?r.props.attach="geometry":r.object.isMaterial&&(r.props.attach="material")),r&&v4(r),e}function v4(e){var t;if(!e.parent)return;e.props.onUpdate==null||e.props.onUpdate(e.object);const n=(t=e.root)==null||t.getState==null?void 0:t.getState();n&&n.internal.frames===0&&n.invalidate()}function vtt(e,t){e.manual||(xbe(e)?(e.left=t.width/-2,e.right=t.width/2,e.top=t.height/2,e.bottom=t.height/-2):e.aspect=t.width/t.height,e.updateProjectionMatrix())}const Jc=e=>e==null?void 0:e.isObject3D;function kE(e){return(e.eventObject||e.object).uuid+"/"+e.index+e.instanceId}function Dbe(e,t,n,r){const i=n.get(t);i&&(n.delete(t),n.size===0&&(e.delete(r),i.target.releasePointerCapture(r)))}function ytt(e,t){const{internal:n}=e.getState();n.interaction=n.interaction.filter(r=>r!==t),n.initialHits=n.initialHits.filter(r=>r!==t),n.hovered.forEach((r,i)=>{(r.eventObject===t||r.object===t)&&n.hovered.delete(i)}),n.capturedMap.forEach((r,i)=>{Dbe(n.capturedMap,t,r,i)})}function btt(e){function t(o){const{internal:s}=e.getState(),c=o.offsetX-s.initialClick[0],d=o.offsetY-s.initialClick[1];return Math.round(Math.sqrt(c*c+d*d))}function n(o){return o.filter(s=>["Move","Over","Enter","Out","Leave"].some(c=>{var d;return(d=s.__r3f)==null?void 0:d.handlers["onPointer"+c]}))}function r(o,s){const c=e.getState(),d=new Set,h=[],m=s?s(c.internal.interaction):c.internal.interaction;for(let S=0;S<m.length;S++){const E=kO(m[S]);E&&(E.raycaster.camera=void 0)}c.previousRoot||c.events.compute==null||c.events.compute(o,c);function y(S){const E=kO(S);if(!E||!E.events.enabled||E.raycaster.camera===null)return[];if(E.raycaster.camera===void 0){var C;E.events.compute==null||E.events.compute(o,E,(C=E.previousRoot)==null?void 0:C.getState()),E.raycaster.camera===void 0&&(E.raycaster.camera=null)}return E.raycaster.camera?E.raycaster.intersectObject(S,!0):[]}let v=m.flatMap(y).sort((S,E)=>{const C=kO(S.object),T=kO(E.object);return!C||!T?S.distance-E.distance:T.events.priority-C.events.priority||S.distance-E.distance}).filter(S=>{const E=kE(S);return d.has(E)?!1:(d.add(E),!0)});c.events.filter&&(v=c.events.filter(v,c));for(const S of v){let E=S.object;for(;E;){var _;(_=E.__r3f)!=null&&_.eventCount&&h.push({...S,eventObject:E}),E=E.parent}}if("pointerId"in o&&c.internal.capturedMap.has(o.pointerId))for(let S of c.internal.capturedMap.get(o.pointerId).values())d.has(kE(S.intersection))||h.push(S.intersection);return h}function i(o,s,c,d){if(o.length){const h={stopped:!1};for(const m of o){let y=kO(m.object);if(y||m.object.traverseAncestors(v=>{const _=kO(v);if(_)return y=_,!1}),y){const{raycaster:v,pointer:_,camera:S,internal:E}=y,C=new li(_.x,_.y,0).unproject(S),T=L=>{var j,V;return(j=(V=E.capturedMap.get(L))==null?void 0:V.has(m.eventObject))!=null?j:!1},R=L=>{const j={intersection:m,target:s.target};E.capturedMap.has(L)?E.capturedMap.get(L).set(m.eventObject,j):E.capturedMap.set(L,new Map([[m.eventObject,j]])),s.target.setPointerCapture(L)},$=L=>{const j=E.capturedMap.get(L);j&&Dbe(E.capturedMap,m.eventObject,j,L)};let k={};for(let L in s){let j=s[L];typeof j!="function"&&(k[L]=j)}let F={...m,...k,pointer:_,intersections:o,stopped:h.stopped,delta:c,unprojectedPoint:C,ray:v.ray,camera:S,stopPropagation(){const L="pointerId"in s&&E.capturedMap.get(s.pointerId);if((!L||L.has(m.eventObject))&&(F.stopped=h.stopped=!0,E.hovered.size&&Array.from(E.hovered.values()).find(j=>j.eventObject===m.eventObject))){const j=o.slice(0,o.indexOf(m));a([...j,m])}},target:{hasPointerCapture:T,setPointerCapture:R,releasePointerCapture:$},currentTarget:{hasPointerCapture:T,setPointerCapture:R,releasePointerCapture:$},nativeEvent:s};if(d(F),h.stopped===!0)break}}}return o}function a(o){const{internal:s}=e.getState();for(const c of s.hovered.values())if(!o.length||!o.find(d=>d.object===c.object&&d.index===c.index&&d.instanceId===c.instanceId)){const h=c.eventObject.__r3f;if(s.hovered.delete(kE(c)),h!=null&&h.eventCount){const m=h.handlers,y={...c,intersections:o};m.onPointerOut==null||m.onPointerOut(y),m.onPointerLeave==null||m.onPointerLeave(y)}}}function u(o,s){for(let c=0;c<s.length;c++){const d=s[c].__r3f;d==null||d.handlers.onPointerMissed==null||d.handlers.onPointerMissed(o)}}function l(o){switch(o){case"onPointerLeave":case"onPointerCancel":return()=>a([]);case"onLostPointerCapture":return s=>{const{internal:c}=e.getState();"pointerId"in s&&c.capturedMap.has(s.pointerId)&&requestAnimationFrame(()=>{c.capturedMap.has(s.pointerId)&&(c.capturedMap.delete(s.pointerId),a([]))})}}return function(c){const{onPointerMissed:d,internal:h}=e.getState();h.lastEvent.current=c;const m=o==="onPointerMove",y=o==="onClick"||o==="onContextMenu"||o==="onDoubleClick",_=r(c,m?n:void 0),S=y?t(c):0;o==="onPointerDown"&&(h.initialClick=[c.offsetX,c.offsetY],h.initialHits=_.map(C=>C.eventObject)),y&&!_.length&&S<=2&&(u(c,h.interaction),d&&d(c)),m&&a(_);function E(C){const T=C.eventObject,R=T.__r3f;if(!(R!=null&&R.eventCount))return;const $=R.handlers;if(m){if($.onPointerOver||$.onPointerEnter||$.onPointerOut||$.onPointerLeave){const k=kE(C),F=h.hovered.get(k);F?F.stopped&&C.stopPropagation():(h.hovered.set(k,C),$.onPointerOver==null||$.onPointerOver(C),$.onPointerEnter==null||$.onPointerEnter(C))}$.onPointerMove==null||$.onPointerMove(C)}else{const k=$[o];k?(!y||h.initialHits.includes(T))&&(u(c,h.interaction.filter(F=>!h.initialHits.includes(F))),k(C)):y&&h.initialHits.includes(T)&&u(c,h.interaction.filter(F=>!h.initialHits.includes(F)))}}i(_,c,S,E)}}return{handlePointer:l}}const QW=e=>!!(e!=null&&e.render),$be=P.createContext(null),Ott=(e,t)=>{const n=Get((l,o)=>{const s=new li,c=new li,d=new li;function h(S=o().camera,E=c,C=o().size){const{width:T,height:R,top:$,left:k}=C,F=T/R;E.isVector3?d.copy(E):d.set(...E);const L=S.getWorldPosition(s).distanceTo(d);if(xbe(S))return{width:T/S.zoom,height:R/S.zoom,top:$,left:k,factor:1,distance:L,aspect:F};{const j=S.fov*Math.PI/180,V=2*Math.tan(j/2)*L,q=V*(T/R);return{width:q,height:V,top:$,left:k,factor:T/q,distance:L,aspect:F}}}let m;const y=S=>l(E=>({performance:{...E.performance,current:S}})),v=new Jl;return{set:l,get:o,gl:null,camera:null,raycaster:null,events:{priority:1,enabled:!0,connected:!1},scene:null,xr:null,invalidate:(S=1)=>e(o(),S),advance:(S,E)=>t(S,E,o()),legacy:!1,linear:!1,flat:!1,controls:null,clock:new uOe,pointer:v,mouse:v,frameloop:"always",onPointerMissed:void 0,performance:{current:1,min:.5,max:1,debounce:200,regress:()=>{const S=o();m&&clearTimeout(m),S.performance.current!==S.performance.min&&y(S.performance.min),m=setTimeout(()=>y(o().performance.max),S.performance.debounce)}},size:{width:0,height:0,top:0,left:0},viewport:{initialDpr:0,dpr:0,width:0,height:0,top:0,left:0,aspect:0,distance:0,factor:0,getCurrentViewport:h},setEvents:S=>l(E=>({...E,events:{...E.events,...S}})),setSize:(S,E,C=0,T=0)=>{const R=o().camera,$={width:S,height:E,top:C,left:T};l(k=>({size:$,viewport:{...k.viewport,...h(R,c,$)}}))},setDpr:S=>l(E=>{const C=_be(S);return{viewport:{...E.viewport,dpr:C,initialDpr:E.viewport.initialDpr||C}}}),setFrameloop:(S="always")=>{const E=o().clock;E.stop(),E.elapsedTime=0,S!=="never"&&(E.start(),E.elapsedTime=0),l(()=>({frameloop:S}))},previousRoot:void 0,internal:{interaction:[],hovered:new Map,subscribers:[],initialClick:[0,0],initialHits:[],capturedMap:new Map,lastEvent:P.createRef(),active:!1,frames:0,priority:0,subscribe:(S,E,C)=>{const T=o().internal;return T.priority=T.priority+(E>0?1:0),T.subscribers.push({ref:S,priority:E,store:C}),T.subscribers=T.subscribers.sort((R,$)=>R.priority-$.priority),()=>{const R=o().internal;R!=null&&R.subscribers&&(R.priority=R.priority-(E>0?1:0),R.subscribers=R.subscribers.filter($=>$.ref!==S))}}}}}),r=n.getState();let i=r.size,a=r.viewport.dpr,u=r.camera;return n.subscribe(()=>{const{camera:l,size:o,viewport:s,gl:c,set:d}=n.getState();if(o.width!==i.width||o.height!==i.height||s.dpr!==a){i=o,a=s.dpr,vtt(l,o),s.dpr>0&&c.setPixelRatio(s.dpr);const h=typeof HTMLCanvasElement<"u"&&c.domElement instanceof HTMLCanvasElement;c.setSize(o.width,o.height,h)}l!==u&&(u=l,d(h=>({viewport:{...h.viewport,...h.viewport.getCurrentViewport(l)}})))}),n.subscribe(l=>e(l)),n};function Cbe(){const e=P.useContext($be);if(!e)throw new Error("R3F: Hooks can only be used within the Canvas component!");return e}function zd(e=n=>n,t){return Cbe()(e,t)}function m5(e,t=0){const n=Cbe(),r=n.getState().internal.subscribe,i=Sbe(e);return QS(()=>r(i,t,n),[t,r,n]),null}function xtt(e){const t=ttt(e);return t.injectIntoDevTools({bundleType:0,rendererPackageName:"@react-three/fiber",version:P.version}),t}const wbe=0,q3={},Stt=/^three(?=[A-Z])/,g5=e=>`${e[0].toUpperCase()}${e.slice(1)}`;let _tt=0;const Ett=e=>typeof e=="function";function Dtt(e){if(Ett(e)){const t=`${_tt++}`;return q3[t]=e,t}else Object.assign(q3,e)}function Rbe(e,t){const n=g5(e),r=q3[n];if(e!=="primitive"&&!r)throw new Error(`R3F: ${n} is not part of the THREE namespace! Did you forget to extend? See: https://docs.pmnd.rs/react-three-fiber/api/objects#using-3rd-party-objects-declaratively`);if(e==="primitive"&&!t.object)throw new Error("R3F: Primitives without 'object' are invalid!");if(t.args!==void 0&&!Array.isArray(t.args))throw new Error("R3F: The args prop must be an array!")}function $tt(e,t,n){var r;return e=g5(e)in q3?e:e.replace(Stt,""),Rbe(e,t),e==="primitive"&&(r=t.object)!=null&&r.__r3f&&delete t.object.__r3f,fC(t.object,n,e,t)}function Ctt(e){if(!e.isHidden){var t;e.props.attach&&(t=e.parent)!=null&&t.object?hC(e.parent,e):Jc(e.object)&&(e.object.visible=!1),e.isHidden=!0,v4(e)}}function Abe(e){if(e.isHidden){var t;e.props.attach&&(t=e.parent)!=null&&t.object?dC(e.parent,e):Jc(e.object)&&e.props.visible!==!1&&(e.object.visible=!0),e.isHidden=!1,v4(e)}}function RB(e,t,n){const r=t.root.getState();if(!(!e.parent&&e.object!==r.scene)){if(!t.object){var i,a;const u=q3[g5(t.type)];t.object=(i=t.props.object)!=null?i:new u(...(a=t.props.args)!=null?a:[]),t.object.__r3f=t}if(Pv(t.object,t.props),t.props.attach)dC(e,t);else if(Jc(t.object)&&Jc(e.object)){const u=e.object.children.indexOf(n==null?void 0:n.object);if(n&&u!==-1){const l=e.object.children.indexOf(t.object);if(l!==-1){e.object.children.splice(l,1);const o=l<u?u-1:u;e.object.children.splice(o,0,t.object)}else t.object.parent=e.object,e.object.children.splice(u,0,t.object),t.object.dispatchEvent({type:"added"}),e.object.dispatchEvent({type:"childadded",child:t.object})}else e.object.add(t.object)}for(const u of t.children)RB(t,u);v4(t)}}function N7(e,t){t&&(t.parent=e,e.children.push(t),RB(e,t))}function zW(e,t,n){if(!t||!n)return;t.parent=e;const r=e.children.indexOf(n);r!==-1?e.children.splice(r,0,t):e.children.push(t),RB(e,t,n)}function Tbe(e){if(typeof e.dispose=="function"){const t=()=>{try{e.dispose()}catch{}};typeof IS_REACT_ACT_ENVIRONMENT<"u"?t():IW.unstable_scheduleCallback(IW.unstable_IdlePriority,t)}}function _F(e,t,n){if(!t)return;t.parent=null;const r=e.children.indexOf(t);r!==-1&&e.children.splice(r,1),t.props.attach?hC(e,t):Jc(t.object)&&Jc(e.object)&&(e.object.remove(t.object),ytt(Obe(t),t.object));const i=t.props.dispose!==null&&n!==!1;for(let a=t.children.length-1;a>=0;a--){const u=t.children[a];_F(t,u,i)}t.children.length=0,delete t.object.__r3f,i&&t.type!=="primitive"&&t.object.type!=="Scene"&&Tbe(t.object),n===void 0&&v4(t)}function wtt(e,t){for(const n of[e,e.alternate])if(n!==null)if(typeof n.ref=="function"){n.refCleanup==null||n.refCleanup();const r=n.ref(t);typeof r=="function"&&(n.refCleanup=r)}else n.ref&&(n.ref.current=t)}const OD=[];function Rtt(){for(const[n]of OD){const r=n.parent;if(r){n.props.attach?hC(r,n):Jc(n.object)&&Jc(r.object)&&r.object.remove(n.object);for(const i of n.children)i.props.attach?hC(n,i):Jc(i.object)&&Jc(n.object)&&n.object.remove(i.object)}n.isHidden&&Abe(n),n.object.__r3f&&delete n.object.__r3f,n.type!=="primitive"&&Tbe(n.object)}for(const[n,r,i]of OD){n.props=r;const a=n.parent;if(a){var e,t;const u=q3[g5(n.type)];n.object=(e=n.props.object)!=null?e:new u(...(t=n.props.args)!=null?t:[]),n.object.__r3f=n,wtt(i,n.object),Pv(n.object,n.props),n.props.attach?dC(a,n):Jc(n.object)&&Jc(a.object)&&a.object.add(n.object);for(const l of n.children)l.props.attach?dC(n,l):Jc(l.object)&&Jc(n.object)&&n.object.add(l.object);v4(n)}}OD.length=0}const I7=()=>{},qW={};let PE=wbe;const Att=0,Ttt=4,EF=xtt({isPrimaryRenderer:!1,warnsIfNotActing:!1,supportsMutation:!0,supportsPersistence:!1,supportsHydration:!1,createInstance:$tt,removeChild:_F,appendChild:N7,appendInitialChild:N7,insertBefore:zW,appendChildToContainer(e,t){const n=e.getState().scene.__r3f;!t||!n||N7(n,t)},removeChildFromContainer(e,t){const n=e.getState().scene.__r3f;!t||!n||_F(n,t)},insertInContainerBefore(e,t,n){const r=e.getState().scene.__r3f;!t||!n||!r||zW(r,t,n)},getRootHostContext:()=>qW,getChildHostContext:()=>qW,commitUpdate(e,t,n,r,i){var a,u,l;Rbe(t,r);let o=!1;if((e.type==="primitive"&&n.object!==r.object||((a=r.args)==null?void 0:a.length)!==((u=n.args)==null?void 0:u.length)||(l=r.args)!=null&&l.some((c,d)=>{var h;return c!==((h=n.args)==null?void 0:h[d])}))&&(o=!0),o)OD.push([e,{...r},i]);else{const c=ptt(e,r);Object.keys(c).length&&(Object.assign(e.props,c),Pv(e.object,c))}(i.sibling===null||(i.flags&Ttt)===Att)&&Rtt()},finalizeInitialChildren:()=>!1,commitMount(){},getPublicInstance:e=>e==null?void 0:e.object,prepareForCommit:()=>null,preparePortalMount:e=>fC(e.getState().scene,e,"",{}),resetAfterCommit:()=>{},shouldSetTextContent:()=>!1,clearContainer:()=>!1,hideInstance:Ctt,unhideInstance:Abe,createTextInstance:I7,hideTextInstance:I7,unhideTextInstance:I7,scheduleTimeout:typeof setTimeout=="function"?setTimeout:void 0,cancelTimeout:typeof clearTimeout=="function"?clearTimeout:void 0,noTimeout:-1,getInstanceFromNode:()=>null,beforeActiveInstanceBlur(){},afterActiveInstanceBlur(){},detachDeletedInstance(){},prepareScopeUpdate(){},getInstanceFromScope:()=>null,shouldAttemptEagerTransition:()=>!1,trackSchedulerEvent:()=>{},resolveEventType:()=>null,resolveEventTimeStamp:()=>-1.1,requestPostPaintCallback(){},maySuspendCommit:()=>!1,preloadInstance:()=>!0,startSuspendingCommit(){},suspendInstance(){},waitForCommitToBeReady:()=>null,NotPendingTransition:null,HostTransitionContext:P.createContext(null),setCurrentUpdatePriority(e){PE=e},getCurrentUpdatePriority(){return PE},resolveUpdatePriority(){var e;if(PE!==wbe)return PE;switch(typeof window<"u"&&((e=window.event)==null?void 0:e.type)){case"click":case"contextmenu":case"dblclick":case"pointercancel":case"pointerdown":case"pointerup":return bD.DiscreteEventPriority;case"pointermove":case"pointerout":case"pointerover":case"pointerenter":case"pointerleave":case"wheel":return bD.ContinuousEventPriority;default:return bD.DefaultEventPriority}},resetFormInstance(){}}),xb=new Map,PO={objects:"shallow",strict:!1};function ktt(e,t){if(!t&&typeof HTMLCanvasElement<"u"&&e instanceof HTMLCanvasElement&&e.parentElement){const{width:n,height:r,top:i,left:a}=e.parentElement.getBoundingClientRect();return{width:n,height:r,top:i,left:a}}else if(!t&&typeof OffscreenCanvas<"u"&&e instanceof OffscreenCanvas)return{width:e.width,height:e.height,top:0,left:0};return{width:0,height:0,top:0,left:0,...t}}function Ptt(e){const t=xb.get(e),n=t==null?void 0:t.fiber,r=t==null?void 0:t.store;t&&console.warn("R3F.createRoot should only be called once!");const i=typeof reportError=="function"?reportError:console.error,a=r||Ott(CF,UW),u=n||EF.createContainer(a,bD.ConcurrentRoot,null,!1,null,"",i,i,i,null);t||xb.set(e,{fiber:u,store:a});let l,o,s=!1,c=null;return{async configure(d={}){let h;c=new Promise(K=>h=K);let{gl:m,size:y,scene:v,events:_,onCreated:S,shadows:E=!1,linear:C=!1,flat:T=!1,legacy:R=!1,orthographic:$=!1,frameloop:k="always",dpr:F=[1,2],performance:L,raycaster:j,camera:V,onPointerMissed:q}=d,N=a.getState(),U=N.gl;if(!N.gl){const K={canvas:e,powerPreference:"high-performance",antialias:!0,alpha:!0},X=typeof m=="function"?await m(K):m;QW(X)?U=X:U=new Xbe({...K,...m}),N.set({gl:U})}let W=N.raycaster;W||N.set({raycaster:W=new Ybe});const{params:G,...J}=j||{};if(lu.equ(J,W,PO)||Pv(W,{...J}),lu.equ(G,W.params,PO)||Pv(W,{params:{...W.params,...G}}),!N.camera||N.camera===o&&!lu.equ(o,V,PO)){o=V;const K=V==null?void 0:V.isCamera,X=K?V:$?new KO(0,0,0,0,.1,1e3):new WO(75,0,.1,1e3);K||(X.position.z=5,V&&(Pv(X,V),X.manual||("aspect"in V||"left"in V||"right"in V||"bottom"in V||"top"in V)&&(X.manual=!0,X.updateProjectionMatrix())),!N.camera&&!(V!=null&&V.rotation)&&X.lookAt(0,0,0)),N.set({camera:X}),W.camera=X}if(!N.scene){let K;v!=null&&v.isScene?(K=v,fC(K,a,"",{})):(K=new Gbe,fC(K,a,"",{}),v&&Pv(K,v)),N.set({scene:K})}_&&!N.events.handlers&&N.set({events:_(a)});const te=ktt(e,y);if(lu.equ(te,N.size,PO)||N.setSize(te.width,te.height,te.top,te.left),F&&N.viewport.dpr!==_be(F)&&N.setDpr(F),N.frameloop!==k&&N.setFrameloop(k),N.onPointerMissed||N.set({onPointerMissed:q}),L&&!lu.equ(L,N.performance,PO)&&N.set(K=>({performance:{...K.performance,...L}})),!N.xr){var H;const K=(ne,oe)=>{const ie=a.getState();ie.frameloop!=="never"&&UW(ne,!0,ie,oe)},X=()=>{const ne=a.getState();ne.gl.xr.enabled=ne.gl.xr.isPresenting,ne.gl.xr.setAnimationLoop(ne.gl.xr.isPresenting?K:null),ne.gl.xr.isPresenting||CF(ne)},B={connect(){const ne=a.getState().gl;ne.xr.addEventListener("sessionstart",X),ne.xr.addEventListener("sessionend",X)},disconnect(){const ne=a.getState().gl;ne.xr.removeEventListener("sessionstart",X),ne.xr.removeEventListener("sessionend",X)}};typeof((H=U.xr)==null?void 0:H.addEventListener)=="function"&&B.connect(),N.set({xr:B})}if(U.shadowMap){const K=U.shadowMap.enabled,X=U.shadowMap.type;if(U.shadowMap.enabled=!!E,lu.boo(E))U.shadowMap.type=U5;else if(lu.str(E)){var M;const B={basic:Jbe,percentage:Wbe,soft:U5,variance:Kbe};U.shadowMap.type=(M=B[E])!=null?M:U5}else lu.obj(E)&&Object.assign(U.shadowMap,E);(K!==U.shadowMap.enabled||X!==U.shadowMap.type)&&(U.shadowMap.needsUpdate=!0)}return eOe.enabled=!R,s||(U.outputColorSpace=C?tOe:rJ,U.toneMapping=T?nOe:rOe),N.legacy!==R&&N.set(()=>({legacy:R})),N.linear!==C&&N.set(()=>({linear:C})),N.flat!==T&&N.set(()=>({flat:T})),m&&!lu.fun(m)&&!QW(m)&&!lu.equ(m,U,PO)&&Pv(U,m),l=S,s=!0,h(),this},render(d){return!s&&!c&&this.configure(),c.then(()=>{EF.updateContainer(Mr.jsx(Mtt,{store:a,children:d,onCreated:l,rootElement:e}),u,null,()=>{})}),a},unmount(){kbe(e)}}}function Mtt({store:e,children:t,onCreated:n,rootElement:r}){return QS(()=>{const i=e.getState();i.set(a=>({internal:{...a.internal,active:!0}})),n&&n(i),e.getState().events.connected||i.events.connect==null||i.events.connect(r)},[]),Mr.jsx($be.Provider,{value:e,children:t})}function kbe(e,t){const n=xb.get(e),r=n==null?void 0:n.fiber;if(r){const i=n==null?void 0:n.store.getState();i&&(i.internal.active=!1),EF.updateContainer(null,r,null,()=>{i&&setTimeout(()=>{try{var a,u,l,o;i.events.disconnect==null||i.events.disconnect(),(a=i.gl)==null||(u=a.renderLists)==null||u.dispose==null||u.dispose(),(l=i.gl)==null||l.forceContextLoss==null||l.forceContextLoss(),(o=i.gl)!=null&&o.xr&&i.xr.disconnect(),ftt(i.scene),xb.delete(e)}catch{}},500)})}}const Ftt=new Set,Ntt=new Set,Itt=new Set;function L7(e,t){if(e.size)for(const{callback:n}of e.values())n(t)}function rx(e,t){switch(e){case"before":return L7(Ftt,t);case"after":return L7(Ntt,t);case"tail":return L7(Itt,t)}}let B7,Q7;function DF(e,t,n){let r=t.clock.getDelta();t.frameloop==="never"&&typeof e=="number"&&(r=e-t.clock.elapsedTime,t.clock.oldTime=t.clock.elapsedTime,t.clock.elapsedTime=e),B7=t.internal.subscribers;for(let i=0;i<B7.length;i++)Q7=B7[i],Q7.ref.current(Q7.store.getState(),r,n);return!t.internal.priority&&t.gl.render&&t.gl.render(t.scene,t.camera),t.internal.frames=Math.max(0,t.internal.frames-1),t.frameloop==="always"?1:t.internal.frames}let pC=!1,$F=!1,z7,VW,MO;function Pbe(e){VW=requestAnimationFrame(Pbe),pC=!0,z7=0,rx("before",e),$F=!0;for(const n of xb.values()){var t;MO=n.store.getState(),MO.internal.active&&(MO.frameloop==="always"||MO.internal.frames>0)&&!((t=MO.gl.xr)!=null&&t.isPresenting)&&(z7+=DF(e,MO))}if($F=!1,rx("after",e),z7===0)return rx("tail",e),pC=!1,cancelAnimationFrame(VW)}function CF(e,t=1){var n;if(!e)return xb.forEach(r=>CF(r.store.getState(),t));(n=e.gl.xr)!=null&&n.isPresenting||!e.internal.active||e.frameloop==="never"||(t>1?e.internal.frames=Math.min(60,e.internal.frames+t):$F?e.internal.frames=2:e.internal.frames=1,pC||(pC=!0,requestAnimationFrame(Pbe)))}function UW(e,t=!0,n,r){if(t&&rx("before",e),n)DF(e,n,r);else for(const i of xb.values())DF(e,i.store.getState());t&&rx("after",e)}const q7={onClick:["click",!1],onContextMenu:["contextmenu",!1],onDoubleClick:["dblclick",!1],onWheel:["wheel",!0],onPointerDown:["pointerdown",!0],onPointerUp:["pointerup",!0],onPointerLeave:["pointerleave",!0],onPointerMove:["pointermove",!0],onPointerCancel:["pointercancel",!0],onLostPointerCapture:["lostpointercapture",!0]};function Ltt(e){const{handlePointer:t}=btt(e);return{priority:1,enabled:!0,compute(n,r,i){r.pointer.set(n.offsetX/r.size.width*2-1,-(n.offsetY/r.size.height)*2+1),r.raycaster.setFromCamera(r.pointer,r.camera)},connected:void 0,handlers:Object.keys(q7).reduce((n,r)=>({...n,[r]:t(r)}),{}),update:()=>{var n;const{events:r,internal:i}=e.getState();(n=i.lastEvent)!=null&&n.current&&r.handlers&&r.handlers.onPointerMove(i.lastEvent.current)},connect:n=>{const{set:r,events:i}=e.getState();if(i.disconnect==null||i.disconnect(),r(a=>({events:{...a.events,connected:n}})),i.handlers)for(const a in i.handlers){const u=i.handlers[a],[l,o]=q7[a];n.addEventListener(l,u,{passive:o})}},disconnect:()=>{const{set:n,events:r}=e.getState();if(r.connected){if(r.handlers)for(const i in r.handlers){const a=r.handlers[i],[u]=q7[i];r.connected.removeEventListener(u,a)}n(i=>({events:{...i.events,connected:void 0}}))}}}}function jW(e,t){let n;return(...r)=>{window.clearTimeout(n),n=window.setTimeout(()=>e(...r),t)}}function Btt({debounce:e,scroll:t,polyfill:n,offsetSize:r}={debounce:0,scroll:!1,offsetSize:!1}){const i=n||(typeof window>"u"?class{}:window.ResizeObserver);if(!i)throw new Error("This browser does not support ResizeObserver out of the box. See: https://github.com/react-spring/react-use-measure/#resize-observer-polyfills");const[a,u]=P.useState({left:0,top:0,width:0,height:0,bottom:0,right:0,x:0,y:0}),l=P.useRef({element:null,scrollContainers:null,resizeObserver:null,lastBounds:a,orientationHandler:null}),o=e?typeof e=="number"?e:e.scroll:null,s=e?typeof e=="number"?e:e.resize:null,c=P.useRef(!1);P.useEffect(()=>(c.current=!0,()=>void(c.current=!1)));const[d,h,m]=P.useMemo(()=>{const S=()=>{if(!l.current.element)return;const{left:E,top:C,width:T,height:R,bottom:$,right:k,x:F,y:L}=l.current.element.getBoundingClientRect(),j={left:E,top:C,width:T,height:R,bottom:$,right:k,x:F,y:L};l.current.element instanceof HTMLElement&&r&&(j.height=l.current.element.offsetHeight,j.width=l.current.element.offsetWidth),Object.freeze(j),c.current&&!Vtt(l.current.lastBounds,j)&&u(l.current.lastBounds=j)};return[S,s?jW(S,s):S,o?jW(S,o):S]},[u,r,o,s]);function y(){l.current.scrollContainers&&(l.current.scrollContainers.forEach(S=>S.removeEventListener("scroll",m,!0)),l.current.scrollContainers=null),l.current.resizeObserver&&(l.current.resizeObserver.disconnect(),l.current.resizeObserver=null),l.current.orientationHandler&&("orientation"in screen&&"removeEventListener"in screen.orientation?screen.orientation.removeEventListener("change",l.current.orientationHandler):"onorientationchange"in window&&window.removeEventListener("orientationchange",l.current.orientationHandler))}function v(){l.current.element&&(l.current.resizeObserver=new i(m),l.current.resizeObserver.observe(l.current.element),t&&l.current.scrollContainers&&l.current.scrollContainers.forEach(S=>S.addEventListener("scroll",m,{capture:!0,passive:!0})),l.current.orientationHandler=()=>{m()},"orientation"in screen&&"addEventListener"in screen.orientation?screen.orientation.addEventListener("change",l.current.orientationHandler):"onorientationchange"in window&&window.addEventListener("orientationchange",l.current.orientationHandler))}const _=S=>{!S||S===l.current.element||(y(),l.current.element=S,l.current.scrollContainers=Mbe(S),v())};return ztt(m,!!t),Qtt(h),P.useEffect(()=>{y(),v()},[t,m,h]),P.useEffect(()=>y,[]),[_,a,d]}function Qtt(e){P.useEffect(()=>{const t=e;return window.addEventListener("resize",t),()=>void window.removeEventListener("resize",t)},[e])}function ztt(e,t){P.useEffect(()=>{if(t){const n=e;return window.addEventListener("scroll",n,{capture:!0,passive:!0}),()=>void window.removeEventListener("scroll",n,!0)}},[e,t])}function Mbe(e){const t=[];if(!e||e===document.body)return t;const{overflow:n,overflowX:r,overflowY:i}=window.getComputedStyle(e);return[n,r,i].some(a=>a==="auto"||a==="scroll")&&t.push(e),[...t,...Mbe(e.parentElement)]}const qtt=["x","y","top","bottom","left","right","width","height"],Vtt=(e,t)=>qtt.every(n=>e[n]===t[n]);function Utt({ref:e,children:t,fallback:n,resize:r,style:i,gl:a,events:u=Ltt,eventSource:l,eventPrefix:o,shadows:s,linear:c,flat:d,legacy:h,orthographic:m,frameloop:y,dpr:v,performance:_,raycaster:S,camera:E,scene:C,onPointerMissed:T,onCreated:R,...$}){P.useMemo(()=>Dtt(lOe),[]);const k=ott(),[F,L]=Btt({scroll:!0,debounce:{scroll:50,resize:0},...r}),j=P.useRef(null),V=P.useRef(null);P.useImperativeHandle(e,()=>j.current);const q=Sbe(T),[N,U]=P.useState(!1),[W,G]=P.useState(!1);if(N)throw N;if(W)throw W;const J=P.useRef(null);QS(()=>{const H=j.current;if(L.width>0&&L.height>0&&H){J.current||(J.current=Ptt(H));async function M(){await J.current.configure({gl:a,scene:C,events:u,shadows:s,linear:c,flat:d,legacy:h,orthographic:m,frameloop:y,dpr:v,performance:_,raycaster:S,camera:E,size:L,onPointerMissed:(...K)=>q.current==null?void 0:q.current(...K),onCreated:K=>{K.events.connect==null||K.events.connect(l?utt(l)?l.current:l:V.current),o&&K.setEvents({compute:(X,B)=>{const ne=X[o+"X"],oe=X[o+"Y"];B.pointer.set(ne/B.size.width*2-1,-(oe/B.size.height)*2+1),B.raycaster.setFromCamera(B.pointer,B.camera)}}),R==null||R(K)}}),J.current.render(Mr.jsx(k,{children:Mr.jsx(ctt,{set:G,children:Mr.jsx(P.Suspense,{fallback:Mr.jsx(stt,{set:U}),children:t??null})})}))}M()}}),P.useEffect(()=>{const H=j.current;if(H)return()=>kbe(H)},[]);const te=l?"none":"auto";return Mr.jsx("div",{ref:V,style:{position:"relative",width:"100%",height:"100%",overflow:"hidden",pointerEvents:te,...i},...$,children:Mr.jsx("div",{ref:F,style:{width:"100%",height:"100%"},children:Mr.jsx("canvas",{ref:j,style:{display:"block"},children:n})})})}function jtt(e){return Mr.jsx(ybe,{children:Mr.jsx(Utt,{...e})})}const zS=new li,AB=new li,Ztt=new li,ZW=new Jl;function Htt(e,t,n){const r=zS.setFromMatrixPosition(e.matrixWorld);r.project(t);const i=n.width/2,a=n.height/2;return[r.x*i+i,-(r.y*a)+a]}function Xtt(e,t){const n=zS.setFromMatrixPosition(e.matrixWorld),r=AB.setFromMatrixPosition(t.matrixWorld),i=n.sub(r),a=t.getWorldDirection(Ztt);return i.angleTo(a)>Math.PI/2}function Ytt(e,t,n,r){const i=zS.setFromMatrixPosition(e.matrixWorld),a=i.clone();a.project(t),ZW.set(a.x,a.y),n.setFromCamera(ZW,t);const u=n.intersectObjects(r,!0);if(u.length){const l=u[0].distance;return i.distanceTo(n.ray.origin)<l}return!0}function Gtt(e,t){if(t instanceof KO)return t.zoom;if(t instanceof WO){const n=zS.setFromMatrixPosition(e.matrixWorld),r=AB.setFromMatrixPosition(t.matrixWorld),i=t.fov*Math.PI/180,a=n.distanceTo(r);return 1/(2*Math.tan(i/2)*a)}else return 1}function Ktt(e,t,n){if(t instanceof WO||t instanceof KO){const r=zS.setFromMatrixPosition(e.matrixWorld),i=AB.setFromMatrixPosition(t.matrixWorld),a=r.distanceTo(i),u=(n[1]-n[0])/(t.far-t.near),l=n[1]-u*t.far;return Math.round(u*a+l)}}const wF=e=>Math.abs(e)<1e-10?0:e;function Fbe(e,t,n=""){let r="matrix3d(";for(let i=0;i!==16;i++)r+=wF(t[i]*e.elements[i])+(i!==15?",":")");return n+r}const Wtt=(e=>t=>Fbe(t,e))([1,-1,1,1,1,-1,1,1,1,-1,1,1,1,-1,1,1]),Jtt=(e=>(t,n)=>Fbe(t,e(n),"translate(-50%,-50%)"))(e=>[1/e,1/e,1/e,1,-1/e,-1/e,-1/e,-1,1/e,1/e,1/e,1,1,1,1,1]);function ent(e){return e&&typeof e=="object"&&"current"in e}const clt=P.forwardRef(({children:e,eps:t=.001,style:n,className:r,prepend:i,center:a,fullscreen:u,portal:l,distanceFactor:o,sprite:s=!1,transform:c=!1,occlude:d,onOcclude:h,castShadow:m,receiveShadow:y,material:v,geometry:_,zIndexRange:S=[16777271,0],calculatePosition:E=Htt,as:C="div",wrapperClass:T,pointerEvents:R="auto",...$},k)=>{const{gl:F,camera:L,scene:j,size:V,raycaster:q,events:N,viewport:U}=zd(),[W]=P.useState(()=>document.createElement(C)),G=P.useRef(null),J=P.useRef(null),te=P.useRef(0),H=P.useRef([0,0]),M=P.useRef(null),K=P.useRef(null),X=(l==null?void 0:l.current)||N.connected||F.domElement.parentNode,B=P.useRef(null),ne=P.useRef(!1),oe=P.useMemo(()=>d&&d!=="blending"||Array.isArray(d)&&d.length&&ent(d[0]),[d]);P.useLayoutEffect(()=>{const pe=F.domElement;d&&d==="blending"?(pe.style.zIndex=`${Math.floor(S[0]/2)}`,pe.style.position="absolute",pe.style.pointerEvents="none"):(pe.style.zIndex=null,pe.style.position=null,pe.style.pointerEvents=null)},[d]),P.useLayoutEffect(()=>{if(J.current){const pe=G.current=xJ.createRoot(W);if(j.updateMatrixWorld(),c)W.style.cssText="position:absolute;top:0;left:0;pointer-events:none;overflow:hidden;";else{const _e=E(J.current,L,V);W.style.cssText=`position:absolute;top:0;left:0;transform:translate3d(${_e[0]}px,${_e[1]}px,0);transform-origin:0 0;`}return X&&(i?X.prepend(W):X.appendChild(W)),()=>{X&&X.removeChild(W),pe.unmount()}}},[X,c]),P.useLayoutEffect(()=>{T&&(W.className=T)},[T]);const ie=P.useMemo(()=>c?{position:"absolute",top:0,left:0,width:V.width,height:V.height,transformStyle:"preserve-3d",pointerEvents:"none"}:{position:"absolute",transform:a?"translate3d(-50%,-50%,0)":"none",...u&&{top:-V.height/2,left:-V.width/2,width:V.width,height:V.height},...n},[n,a,u,V,c]),de=P.useMemo(()=>({position:"absolute",pointerEvents:R}),[R]);P.useLayoutEffect(()=>{if(ne.current=!1,c){var pe;(pe=G.current)==null||pe.render(P.createElement("div",{ref:M,style:ie},P.createElement("div",{ref:K,style:de},P.createElement("div",{ref:k,className:r,style:n,children:e}))))}else{var _e;(_e=G.current)==null||_e.render(P.createElement("div",{ref:k,style:ie,className:r,children:e}))}});const be=P.useRef(!0);m5(pe=>{if(J.current){L.updateMatrixWorld(),J.current.updateWorldMatrix(!0,!1);const _e=c?H.current:E(J.current,L,V);if(c||Math.abs(te.current-L.zoom)>t||Math.abs(H.current[0]-_e[0])>t||Math.abs(H.current[1]-_e[1])>t){const se=Xtt(J.current,L);let me=!1;oe&&(Array.isArray(d)?me=d.map(Re=>Re.current):d!=="blending"&&(me=[j]));const ge=be.current;if(me){const Re=Ytt(J.current,L,q,me);be.current=Re&&!se}else be.current=!se;ge!==be.current&&(h?h(!be.current):W.style.display=be.current?"block":"none");const we=Math.floor(S[0]/2),Ne=d?oe?[S[0],we]:[we-1,0]:S;if(W.style.zIndex=`${Ktt(J.current,L,Ne)}`,c){const[Re,et]=[V.width/2,V.height/2],tt=L.projectionMatrix.elements[5]*et,{isOrthographicCamera:Oe,top:$e,left:Ae,bottom:Ue,right:Ze}=L,Ye=Wtt(L.matrixWorldInverse),Me=Oe?`scale(${tt})translate(${wF(-(Ze+Ae)/2)}px,${wF(($e+Ue)/2)}px)`:`translateZ(${tt}px)`;let ze=J.current.matrixWorld;s&&(ze=L.matrixWorldInverse.clone().transpose().copyPosition(ze).scale(J.current.scale),ze.elements[3]=ze.elements[7]=ze.elements[11]=0,ze.elements[15]=1),W.style.width=V.width+"px",W.style.height=V.height+"px",W.style.perspective=Oe?"":`${tt}px`,M.current&&K.current&&(M.current.style.transform=`${Me}${Ye}translate(${Re}px,${et}px)`,K.current.style.transform=Jtt(ze,1/((o||10)/400)))}else{const Re=o===void 0?1:Gtt(J.current,L)*o;W.style.transform=`translate3d(${_e[0]}px,${_e[1]}px,0) scale(${Re})`}H.current=_e,te.current=L.zoom}}if(!oe&&B.current&&!ne.current)if(c){if(M.current){const _e=M.current.children[0];if(_e!=null&&_e.clientWidth&&_e!=null&&_e.clientHeight){const{isOrthographicCamera:se}=L;if(se||_)$.scale&&(Array.isArray($.scale)?$.scale instanceof li?B.current.scale.copy($.scale.clone().divideScalar(1)):B.current.scale.set(1/$.scale[0],1/$.scale[1],1/$.scale[2]):B.current.scale.setScalar(1/$.scale));else{const me=(o||10)/400,ge=_e.clientWidth*me,we=_e.clientHeight*me;B.current.scale.set(ge,we,1)}ne.current=!0}}}else{const _e=W.children[0];if(_e!=null&&_e.clientWidth&&_e!=null&&_e.clientHeight){const se=1/U.factor,me=_e.clientWidth*se,ge=_e.clientHeight*se;B.current.scale.set(me,ge,1),ne.current=!0}B.current.lookAt(pe.camera.position)}});const ve=P.useMemo(()=>({vertexShader:c?void 0:`
          /*
            This shader is from the THREE's SpriteMaterial.
            We need to turn the backing plane into a Sprite
            (make it always face the camera) if "transfrom"
            is false.
          */
          #include <common>

          void main() {
            vec2 center = vec2(0., 1.);
            float rotation = 0.0;

            // This is somewhat arbitrary, but it seems to work well
            // Need to figure out how to derive this dynamically if it even matters
            float size = 0.03;

            vec4 mvPosition = modelViewMatrix * vec4( 0.0, 0.0, 0.0, 1.0 );
            vec2 scale;
            scale.x = length( vec3( modelMatrix[ 0 ].x, modelMatrix[ 0 ].y, modelMatrix[ 0 ].z ) );
            scale.y = length( vec3( modelMatrix[ 1 ].x, modelMatrix[ 1 ].y, modelMatrix[ 1 ].z ) );

            bool isPerspective = isPerspectiveMatrix( projectionMatrix );
            if ( isPerspective ) scale *= - mvPosition.z;

            vec2 alignedPosition = ( position.xy - ( center - vec2( 0.5 ) ) ) * scale * size;
            vec2 rotatedPosition;
            rotatedPosition.x = cos( rotation ) * alignedPosition.x - sin( rotation ) * alignedPosition.y;
            rotatedPosition.y = sin( rotation ) * alignedPosition.x + cos( rotation ) * alignedPosition.y;
            mvPosition.xy += rotatedPosition;

            gl_Position = projectionMatrix * mvPosition;
          }
      `,fragmentShader:`
        void main() {
          gl_FragColor = vec4(0.0, 0.0, 0.0, 0.0);
        }
      `}),[c]);return P.createElement("group",ry({},$,{ref:J}),d&&!oe&&P.createElement("mesh",{castShadow:m,receiveShadow:y,ref:B},_||P.createElement("planeGeometry",null),v||P.createElement("shaderMaterial",{side:oOe,vertexShader:ve.vertexShader,fragmentShader:ve.fragmentShader})))}),Nbe=parseInt(sOe.replace(/\D+/g,"")),Ibe=Nbe>=125?"uv1":"uv2",tnt=(e,t)=>{const n=e[0].index!==null,r=new Set(Object.keys(e[0].attributes)),i=new Set(Object.keys(e[0].morphAttributes)),a={},u={},l=e[0].morphTargetsRelative,o=new cOe;if(e.forEach((s,c)=>{let d=0;if(n!==(s.index!==null))return console.error("THREE.BufferGeometryUtils: .mergeBufferGeometries() failed with geometry at index "+c+". All geometries must have compatible attributes; make sure index attribute exists among all geometries, or in none of them."),null;for(let h in s.attributes){if(!r.has(h))return console.error("THREE.BufferGeometryUtils: .mergeBufferGeometries() failed with geometry at index "+c+'. All geometries must have compatible attributes; make sure "'+h+'" attribute exists among all geometries, or in none of them.'),null;a[h]===void 0&&(a[h]=[]),a[h].push(s.attributes[h]),d++}if(d!==r.size)return console.error("THREE.BufferGeometryUtils: .mergeBufferGeometries() failed with geometry at index "+c+". Make sure all geometries have the same number of attributes."),null;if(l!==s.morphTargetsRelative)return console.error("THREE.BufferGeometryUtils: .mergeBufferGeometries() failed with geometry at index "+c+". .morphTargetsRelative must be consistent throughout all geometries."),null;for(let h in s.morphAttributes){if(!i.has(h))return console.error("THREE.BufferGeometryUtils: .mergeBufferGeometries() failed with geometry at index "+c+".  .morphAttributes must be consistent throughout all geometries."),null;u[h]===void 0&&(u[h]=[]),u[h].push(s.morphAttributes[h])}o.userData.mergedUserData=o.userData.mergedUserData||[],o.userData.mergedUserData.push(s.userData)}),n){let s=0;const c=[];e.forEach(d=>{const h=d.index;for(let m=0;m<h.count;++m)c.push(h.getX(m)+s);s+=d.attributes.position.count}),o.setIndex(c)}for(let s in a){const c=HW(a[s]);if(!c)return console.error("THREE.BufferGeometryUtils: .mergeBufferGeometries() failed while trying to merge the "+s+" attribute."),null;o.setAttribute(s,c)}for(let s in u){const c=u[s][0].length;if(c===0)break;o.morphAttributes=o.morphAttributes||{},o.morphAttributes[s]=[];for(let d=0;d<c;++d){const h=[];for(let y=0;y<u[s].length;++y)h.push(u[s][y][d]);const m=HW(h);if(!m)return console.error("THREE.BufferGeometryUtils: .mergeBufferGeometries() failed while trying to merge the "+s+" morphAttribute."),null;o.morphAttributes[s].push(m)}}return o},HW=e=>{let t,n,r,i=0;if(e.forEach(a=>{if(t===void 0&&(t=a.array.constructor),t!==a.array.constructor)return console.error("THREE.BufferGeometryUtils: .mergeBufferAttributes() failed. BufferAttribute.array must be of consistent array types across matching attributes."),null;if(n===void 0&&(n=a.itemSize),n!==a.itemSize)return console.error("THREE.BufferGeometryUtils: .mergeBufferAttributes() failed. BufferAttribute.itemSize must be consistent across matching attributes."),null;if(r===void 0&&(r=a.normalized),r!==a.normalized)return console.error("THREE.BufferGeometryUtils: .mergeBufferAttributes() failed. BufferAttribute.normalized must be consistent across matching attributes."),null;i+=a.array.length}),t&&n){const a=new t(i);let u=0;return e.forEach(l=>{a.set(l.array,u),u+=l.array.length}),new fOe(a,n,r)}};var nnt=Object.defineProperty,rnt=(e,t,n)=>t in e?nnt(e,t,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n,int=(e,t,n)=>(rnt(e,t+"",n),n);class ant{constructor(){int(this,"_listeners")}addEventListener(t,n){this._listeners===void 0&&(this._listeners={});const r=this._listeners;r[t]===void 0&&(r[t]=[]),r[t].indexOf(n)===-1&&r[t].push(n)}hasEventListener(t,n){if(this._listeners===void 0)return!1;const r=this._listeners;return r[t]!==void 0&&r[t].indexOf(n)!==-1}removeEventListener(t,n){if(this._listeners===void 0)return;const i=this._listeners[t];if(i!==void 0){const a=i.indexOf(n);a!==-1&&i.splice(a,1)}}dispatchEvent(t){if(this._listeners===void 0)return;const r=this._listeners[t.type];if(r!==void 0){t.target=this;const i=r.slice(0);for(let a=0,u=i.length;a<u;a++)i[a].call(this,t);t.target=null}}}var unt=Object.defineProperty,lnt=(e,t,n)=>t in e?unt(e,t,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n,Pn=(e,t,n)=>(lnt(e,typeof t!="symbol"?t+"":t,n),n);const ME=new dOe,XW=new hOe,ont=Math.cos(70*(Math.PI/180)),YW=(e,t)=>(e%t+t)%t;let snt=class extends ant{constructor(t,n){super(),Pn(this,"object"),Pn(this,"domElement"),Pn(this,"enabled",!0),Pn(this,"target",new li),Pn(this,"minDistance",0),Pn(this,"maxDistance",1/0),Pn(this,"minZoom",0),Pn(this,"maxZoom",1/0),Pn(this,"minPolarAngle",0),Pn(this,"maxPolarAngle",Math.PI),Pn(this,"minAzimuthAngle",-1/0),Pn(this,"maxAzimuthAngle",1/0),Pn(this,"enableDamping",!1),Pn(this,"dampingFactor",.05),Pn(this,"enableZoom",!0),Pn(this,"zoomSpeed",1),Pn(this,"enableRotate",!0),Pn(this,"rotateSpeed",1),Pn(this,"enablePan",!0),Pn(this,"panSpeed",1),Pn(this,"screenSpacePanning",!0),Pn(this,"keyPanSpeed",7),Pn(this,"zoomToCursor",!1),Pn(this,"autoRotate",!1),Pn(this,"autoRotateSpeed",2),Pn(this,"reverseOrbit",!1),Pn(this,"reverseHorizontalOrbit",!1),Pn(this,"reverseVerticalOrbit",!1),Pn(this,"keys",{LEFT:"ArrowLeft",UP:"ArrowUp",RIGHT:"ArrowRight",BOTTOM:"ArrowDown"}),Pn(this,"mouseButtons",{LEFT:mO.ROTATE,MIDDLE:mO.DOLLY,RIGHT:mO.PAN}),Pn(this,"touches",{ONE:gO.ROTATE,TWO:gO.DOLLY_PAN}),Pn(this,"target0"),Pn(this,"position0"),Pn(this,"zoom0"),Pn(this,"_domElementKeyEvents",null),Pn(this,"getPolarAngle"),Pn(this,"getAzimuthalAngle"),Pn(this,"setPolarAngle"),Pn(this,"setAzimuthalAngle"),Pn(this,"getDistance"),Pn(this,"getZoomScale"),Pn(this,"listenToKeyEvents"),Pn(this,"stopListenToKeyEvents"),Pn(this,"saveState"),Pn(this,"reset"),Pn(this,"update"),Pn(this,"connect"),Pn(this,"dispose"),Pn(this,"dollyIn"),Pn(this,"dollyOut"),Pn(this,"getScale"),Pn(this,"setScale"),this.object=t,this.domElement=n,this.target0=this.target.clone(),this.position0=this.object.position.clone(),this.zoom0=this.object.zoom,this.getPolarAngle=()=>c.phi,this.getAzimuthalAngle=()=>c.theta,this.setPolarAngle=Fe=>{let ht=YW(Fe,2*Math.PI),Tt=c.phi;Tt<0&&(Tt+=2*Math.PI),ht<0&&(ht+=2*Math.PI);let Qt=Math.abs(ht-Tt);2*Math.PI-Qt<Qt&&(ht<Tt?ht+=2*Math.PI:Tt+=2*Math.PI),d.phi=ht-Tt,r.update()},this.setAzimuthalAngle=Fe=>{let ht=YW(Fe,2*Math.PI),Tt=c.theta;Tt<0&&(Tt+=2*Math.PI),ht<0&&(ht+=2*Math.PI);let Qt=Math.abs(ht-Tt);2*Math.PI-Qt<Qt&&(ht<Tt?ht+=2*Math.PI:Tt+=2*Math.PI),d.theta=ht-Tt,r.update()},this.getDistance=()=>r.object.position.distanceTo(r.target),this.listenToKeyEvents=Fe=>{Fe.addEventListener("keydown",st),this._domElementKeyEvents=Fe},this.stopListenToKeyEvents=()=>{this._domElementKeyEvents.removeEventListener("keydown",st),this._domElementKeyEvents=null},this.saveState=()=>{r.target0.copy(r.target),r.position0.copy(r.object.position),r.zoom0=r.object.zoom},this.reset=()=>{r.target.copy(r.target0),r.object.position.copy(r.position0),r.object.zoom=r.zoom0,r.object.updateProjectionMatrix(),r.dispatchEvent(i),r.update(),o=l.NONE},this.update=(()=>{const Fe=new li,ht=new li(0,1,0),Tt=new IB().setFromUnitVectors(t.up,ht),Qt=Tt.clone().invert(),un=new li,Ln=new IB,ln=2*Math.PI;return function(){const cr=r.object.position;Tt.setFromUnitVectors(t.up,ht),Qt.copy(Tt).invert(),Fe.copy(cr).sub(r.target),Fe.applyQuaternion(Tt),c.setFromVector3(Fe),r.autoRotate&&o===l.NONE&&U(q()),r.enableDamping?(c.theta+=d.theta*r.dampingFactor,c.phi+=d.phi*r.dampingFactor):(c.theta+=d.theta,c.phi+=d.phi);let ur=r.minAzimuthAngle,Cr=r.maxAzimuthAngle;isFinite(ur)&&isFinite(Cr)&&(ur<-Math.PI?ur+=ln:ur>Math.PI&&(ur-=ln),Cr<-Math.PI?Cr+=ln:Cr>Math.PI&&(Cr-=ln),ur<=Cr?c.theta=Math.max(ur,Math.min(Cr,c.theta)):c.theta=c.theta>(ur+Cr)/2?Math.max(ur,c.theta):Math.min(Cr,c.theta)),c.phi=Math.max(r.minPolarAngle,Math.min(r.maxPolarAngle,c.phi)),c.makeSafe(),r.enableDamping===!0?r.target.addScaledVector(m,r.dampingFactor):r.target.add(m),r.zoomToCursor&&L||r.object.isOrthographicCamera?c.radius=B(c.radius):c.radius=B(c.radius*h),Fe.setFromSpherical(c),Fe.applyQuaternion(Qt),cr.copy(r.target).add(Fe),r.object.matrixAutoUpdate||r.object.updateMatrix(),r.object.lookAt(r.target),r.enableDamping===!0?(d.theta*=1-r.dampingFactor,d.phi*=1-r.dampingFactor,m.multiplyScalar(1-r.dampingFactor)):(d.set(0,0,0),m.set(0,0,0));let Vr=!1;if(r.zoomToCursor&&L){let ke=null;if(r.object instanceof WO&&r.object.isPerspectiveCamera){const He=Fe.length();ke=B(He*h);const nt=He-ke;r.object.position.addScaledVector(k,nt),r.object.updateMatrixWorld()}else if(r.object.isOrthographicCamera){const He=new li(F.x,F.y,0);He.unproject(r.object),r.object.zoom=Math.max(r.minZoom,Math.min(r.maxZoom,r.object.zoom/h)),r.object.updateProjectionMatrix(),Vr=!0;const nt=new li(F.x,F.y,0);nt.unproject(r.object),r.object.position.sub(nt).add(He),r.object.updateMatrixWorld(),ke=Fe.length()}else console.warn("WARNING: OrbitControls.js encountered an unknown camera type - zoom to cursor disabled."),r.zoomToCursor=!1;ke!==null&&(r.screenSpacePanning?r.target.set(0,0,-1).transformDirection(r.object.matrix).multiplyScalar(ke).add(r.object.position):(ME.origin.copy(r.object.position),ME.direction.set(0,0,-1).transformDirection(r.object.matrix),Math.abs(r.object.up.dot(ME.direction))<ont?t.lookAt(r.target):(XW.setFromNormalAndCoplanarPoint(r.object.up,r.target),ME.intersectPlane(XW,r.target))))}else r.object instanceof KO&&r.object.isOrthographicCamera&&(Vr=h!==1,Vr&&(r.object.zoom=Math.max(r.minZoom,Math.min(r.maxZoom,r.object.zoom/h)),r.object.updateProjectionMatrix()));return h=1,L=!1,Vr||un.distanceToSquared(r.object.position)>s||8*(1-Ln.dot(r.object.quaternion))>s?(r.dispatchEvent(i),un.copy(r.object.position),Ln.copy(r.object.quaternion),Vr=!1,!0):!1}})(),this.connect=Fe=>{r.domElement=Fe,r.domElement.style.touchAction="none",r.domElement.addEventListener("contextmenu",gt),r.domElement.addEventListener("pointerdown",Ae),r.domElement.addEventListener("pointercancel",Ze),r.domElement.addEventListener("wheel",ze)},this.dispose=()=>{var Fe,ht,Tt,Qt,un,Ln;r.domElement&&(r.domElement.style.touchAction="auto"),(Fe=r.domElement)==null||Fe.removeEventListener("contextmenu",gt),(ht=r.domElement)==null||ht.removeEventListener("pointerdown",Ae),(Tt=r.domElement)==null||Tt.removeEventListener("pointercancel",Ze),(Qt=r.domElement)==null||Qt.removeEventListener("wheel",ze),(un=r.domElement)==null||un.ownerDocument.removeEventListener("pointermove",Ue),(Ln=r.domElement)==null||Ln.ownerDocument.removeEventListener("pointerup",Ze),r._domElementKeyEvents!==null&&r._domElementKeyEvents.removeEventListener("keydown",st)};const r=this,i={type:"change"},a={type:"start"},u={type:"end"},l={NONE:-1,ROTATE:0,DOLLY:1,PAN:2,TOUCH_ROTATE:3,TOUCH_PAN:4,TOUCH_DOLLY_PAN:5,TOUCH_DOLLY_ROTATE:6};let o=l.NONE;const s=1e-6,c=new NB,d=new NB;let h=1;const m=new li,y=new Jl,v=new Jl,_=new Jl,S=new Jl,E=new Jl,C=new Jl,T=new Jl,R=new Jl,$=new Jl,k=new li,F=new Jl;let L=!1;const j=[],V={};function q(){return 2*Math.PI/60/60*r.autoRotateSpeed}function N(){return Math.pow(.95,r.zoomSpeed)}function U(Fe){r.reverseOrbit||r.reverseHorizontalOrbit?d.theta+=Fe:d.theta-=Fe}function W(Fe){r.reverseOrbit||r.reverseVerticalOrbit?d.phi+=Fe:d.phi-=Fe}const G=(()=>{const Fe=new li;return function(Tt,Qt){Fe.setFromMatrixColumn(Qt,0),Fe.multiplyScalar(-Tt),m.add(Fe)}})(),J=(()=>{const Fe=new li;return function(Tt,Qt){r.screenSpacePanning===!0?Fe.setFromMatrixColumn(Qt,1):(Fe.setFromMatrixColumn(Qt,0),Fe.crossVectors(r.object.up,Fe)),Fe.multiplyScalar(Tt),m.add(Fe)}})(),te=(()=>{const Fe=new li;return function(Tt,Qt){const un=r.domElement;if(un&&r.object instanceof WO&&r.object.isPerspectiveCamera){const Ln=r.object.position;Fe.copy(Ln).sub(r.target);let ln=Fe.length();ln*=Math.tan(r.object.fov/2*Math.PI/180),G(2*Tt*ln/un.clientHeight,r.object.matrix),J(2*Qt*ln/un.clientHeight,r.object.matrix)}else un&&r.object instanceof KO&&r.object.isOrthographicCamera?(G(Tt*(r.object.right-r.object.left)/r.object.zoom/un.clientWidth,r.object.matrix),J(Qt*(r.object.top-r.object.bottom)/r.object.zoom/un.clientHeight,r.object.matrix)):(console.warn("WARNING: OrbitControls.js encountered an unknown camera type - pan disabled."),r.enablePan=!1)}})();function H(Fe){r.object instanceof WO&&r.object.isPerspectiveCamera||r.object instanceof KO&&r.object.isOrthographicCamera?h=Fe:(console.warn("WARNING: OrbitControls.js encountered an unknown camera type - dolly/zoom disabled."),r.enableZoom=!1)}function M(Fe){H(h/Fe)}function K(Fe){H(h*Fe)}function X(Fe){if(!r.zoomToCursor||!r.domElement)return;L=!0;const ht=r.domElement.getBoundingClientRect(),Tt=Fe.clientX-ht.left,Qt=Fe.clientY-ht.top,un=ht.width,Ln=ht.height;F.x=Tt/un*2-1,F.y=-(Qt/Ln)*2+1,k.set(F.x,F.y,1).unproject(r.object).sub(r.object.position).normalize()}function B(Fe){return Math.max(r.minDistance,Math.min(r.maxDistance,Fe))}function ne(Fe){y.set(Fe.clientX,Fe.clientY)}function oe(Fe){X(Fe),T.set(Fe.clientX,Fe.clientY)}function ie(Fe){S.set(Fe.clientX,Fe.clientY)}function de(Fe){v.set(Fe.clientX,Fe.clientY),_.subVectors(v,y).multiplyScalar(r.rotateSpeed);const ht=r.domElement;ht&&(U(2*Math.PI*_.x/ht.clientHeight),W(2*Math.PI*_.y/ht.clientHeight)),y.copy(v),r.update()}function be(Fe){R.set(Fe.clientX,Fe.clientY),$.subVectors(R,T),$.y>0?M(N()):$.y<0&&K(N()),T.copy(R),r.update()}function ve(Fe){E.set(Fe.clientX,Fe.clientY),C.subVectors(E,S).multiplyScalar(r.panSpeed),te(C.x,C.y),S.copy(E),r.update()}function pe(Fe){X(Fe),Fe.deltaY<0?K(N()):Fe.deltaY>0&&M(N()),r.update()}function _e(Fe){let ht=!1;switch(Fe.code){case r.keys.UP:te(0,r.keyPanSpeed),ht=!0;break;case r.keys.BOTTOM:te(0,-r.keyPanSpeed),ht=!0;break;case r.keys.LEFT:te(r.keyPanSpeed,0),ht=!0;break;case r.keys.RIGHT:te(-r.keyPanSpeed,0),ht=!0;break}ht&&(Fe.preventDefault(),r.update())}function se(){if(j.length==1)y.set(j[0].pageX,j[0].pageY);else{const Fe=.5*(j[0].pageX+j[1].pageX),ht=.5*(j[0].pageY+j[1].pageY);y.set(Fe,ht)}}function me(){if(j.length==1)S.set(j[0].pageX,j[0].pageY);else{const Fe=.5*(j[0].pageX+j[1].pageX),ht=.5*(j[0].pageY+j[1].pageY);S.set(Fe,ht)}}function ge(){const Fe=j[0].pageX-j[1].pageX,ht=j[0].pageY-j[1].pageY,Tt=Math.sqrt(Fe*Fe+ht*ht);T.set(0,Tt)}function we(){r.enableZoom&&ge(),r.enablePan&&me()}function Ne(){r.enableZoom&&ge(),r.enableRotate&&se()}function Re(Fe){if(j.length==1)v.set(Fe.pageX,Fe.pageY);else{const Tt=rn(Fe),Qt=.5*(Fe.pageX+Tt.x),un=.5*(Fe.pageY+Tt.y);v.set(Qt,un)}_.subVectors(v,y).multiplyScalar(r.rotateSpeed);const ht=r.domElement;ht&&(U(2*Math.PI*_.x/ht.clientHeight),W(2*Math.PI*_.y/ht.clientHeight)),y.copy(v)}function et(Fe){if(j.length==1)E.set(Fe.pageX,Fe.pageY);else{const ht=rn(Fe),Tt=.5*(Fe.pageX+ht.x),Qt=.5*(Fe.pageY+ht.y);E.set(Tt,Qt)}C.subVectors(E,S).multiplyScalar(r.panSpeed),te(C.x,C.y),S.copy(E)}function tt(Fe){const ht=rn(Fe),Tt=Fe.pageX-ht.x,Qt=Fe.pageY-ht.y,un=Math.sqrt(Tt*Tt+Qt*Qt);R.set(0,un),$.set(0,Math.pow(R.y/T.y,r.zoomSpeed)),M($.y),T.copy(R)}function Oe(Fe){r.enableZoom&&tt(Fe),r.enablePan&&et(Fe)}function $e(Fe){r.enableZoom&&tt(Fe),r.enableRotate&&Re(Fe)}function Ae(Fe){var ht,Tt;r.enabled!==!1&&(j.length===0&&((ht=r.domElement)==null||ht.ownerDocument.addEventListener("pointermove",Ue),(Tt=r.domElement)==null||Tt.ownerDocument.addEventListener("pointerup",Ze)),qt(Fe),Fe.pointerType==="touch"?Ot(Fe):Ye(Fe))}function Ue(Fe){r.enabled!==!1&&(Fe.pointerType==="touch"?Nt(Fe):Me(Fe))}function Ze(Fe){var ht,Tt,Qt;zt(Fe),j.length===0&&((ht=r.domElement)==null||ht.releasePointerCapture(Fe.pointerId),(Tt=r.domElement)==null||Tt.ownerDocument.removeEventListener("pointermove",Ue),(Qt=r.domElement)==null||Qt.ownerDocument.removeEventListener("pointerup",Ze)),r.dispatchEvent(u),o=l.NONE}function Ye(Fe){let ht;switch(Fe.button){case 0:ht=r.mouseButtons.LEFT;break;case 1:ht=r.mouseButtons.MIDDLE;break;case 2:ht=r.mouseButtons.RIGHT;break;default:ht=-1}switch(ht){case mO.DOLLY:if(r.enableZoom===!1)return;oe(Fe),o=l.DOLLY;break;case mO.ROTATE:if(Fe.ctrlKey||Fe.metaKey||Fe.shiftKey){if(r.enablePan===!1)return;ie(Fe),o=l.PAN}else{if(r.enableRotate===!1)return;ne(Fe),o=l.ROTATE}break;case mO.PAN:if(Fe.ctrlKey||Fe.metaKey||Fe.shiftKey){if(r.enableRotate===!1)return;ne(Fe),o=l.ROTATE}else{if(r.enablePan===!1)return;ie(Fe),o=l.PAN}break;default:o=l.NONE}o!==l.NONE&&r.dispatchEvent(a)}function Me(Fe){if(r.enabled!==!1)switch(o){case l.ROTATE:if(r.enableRotate===!1)return;de(Fe);break;case l.DOLLY:if(r.enableZoom===!1)return;be(Fe);break;case l.PAN:if(r.enablePan===!1)return;ve(Fe);break}}function ze(Fe){r.enabled===!1||r.enableZoom===!1||o!==l.NONE&&o!==l.ROTATE||(Fe.preventDefault(),r.dispatchEvent(a),pe(Fe),r.dispatchEvent(u))}function st(Fe){r.enabled===!1||r.enablePan===!1||_e(Fe)}function Ot(Fe){switch(an(Fe),j.length){case 1:switch(r.touches.ONE){case gO.ROTATE:if(r.enableRotate===!1)return;se(),o=l.TOUCH_ROTATE;break;case gO.PAN:if(r.enablePan===!1)return;me(),o=l.TOUCH_PAN;break;default:o=l.NONE}break;case 2:switch(r.touches.TWO){case gO.DOLLY_PAN:if(r.enableZoom===!1&&r.enablePan===!1)return;we(),o=l.TOUCH_DOLLY_PAN;break;case gO.DOLLY_ROTATE:if(r.enableZoom===!1&&r.enableRotate===!1)return;Ne(),o=l.TOUCH_DOLLY_ROTATE;break;default:o=l.NONE}break;default:o=l.NONE}o!==l.NONE&&r.dispatchEvent(a)}function Nt(Fe){switch(an(Fe),o){case l.TOUCH_ROTATE:if(r.enableRotate===!1)return;Re(Fe),r.update();break;case l.TOUCH_PAN:if(r.enablePan===!1)return;et(Fe),r.update();break;case l.TOUCH_DOLLY_PAN:if(r.enableZoom===!1&&r.enablePan===!1)return;Oe(Fe),r.update();break;case l.TOUCH_DOLLY_ROTATE:if(r.enableZoom===!1&&r.enableRotate===!1)return;$e(Fe),r.update();break;default:o=l.NONE}}function gt(Fe){r.enabled!==!1&&Fe.preventDefault()}function qt(Fe){j.push(Fe)}function zt(Fe){delete V[Fe.pointerId];for(let ht=0;ht<j.length;ht++)if(j[ht].pointerId==Fe.pointerId){j.splice(ht,1);return}}function an(Fe){let ht=V[Fe.pointerId];ht===void 0&&(ht=new Jl,V[Fe.pointerId]=ht),ht.set(Fe.pageX,Fe.pageY)}function rn(Fe){const ht=Fe.pointerId===j[0].pointerId?j[1]:j[0];return V[ht.pointerId]}this.dollyIn=(Fe=N())=>{K(Fe),r.update()},this.dollyOut=(Fe=N())=>{M(Fe),r.update()},this.getScale=()=>h,this.setScale=Fe=>{H(Fe),r.update()},this.getZoomScale=()=>N(),n!==void 0&&this.connect(n),this.update()}};const GW=new RF,FE=new li;class TB extends pOe{constructor(){super(),this.isLineSegmentsGeometry=!0,this.type="LineSegmentsGeometry";const t=[-1,2,0,1,2,0,-1,1,0,1,1,0,-1,0,0,1,0,0,-1,-1,0,1,-1,0],n=[-1,2,1,2,-1,1,1,1,-1,-1,1,-1,-1,-2,1,-2],r=[0,2,1,2,3,1,2,4,3,4,5,3,4,6,5,6,7,5];this.setIndex(r),this.setAttribute("position",new H7(t,3)),this.setAttribute("uv",new H7(n,2))}applyMatrix4(t){const n=this.attributes.instanceStart,r=this.attributes.instanceEnd;return n!==void 0&&(n.applyMatrix4(t),r.applyMatrix4(t),n.needsUpdate=!0),this.boundingBox!==null&&this.computeBoundingBox(),this.boundingSphere!==null&&this.computeBoundingSphere(),this}setPositions(t){let n;t instanceof Float32Array?n=t:Array.isArray(t)&&(n=new Float32Array(t));const r=new X7(n,6,1);return this.setAttribute("instanceStart",new qO(r,3,0)),this.setAttribute("instanceEnd",new qO(r,3,3)),this.computeBoundingBox(),this.computeBoundingSphere(),this}setColors(t,n=3){let r;t instanceof Float32Array?r=t:Array.isArray(t)&&(r=new Float32Array(t));const i=new X7(r,n*2,1);return this.setAttribute("instanceColorStart",new qO(i,n,0)),this.setAttribute("instanceColorEnd",new qO(i,n,n)),this}fromWireframeGeometry(t){return this.setPositions(t.attributes.position.array),this}fromEdgesGeometry(t){return this.setPositions(t.attributes.position.array),this}fromMesh(t){return this.fromWireframeGeometry(new mOe(t.geometry)),this}fromLineSegments(t){const n=t.geometry;return this.setPositions(n.attributes.position.array),this}computeBoundingBox(){this.boundingBox===null&&(this.boundingBox=new RF);const t=this.attributes.instanceStart,n=this.attributes.instanceEnd;t!==void 0&&n!==void 0&&(this.boundingBox.setFromBufferAttribute(t),GW.setFromBufferAttribute(n),this.boundingBox.union(GW))}computeBoundingSphere(){this.boundingSphere===null&&(this.boundingSphere=new iJ),this.boundingBox===null&&this.computeBoundingBox();const t=this.attributes.instanceStart,n=this.attributes.instanceEnd;if(t!==void 0&&n!==void 0){const r=this.boundingSphere.center;this.boundingBox.getCenter(r);let i=0;for(let a=0,u=t.count;a<u;a++)FE.fromBufferAttribute(t,a),i=Math.max(i,r.distanceToSquared(FE)),FE.fromBufferAttribute(n,a),i=Math.max(i,r.distanceToSquared(FE));this.boundingSphere.radius=Math.sqrt(i),isNaN(this.boundingSphere.radius)&&console.error("THREE.LineSegmentsGeometry.computeBoundingSphere(): Computed radius is NaN. The instanced position data is likely to have NaN values.",this)}}toJSON(){}applyMatrix(t){return console.warn("THREE.LineSegmentsGeometry: applyMatrix() has been renamed to applyMatrix4()."),this.applyMatrix4(t)}}class Lbe extends TB{constructor(){super(),this.isLineGeometry=!0,this.type="LineGeometry"}setPositions(t){const n=t.length-3,r=new Float32Array(2*n);for(let i=0;i<n;i+=3)r[2*i]=t[i],r[2*i+1]=t[i+1],r[2*i+2]=t[i+2],r[2*i+3]=t[i+3],r[2*i+4]=t[i+4],r[2*i+5]=t[i+5];return super.setPositions(r),this}setColors(t,n=3){const r=t.length-n,i=new Float32Array(2*r);if(n===3)for(let a=0;a<r;a+=n)i[2*a]=t[a],i[2*a+1]=t[a+1],i[2*a+2]=t[a+2],i[2*a+3]=t[a+3],i[2*a+4]=t[a+4],i[2*a+5]=t[a+5];else for(let a=0;a<r;a+=n)i[2*a]=t[a],i[2*a+1]=t[a+1],i[2*a+2]=t[a+2],i[2*a+3]=t[a+3],i[2*a+4]=t[a+4],i[2*a+5]=t[a+5],i[2*a+6]=t[a+6],i[2*a+7]=t[a+7];return super.setColors(i,n),this}fromLine(t){const n=t.geometry;return this.setPositions(n.attributes.position.array),this}}class kB extends gOe{constructor(t){super({type:"LineMaterial",uniforms:LB.clone(LB.merge([BB.common,BB.fog,{worldUnits:{value:1},linewidth:{value:1},resolution:{value:new Jl(1,1)},dashOffset:{value:0},dashScale:{value:1},dashSize:{value:1},gapSize:{value:1}}])),vertexShader:`
				#include <common>
				#include <fog_pars_vertex>
				#include <logdepthbuf_pars_vertex>
				#include <clipping_planes_pars_vertex>

				uniform float linewidth;
				uniform vec2 resolution;

				attribute vec3 instanceStart;
				attribute vec3 instanceEnd;

				#ifdef USE_COLOR
					#ifdef USE_LINE_COLOR_ALPHA
						varying vec4 vLineColor;
						attribute vec4 instanceColorStart;
						attribute vec4 instanceColorEnd;
					#else
						varying vec3 vLineColor;
						attribute vec3 instanceColorStart;
						attribute vec3 instanceColorEnd;
					#endif
				#endif

				#ifdef WORLD_UNITS

					varying vec4 worldPos;
					varying vec3 worldStart;
					varying vec3 worldEnd;

					#ifdef USE_DASH

						varying vec2 vUv;

					#endif

				#else

					varying vec2 vUv;

				#endif

				#ifdef USE_DASH

					uniform float dashScale;
					attribute float instanceDistanceStart;
					attribute float instanceDistanceEnd;
					varying float vLineDistance;

				#endif

				void trimSegment( const in vec4 start, inout vec4 end ) {

					// trim end segment so it terminates between the camera plane and the near plane

					// conservative estimate of the near plane
					float a = projectionMatrix[ 2 ][ 2 ]; // 3nd entry in 3th column
					float b = projectionMatrix[ 3 ][ 2 ]; // 3nd entry in 4th column
					float nearEstimate = - 0.5 * b / a;

					float alpha = ( nearEstimate - start.z ) / ( end.z - start.z );

					end.xyz = mix( start.xyz, end.xyz, alpha );

				}

				void main() {

					#ifdef USE_COLOR

						vLineColor = ( position.y < 0.5 ) ? instanceColorStart : instanceColorEnd;

					#endif

					#ifdef USE_DASH

						vLineDistance = ( position.y < 0.5 ) ? dashScale * instanceDistanceStart : dashScale * instanceDistanceEnd;
						vUv = uv;

					#endif

					float aspect = resolution.x / resolution.y;

					// camera space
					vec4 start = modelViewMatrix * vec4( instanceStart, 1.0 );
					vec4 end = modelViewMatrix * vec4( instanceEnd, 1.0 );

					#ifdef WORLD_UNITS

						worldStart = start.xyz;
						worldEnd = end.xyz;

					#else

						vUv = uv;

					#endif

					// special case for perspective projection, and segments that terminate either in, or behind, the camera plane
					// clearly the gpu firmware has a way of addressing this issue when projecting into ndc space
					// but we need to perform ndc-space calculations in the shader, so we must address this issue directly
					// perhaps there is a more elegant solution -- WestLangley

					bool perspective = ( projectionMatrix[ 2 ][ 3 ] == - 1.0 ); // 4th entry in the 3rd column

					if ( perspective ) {

						if ( start.z < 0.0 && end.z >= 0.0 ) {

							trimSegment( start, end );

						} else if ( end.z < 0.0 && start.z >= 0.0 ) {

							trimSegment( end, start );

						}

					}

					// clip space
					vec4 clipStart = projectionMatrix * start;
					vec4 clipEnd = projectionMatrix * end;

					// ndc space
					vec3 ndcStart = clipStart.xyz / clipStart.w;
					vec3 ndcEnd = clipEnd.xyz / clipEnd.w;

					// direction
					vec2 dir = ndcEnd.xy - ndcStart.xy;

					// account for clip-space aspect ratio
					dir.x *= aspect;
					dir = normalize( dir );

					#ifdef WORLD_UNITS

						// get the offset direction as perpendicular to the view vector
						vec3 worldDir = normalize( end.xyz - start.xyz );
						vec3 offset;
						if ( position.y < 0.5 ) {

							offset = normalize( cross( start.xyz, worldDir ) );

						} else {

							offset = normalize( cross( end.xyz, worldDir ) );

						}

						// sign flip
						if ( position.x < 0.0 ) offset *= - 1.0;

						float forwardOffset = dot( worldDir, vec3( 0.0, 0.0, 1.0 ) );

						// don't extend the line if we're rendering dashes because we
						// won't be rendering the endcaps
						#ifndef USE_DASH

							// extend the line bounds to encompass  endcaps
							start.xyz += - worldDir * linewidth * 0.5;
							end.xyz += worldDir * linewidth * 0.5;

							// shift the position of the quad so it hugs the forward edge of the line
							offset.xy -= dir * forwardOffset;
							offset.z += 0.5;

						#endif

						// endcaps
						if ( position.y > 1.0 || position.y < 0.0 ) {

							offset.xy += dir * 2.0 * forwardOffset;

						}

						// adjust for linewidth
						offset *= linewidth * 0.5;

						// set the world position
						worldPos = ( position.y < 0.5 ) ? start : end;
						worldPos.xyz += offset;

						// project the worldpos
						vec4 clip = projectionMatrix * worldPos;

						// shift the depth of the projected points so the line
						// segments overlap neatly
						vec3 clipPose = ( position.y < 0.5 ) ? ndcStart : ndcEnd;
						clip.z = clipPose.z * clip.w;

					#else

						vec2 offset = vec2( dir.y, - dir.x );
						// undo aspect ratio adjustment
						dir.x /= aspect;
						offset.x /= aspect;

						// sign flip
						if ( position.x < 0.0 ) offset *= - 1.0;

						// endcaps
						if ( position.y < 0.0 ) {

							offset += - dir;

						} else if ( position.y > 1.0 ) {

							offset += dir;

						}

						// adjust for linewidth
						offset *= linewidth;

						// adjust for clip-space to screen-space conversion // maybe resolution should be based on viewport ...
						offset /= resolution.y;

						// select end
						vec4 clip = ( position.y < 0.5 ) ? clipStart : clipEnd;

						// back to clip space
						offset *= clip.w;

						clip.xy += offset;

					#endif

					gl_Position = clip;

					vec4 mvPosition = ( position.y < 0.5 ) ? start : end; // this is an approximation

					#include <logdepthbuf_vertex>
					#include <clipping_planes_vertex>
					#include <fog_vertex>

				}
			`,fragmentShader:`
				uniform vec3 diffuse;
				uniform float opacity;
				uniform float linewidth;

				#ifdef USE_DASH

					uniform float dashOffset;
					uniform float dashSize;
					uniform float gapSize;

				#endif

				varying float vLineDistance;

				#ifdef WORLD_UNITS

					varying vec4 worldPos;
					varying vec3 worldStart;
					varying vec3 worldEnd;

					#ifdef USE_DASH

						varying vec2 vUv;

					#endif

				#else

					varying vec2 vUv;

				#endif

				#include <common>
				#include <fog_pars_fragment>
				#include <logdepthbuf_pars_fragment>
				#include <clipping_planes_pars_fragment>

				#ifdef USE_COLOR
					#ifdef USE_LINE_COLOR_ALPHA
						varying vec4 vLineColor;
					#else
						varying vec3 vLineColor;
					#endif
				#endif

				vec2 closestLineToLine(vec3 p1, vec3 p2, vec3 p3, vec3 p4) {

					float mua;
					float mub;

					vec3 p13 = p1 - p3;
					vec3 p43 = p4 - p3;

					vec3 p21 = p2 - p1;

					float d1343 = dot( p13, p43 );
					float d4321 = dot( p43, p21 );
					float d1321 = dot( p13, p21 );
					float d4343 = dot( p43, p43 );
					float d2121 = dot( p21, p21 );

					float denom = d2121 * d4343 - d4321 * d4321;

					float numer = d1343 * d4321 - d1321 * d4343;

					mua = numer / denom;
					mua = clamp( mua, 0.0, 1.0 );
					mub = ( d1343 + d4321 * ( mua ) ) / d4343;
					mub = clamp( mub, 0.0, 1.0 );

					return vec2( mua, mub );

				}

				void main() {

					#include <clipping_planes_fragment>

					#ifdef USE_DASH

						if ( vUv.y < - 1.0 || vUv.y > 1.0 ) discard; // discard endcaps

						if ( mod( vLineDistance + dashOffset, dashSize + gapSize ) > dashSize ) discard; // todo - FIX

					#endif

					float alpha = opacity;

					#ifdef WORLD_UNITS

						// Find the closest points on the view ray and the line segment
						vec3 rayEnd = normalize( worldPos.xyz ) * 1e5;
						vec3 lineDir = worldEnd - worldStart;
						vec2 params = closestLineToLine( worldStart, worldEnd, vec3( 0.0, 0.0, 0.0 ), rayEnd );

						vec3 p1 = worldStart + lineDir * params.x;
						vec3 p2 = rayEnd * params.y;
						vec3 delta = p1 - p2;
						float len = length( delta );
						float norm = len / linewidth;

						#ifndef USE_DASH

							#ifdef USE_ALPHA_TO_COVERAGE

								float dnorm = fwidth( norm );
								alpha = 1.0 - smoothstep( 0.5 - dnorm, 0.5 + dnorm, norm );

							#else

								if ( norm > 0.5 ) {

									discard;

								}

							#endif

						#endif

					#else

						#ifdef USE_ALPHA_TO_COVERAGE

							// artifacts appear on some hardware if a derivative is taken within a conditional
							float a = vUv.x;
							float b = ( vUv.y > 0.0 ) ? vUv.y - 1.0 : vUv.y + 1.0;
							float len2 = a * a + b * b;
							float dlen = fwidth( len2 );

							if ( abs( vUv.y ) > 1.0 ) {

								alpha = 1.0 - smoothstep( 1.0 - dlen, 1.0 + dlen, len2 );

							}

						#else

							if ( abs( vUv.y ) > 1.0 ) {

								float a = vUv.x;
								float b = ( vUv.y > 0.0 ) ? vUv.y - 1.0 : vUv.y + 1.0;
								float len2 = a * a + b * b;

								if ( len2 > 1.0 ) discard;

							}

						#endif

					#endif

					vec4 diffuseColor = vec4( diffuse, alpha );
					#ifdef USE_COLOR
						#ifdef USE_LINE_COLOR_ALPHA
							diffuseColor *= vLineColor;
						#else
							diffuseColor.rgb *= vLineColor;
						#endif
					#endif

					#include <logdepthbuf_fragment>

					gl_FragColor = diffuseColor;

					#include <tonemapping_fragment>
					#include <${Nbe>=154?"colorspace_fragment":"encodings_fragment"}>
					#include <fog_fragment>
					#include <premultiplied_alpha_fragment>

				}
			`,clipping:!0}),this.isLineMaterial=!0,this.onBeforeCompile=function(){this.transparent?this.defines.USE_LINE_COLOR_ALPHA="1":delete this.defines.USE_LINE_COLOR_ALPHA},Object.defineProperties(this,{color:{enumerable:!0,get:function(){return this.uniforms.diffuse.value},set:function(n){this.uniforms.diffuse.value=n}},worldUnits:{enumerable:!0,get:function(){return"WORLD_UNITS"in this.defines},set:function(n){n===!0?this.defines.WORLD_UNITS="":delete this.defines.WORLD_UNITS}},linewidth:{enumerable:!0,get:function(){return this.uniforms.linewidth.value},set:function(n){this.uniforms.linewidth.value=n}},dashed:{enumerable:!0,get:function(){return"USE_DASH"in this.defines},set(n){!!n!="USE_DASH"in this.defines&&(this.needsUpdate=!0),n===!0?this.defines.USE_DASH="":delete this.defines.USE_DASH}},dashScale:{enumerable:!0,get:function(){return this.uniforms.dashScale.value},set:function(n){this.uniforms.dashScale.value=n}},dashSize:{enumerable:!0,get:function(){return this.uniforms.dashSize.value},set:function(n){this.uniforms.dashSize.value=n}},dashOffset:{enumerable:!0,get:function(){return this.uniforms.dashOffset.value},set:function(n){this.uniforms.dashOffset.value=n}},gapSize:{enumerable:!0,get:function(){return this.uniforms.gapSize.value},set:function(n){this.uniforms.gapSize.value=n}},opacity:{enumerable:!0,get:function(){return this.uniforms.opacity.value},set:function(n){this.uniforms.opacity.value=n}},resolution:{enumerable:!0,get:function(){return this.uniforms.resolution.value},set:function(n){this.uniforms.resolution.value.copy(n)}},alphaToCoverage:{enumerable:!0,get:function(){return"USE_ALPHA_TO_COVERAGE"in this.defines},set:function(n){!!n!="USE_ALPHA_TO_COVERAGE"in this.defines&&(this.needsUpdate=!0),n===!0?(this.defines.USE_ALPHA_TO_COVERAGE="",this.extensions.derivatives=!0):(delete this.defines.USE_ALPHA_TO_COVERAGE,this.extensions.derivatives=!1)}}}),this.setValues(t)}}const V7=new V3,KW=new li,WW=new li,wo=new V3,Ro=new V3,s0=new V3,U7=new li,j7=new bOe,To=new yOe,JW=new li,NE=new RF,IE=new iJ,c0=new V3;let y0,W1;function eJ(e,t,n){return c0.set(0,0,-t,1).applyMatrix4(e.projectionMatrix),c0.multiplyScalar(1/c0.w),c0.x=W1/n.width,c0.y=W1/n.height,c0.applyMatrix4(e.projectionMatrixInverse),c0.multiplyScalar(1/c0.w),Math.abs(Math.max(c0.x,c0.y))}function cnt(e,t){const n=e.matrixWorld,r=e.geometry,i=r.attributes.instanceStart,a=r.attributes.instanceEnd,u=Math.min(r.instanceCount,i.count);for(let l=0,o=u;l<o;l++){To.start.fromBufferAttribute(i,l),To.end.fromBufferAttribute(a,l),To.applyMatrix4(n);const s=new li,c=new li;y0.distanceSqToSegment(To.start,To.end,c,s),c.distanceTo(s)<W1*.5&&t.push({point:c,pointOnLine:s,distance:y0.origin.distanceTo(c),object:e,face:null,faceIndex:l,uv:null,[Ibe]:null})}}function fnt(e,t,n){const r=t.projectionMatrix,a=e.material.resolution,u=e.matrixWorld,l=e.geometry,o=l.attributes.instanceStart,s=l.attributes.instanceEnd,c=Math.min(l.instanceCount,o.count),d=-t.near;y0.at(1,s0),s0.w=1,s0.applyMatrix4(t.matrixWorldInverse),s0.applyMatrix4(r),s0.multiplyScalar(1/s0.w),s0.x*=a.x/2,s0.y*=a.y/2,s0.z=0,U7.copy(s0),j7.multiplyMatrices(t.matrixWorldInverse,u);for(let h=0,m=c;h<m;h++){if(wo.fromBufferAttribute(o,h),Ro.fromBufferAttribute(s,h),wo.w=1,Ro.w=1,wo.applyMatrix4(j7),Ro.applyMatrix4(j7),wo.z>d&&Ro.z>d)continue;if(wo.z>d){const C=wo.z-Ro.z,T=(wo.z-d)/C;wo.lerp(Ro,T)}else if(Ro.z>d){const C=Ro.z-wo.z,T=(Ro.z-d)/C;Ro.lerp(wo,T)}wo.applyMatrix4(r),Ro.applyMatrix4(r),wo.multiplyScalar(1/wo.w),Ro.multiplyScalar(1/Ro.w),wo.x*=a.x/2,wo.y*=a.y/2,Ro.x*=a.x/2,Ro.y*=a.y/2,To.start.copy(wo),To.start.z=0,To.end.copy(Ro),To.end.z=0;const v=To.closestPointToPointParameter(U7,!0);To.at(v,JW);const _=aJ.lerp(wo.z,Ro.z,v),S=_>=-1&&_<=1,E=U7.distanceTo(JW)<W1*.5;if(S&&E){To.start.fromBufferAttribute(o,h),To.end.fromBufferAttribute(s,h),To.start.applyMatrix4(u),To.end.applyMatrix4(u);const C=new li,T=new li;y0.distanceSqToSegment(To.start,To.end,T,C),n.push({point:T,pointOnLine:C,distance:y0.origin.distanceTo(T),object:e,face:null,faceIndex:h,uv:null,[Ibe]:null})}}}class Bbe extends vOe{constructor(t=new TB,n=new kB({color:Math.random()*16777215})){super(t,n),this.isLineSegments2=!0,this.type="LineSegments2"}computeLineDistances(){const t=this.geometry,n=t.attributes.instanceStart,r=t.attributes.instanceEnd,i=new Float32Array(2*n.count);for(let u=0,l=0,o=n.count;u<o;u++,l+=2)KW.fromBufferAttribute(n,u),WW.fromBufferAttribute(r,u),i[l]=l===0?0:i[l-1],i[l+1]=i[l]+KW.distanceTo(WW);const a=new X7(i,2,1);return t.setAttribute("instanceDistanceStart",new qO(a,1,0)),t.setAttribute("instanceDistanceEnd",new qO(a,1,1)),this}raycast(t,n){const r=this.material.worldUnits,i=t.camera;i===null&&!r&&console.error('LineSegments2: "Raycaster.camera" needs to be set in order to raycast against LineSegments2 while worldUnits is set to false.');const a=t.params.Line2!==void 0&&t.params.Line2.threshold||0;y0=t.ray;const u=this.matrixWorld,l=this.geometry,o=this.material;W1=o.linewidth+a,l.boundingSphere===null&&l.computeBoundingSphere(),IE.copy(l.boundingSphere).applyMatrix4(u);let s;if(r)s=W1*.5;else{const d=Math.max(i.near,IE.distanceToPoint(y0.origin));s=eJ(i,d,o.resolution)}if(IE.radius+=s,y0.intersectsSphere(IE)===!1)return;l.boundingBox===null&&l.computeBoundingBox(),NE.copy(l.boundingBox).applyMatrix4(u);let c;if(r)c=W1*.5;else{const d=Math.max(i.near,NE.distanceToPoint(y0.origin));c=eJ(i,d,o.resolution)}NE.expandByScalar(c),y0.intersectsBox(NE)!==!1&&(r?cnt(this,n):fnt(this,i,n))}onBeforeRender(t){const n=this.material.uniforms;n&&n.resolution&&(t.getViewport(V7),this.material.uniforms.resolution.value.set(V7.z,V7.w))}}class dnt extends Bbe{constructor(t=new Lbe,n=new kB({color:Math.random()*16777215})){super(t,n),this.isLine2=!0,this.type="Line2"}}const hnt=P.forwardRef(function({points:t,color:n=16777215,vertexColors:r,linewidth:i,lineWidth:a,segments:u,dashed:l,...o},s){var c,d;const h=zd(S=>S.size),m=P.useMemo(()=>u?new Bbe:new dnt,[u]),[y]=P.useState(()=>new kB),v=(r==null||(c=r[0])==null?void 0:c.length)===4?4:3,_=P.useMemo(()=>{const S=u?new TB:new Lbe,E=t.map(C=>{const T=Array.isArray(C);return C instanceof li||C instanceof V3?[C.x,C.y,C.z]:C instanceof Jl?[C.x,C.y,0]:T&&C.length===3?[C[0],C[1],C[2]]:T&&C.length===2?[C[0],C[1],0]:C});if(S.setPositions(E.flat()),r){n=16777215;const C=r.map(T=>T instanceof mC?T.toArray():T);S.setColors(C.flat(),v)}return S},[t,u,r,v]);return P.useLayoutEffect(()=>{m.computeLineDistances()},[t,m]),P.useLayoutEffect(()=>{l?y.defines.USE_DASH="":delete y.defines.USE_DASH,y.needsUpdate=!0},[l,y]),P.useEffect(()=>()=>{_.dispose(),y.dispose()},[_]),P.createElement("primitive",ry({object:m,ref:s},o),P.createElement("primitive",{object:_,attach:"geometry"}),P.createElement("primitive",ry({object:y,attach:"material",color:n,vertexColors:!!r,resolution:[h.width,h.height],linewidth:(d=i??a)!==null&&d!==void 0?d:1,dashed:l,transparent:v===4},o)))}),pnt=new li,dlt=P.forwardRef(function({start:t=[0,0,0],end:n=[0,0,0],mid:r,segments:i=20,...a},u){const l=P.useRef(null);P.useImperativeHandle(u,()=>l.current);const[o]=P.useState(()=>new OOe(void 0,void 0,void 0)),s=P.useCallback((d,h,m,y=20)=>(d instanceof li?o.v0.copy(d):o.v0.set(...d),h instanceof li?o.v2.copy(h):o.v2.set(...h),m instanceof li?o.v1.copy(m):Array.isArray(m)?o.v1.set(...m):o.v1.copy(o.v0.clone().add(o.v2.clone().sub(o.v0)).add(pnt.set(0,o.v0.y-o.v2.y,0))),o.getPoints(y)),[]);P.useLayoutEffect(()=>{l.current.setPoints=(d,h,m)=>{const y=s(d,h,m);l.current.geometry&&l.current.geometry.setPositions(y.map(v=>v.toArray()).flat())}},[]);const c=P.useMemo(()=>s(t,n,r,i),[t,n,r,i]);return P.createElement(hnt,ry({ref:l,points:c},a))}),mnt=P.forwardRef(({makeDefault:e,camera:t,regress:n,domElement:r,enableDamping:i=!0,keyEvents:a=!1,onChange:u,onStart:l,onEnd:o,...s},c)=>{const d=zd($=>$.invalidate),h=zd($=>$.camera),m=zd($=>$.gl),y=zd($=>$.events),v=zd($=>$.setEvents),_=zd($=>$.set),S=zd($=>$.get),E=zd($=>$.performance),C=t||h,T=r||y.connected||m.domElement,R=P.useMemo(()=>new snt(C),[C]);return m5(()=>{R.enabled&&R.update()},-1),P.useEffect(()=>(a&&R.connect(a===!0?T:a),R.connect(T),()=>void R.dispose()),[a,T,n,R,d]),P.useEffect(()=>{const $=L=>{d(),n&&E.regress(),u&&u(L)},k=L=>{l&&l(L)},F=L=>{o&&o(L)};return R.addEventListener("change",$),R.addEventListener("start",k),R.addEventListener("end",F),()=>{R.removeEventListener("start",k),R.removeEventListener("end",F),R.removeEventListener("change",$)}},[u,l,o,R,d,v]),P.useEffect(()=>{if(e){const $=S().controls;return _({controls:R}),()=>_({controls:$})}},[e,R]),P.createElement("primitive",ry({ref:c,object:R,enableDamping:i},s))});function hlt(...e){const t=P.useRef([]);return t.current=e.map(n=>P.useContext(n)),P.useMemo(()=>({children:n})=>e.reduceRight((r,i,a)=>P.createElement(i.Provider,{value:t.current[a],children:r}),n),[])}function gnt(e,t){const n=e+"Geometry";return P.forwardRef(({args:r,children:i,...a},u)=>{const l=P.useRef(null);return P.useImperativeHandle(u,()=>l.current),P.useLayoutEffect(()=>void(t==null?void 0:t(l.current))),P.createElement("mesh",ry({ref:l},a),P.createElement(n,{attach:"geometry",args:r}),i)})}const plt=gnt("sphere");function vnt(e,t){const n=e[0],r=e[1];let i=!1;for(let a=0,u=t.length-1;a<t.length;u=a++){const l=t[a][0],o=t[a][1],s=t[u][0],c=t[u][1];o>r!=c>r&&n<(s-l)*(r-o)/(c-o)+l&&(i=!i)}return i}const ynt={minX:0,maxX:0,minY:0,maxY:0,minZ:0,maxZ:0};function mlt(e,t){if(e.length===0)return(t==null?void 0:t.fallbackBounds)||ynt;let n=1/0,r=1/0,i=-1/0,a=-1/0,u=1/0,l=-1/0;return e.forEach(o=>{n=Math.min(n,o[0]),r=Math.min(r,o[1]),u=Math.min(u,o[2]),i=Math.max(i,o[0]),a=Math.max(a,o[1]),l=Math.max(l,o[2])}),{minX:n,maxX:i,minY:r,maxY:a,minZ:u,maxZ:l}}function bnt({minX:e,maxX:t,minY:n,maxY:r,minZ:i,maxZ:a}){return[e+(t-e)/2,n+(r-n)/2,i+(a-i)/2]}function Ont({minX:e,maxX:t,minY:n,maxY:r,minZ:i,maxZ:a}){return Math.max(Math.abs(e),Math.abs(t),Math.abs(n),Math.abs(r),Math.abs(i),Math.abs(a))}function Qbe(e){return e.isOrthographicCamera}P.createContext({bounds:{minX:-10,maxX:10,minY:-10,maxY:10},center:[0,0]});function glt({children:e,camera:t,orthographic:n=!1,...r}){return Mr.jsx(jtt,{orthographic:n,camera:{position:[0,0,1],zoom:1,up:[0,1,0],...t},...r,children:e})}function vlt({enabled:e=!0,zoomSpeed:t=1,enableZoom:n=!0,enablePan:r=!0,enableRotate:i=!0,autoRotate:a=!1,autoRotateSpeed:u=5,...l}){return Mr.jsx(mnt,{enabled:e,zoomSpeed:t,enableZoom:n,enablePan:r,enableRotate:i,autoRotate:a,autoRotateSpeed:u,...l})}const xnt=P.createContext({bounds:{minX:-10,maxX:10,minY:-10,maxY:10,minZ:-10,maxZ:10},center:[0,0,0]}),tJ=10;function ylt({bounds:e,children:t,offset:n=1.5,boundsZoomPaddingFactor:r=.9}){const i=bnt(e),{camera:a,size:{width:u,height:l}}=zd();return P.useEffect(()=>{const{minX:o,maxX:s,minY:c,maxY:d,minZ:h,maxZ:m}=e,y=s-o,v=d-c,_=m-h,S=Math.max(y,v,_);if(a.position.x=y/2+o,a.position.y=v/2+c,Qbe(a)){a.zoom=Math.min(u/y,l/v)*r;const E=Ont(e),C=Math.abs(E)+tJ;a.position.z=C;const T=Math.max(a.far,C+E+tJ);a.far=T}else{const E=a.fov*(Math.PI/180),C=S/(2*Math.tan(E/2));a.position.z=(C+i[2])*n;const T=h<0?-h+a.position.z:a.position.z-h;a.far=T*3}a.updateProjectionMatrix(),a.lookAt(...i)},[e]),Mr.jsx(xnt.Provider,{value:{bounds:e,center:i},children:t})}const blt=({size:e,color:t="#ffffff"})=>{const n=P.useRef(null);return P.useEffect(()=>{if(n.current){const r=new mC(t);n.current.setColors(r,r,r)}},[t]),Mr.jsx("axesHelper",{ref:n,args:[e]})},Snt={color:"blue",scale:1},C2=new _Oe,Z7=new mC;function Olt({data:e,pointProps:t=Snt,onPointsClicked:n,onPointClicked:r,onPointHovered:i,onPointerLeave:a,pointShape:u="sphere",opacity:l=1,material:o="meshMatcap"}){const s=P.useCallback(y=>typeof t.color=="function"?t.color(y):t.color,[t.color]),c=P.useMemo(()=>Float32Array.from(new Array(e.length).fill(null).flatMap((y,v)=>Z7.set(s(e[v])).toArray())),[e]),d=P.useRef(null);m5(()=>{e.forEach(({position:y},v)=>{if(C2.position.set(y[0],y[1],y[2]||0),t.scale&&C2.scale.set(t.scale,t.scale,t.scale),d.current){d.current.setMatrixAt(v,C2.matrix),d.current.instanceMatrix.needsUpdate=!0;const _=s(e[v]);Z7.set(_),Z7.toArray(c,v*3),d.current.geometry.attributes.color.needsUpdate=!0,C2.updateMatrix(),d.current.setMatrixAt(v,C2.matrix)}})});const h=P.useMemo(()=>{switch(u){case"sphere":return Mr.jsx("sphereGeometry",{args:[t.radius||.02,20,20],children:Mr.jsx("instancedBufferAttribute",{attach:"attributes-color",args:[c,3]})});case"cube":{const y=typeof(t==null?void 0:t.size)=="number"?[t.size,t.size,t.size]:[.03,.03,.03];return Mr.jsx("boxGeometry",{args:y,children:Mr.jsx("instancedBufferAttribute",{attach:"attributes-color",args:[c,3]})})}case"octahedron":return Mr.jsx("octahedronGeometry",{args:[t.radius||.02,0],children:Mr.jsx("instancedBufferAttribute",{attach:"attributes-color",args:[c,3]})});default:throw new Error(`Unsupported point shape: ${u}`)}},[u,t]),m=P.useMemo(()=>{switch(o){case"meshMatcap":return Mr.jsx("meshMatcapMaterial",{vertexColors:!0,opacity:l,transparent:l<1});default:return Mr.jsx("meshStandardMaterial",{vertexColors:!0,opacity:l,transparent:l<1})}},[o]);return Mr.jsxs("instancedMesh",{args:[void 0,void 0,e.length],ref:d,onPointerUp:y=>{if(y.intersections){const v=y.intersections.map(_=>_==null?void 0:_.instanceId).filter(_=>_!=null);n&&n(v.map(_=>e[_])),v.length>0&&r&&r(e[v[0]])}},onPointerOver:y=>{if(y.intersections){const v=y.intersections.map(_=>_==null?void 0:_.instanceId).filter(_=>_!=null);v.length>0&&i&&i(e[v[0]])}},onPointerLeave:()=>{a&&a()},children:[h,m]})}const _nt=.1;function xlt({data:e,pointRadius:t=_nt,color:n="#999999",opacity:r=.2,wireframe:i=!1}){const a=P.useMemo(()=>{const u=[],l=new Set;return e.forEach(s=>{const{position:c}=s;if(!l.has(c.join(","))){const d=new SOe(t,12,12);d.translate(c[0],c[1],c[2]||0),u.push(d),l.add(c.join(","))}}),tnt(u)},[e]);return Mr.jsx("mesh",{geometry:a??void 0,visible:r>0,children:Mr.jsx("meshBasicMaterial",{opacity:r,transparent:r<1,color:n,wireframe:i})})}function Ent(){const e=new xOe;return e.renderOrder=1,e.position.z=-.2,e.depthTest=!1,e.scale.setScalar(1),e}function Slt({children:e,lineColor:t="#53d7fb",onChange:n,points:r,enabled:i}){const{camera:a,raycaster:u,gl:l,controls:o,size:s,scene:c}=zd(),d=P.useRef(Ent()),h=P.useRef({selectionPoints:[],isDragging:!1,selectionNeedsUpdate:!1,selectionShapeNeedsUpdate:!1});return P.useEffect(()=>{d.current.material.color.set(t).convertSRGBToLinear(),a.add(d.current),c.add(a)},[]),P.useEffect(()=>{let m=-1/0,y=-1/0;const v=new Jl,_=new Jl,S=new Jl;function E(R){if(i){const $=l.domElement.getClientRects()[0];m=R.clientX-$.left,y=R.clientY-$.top,h.current.selectionPoints.length=0,h.current.isDragging=!0}}function C(R){if(h.current.isDragging){const{selectionPoints:$}=h.current,k=l.domElement.getClientRects()[0],F=R.clientX-k.left,L=R.clientY-k.top,j=F/k.width*2-1,V=-(L/k.height*2-1);if(Math.abs(F-m)>=3||Math.abs(L-y)>=3){const N=($.length/3-1)*3;let U=!1;$.length>3&&(v.set($[N-3],$[N-3+1]),_.set($[N],$[N+1]),_.sub(v).normalize(),v.set($[N],$[N+1]),S.set(j,V),S.sub(v).normalize(),U=_.dot(S)>.99),U?($[N]=j,$[N+1]=V):$.push(j,V,0),h.current.selectionShapeNeedsUpdate=!0,d.current.visible=!0,m=F,y=L}}}function T(){i&&h.current.isDragging&&h.current.selectionPoints.length&&(h.current.selectionShapeNeedsUpdate=!0,h.current.selectionNeedsUpdate=!0),d.current.visible=!1,h.current.isDragging=!1}return l.domElement.addEventListener("pointerdown",E,{passive:!0}),document.addEventListener("pointermove",C,{passive:!0,capture:!0}),document.addEventListener("pointerup",T,{passive:!0}),()=>{l.domElement.removeEventListener("pointerdown",E),document.removeEventListener("pointermove",C),document.removeEventListener("pointerup",T)}},[s,u,a,o,l,i]),m5(({camera:m})=>{const{selectionShapeNeedsUpdate:y,selectionPoints:v}=h.current;if(y){const _=v.length;v.push(v[0],v[1],v[2]),d.current.geometry.setAttribute("position",new H7(v,3,!1)),v.length=_,d.current.frustumCulled=!1,h.current.selectionShapeNeedsUpdate=!1}if(h.current.selectionNeedsUpdate&&v.length>0&&(h.current.selectionNeedsUpdate=!1,n(Dnt({points:r,camera:m,selectionPoints:h.current.selectionPoints}))),Qbe(m))d.current.scale.set((m.right-m.left)/m.zoom/2,(m.top-m.bottom)/m.zoom/2,1);else{const _=Math.tan(aJ.DEG2RAD*m.fov/2)*d.current.position.z;d.current.scale.set(-_*m.aspect,-_,1)}}),Mr.jsx(Mr.Fragment,{children:e})}function Dnt({points:e,camera:t,selectionPoints:n}){const r=[],i=[];for(let u=0;u<n.length;u+=3)i.push([n[u],n[u+1]]);const a=new li;return e.forEach(u=>{const l=u.position.length===3,o=l?u.position:[u.position[0],u.position[1],0];a.fromArray(o),l||a.sub(t.position).applyMatrix4(t.matrixWorld),a.project(t),vnt([a.x,a.y],i)&&r.push(u)}),r}const nJ={Orange:"#ff7847",LightBlue:"#23abd8"},$nt={LightBlueOrange:[nJ.LightBlue,nJ.Orange]},_lt={Discrete2:$nt};export{Lit as $,aat as A,uat as B,jRe as C,lat as D,tat as E,nat as F,sat as G,Brt as H,Vf as I,Fnt as J,Int as K,$3 as L,Nnt as M,Mnt as N,Pnt as O,Jit as P,fit as Q,ye as R,dit as S,Lrt as T,hit as U,Rnt as V,Nwe as W,Nrt as X,$we as Y,Qrt as Z,Pwe as _,p9 as a,Pat as a$,Jrt as a0,uit as a1,Gt as a2,Ewe as a3,Tit as a4,bit as a5,git as a6,fat as a7,Rit as a8,Cit as a9,bs as aA,_it as aB,Eit as aC,Dit as aD,$it as aE,Oit as aF,Mit as aG,Pit as aH,Bit as aI,Trt as aJ,Frt as aK,Mrt as aL,Irt as aM,Iit as aN,jrt as aO,qrt as aP,Sit as aQ,eit as aR,nit as aS,rit as aT,vat as aU,MTe as aV,gat as aW,kit as aX,xit as aY,kat as aZ,Mat as a_,wit as aa,Wrt as ab,mit as ac,o5e as ad,cat as ae,ait as af,iit as ag,lit as ah,oit as ai,oS as aj,mat as ak,sit as al,cit as am,hat as an,zrt as ao,J_e as ap,vit as aq,yit as ar,Nit as as,Fit as at,Yrt as au,Krt as av,Grt as aw,Xrt as ax,WC as ay,vs as az,Lnt as b,mU as b$,Fat as b0,NI as b1,wRe as b2,Ait as b3,Cat as b4,$at as b5,Dat as b6,Eat as b7,xat as b8,Kut as b9,xlt as bA,plt as bB,m5 as bC,dlt as bD,Nat as bE,Olt as bF,clt as bG,mlt as bH,hlt as bI,vlt as bJ,ylt as bK,Slt as bL,blt as bM,glt as bN,bJ as bO,Bnt as bP,znt as bQ,Xnt as bR,Hnt as bS,yrt as bT,qnt as bU,brt as bV,Drt as bW,Ort as bX,Ft as bY,Knt as bZ,Ert as b_,CRe as ba,Vit as bb,Vrt as bc,Zrt as bd,Hrt as be,Aat as bf,Iat as bg,hZe as bh,QZe as bi,LZe as bj,elt as bk,tlt as bl,CN as bm,krt as bn,wrt as bo,yTe as bp,dat as bq,sw as br,xne as bs,Prt as bt,tit as bu,Og as bv,dI as bw,_lt as bx,wat as by,Tat as bz,Qnt as c,A0 as c$,Xit as c0,Uit as c1,pat as c2,out as c3,sut as c4,kze as c5,Rat as c6,Rrt as c7,qit as c8,Art as c9,Sat as cA,j6e as cB,GRe as cC,rat as cD,Oat as cE,mS as cF,olt as cG,srt as cH,crt as cI,hrt as cJ,rb as cK,FD as cL,Sa as cM,ep as cN,Po as cO,urt as cP,G2e as cQ,og as cR,axe as cS,grt as cT,Lat as cU,prt as cV,of as cW,su as cX,q8e as cY,Uat as cZ,Vat as c_,_at as ca,zit as cb,Wut as cc,iat as cd,jit as ce,Kit as cf,xrt as cg,Srt as ch,_rt as ci,$rt as cj,Crt as ck,Jut as cl,gZ as cm,rlt as cn,nlt as co,alt as cp,cbe as cq,ilt as cr,llt as cs,ibe as ct,abe as cu,ult as cv,lC as cw,Zit as cx,Qit as cy,Hit as cz,Znt as d,Vut as d$,hs as d0,mM as d1,Qat as d2,fg as d3,$r as d4,qat as d5,Bat as d6,Mr as d7,ry as d8,jat as d9,Qut as dA,kut as dB,$Y as dC,Fut as dD,Mut as dE,Vx as dF,Put as dG,Xqe as dH,Lut as dI,dut as dJ,Vze as dK,Aut as dL,Tut as dM,Rut as dN,wut as dO,Cut as dP,$ut as dQ,uve as dR,Dut as dS,put as dT,hut as dU,Sut as dV,Eut as dW,_ut as dX,qut as dY,jut as dZ,Uut as d_,sp as da,yat as db,Kat as dc,Wat as dd,Jat as de,Xat as df,Yf as dg,Hat as dh,eut as di,art as dj,tut as dk,cut as dl,fut as dm,xut as dn,Out as dp,but as dq,yut as dr,vut as ds,gut as dt,mut as du,Uze as dv,Nut as dw,l2e as dx,Dqe as dy,Iut as dz,Vnt as e,Zut as e0,Hut as e1,Xut as e2,Yut as e3,L3 as e4,zut as e5,But as e6,Iqe as e7,Gut as e8,Gat as e9,Wit as ea,Git as eb,Yit as ec,bat as ed,eRe as ee,knt as ef,Gnt as f,spe as g,NRe as h,Tnt as i,Ant as j,eat as k,Ynt as l,Hi as m,MSe as n,Unt as o,qCe as p,pit as q,P as r,nN as s,ot as t,jnt as u,Urt as v,oat as w,JRe as x,xZ as y,VRe as z};
